""" Cisco_IOS_XR_ipv6_ospfv3_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv6\-ospfv3 package operational data.

This module contains definitions
for the following management objects\:
  ospfv3\: OSPFv3 operational information 

Copyright (c) 2013\-2018 by Cisco Systems, Inc.
All rights reserved.

"""
from collections import OrderedDict

from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class ImStateEnum(Enum):
    """
    ImStateEnum (Enum Class)

    Im state enum

    .. data:: im_state_not_ready = 0

    	im state not ready

    .. data:: im_state_admin_down = 1

    	im state admin down

    .. data:: im_state_down = 2

    	im state down

    .. data:: im_state_up = 3

    	im state up

    .. data:: im_state_shutdown = 4

    	im state shutdown

    .. data:: im_state_err_disable = 5

    	im state err disable

    .. data:: im_state_down_immediate = 6

    	im state down immediate

    .. data:: im_state_down_immediate_admin = 7

    	im state down immediate admin

    .. data:: im_state_down_graceful = 8

    	im state down graceful

    .. data:: im_state_begin_shutdown = 9

    	im state begin shutdown

    .. data:: im_state_end_shutdown = 10

    	im state end shutdown

    .. data:: im_state_begin_error_disable = 11

    	im state begin error disable

    .. data:: im_state_end_error_disable = 12

    	im state end error disable

    .. data:: im_state_begin_down_graceful = 13

    	im state begin down graceful

    .. data:: im_state_reset = 14

    	im state reset

    .. data:: im_state_operational = 15

    	im state operational

    .. data:: im_state_not_operational = 16

    	im state not operational

    .. data:: im_state_unknown = 17

    	im state unknown

    .. data:: im_state_last = 18

    	im state last

    """

    im_state_not_ready = Enum.YLeaf(0, "im-state-not-ready")

    im_state_admin_down = Enum.YLeaf(1, "im-state-admin-down")

    im_state_down = Enum.YLeaf(2, "im-state-down")

    im_state_up = Enum.YLeaf(3, "im-state-up")

    im_state_shutdown = Enum.YLeaf(4, "im-state-shutdown")

    im_state_err_disable = Enum.YLeaf(5, "im-state-err-disable")

    im_state_down_immediate = Enum.YLeaf(6, "im-state-down-immediate")

    im_state_down_immediate_admin = Enum.YLeaf(7, "im-state-down-immediate-admin")

    im_state_down_graceful = Enum.YLeaf(8, "im-state-down-graceful")

    im_state_begin_shutdown = Enum.YLeaf(9, "im-state-begin-shutdown")

    im_state_end_shutdown = Enum.YLeaf(10, "im-state-end-shutdown")

    im_state_begin_error_disable = Enum.YLeaf(11, "im-state-begin-error-disable")

    im_state_end_error_disable = Enum.YLeaf(12, "im-state-end-error-disable")

    im_state_begin_down_graceful = Enum.YLeaf(13, "im-state-begin-down-graceful")

    im_state_reset = Enum.YLeaf(14, "im-state-reset")

    im_state_operational = Enum.YLeaf(15, "im-state-operational")

    im_state_not_operational = Enum.YLeaf(16, "im-state-not-operational")

    im_state_unknown = Enum.YLeaf(17, "im-state-unknown")

    im_state_last = Enum.YLeaf(18, "im-state-last")


class IpfrrTbrkr(Enum):
    """
    IpfrrTbrkr (Enum Class)

    FRR Tiebreakers

    .. data:: downstream = 0

    	Downsteram

    .. data:: line_card_disjoint = 1

    	LC Disjoint

    .. data:: backup_metric = 2

    	Backup metric

    .. data:: node_protect = 3

    	Node protection

    .. data:: primary_path = 4

    	Primary path

    .. data:: secondary_path = 5

    	Secondary path

    .. data:: srlg_disjoint = 6

    	SRLG disjoint

    .. data:: tunnel = 7

    	Tunnel

    """

    downstream = Enum.YLeaf(0, "downstream")

    line_card_disjoint = Enum.YLeaf(1, "line-card-disjoint")

    backup_metric = Enum.YLeaf(2, "backup-metric")

    node_protect = Enum.YLeaf(3, "node-protect")

    primary_path = Enum.YLeaf(4, "primary-path")

    secondary_path = Enum.YLeaf(5, "secondary-path")

    srlg_disjoint = Enum.YLeaf(6, "srlg-disjoint")

    tunnel = Enum.YLeaf(7, "tunnel")


class OspfLsaSyncState(Enum):
    """
    OspfLsaSyncState (Enum Class)

    LSA synchronization states

    .. data:: none = 0

    	State not set

    .. data:: out_of_sync = 1

    	LSA out of sync with active

    .. data:: in_sync = 2

    	LSA in sync with active

    .. data:: nsr_ack_pending = 3

    	NSR ack pending for LSA sync

    """

    none = Enum.YLeaf(0, "none")

    out_of_sync = Enum.YLeaf(1, "out-of-sync")

    in_sync = Enum.YLeaf(2, "in-sync")

    nsr_ack_pending = Enum.YLeaf(3, "nsr-ack-pending")


class OspfNsrSchedPri(Enum):
    """
    OspfNsrSchedPri (Enum Class)

    Ospf nsr sched pri

    .. data:: ospf_nsr_stats_sched_pri_hi = 0

    	ospf nsr stats sched pri hi

    .. data:: ospf_nsr_stats_sched_pri_med = 1

    	ospf nsr stats sched pri med

    .. data:: ospf_nsr_stats_sched_pri_low = 2

    	ospf nsr stats sched pri low

    .. data:: ospf_nsr_stats_sched_pri_max = 3

    	ospf nsr stats sched pri max

    """

    ospf_nsr_stats_sched_pri_hi = Enum.YLeaf(0, "ospf-nsr-stats-sched-pri-hi")

    ospf_nsr_stats_sched_pri_med = Enum.YLeaf(1, "ospf-nsr-stats-sched-pri-med")

    ospf_nsr_stats_sched_pri_low = Enum.YLeaf(2, "ospf-nsr-stats-sched-pri-low")

    ospf_nsr_stats_sched_pri_max = Enum.YLeaf(3, "ospf-nsr-stats-sched-pri-max")


class Ospfv3AreaRangeStatus(Enum):
    """
    Ospfv3AreaRangeStatus (Enum Class)

    Ospfv3 area range status

    .. data:: advertise = 1

    	Advertise this range

    .. data:: do_not_advertise = 2

    	Do not advertise this range

    """

    advertise = Enum.YLeaf(1, "advertise")

    do_not_advertise = Enum.YLeaf(2, "do-not-advertise")


class Ospfv3BorderRoute(Enum):
    """
    Ospfv3BorderRoute (Enum Class)

    OSPFv3 border route destination types

    .. data:: abr = 1

    	Area border router

    .. data:: asbr = 2

    	Area system boundary router

    .. data:: abr_asbr = 3

    	Area border router and area system boundary

    	router

    """

    abr = Enum.YLeaf(1, "abr")

    asbr = Enum.YLeaf(2, "asbr")

    abr_asbr = Enum.YLeaf(3, "abr-asbr")


class Ospfv3DefaultMetric(Enum):
    """
    Ospfv3DefaultMetric (Enum Class)

    OSPFv3 default metric types 

    .. data:: type_none = 0

    	OSPFv3 default metric type None 

    .. data:: type1 = 1

    	OSPFv3 default metric type 1 

    .. data:: type2 = 2

    	OSPFv3 default metric type 2 

    """

    type_none = Enum.YLeaf(0, "type-none")

    type1 = Enum.YLeaf(1, "type1")

    type2 = Enum.YLeaf(2, "type2")


class Ospfv3GracefulRestartReason(Enum):
    """
    Ospfv3GracefulRestartReason (Enum Class)

    Reason for router restart

    .. data:: grace_reason_unknown = 0

    	Grace reason unknown

    .. data:: grace_reason_software_restart = 1

    	Grace reason software restart

    .. data:: grace_reason_software_upgrade = 2

    	Software reload/upgrade, RFC 3623

    .. data:: grace_reason_switchover = 3

    	Switch to redundant control processor

    """

    grace_reason_unknown = Enum.YLeaf(0, "grace-reason-unknown")

    grace_reason_software_restart = Enum.YLeaf(1, "grace-reason-software-restart")

    grace_reason_software_upgrade = Enum.YLeaf(2, "grace-reason-software-upgrade")

    grace_reason_switchover = Enum.YLeaf(3, "grace-reason-switchover")


class Ospfv3GracefulShutdownState(Enum):
    """
    Ospfv3GracefulShutdownState (Enum Class)

    Graceful Shutdown state

    .. data:: init = 0

    	Init

    .. data:: normal = 1

    	Normal

    .. data:: flushing = 2

    	Flushing

    .. data:: empty_hellos = 3

    	Empty Hellos

    .. data:: quiet = 4

    	Quiet

    """

    init = Enum.YLeaf(0, "init")

    normal = Enum.YLeaf(1, "normal")

    flushing = Enum.YLeaf(2, "flushing")

    empty_hellos = Enum.YLeaf(3, "empty-hellos")

    quiet = Enum.YLeaf(4, "quiet")


class Ospfv3Interface(Enum):
    """
    Ospfv3Interface (Enum Class)

    OSPFv3 neighbor interface types

    .. data:: none = 0

    	None

    .. data:: broadcast = 1

    	Broadcast

    .. data:: non_broadcast = 2

    	Non broadcast

    .. data:: point_to_point = 3

    	Point To Point

    .. data:: point_to_multipoint = 4

    	Point To Multipoint

    .. data:: point_to_multipoint_non_broadcast = 5

    	Point-To-Multipoint Non broadcast

    .. data:: virtual_link = 6

    	Virtual link

    .. data:: loopback_interface = 7

    	Loopback

    .. data:: mpls_traffic_engineering = 8

    	MPLS traffic engineering

    .. data:: sham_link = 9

    	Sham link

    """

    none = Enum.YLeaf(0, "none")

    broadcast = Enum.YLeaf(1, "broadcast")

    non_broadcast = Enum.YLeaf(2, "non-broadcast")

    point_to_point = Enum.YLeaf(3, "point-to-point")

    point_to_multipoint = Enum.YLeaf(4, "point-to-multipoint")

    point_to_multipoint_non_broadcast = Enum.YLeaf(5, "point-to-multipoint-non-broadcast")

    virtual_link = Enum.YLeaf(6, "virtual-link")

    loopback_interface = Enum.YLeaf(7, "loopback-interface")

    mpls_traffic_engineering = Enum.YLeaf(8, "mpls-traffic-engineering")

    sham_link = Enum.YLeaf(9, "sham-link")


class Ospfv3InterfaceState(Enum):
    """
    Ospfv3InterfaceState (Enum Class)

    OSPFv3 interface states

    .. data:: down = 0

    	Down

    .. data:: loopback = 1

    	Loopback

    .. data:: waiting = 2

    	Waiting

    .. data:: point_to_multipoint = 3

    	Point To Multipoint

    .. data:: point_to_point = 4

    	Point To Point

    .. data:: designated_router = 5

    	Designated router

    .. data:: backup_designated_router = 6

    	Backup designated router

    .. data:: other_designated_router = 7

    	Other designated router

    """

    down = Enum.YLeaf(0, "down")

    loopback = Enum.YLeaf(1, "loopback")

    waiting = Enum.YLeaf(2, "waiting")

    point_to_multipoint = Enum.YLeaf(3, "point-to-multipoint")

    point_to_point = Enum.YLeaf(4, "point-to-point")

    designated_router = Enum.YLeaf(5, "designated-router")

    backup_designated_router = Enum.YLeaf(6, "backup-designated-router")

    other_designated_router = Enum.YLeaf(7, "other-designated-router")


class Ospfv3Link(Enum):
    """
    Ospfv3Link (Enum Class)

    OSPFV3 Link type

    .. data:: link_router = 1

    	Router link

    .. data:: link_trans_net = 2

    	Transit network link

    .. data:: link_virtual_link = 4

    	Virutal link

    """

    link_router = Enum.YLeaf(1, "link-router")

    link_trans_net = Enum.YLeaf(2, "link-trans-net")

    link_virtual_link = Enum.YLeaf(4, "link-virtual-link")


class Ospfv3Lsa(Enum):
    """
    Ospfv3Lsa (Enum Class)

    Ospfv3 lsa

    .. data:: link_lsa = 8

    	Link LSA

    .. data:: grace_lsa = 11

    	Grace LSA

    .. data:: router = 8193

    	Router LSA

    .. data:: network = 8194

    	Network LSA

    .. data:: inter_area_prefix = 8195

    	Inter-Area Prefix LSA

    .. data:: inter_area_router = 8196

    	Inter-Area Router LSA

    .. data:: nssa_external = 8199

    	NSSA External LSA

    .. data:: intra_area_prefix = 8201

    	Intra-Area Prefix LSA

    .. data:: external = 16389

    	External LSA

    .. data:: opaque_link = 32768

    	Opaque LSALink Scope

    .. data:: opaque_area = 40960

    	Opaque LSA Area Scope

    .. data:: opaque_as = 49152

    	Opaque LSA AS Scope

    .. data:: unknown = 57344

    	Unknown Reserved Scope LSAs

    """

    link_lsa = Enum.YLeaf(8, "link-lsa")

    grace_lsa = Enum.YLeaf(11, "grace-lsa")

    router = Enum.YLeaf(8193, "router")

    network = Enum.YLeaf(8194, "network")

    inter_area_prefix = Enum.YLeaf(8195, "inter-area-prefix")

    inter_area_router = Enum.YLeaf(8196, "inter-area-router")

    nssa_external = Enum.YLeaf(8199, "nssa-external")

    intra_area_prefix = Enum.YLeaf(8201, "intra-area-prefix")

    external = Enum.YLeaf(16389, "external")

    opaque_link = Enum.YLeaf(32768, "opaque-link")

    opaque_area = Enum.YLeaf(40960, "opaque-area")

    opaque_as = Enum.YLeaf(49152, "opaque-as")

    unknown = Enum.YLeaf(57344, "unknown")


class Ospfv3Lsa1(Enum):
    """
    Ospfv3Lsa1 (Enum Class)

    OSPFv3 LSA types

    .. data:: link = 8

    	Link LSA

    .. data:: grace = 11

    	Grace LSA

    .. data:: router = 8193

    	Router LSA

    .. data:: network = 8194

    	Network LSA

    .. data:: inter_area_prefix = 8195

    	Inter area prefix LSA

    .. data:: inter_area_router = 8196

    	Inter area router LSA

    .. data:: mospf = 8198

    	MOSPF LSA

    .. data:: type7_external = 8199

    	Type-7 External LSA

    .. data:: lsa_prefix = 8201

    	Prefix LSA

    .. data:: as_external = 16389

    	AS external LSA

    .. data:: unknown_link = 32768

    	Unknown link LSA

    .. data:: unknown_area = 40960

    	Unknown area LSA

    .. data:: unknown_as = 49152

    	Unknown AS LSA

    .. data:: unknown_type = 57344

    	Unknown type LSA

    """

    link = Enum.YLeaf(8, "link")

    grace = Enum.YLeaf(11, "grace")

    router = Enum.YLeaf(8193, "router")

    network = Enum.YLeaf(8194, "network")

    inter_area_prefix = Enum.YLeaf(8195, "inter-area-prefix")

    inter_area_router = Enum.YLeaf(8196, "inter-area-router")

    mospf = Enum.YLeaf(8198, "mospf")

    type7_external = Enum.YLeaf(8199, "type7-external")

    lsa_prefix = Enum.YLeaf(8201, "lsa-prefix")

    as_external = Enum.YLeaf(16389, "as-external")

    unknown_link = Enum.YLeaf(32768, "unknown-link")

    unknown_area = Enum.YLeaf(40960, "unknown-area")

    unknown_as = Enum.YLeaf(49152, "unknown-as")

    unknown_type = Enum.YLeaf(57344, "unknown-type")


class Ospfv3LsaInfoTypes(Enum):
    """
    Ospfv3LsaInfoTypes (Enum Class)

    OSPFv3 LSA format types

    .. data:: mgmt_lsa_lsasum_type = 0

    	Summary information of LSAs

    .. data:: mgmt_lsa_link_type = 8

    	Link LSA

    .. data:: mgmt_lsa_gr_type = 11

    	Grace LSA

    .. data:: mgmt_lsa_rtr_type = 8193

    	Router LSA

    .. data:: mgmt_lsa_net_type = 8194

    	Network LSA

    .. data:: mgmt_lsa_iapfx_type = 8195

    	Inter Area Prefix Summary LSA

    .. data:: mgmt_lsa_iartr_type = 8196

    	Inter Area Router Summay LSA

    .. data:: mgmt_lsa_nssaext_type = 8199

    	NSSA external LSA

    .. data:: mgmt_lsa_prefix_type = 8201

    	Intra Area Prefix LSA

    .. data:: mgmt_lsa_ext_type = 16389

    	Type 5 External LSA

    .. data:: mgmt_lsa_unk_link_type = 32768

    	Opaque Link scope LSA

    .. data:: mgmt_lsa_unk_area_type = 40960

    	Opaque Area scope LSA

    .. data:: mgmt_lsa_unk_as_type = 49152

    	Opaque AS scope LSA

    .. data:: mgmt_lsa_unk_type = 57344

    	Opaque Reserved scope LSA

    """

    mgmt_lsa_lsasum_type = Enum.YLeaf(0, "mgmt-lsa-lsasum-type")

    mgmt_lsa_link_type = Enum.YLeaf(8, "mgmt-lsa-link-type")

    mgmt_lsa_gr_type = Enum.YLeaf(11, "mgmt-lsa-gr-type")

    mgmt_lsa_rtr_type = Enum.YLeaf(8193, "mgmt-lsa-rtr-type")

    mgmt_lsa_net_type = Enum.YLeaf(8194, "mgmt-lsa-net-type")

    mgmt_lsa_iapfx_type = Enum.YLeaf(8195, "mgmt-lsa-iapfx-type")

    mgmt_lsa_iartr_type = Enum.YLeaf(8196, "mgmt-lsa-iartr-type")

    mgmt_lsa_nssaext_type = Enum.YLeaf(8199, "mgmt-lsa-nssaext-type")

    mgmt_lsa_prefix_type = Enum.YLeaf(8201, "mgmt-lsa-prefix-type")

    mgmt_lsa_ext_type = Enum.YLeaf(16389, "mgmt-lsa-ext-type")

    mgmt_lsa_unk_link_type = Enum.YLeaf(32768, "mgmt-lsa-unk-link-type")

    mgmt_lsa_unk_area_type = Enum.YLeaf(40960, "mgmt-lsa-unk-area-type")

    mgmt_lsa_unk_as_type = Enum.YLeaf(49152, "mgmt-lsa-unk-as-type")

    mgmt_lsa_unk_type = Enum.YLeaf(57344, "mgmt-lsa-unk-type")


class Ospfv3NeighborState(Enum):
    """
    Ospfv3NeighborState (Enum Class)

    OSPFv3 neighbor states

    .. data:: neigbhor_down = 0

    	Down

    .. data:: attempt = 1

    	Attempting

    .. data:: init = 2

    	Initializing

    .. data:: two_way = 3

    	2 Way

    .. data:: exstart = 4

    	Exstart

    .. data:: exchange = 5

    	Exchange

    .. data:: loading = 6

    	Loading

    .. data:: full = 7

    	Full

    .. data:: sc_virtual = 8

    	SCVirtual

    """

    neigbhor_down = Enum.YLeaf(0, "neigbhor-down")

    attempt = Enum.YLeaf(1, "attempt")

    init = Enum.YLeaf(2, "init")

    two_way = Enum.YLeaf(3, "two-way")

    exstart = Enum.YLeaf(4, "exstart")

    exchange = Enum.YLeaf(5, "exchange")

    loading = Enum.YLeaf(6, "loading")

    full = Enum.YLeaf(7, "full")

    sc_virtual = Enum.YLeaf(8, "sc-virtual")


class PrefixPriority(Enum):
    """
    PrefixPriority (Enum Class)

    Prefix priority

    .. data:: critical = 0

    	Critical priority

    .. data:: high = 1

    	High priority

    .. data:: medium = 2

    	Medium priority

    .. data:: low = 3

    	Low priority

    """

    critical = Enum.YLeaf(0, "critical")

    high = Enum.YLeaf(1, "high")

    medium = Enum.YLeaf(2, "medium")

    low = Enum.YLeaf(3, "low")


class StubRouterAbrOffReason(Enum):
    """
    StubRouterAbrOffReason (Enum Class)

    Reason to exiting stub router mode

    .. data:: init_delay = 2

    	Initial delay when stub router mode is

    	activated

    .. data:: no_neighbor = 3

    	No neighbor present

    .. data:: no_full_neighbor = 4

    	No neighbor in FULL state present

    .. data:: new_neighbor = 5

    	A new neighbor discovered less than 60 seconds

    	ago

    .. data:: full_neighbor = 6

    	A neighbor transitioned to FULL state less than

    	60 seconds ago

    """

    init_delay = Enum.YLeaf(2, "init-delay")

    no_neighbor = Enum.YLeaf(3, "no-neighbor")

    no_full_neighbor = Enum.YLeaf(4, "no-full-neighbor")

    new_neighbor = Enum.YLeaf(5, "new-neighbor")

    full_neighbor = Enum.YLeaf(6, "full-neighbor")


class StubRouterExitReason(Enum):
    """
    StubRouterExitReason (Enum Class)

    Reason to exiting stub router mode

    .. data:: none = 0

    	No reason

    .. data:: bgp = 1

    	BGP has converged

    .. data:: timer = 2

    	Stub Router timer has expired

    .. data:: configuration = 3

    	Configuration has changed

    .. data:: cleared = 4

    	Process has been cleared

    .. data:: override = 5

    	Preempted by always

    """

    none = Enum.YLeaf(0, "none")

    bgp = Enum.YLeaf(1, "bgp")

    timer = Enum.YLeaf(2, "timer")

    configuration = Enum.YLeaf(3, "configuration")

    cleared = Enum.YLeaf(4, "cleared")

    override = Enum.YLeaf(5, "override")


class StubRouterMode(Enum):
    """
    StubRouterMode (Enum Class)

    Stub Router mode

    .. data:: rbit = 0

    	Stub Router mode r-bit

    .. data:: v6bit = 1

    	Stub Router mode v6-bit

    .. data:: max_metric = 2

    	Stub Router mode max-metric

    .. data:: none = 3

    	Stub Router not configured

    """

    rbit = Enum.YLeaf(0, "rbit")

    v6bit = Enum.YLeaf(1, "v6bit")

    max_metric = Enum.YLeaf(2, "max-metric")

    none = Enum.YLeaf(3, "none")


class StubRouterTrigger(Enum):
    """
    StubRouterTrigger (Enum Class)

    Trigger for entering stub router mode

    .. data:: on_proc_migration = 0

    	Process migration

    .. data:: on_proc_restart = 1

    	Process restart

    .. data:: on_switchover = 2

    	RP switchover

    .. data:: on_startup = 3

    	Router startup

    .. data:: always = 4

    	Always on

    .. data:: none = 5

    	No trigger

    """

    on_proc_migration = Enum.YLeaf(0, "on-proc-migration")

    on_proc_restart = Enum.YLeaf(1, "on-proc-restart")

    on_switchover = Enum.YLeaf(2, "on-switchover")

    on_startup = Enum.YLeaf(3, "on-startup")

    always = Enum.YLeaf(4, "always")

    none = Enum.YLeaf(5, "none")



class Ospfv3(Entity):
    """
    OSPFv3 operational information 
    
    .. attribute:: processes
    
    	OSPFv3 Process Table
    	**type**\:  :py:class:`Processes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes>`
    
    

    """

    _prefix = 'ipv6-ospfv3-oper'
    _revision = '2017-10-30'

    def __init__(self):
        super(Ospfv3, self).__init__()
        self._top_entity = None

        self.yang_name = "ospfv3"
        self.yang_parent_name = "Cisco-IOS-XR-ipv6-ospfv3-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("processes", ("processes", Ospfv3.Processes))])
        self._leafs = OrderedDict()

        self.processes = Ospfv3.Processes()
        self.processes.parent = self
        self._children_name_map["processes"] = "processes"
        self._segment_path = lambda: "Cisco-IOS-XR-ipv6-ospfv3-oper:ospfv3"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(Ospfv3, [], name, value)


    class Processes(Entity):
        """
        OSPFv3 Process Table
        
        .. attribute:: process
        
        	OSPFv3 Operational data for a particular OSPFv3 process 
        	**type**\: list of  		 :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process>`
        
        

        """

        _prefix = 'ipv6-ospfv3-oper'
        _revision = '2017-10-30'

        def __init__(self):
            super(Ospfv3.Processes, self).__init__()

            self.yang_name = "processes"
            self.yang_parent_name = "ospfv3"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("process", ("process", Ospfv3.Processes.Process))])
            self._leafs = OrderedDict()

            self.process = YList(self)
            self._segment_path = lambda: "processes"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv6-ospfv3-oper:ospfv3/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Ospfv3.Processes, [], name, value)


        class Process(Entity):
            """
            OSPFv3 Operational data for a particular OSPFv3
            process 
            
            .. attribute:: process_name  (key)
            
            	Particular OSPFv3 process
            	**type**\: str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: vrfs
            
            	Table for each VRF
            	**type**\:  :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs>`
            
            .. attribute:: statistics
            
            	Container for Statistics
            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics>`
            
            .. attribute:: default_vrf
            
            	Operational data for the default VRF (instance) in the OSPFv3 process
            	**type**\:  :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf>`
            
            

            """

            _prefix = 'ipv6-ospfv3-oper'
            _revision = '2017-10-30'

            def __init__(self):
                super(Ospfv3.Processes.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "processes"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['process_name']
                self._child_classes = OrderedDict([("vrfs", ("vrfs", Ospfv3.Processes.Process.Vrfs)), ("statistics", ("statistics", Ospfv3.Processes.Process.Statistics)), ("default-vrf", ("default_vrf", Ospfv3.Processes.Process.DefaultVrf))])
                self._leafs = OrderedDict([
                    ('process_name', (YLeaf(YType.str, 'process-name'), ['str'])),
                ])
                self.process_name = None

                self.vrfs = Ospfv3.Processes.Process.Vrfs()
                self.vrfs.parent = self
                self._children_name_map["vrfs"] = "vrfs"

                self.statistics = Ospfv3.Processes.Process.Statistics()
                self.statistics.parent = self
                self._children_name_map["statistics"] = "statistics"

                self.default_vrf = Ospfv3.Processes.Process.DefaultVrf()
                self.default_vrf.parent = self
                self._children_name_map["default_vrf"] = "default-vrf"
                self._segment_path = lambda: "process" + "[process-name='" + str(self.process_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv6-ospfv3-oper:ospfv3/processes/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Ospfv3.Processes.Process, ['process_name'], name, value)


            class Vrfs(Entity):
                """
                Table for each VRF
                
                .. attribute:: vrf
                
                	Operational data for a particular VRF (instance) in the OSPFv3 process
                	**type**\: list of  		 :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf>`
                
                

                """

                _prefix = 'ipv6-ospfv3-oper'
                _revision = '2017-10-30'

                def __init__(self):
                    super(Ospfv3.Processes.Process.Vrfs, self).__init__()

                    self.yang_name = "vrfs"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("vrf", ("vrf", Ospfv3.Processes.Process.Vrfs.Vrf))])
                    self._leafs = OrderedDict()

                    self.vrf = YList(self)
                    self._segment_path = lambda: "vrfs"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs, [], name, value)


                class Vrf(Entity):
                    """
                    Operational data for a particular VRF
                    (instance) in the OSPFv3 process
                    
                    .. attribute:: vrf_name  (key)
                    
                    	VRF Name
                    	**type**\: str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: summary_prefixes
                    
                    	Summary prefix information table
                    	**type**\:  :py:class:`SummaryPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes>`
                    
                    .. attribute:: border_routers
                    
                    	OSPFv3 border router information table
                    	**type**\:  :py:class:`BorderRouters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters>`
                    
                    .. attribute:: sham_link_table
                    
                    	Sham link information
                    	**type**\:  :py:class:`ShamLinkTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable>`
                    
                    .. attribute:: area_informations
                    
                    	OSPFv3 area information table
                    	**type**\:  :py:class:`AreaInformations <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations>`
                    
                    .. attribute:: database_table
                    
                    	OSPF Link State Database
                    	**type**\:  :py:class:`DatabaseTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable>`
                    
                    .. attribute:: interface_process_table
                    
                    	OSPFv3 interface information table for all areas
                    	**type**\:  :py:class:`InterfaceProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable>`
                    
                    .. attribute:: redistributions
                    
                    	Redistribution information table
                    	**type**\:  :py:class:`Redistributions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions>`
                    
                    .. attribute:: external_routes
                    
                    	OSPFv3 external route information table
                    	**type**\:  :py:class:`ExternalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes>`
                    
                    .. attribute:: request_list_process_table
                    
                    	OSPFv3 request list information for all areas
                    	**type**\:  :py:class:`RequestListProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable>`
                    
                    .. attribute:: virtual_link
                    
                    	Virtual link information
                    	**type**\:  :py:class:`VirtualLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink>`
                    
                    .. attribute:: flood_list_process_table
                    
                    	OSPFv3 flood list information table for all areas
                    	**type**\:  :py:class:`FloodListProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable>`
                    
                    .. attribute:: route_summary
                    
                    	Summarize OSPFv3 local RIB tables
                    	**type**\:  :py:class:`RouteSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RouteSummary>`
                    
                    .. attribute:: areas
                    
                    	OSPFv3 area table
                    	**type**\:  :py:class:`Areas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas>`
                    
                    .. attribute:: internal_routes
                    
                    	OSPFv3 internal route information table
                    	**type**\:  :py:class:`InternalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes>`
                    
                    .. attribute:: protocol_areas
                    
                    	Protocol area table 
                    	**type**\:  :py:class:`ProtocolAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas>`
                    
                    .. attribute:: connected_routes
                    
                    	OSPFv3 connected route information table
                    	**type**\:  :py:class:`ConnectedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes>`
                    
                    .. attribute:: vrf_statistics
                    
                    	Container for Statistics
                    	**type**\:  :py:class:`VrfStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics>`
                    
                    .. attribute:: summary
                    
                    	OSPFv3 summary
                    	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary>`
                    
                    .. attribute:: retransmission_list_process_table
                    
                    	OSPFv3 retransmission list information table for all areas
                    	**type**\:  :py:class:`RetransmissionListProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable>`
                    
                    .. attribute:: bad_checksums
                    
                    	Bad Checksum Packets information table
                    	**type**\:  :py:class:`BadChecksums <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums>`
                    
                    .. attribute:: database_summary_table
                    
                    	Database summary table
                    	**type**\:  :py:class:`DatabaseSummaryTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable>`
                    
                    .. attribute:: neighbor_process_table
                    
                    	OSPFv3 neighbor information table for all areas
                    	**type**\:  :py:class:`NeighborProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable>`
                    
                    .. attribute:: fast_reroutes
                    
                    	OSPFv3 fast reroute topology information table
                    	**type**\:  :py:class:`FastReroutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes>`
                    
                    .. attribute:: interface_brief_process_table
                    
                    	OSPFv3 interface brief information table for all areas
                    	**type**\:  :py:class:`InterfaceBriefProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable>`
                    
                    .. attribute:: neighbor_detail_process_table
                    
                    	OSPFv3 neighbor information table for all areas
                    	**type**\:  :py:class:`NeighborDetailProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Vrfs.Vrf, self).__init__()

                        self.yang_name = "vrf"
                        self.yang_parent_name = "vrfs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['vrf_name']
                        self._child_classes = OrderedDict([("summary-prefixes", ("summary_prefixes", Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes)), ("border-routers", ("border_routers", Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters)), ("sham-link-table", ("sham_link_table", Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable)), ("area-informations", ("area_informations", Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations)), ("database-table", ("database_table", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable)), ("interface-process-table", ("interface_process_table", Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable)), ("redistributions", ("redistributions", Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions)), ("external-routes", ("external_routes", Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes)), ("request-list-process-table", ("request_list_process_table", Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable)), ("virtual-link", ("virtual_link", Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink)), ("flood-list-process-table", ("flood_list_process_table", Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable)), ("route-summary", ("route_summary", Ospfv3.Processes.Process.Vrfs.Vrf.RouteSummary)), ("areas", ("areas", Ospfv3.Processes.Process.Vrfs.Vrf.Areas)), ("internal-routes", ("internal_routes", Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes)), ("protocol-areas", ("protocol_areas", Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas)), ("connected-routes", ("connected_routes", Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes)), ("vrf-statistics", ("vrf_statistics", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics)), ("summary", ("summary", Ospfv3.Processes.Process.Vrfs.Vrf.Summary)), ("retransmission-list-process-table", ("retransmission_list_process_table", Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable)), ("bad-checksums", ("bad_checksums", Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums)), ("database-summary-table", ("database_summary_table", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable)), ("neighbor-process-table", ("neighbor_process_table", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable)), ("fast-reroutes", ("fast_reroutes", Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes)), ("interface-brief-process-table", ("interface_brief_process_table", Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable)), ("neighbor-detail-process-table", ("neighbor_detail_process_table", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable))])
                        self._leafs = OrderedDict([
                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                        ])
                        self.vrf_name = None

                        self.summary_prefixes = Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes()
                        self.summary_prefixes.parent = self
                        self._children_name_map["summary_prefixes"] = "summary-prefixes"

                        self.border_routers = Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters()
                        self.border_routers.parent = self
                        self._children_name_map["border_routers"] = "border-routers"

                        self.sham_link_table = Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable()
                        self.sham_link_table.parent = self
                        self._children_name_map["sham_link_table"] = "sham-link-table"

                        self.area_informations = Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations()
                        self.area_informations.parent = self
                        self._children_name_map["area_informations"] = "area-informations"

                        self.database_table = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable()
                        self.database_table.parent = self
                        self._children_name_map["database_table"] = "database-table"

                        self.interface_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable()
                        self.interface_process_table.parent = self
                        self._children_name_map["interface_process_table"] = "interface-process-table"

                        self.redistributions = Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions()
                        self.redistributions.parent = self
                        self._children_name_map["redistributions"] = "redistributions"

                        self.external_routes = Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes()
                        self.external_routes.parent = self
                        self._children_name_map["external_routes"] = "external-routes"

                        self.request_list_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable()
                        self.request_list_process_table.parent = self
                        self._children_name_map["request_list_process_table"] = "request-list-process-table"

                        self.virtual_link = Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink()
                        self.virtual_link.parent = self
                        self._children_name_map["virtual_link"] = "virtual-link"

                        self.flood_list_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable()
                        self.flood_list_process_table.parent = self
                        self._children_name_map["flood_list_process_table"] = "flood-list-process-table"

                        self.route_summary = Ospfv3.Processes.Process.Vrfs.Vrf.RouteSummary()
                        self.route_summary.parent = self
                        self._children_name_map["route_summary"] = "route-summary"

                        self.areas = Ospfv3.Processes.Process.Vrfs.Vrf.Areas()
                        self.areas.parent = self
                        self._children_name_map["areas"] = "areas"

                        self.internal_routes = Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes()
                        self.internal_routes.parent = self
                        self._children_name_map["internal_routes"] = "internal-routes"

                        self.protocol_areas = Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas()
                        self.protocol_areas.parent = self
                        self._children_name_map["protocol_areas"] = "protocol-areas"

                        self.connected_routes = Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes()
                        self.connected_routes.parent = self
                        self._children_name_map["connected_routes"] = "connected-routes"

                        self.vrf_statistics = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics()
                        self.vrf_statistics.parent = self
                        self._children_name_map["vrf_statistics"] = "vrf-statistics"

                        self.summary = Ospfv3.Processes.Process.Vrfs.Vrf.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"

                        self.retransmission_list_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable()
                        self.retransmission_list_process_table.parent = self
                        self._children_name_map["retransmission_list_process_table"] = "retransmission-list-process-table"

                        self.bad_checksums = Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums()
                        self.bad_checksums.parent = self
                        self._children_name_map["bad_checksums"] = "bad-checksums"

                        self.database_summary_table = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable()
                        self.database_summary_table.parent = self
                        self._children_name_map["database_summary_table"] = "database-summary-table"

                        self.neighbor_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable()
                        self.neighbor_process_table.parent = self
                        self._children_name_map["neighbor_process_table"] = "neighbor-process-table"

                        self.fast_reroutes = Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes()
                        self.fast_reroutes.parent = self
                        self._children_name_map["fast_reroutes"] = "fast-reroutes"

                        self.interface_brief_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable()
                        self.interface_brief_process_table.parent = self
                        self._children_name_map["interface_brief_process_table"] = "interface-brief-process-table"

                        self.neighbor_detail_process_table = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable()
                        self.neighbor_detail_process_table.parent = self
                        self._children_name_map["neighbor_detail_process_table"] = "neighbor-detail-process-table"
                        self._segment_path = lambda: "vrf" + "[vrf-name='" + str(self.vrf_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf, ['vrf_name'], name, value)


                    class SummaryPrefixes(Entity):
                        """
                        Summary prefix information table
                        
                        .. attribute:: summary_prefix
                        
                        	Summary prefix information
                        	**type**\: list of  		 :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes, self).__init__()

                            self.yang_name = "summary-prefixes"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("summary-prefix", ("summary_prefix", Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix))])
                            self._leafs = OrderedDict()

                            self.summary_prefix = YList(self)
                            self._segment_path = lambda: "summary-prefixes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes, [], name, value)


                        class SummaryPrefix(Entity):
                            """
                            Summary prefix information
                            
                            .. attribute:: prefix
                            
                            	Summary prefix
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\: int
                            
                            	**range:** 0..128
                            
                            .. attribute:: prefix_metric
                            
                            	Prefix metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: prefix_metric_type
                            
                            	Prefix metric type
                            	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                            
                            .. attribute:: tag
                            
                            	Tag
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix, self).__init__()

                                self.yang_name = "summary-prefix"
                                self.yang_parent_name = "summary-prefixes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                    ('prefix_metric', (YLeaf(YType.uint32, 'prefix-metric'), ['int'])),
                                    ('prefix_metric_type', (YLeaf(YType.enumeration, 'prefix-metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                ])
                                self.prefix = None
                                self.prefix_length = None
                                self.prefix_metric = None
                                self.prefix_metric_type = None
                                self.tag = None
                                self._segment_path = lambda: "summary-prefix"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.SummaryPrefixes.SummaryPrefix, ['prefix', 'prefix_length', u'prefix_metric', u'prefix_metric_type', u'tag'], name, value)


                    class BorderRouters(Entity):
                        """
                        OSPFv3 border router information table
                        
                        .. attribute:: border_router
                        
                        	OSPFv3 border router information
                        	**type**\: list of  		 :py:class:`BorderRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters, self).__init__()

                            self.yang_name = "border-routers"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("border-router", ("border_router", Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter))])
                            self._leafs = OrderedDict()

                            self.border_router = YList(self)
                            self._segment_path = lambda: "border-routers"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters, [], name, value)


                        class BorderRouter(Entity):
                            """
                            OSPFv3 border router information
                            
                            .. attribute:: border_router_id  (key)
                            
                            	Router address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: border_router_path
                            
                            	List of border router paths
                            	**type**\: list of  		 :py:class:`BorderRouterPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter, self).__init__()

                                self.yang_name = "border-router"
                                self.yang_parent_name = "border-routers"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['border_router_id']
                                self._child_classes = OrderedDict([("border-router-path", ("border_router_path", Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath))])
                                self._leafs = OrderedDict([
                                    ('border_router_id', (YLeaf(YType.str, 'border-router-id'), ['str'])),
                                ])
                                self.border_router_id = None

                                self.border_router_path = YList(self)
                                self._segment_path = lambda: "border-router" + "[border-router-id='" + str(self.border_router_id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter, ['border_router_id'], name, value)


                            class BorderRouterPath(Entity):
                                """
                                List of border router paths
                                
                                .. attribute:: is_intra_area_router
                                
                                	If true, intra\-area router else inter\-area router
                                	**type**\: bool
                                
                                .. attribute:: border_router_route_metric
                                
                                	Metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: border_router_next_hop
                                
                                	Next hop address 
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_name
                                
                                	Next hop interface name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: border_router_type
                                
                                	Border router type 
                                	**type**\:  :py:class:`Ospfv3BorderRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3BorderRoute>`
                                
                                .. attribute:: border_router_area_id
                                
                                	Area string in decimal or dotted\-decimal format 
                                	**type**\: str
                                
                                	**length:** 0..16
                                
                                .. attribute:: spf_version
                                
                                	SPF version
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath, self).__init__()

                                    self.yang_name = "border-router-path"
                                    self.yang_parent_name = "border-router"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('is_intra_area_router', (YLeaf(YType.boolean, 'is-intra-area-router'), ['bool'])),
                                        ('border_router_route_metric', (YLeaf(YType.uint32, 'border-router-route-metric'), ['int'])),
                                        ('border_router_next_hop', (YLeaf(YType.str, 'border-router-next-hop'), ['str'])),
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('border_router_type', (YLeaf(YType.enumeration, 'border-router-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3BorderRoute', '')])),
                                        ('border_router_area_id', (YLeaf(YType.str, 'border-router-area-id'), ['str'])),
                                        ('spf_version', (YLeaf(YType.uint32, 'spf-version'), ['int'])),
                                    ])
                                    self.is_intra_area_router = None
                                    self.border_router_route_metric = None
                                    self.border_router_next_hop = None
                                    self.interface_name = None
                                    self.border_router_type = None
                                    self.border_router_area_id = None
                                    self.spf_version = None
                                    self._segment_path = lambda: "border-router-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.BorderRouters.BorderRouter.BorderRouterPath, [u'is_intra_area_router', u'border_router_route_metric', u'border_router_next_hop', u'interface_name', u'border_router_type', u'border_router_area_id', u'spf_version'], name, value)


                    class ShamLinkTable(Entity):
                        """
                        Sham link information
                        
                        .. attribute:: sham_link_neighbor
                        
                        	Neighbor information
                        	**type**\:  :py:class:`ShamLinkNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor>`
                        
                        .. attribute:: sham_link_neighbor_id
                        
                        	Neighbor on other end of this sham link
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: sham_link_source_address
                        
                        	Sham\-link source
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: sham_link_dest_address
                        
                        	Sham\-link dest
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: sham_link_state
                        
                        	OSPF interface state for the sham link
                        	**type**\:  :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                        
                        .. attribute:: sham_link_demand_circuit
                        
                        	If true, the link runs as demand circuit
                        	**type**\: bool
                        
                        .. attribute:: sham_link_dc_bitless_lsa
                        
                        	Number of LSA's with demand circuit bit not set
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_ifindex
                        
                        	Sham\-link ifindex
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_area
                        
                        	Area id
                        	**type**\: str
                        
                        .. attribute:: sham_link_cost
                        
                        	Cost of the sham link
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: sham_link_transmission_delay
                        
                        	Transmission delay in seconds
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: sham_link_hello_interval
                        
                        	Hello interval (s)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_dead_interval
                        
                        	Dead interval (s)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_wait_interval
                        
                        	Wait interval (s)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_retransmission_interval
                        
                        	Retransmission interval (s)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_next_hello
                        
                        	Time until next hello (s)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_passive
                        
                        	If true, interface is passive
                        	**type**\: bool
                        
                        .. attribute:: is_sham_link_ip_security_required
                        
                        	If true, sham link IP security is required 
                        	**type**\: bool
                        
                        .. attribute:: is_sham_link_ip_security_active
                        
                        	If true, Sham link IP security is active 
                        	**type**\: bool
                        
                        .. attribute:: is_sham_link_authentication_enabled
                        
                        	If true, sham link authentication is enabled 
                        	**type**\: bool
                        
                        .. attribute:: virtual_link_authentication_spi
                        
                        	Sham link authentication spi 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_authentication_transmit
                        
                        	Sham link authentication transmit 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_sham_link_encryption_enabled
                        
                        	If true, sham link encryption is enabled 
                        	**type**\: bool
                        
                        .. attribute:: sham_link_encryption_spi
                        
                        	Sham link encryption spi
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_encryption_transmitted
                        
                        	Sham link encryption transmitted 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_encrypted_authentication_transmitted
                        
                        	Sham link encrypted authentication transmitted 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sham_link_gr_enabled
                        
                        	If true,  enabled
                        	**type**\: bool
                        
                        .. attribute:: sham_link_gr
                        
                        	If true, Gracefule restart in progress
                        	**type**\: bool
                        
                        .. attribute:: sham_link_last_gr
                        
                        	Time in seconds since last GR
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable, self).__init__()

                            self.yang_name = "sham-link-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sham-link-neighbor", ("sham_link_neighbor", Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor))])
                            self._leafs = OrderedDict([
                                ('sham_link_neighbor_id', (YLeaf(YType.str, 'sham-link-neighbor-id'), ['str'])),
                                ('sham_link_source_address', (YLeaf(YType.str, 'sham-link-source-address'), ['str'])),
                                ('sham_link_dest_address', (YLeaf(YType.str, 'sham-link-dest-address'), ['str'])),
                                ('sham_link_state', (YLeaf(YType.enumeration, 'sham-link-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3InterfaceState', '')])),
                                ('sham_link_demand_circuit', (YLeaf(YType.boolean, 'sham-link-demand-circuit'), ['bool'])),
                                ('sham_link_dc_bitless_lsa', (YLeaf(YType.uint32, 'sham-link-dc-bitless-lsa'), ['int'])),
                                ('sham_link_ifindex', (YLeaf(YType.uint32, 'sham-link-ifindex'), ['int'])),
                                ('sham_link_area', (YLeaf(YType.str, 'sham-link-area'), ['str'])),
                                ('sham_link_cost', (YLeaf(YType.uint16, 'sham-link-cost'), ['int'])),
                                ('sham_link_transmission_delay', (YLeaf(YType.uint16, 'sham-link-transmission-delay'), ['int'])),
                                ('sham_link_hello_interval', (YLeaf(YType.uint32, 'sham-link-hello-interval'), ['int'])),
                                ('sham_link_dead_interval', (YLeaf(YType.uint32, 'sham-link-dead-interval'), ['int'])),
                                ('sham_link_wait_interval', (YLeaf(YType.uint32, 'sham-link-wait-interval'), ['int'])),
                                ('sham_link_retransmission_interval', (YLeaf(YType.uint32, 'sham-link-retransmission-interval'), ['int'])),
                                ('sham_link_next_hello', (YLeaf(YType.uint32, 'sham-link-next-hello'), ['int'])),
                                ('sham_link_passive', (YLeaf(YType.boolean, 'sham-link-passive'), ['bool'])),
                                ('is_sham_link_ip_security_required', (YLeaf(YType.boolean, 'is-sham-link-ip-security-required'), ['bool'])),
                                ('is_sham_link_ip_security_active', (YLeaf(YType.boolean, 'is-sham-link-ip-security-active'), ['bool'])),
                                ('is_sham_link_authentication_enabled', (YLeaf(YType.boolean, 'is-sham-link-authentication-enabled'), ['bool'])),
                                ('virtual_link_authentication_spi', (YLeaf(YType.uint32, 'virtual-link-authentication-spi'), ['int'])),
                                ('sham_link_authentication_transmit', (YLeaf(YType.uint32, 'sham-link-authentication-transmit'), ['int'])),
                                ('is_sham_link_encryption_enabled', (YLeaf(YType.boolean, 'is-sham-link-encryption-enabled'), ['bool'])),
                                ('sham_link_encryption_spi', (YLeaf(YType.uint32, 'sham-link-encryption-spi'), ['int'])),
                                ('sham_link_encryption_transmitted', (YLeaf(YType.uint32, 'sham-link-encryption-transmitted'), ['int'])),
                                ('sham_link_encrypted_authentication_transmitted', (YLeaf(YType.uint32, 'sham-link-encrypted-authentication-transmitted'), ['int'])),
                                ('sham_link_gr_enabled', (YLeaf(YType.boolean, 'sham-link-gr-enabled'), ['bool'])),
                                ('sham_link_gr', (YLeaf(YType.boolean, 'sham-link-gr'), ['bool'])),
                                ('sham_link_last_gr', (YLeaf(YType.uint32, 'sham-link-last-gr'), ['int'])),
                            ])
                            self.sham_link_neighbor_id = None
                            self.sham_link_source_address = None
                            self.sham_link_dest_address = None
                            self.sham_link_state = None
                            self.sham_link_demand_circuit = None
                            self.sham_link_dc_bitless_lsa = None
                            self.sham_link_ifindex = None
                            self.sham_link_area = None
                            self.sham_link_cost = None
                            self.sham_link_transmission_delay = None
                            self.sham_link_hello_interval = None
                            self.sham_link_dead_interval = None
                            self.sham_link_wait_interval = None
                            self.sham_link_retransmission_interval = None
                            self.sham_link_next_hello = None
                            self.sham_link_passive = None
                            self.is_sham_link_ip_security_required = None
                            self.is_sham_link_ip_security_active = None
                            self.is_sham_link_authentication_enabled = None
                            self.virtual_link_authentication_spi = None
                            self.sham_link_authentication_transmit = None
                            self.is_sham_link_encryption_enabled = None
                            self.sham_link_encryption_spi = None
                            self.sham_link_encryption_transmitted = None
                            self.sham_link_encrypted_authentication_transmitted = None
                            self.sham_link_gr_enabled = None
                            self.sham_link_gr = None
                            self.sham_link_last_gr = None

                            self.sham_link_neighbor = Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor()
                            self.sham_link_neighbor.parent = self
                            self._children_name_map["sham_link_neighbor"] = "sham-link-neighbor"
                            self._segment_path = lambda: "sham-link-table"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable, [u'sham_link_neighbor_id', u'sham_link_source_address', u'sham_link_dest_address', u'sham_link_state', u'sham_link_demand_circuit', u'sham_link_dc_bitless_lsa', u'sham_link_ifindex', u'sham_link_area', u'sham_link_cost', u'sham_link_transmission_delay', u'sham_link_hello_interval', u'sham_link_dead_interval', u'sham_link_wait_interval', u'sham_link_retransmission_interval', u'sham_link_next_hello', u'sham_link_passive', u'is_sham_link_ip_security_required', u'is_sham_link_ip_security_active', u'is_sham_link_authentication_enabled', u'virtual_link_authentication_spi', u'sham_link_authentication_transmit', u'is_sham_link_encryption_enabled', u'sham_link_encryption_spi', u'sham_link_encryption_transmitted', u'sham_link_encrypted_authentication_transmitted', u'sham_link_gr_enabled', u'sham_link_gr', u'sham_link_last_gr'], name, value)


                        class ShamLinkNeighbor(Entity):
                            """
                            Neighbor information
                            
                            .. attribute:: sham_link_retransmission
                            
                            	Neighbor retransmission info
                            	**type**\:  :py:class:`ShamLinkRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission>`
                            
                            .. attribute:: sham_link_suppress_hello
                            
                            	If true Hellos suppressed
                            	**type**\: bool
                            
                            .. attribute:: sham_link_state
                            
                            	Adjacency state
                            	**type**\:  :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor, self).__init__()

                                self.yang_name = "sham-link-neighbor"
                                self.yang_parent_name = "sham-link-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("sham-link-retransmission", ("sham_link_retransmission", Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission))])
                                self._leafs = OrderedDict([
                                    ('sham_link_suppress_hello', (YLeaf(YType.boolean, 'sham-link-suppress-hello'), ['bool'])),
                                    ('sham_link_state', (YLeaf(YType.enumeration, 'sham-link-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3NeighborState', '')])),
                                ])
                                self.sham_link_suppress_hello = None
                                self.sham_link_state = None

                                self.sham_link_retransmission = Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission()
                                self.sham_link_retransmission.parent = self
                                self._children_name_map["sham_link_retransmission"] = "sham-link-retransmission"
                                self._segment_path = lambda: "sham-link-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor, [u'sham_link_suppress_hello', u'sham_link_state'], name, value)


                            class ShamLinkRetransmission(Entity):
                                """
                                Neighbor retransmission info
                                
                                .. attribute:: database_descriptor_retransmissions
                                
                                	Number of database descriptor retransmissions during last exchange
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_flood_index
                                
                                	Area scope LSA's flood index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_flood_index
                                
                                	AS scope LSA's flood index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_flood_index
                                
                                	Link flood index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_retransmissions
                                
                                	Number of neighbor retransmissions 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmissions
                                
                                	Number of retransmissions for this neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_first_flood
                                
                                	First flood item for area scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_first_flood_index
                                
                                	Index of the first flood item for area scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood
                                
                                	First flood item for AS scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood_index
                                
                                	Index for first flood item for AS scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood
                                
                                	Link first flood information 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood_index
                                
                                	Link first flood information index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood
                                
                                	Next flood item for area scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood_index
                                
                                	Index of next flood item for Area scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood
                                
                                	Next flood item for AS scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood_index
                                
                                	Index of next flood item for AS scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood
                                
                                	Link next flood information 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood_index
                                
                                	Link next flood information index 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_length
                                
                                	Number of LSAs sent in last retransmission
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_length
                                
                                	Maximum number of LSAs sent in a retransmission
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_time
                                
                                	Last retransmission scan time (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_time
                                
                                	Maximum retransmission scan time (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_retransmission_timer
                                
                                	Time until next LSA retransmission (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission, self).__init__()

                                    self.yang_name = "sham-link-retransmission"
                                    self.yang_parent_name = "sham-link-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('database_descriptor_retransmissions', (YLeaf(YType.uint32, 'database-descriptor-retransmissions'), ['int'])),
                                        ('area_flood_index', (YLeaf(YType.uint32, 'area-flood-index'), ['int'])),
                                        ('as_flood_index', (YLeaf(YType.uint32, 'as-flood-index'), ['int'])),
                                        ('link_flood_index', (YLeaf(YType.uint32, 'link-flood-index'), ['int'])),
                                        ('neighbor_retransmissions', (YLeaf(YType.uint32, 'neighbor-retransmissions'), ['int'])),
                                        ('retransmissions', (YLeaf(YType.uint32, 'retransmissions'), ['int'])),
                                        ('area_first_flood', (YLeaf(YType.uint32, 'area-first-flood'), ['int'])),
                                        ('area_first_flood_index', (YLeaf(YType.uint32, 'area-first-flood-index'), ['int'])),
                                        ('as_first_flood', (YLeaf(YType.uint32, 'as-first-flood'), ['int'])),
                                        ('as_first_flood_index', (YLeaf(YType.uint32, 'as-first-flood-index'), ['int'])),
                                        ('link_first_flood', (YLeaf(YType.uint32, 'link-first-flood'), ['int'])),
                                        ('link_first_flood_index', (YLeaf(YType.uint32, 'link-first-flood-index'), ['int'])),
                                        ('area_next_flood', (YLeaf(YType.uint32, 'area-next-flood'), ['int'])),
                                        ('area_next_flood_index', (YLeaf(YType.uint32, 'area-next-flood-index'), ['int'])),
                                        ('as_next_flood', (YLeaf(YType.uint32, 'as-next-flood'), ['int'])),
                                        ('as_next_flood_index', (YLeaf(YType.uint32, 'as-next-flood-index'), ['int'])),
                                        ('link_next_flood', (YLeaf(YType.uint32, 'link-next-flood'), ['int'])),
                                        ('link_next_flood_index', (YLeaf(YType.uint32, 'link-next-flood-index'), ['int'])),
                                        ('last_retransmission_length', (YLeaf(YType.uint32, 'last-retransmission-length'), ['int'])),
                                        ('maximum_retransmission_length', (YLeaf(YType.uint32, 'maximum-retransmission-length'), ['int'])),
                                        ('last_retransmission_time', (YLeaf(YType.uint32, 'last-retransmission-time'), ['int'])),
                                        ('maximum_retransmission_time', (YLeaf(YType.uint32, 'maximum-retransmission-time'), ['int'])),
                                        ('lsa_retransmission_timer', (YLeaf(YType.uint32, 'lsa-retransmission-timer'), ['int'])),
                                    ])
                                    self.database_descriptor_retransmissions = None
                                    self.area_flood_index = None
                                    self.as_flood_index = None
                                    self.link_flood_index = None
                                    self.neighbor_retransmissions = None
                                    self.retransmissions = None
                                    self.area_first_flood = None
                                    self.area_first_flood_index = None
                                    self.as_first_flood = None
                                    self.as_first_flood_index = None
                                    self.link_first_flood = None
                                    self.link_first_flood_index = None
                                    self.area_next_flood = None
                                    self.area_next_flood_index = None
                                    self.as_next_flood = None
                                    self.as_next_flood_index = None
                                    self.link_next_flood = None
                                    self.link_next_flood_index = None
                                    self.last_retransmission_length = None
                                    self.maximum_retransmission_length = None
                                    self.last_retransmission_time = None
                                    self.maximum_retransmission_time = None
                                    self.lsa_retransmission_timer = None
                                    self._segment_path = lambda: "sham-link-retransmission"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission, [u'database_descriptor_retransmissions', u'area_flood_index', u'as_flood_index', u'link_flood_index', u'neighbor_retransmissions', u'retransmissions', u'area_first_flood', u'area_first_flood_index', u'as_first_flood', u'as_first_flood_index', u'link_first_flood', u'link_first_flood_index', u'area_next_flood', u'area_next_flood_index', u'as_next_flood', u'as_next_flood_index', u'link_next_flood', u'link_next_flood_index', u'last_retransmission_length', u'maximum_retransmission_length', u'last_retransmission_time', u'maximum_retransmission_time', u'lsa_retransmission_timer'], name, value)


                    class AreaInformations(Entity):
                        """
                        OSPFv3 area information table
                        
                        .. attribute:: area_information
                        
                        	OSPFv3 area information
                        	**type**\: list of  		 :py:class:`AreaInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations, self).__init__()

                            self.yang_name = "area-informations"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area-information", ("area_information", Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation))])
                            self._leafs = OrderedDict()

                            self.area_information = YList(self)
                            self._segment_path = lambda: "area-informations"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations, [], name, value)


                        class AreaInformation(Entity):
                            """
                            OSPFv3 area information
                            
                            .. attribute:: area_id  (key)
                            
                            	Area ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_backbone_area_active
                            
                            	If true, Backbone area is active
                            	**type**\: bool
                            
                            .. attribute:: area_interfaces
                            
                            	Number of interfaces in the area
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: is_area_stubbed
                            
                            	If true, stub area
                            	**type**\: bool
                            
                            .. attribute:: is_area_total_stubbed
                            
                            	If true, totally stubby area
                            	**type**\: bool
                            
                            .. attribute:: stub_default_cost
                            
                            	Default cost for Stub or NSSA area
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: is_area_nssa
                            
                            	If true, area is a NSSA
                            	**type**\: bool
                            
                            .. attribute:: nssa_no_redistribution
                            
                            	If true, No redistribution into this NSSA area
                            	**type**\: bool
                            
                            .. attribute:: is_nssa_translated
                            
                            	If true, perform 7/5 translation
                            	**type**\: bool
                            
                            .. attribute:: is_nssa_translated_always
                            
                            	If true, perform 7/5 translation always
                            	**type**\: bool
                            
                            .. attribute:: is_nssa_default
                            
                            	If true, generate NSSA default route
                            	**type**\: bool
                            
                            .. attribute:: is_rrr_enabled
                            
                            	If true, RRR is enabled
                            	**type**\: bool
                            
                            .. attribute:: sp_fs
                            
                            	Number of SPF calculations run
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_opaque_lsas
                            
                            	Number of opaque LSAs in the area
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_opaque_lsa_checksum
                            
                            	Sum of opaque LSA checksums
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_dc_bitless_ls_as
                            
                            	Number of LSA with demand circuit bit not set
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: indication_ls_as
                            
                            	Number of indication LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: do_not_age_ls_as
                            
                            	Number of do not age LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: flood_list_length
                            
                            	Number of LSAs which need to be flooded
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_lfa_interface_count
                            
                            	Number of LFA enabled interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_per_prefix_lfa_interface_count
                            
                            	Number of Per Prefix LFA enabled interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_lfa_revision
                            
                            	Area LFA revision
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_range
                            
                            	List of ranges to summarize
                            	**type**\: list of  		 :py:class:`AreaRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation.AreaRange>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation, self).__init__()

                                self.yang_name = "area-information"
                                self.yang_parent_name = "area-informations"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['area_id']
                                self._child_classes = OrderedDict([("area-range", ("area_range", Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation.AreaRange))])
                                self._leafs = OrderedDict([
                                    ('area_id', (YLeaf(YType.uint32, 'area-id'), ['int'])),
                                    ('is_backbone_area_active', (YLeaf(YType.boolean, 'is-backbone-area-active'), ['bool'])),
                                    ('area_interfaces', (YLeaf(YType.uint16, 'area-interfaces'), ['int'])),
                                    ('is_area_stubbed', (YLeaf(YType.boolean, 'is-area-stubbed'), ['bool'])),
                                    ('is_area_total_stubbed', (YLeaf(YType.boolean, 'is-area-total-stubbed'), ['bool'])),
                                    ('stub_default_cost', (YLeaf(YType.uint16, 'stub-default-cost'), ['int'])),
                                    ('is_area_nssa', (YLeaf(YType.boolean, 'is-area-nssa'), ['bool'])),
                                    ('nssa_no_redistribution', (YLeaf(YType.boolean, 'nssa-no-redistribution'), ['bool'])),
                                    ('is_nssa_translated', (YLeaf(YType.boolean, 'is-nssa-translated'), ['bool'])),
                                    ('is_nssa_translated_always', (YLeaf(YType.boolean, 'is-nssa-translated-always'), ['bool'])),
                                    ('is_nssa_default', (YLeaf(YType.boolean, 'is-nssa-default'), ['bool'])),
                                    ('is_rrr_enabled', (YLeaf(YType.boolean, 'is-rrr-enabled'), ['bool'])),
                                    ('sp_fs', (YLeaf(YType.uint32, 'sp-fs'), ['int'])),
                                    ('area_opaque_lsas', (YLeaf(YType.uint32, 'area-opaque-lsas'), ['int'])),
                                    ('area_opaque_lsa_checksum', (YLeaf(YType.uint32, 'area-opaque-lsa-checksum'), ['int'])),
                                    ('area_dc_bitless_ls_as', (YLeaf(YType.uint32, 'area-dc-bitless-ls-as'), ['int'])),
                                    ('indication_ls_as', (YLeaf(YType.uint32, 'indication-ls-as'), ['int'])),
                                    ('do_not_age_ls_as', (YLeaf(YType.uint32, 'do-not-age-ls-as'), ['int'])),
                                    ('flood_list_length', (YLeaf(YType.uint32, 'flood-list-length'), ['int'])),
                                    ('area_lfa_interface_count', (YLeaf(YType.uint32, 'area-lfa-interface-count'), ['int'])),
                                    ('area_per_prefix_lfa_interface_count', (YLeaf(YType.uint32, 'area-per-prefix-lfa-interface-count'), ['int'])),
                                    ('area_lfa_revision', (YLeaf(YType.uint32, 'area-lfa-revision'), ['int'])),
                                ])
                                self.area_id = None
                                self.is_backbone_area_active = None
                                self.area_interfaces = None
                                self.is_area_stubbed = None
                                self.is_area_total_stubbed = None
                                self.stub_default_cost = None
                                self.is_area_nssa = None
                                self.nssa_no_redistribution = None
                                self.is_nssa_translated = None
                                self.is_nssa_translated_always = None
                                self.is_nssa_default = None
                                self.is_rrr_enabled = None
                                self.sp_fs = None
                                self.area_opaque_lsas = None
                                self.area_opaque_lsa_checksum = None
                                self.area_dc_bitless_ls_as = None
                                self.indication_ls_as = None
                                self.do_not_age_ls_as = None
                                self.flood_list_length = None
                                self.area_lfa_interface_count = None
                                self.area_per_prefix_lfa_interface_count = None
                                self.area_lfa_revision = None

                                self.area_range = YList(self)
                                self._segment_path = lambda: "area-information" + "[area-id='" + str(self.area_id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation, ['area_id', u'is_backbone_area_active', u'area_interfaces', u'is_area_stubbed', u'is_area_total_stubbed', u'stub_default_cost', u'is_area_nssa', u'nssa_no_redistribution', u'is_nssa_translated', u'is_nssa_translated_always', u'is_nssa_default', u'is_rrr_enabled', u'sp_fs', u'area_opaque_lsas', u'area_opaque_lsa_checksum', u'area_dc_bitless_ls_as', u'indication_ls_as', u'do_not_age_ls_as', u'flood_list_length', u'area_lfa_interface_count', u'area_per_prefix_lfa_interface_count', u'area_lfa_revision'], name, value)


                            class AreaRange(Entity):
                                """
                                List of ranges to summarize
                                
                                .. attribute:: range_prefix
                                
                                	IP prefix for summarization
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: range_prefix_length
                                
                                	IP prefix length for summarization
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: net_cost
                                
                                	Net cost 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status
                                
                                	Area range status 
                                	**type**\:  :py:class:`Ospfv3AreaRangeStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3AreaRangeStatus>`
                                
                                .. attribute:: is_cost_configured
                                
                                	If true, cost is configured 
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation.AreaRange, self).__init__()

                                    self.yang_name = "area-range"
                                    self.yang_parent_name = "area-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('range_prefix', (YLeaf(YType.str, 'range-prefix'), ['str'])),
                                        ('range_prefix_length', (YLeaf(YType.uint32, 'range-prefix-length'), ['int'])),
                                        ('net_cost', (YLeaf(YType.uint32, 'net-cost'), ['int'])),
                                        ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3AreaRangeStatus', '')])),
                                        ('is_cost_configured', (YLeaf(YType.boolean, 'is-cost-configured'), ['bool'])),
                                    ])
                                    self.range_prefix = None
                                    self.range_prefix_length = None
                                    self.net_cost = None
                                    self.status = None
                                    self.is_cost_configured = None
                                    self._segment_path = lambda: "area-range"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.AreaInformations.AreaInformation.AreaRange, [u'range_prefix', u'range_prefix_length', u'net_cost', u'status', u'is_cost_configured'], name, value)


                    class DatabaseTable(Entity):
                        """
                        OSPF Link State Database
                        
                        .. attribute:: lsa_table
                        
                        	Database LSA information
                        	**type**\:  :py:class:`LsaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable>`
                        
                        .. attribute:: lsa_internal_table
                        
                        	Database LSA information
                        	**type**\:  :py:class:`LsaInternalTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable, self).__init__()

                            self.yang_name = "database-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lsa-table", ("lsa_table", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable)), ("lsa-internal-table", ("lsa_internal_table", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable))])
                            self._leafs = OrderedDict()

                            self.lsa_table = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable()
                            self.lsa_table.parent = self
                            self._children_name_map["lsa_table"] = "lsa-table"

                            self.lsa_internal_table = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable()
                            self.lsa_internal_table.parent = self
                            self._children_name_map["lsa_internal_table"] = "lsa-internal-table"
                            self._segment_path = lambda: "database-table"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable, [], name, value)


                        class LsaTable(Entity):
                            """
                            Database LSA information
                            
                            .. attribute:: lsa
                            
                            	Database LSA information
                            	**type**\: list of  		 :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable, self).__init__()

                                self.yang_name = "lsa-table"
                                self.yang_parent_name = "database-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lsa", ("lsa", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa))])
                                self._leafs = OrderedDict()

                                self.lsa = YList(self)
                                self._segment_path = lambda: "lsa-table"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable, [], name, value)


                            class Lsa(Entity):
                                """
                                Database LSA information
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ls_type
                                
                                	LSA type
                                	**type**\:  :py:class:`Ospfv3Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa>`
                                
                                .. attribute:: advertising_router
                                
                                	Advertising Router ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ls_id
                                
                                	Link state ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name
                                
                                	InterfaceName
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: lsa_info
                                
                                	Summary of all LSAs or LSA specific information 
                                	**type**\:  :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa, self).__init__()

                                    self.yang_name = "lsa"
                                    self.yang_parent_name = "lsa-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lsa-info", ("lsa_info", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo))])
                                    self._leafs = OrderedDict([
                                        ('area_id', (YLeaf(YType.uint32, 'area-id'), ['int'])),
                                        ('ls_type', (YLeaf(YType.enumeration, 'ls-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa', '')])),
                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ])
                                    self.area_id = None
                                    self.ls_type = None
                                    self.advertising_router = None
                                    self.ls_id = None
                                    self.interface_name = None

                                    self.lsa_info = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo()
                                    self.lsa_info.parent = self
                                    self._children_name_map["lsa_info"] = "lsa-info"
                                    self._segment_path = lambda: "lsa"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa, ['area_id', 'ls_type', 'advertising_router', 'ls_id', 'interface_name'], name, value)


                                class LsaInfo(Entity):
                                    """
                                    Summary of all LSAs or LSA specific information 
                                    
                                    .. attribute:: lsa_summary_info
                                    
                                    	Summary information of LSAs
                                    	**type**\:  :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                    
                                    .. attribute:: router_lsa_type
                                    
                                    	Router LSA
                                    	**type**\:  :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType>`
                                    
                                    .. attribute:: network_lsa_type
                                    
                                    	Network LSA
                                    	**type**\:  :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType>`
                                    
                                    .. attribute:: inter_area_prefix_lsa_type
                                    
                                    	Inter Area Prefix LSA
                                    	**type**\:  :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                    
                                    .. attribute:: inter_area_router_lsa_type
                                    
                                    	Inter Area Router LSA
                                    	**type**\:  :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                    
                                    .. attribute:: external_lsa_type
                                    
                                    	External LSA
                                    	**type**\:  :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType>`
                                    
                                    .. attribute:: nssalsa_type
                                    
                                    	NSSA External LSA
                                    	**type**\:  :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType>`
                                    
                                    .. attribute:: link_lsa_type
                                    
                                    	Link LSA
                                    	**type**\:  :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType>`
                                    
                                    .. attribute:: intra_area_prefix_lsa_type
                                    
                                    	Intra Area Prefix LSA
                                    	**type**\:  :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                    
                                    .. attribute:: grace_lsa
                                    
                                    	Grace LSA
                                    	**type**\:  :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa>`
                                    
                                    .. attribute:: unknown_link_lsa_type
                                    
                                    	Unknown Link Scope LSA
                                    	**type**\:  :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                    
                                    .. attribute:: unknown_area_lsa_type
                                    
                                    	Unknown\-Area scope LSA
                                    	**type**\:  :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                    
                                    .. attribute:: unknown_aslsa_type
                                    
                                    	Unknown\-AS scope LSA
                                    	**type**\:  :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType>`
                                    
                                    .. attribute:: unknown_lsa_type
                                    
                                    	Unknown LSA
                                    	**type**\:  :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType>`
                                    
                                    .. attribute:: lsa_info_type
                                    
                                    	LSAInfoType
                                    	**type**\:  :py:class:`Ospfv3LsaInfoTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypes>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo, self).__init__()

                                        self.yang_name = "lsa-info"
                                        self.yang_parent_name = "lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-summary-info", ("lsa_summary_info", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo)), ("router-lsa-type", ("router_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType)), ("network-lsa-type", ("network_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType)), ("inter-area-prefix-lsa-type", ("inter_area_prefix_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType)), ("inter-area-router-lsa-type", ("inter_area_router_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType)), ("external-lsa-type", ("external_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType)), ("nssalsa-type", ("nssalsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType)), ("link-lsa-type", ("link_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType)), ("intra-area-prefix-lsa-type", ("intra_area_prefix_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType)), ("grace-lsa", ("grace_lsa", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa)), ("unknown-link-lsa-type", ("unknown_link_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType)), ("unknown-area-lsa-type", ("unknown_area_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType)), ("unknown-aslsa-type", ("unknown_aslsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType)), ("unknown-lsa-type", ("unknown_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType))])
                                        self._leafs = OrderedDict([
                                            ('lsa_info_type', (YLeaf(YType.enumeration, 'lsa-info-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3LsaInfoTypes', '')])),
                                        ])
                                        self.lsa_info_type = None

                                        self.lsa_summary_info = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo()
                                        self.lsa_summary_info.parent = self
                                        self._children_name_map["lsa_summary_info"] = "lsa-summary-info"

                                        self.router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType()
                                        self.router_lsa_type.parent = self
                                        self._children_name_map["router_lsa_type"] = "router-lsa-type"

                                        self.network_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType()
                                        self.network_lsa_type.parent = self
                                        self._children_name_map["network_lsa_type"] = "network-lsa-type"

                                        self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                        self.inter_area_prefix_lsa_type.parent = self
                                        self._children_name_map["inter_area_prefix_lsa_type"] = "inter-area-prefix-lsa-type"

                                        self.inter_area_router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                        self.inter_area_router_lsa_type.parent = self
                                        self._children_name_map["inter_area_router_lsa_type"] = "inter-area-router-lsa-type"

                                        self.external_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType()
                                        self.external_lsa_type.parent = self
                                        self._children_name_map["external_lsa_type"] = "external-lsa-type"

                                        self.nssalsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType()
                                        self.nssalsa_type.parent = self
                                        self._children_name_map["nssalsa_type"] = "nssalsa-type"

                                        self.link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType()
                                        self.link_lsa_type.parent = self
                                        self._children_name_map["link_lsa_type"] = "link-lsa-type"

                                        self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                        self.intra_area_prefix_lsa_type.parent = self
                                        self._children_name_map["intra_area_prefix_lsa_type"] = "intra-area-prefix-lsa-type"

                                        self.grace_lsa = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa()
                                        self.grace_lsa.parent = self
                                        self._children_name_map["grace_lsa"] = "grace-lsa"

                                        self.unknown_link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                        self.unknown_link_lsa_type.parent = self
                                        self._children_name_map["unknown_link_lsa_type"] = "unknown-link-lsa-type"

                                        self.unknown_area_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                        self.unknown_area_lsa_type.parent = self
                                        self._children_name_map["unknown_area_lsa_type"] = "unknown-area-lsa-type"

                                        self.unknown_aslsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType()
                                        self.unknown_aslsa_type.parent = self
                                        self._children_name_map["unknown_aslsa_type"] = "unknown-aslsa-type"

                                        self.unknown_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType()
                                        self.unknown_lsa_type.parent = self
                                        self._children_name_map["unknown_lsa_type"] = "unknown-lsa-type"
                                        self._segment_path = lambda: "lsa-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo, [u'lsa_info_type'], name, value)


                                    class LsaSummaryInfo(Entity):
                                        """
                                        Summary information of LSAs
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                        
                                        .. attribute:: links
                                        
                                        	Number of links
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: router_la_bits
                                        
                                        	Router LA bits 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: reference_type
                                        
                                        	Reference type 
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: reference_lsa_id
                                        
                                        	Reference LSA ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_router_id
                                        
                                        	LSA router ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 address Prefix 
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\: bool
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\: bool
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Sham link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo, self).__init__()

                                            self.yang_name = "lsa-summary-info"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('links', (YLeaf(YType.uint16, 'links'), ['int'])),
                                                ('router_la_bits', (YLeaf(YType.uint8, 'router-la-bits'), ['int'])),
                                                ('reference_type', (YLeaf(YType.uint16, 'reference-type'), ['int'])),
                                                ('reference_lsa_id', (YLeaf(YType.uint32, 'reference-lsa-id'), ['int'])),
                                                ('lsa_router_id', (YLeaf(YType.uint32, 'lsa-router-id'), ['int'])),
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                            ])
                                            self.links = None
                                            self.router_la_bits = None
                                            self.reference_type = None
                                            self.reference_lsa_id = None
                                            self.lsa_router_id = None
                                            self.prefix = None
                                            self.prefix_length = None
                                            self.interface_name = None
                                            self.is_virtual_link = None
                                            self.virtual_link_id = None
                                            self.is_sham_link = None
                                            self.sham_link_id = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "lsa-summary-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo, [u'links', u'router_la_bits', u'reference_type', u'reference_lsa_id', u'lsa_router_id', u'prefix', u'prefix_length', u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "lsa-summary-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "lsa-summary-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class RouterLsaType(Entity):
                                        """
                                        Router LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                        
                                        .. attribute:: rpf_path
                                        
                                        	Router LSA Reverse\-Path Forwarding information 
                                        	**type**\:  :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                        
                                        .. attribute:: router_la_bits
                                        
                                        	Router LA bits 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: link
                                        
                                        	List of links in this LSA
                                        	**type**\: list of  		 :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType, self).__init__()

                                            self.yang_name = "router-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail)), ("rpf-path", ("rpf_path", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath)), ("link", ("link", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link))])
                                            self._leafs = OrderedDict([
                                                ('router_la_bits', (YLeaf(YType.uint8, 'router-la-bits'), ['int'])),
                                            ])
                                            self.router_la_bits = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"

                                            self.rpf_path = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                            self.rpf_path.parent = self
                                            self._children_name_map["rpf_path"] = "rpf-path"

                                            self.link = YList(self)
                                            self._segment_path = lambda: "router-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType, [u'router_la_bits'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class RpfPath(Entity):
                                            """
                                            Router LSA Reverse\-Path Forwarding information 
                                            
                                            .. attribute:: rpf_multicast_next_hop
                                            
                                            	RPF multicast next hop 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_name
                                            
                                            	RPF multicast IDB 
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath, self).__init__()

                                                self.yang_name = "rpf-path"
                                                self.yang_parent_name = "router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('rpf_multicast_next_hop', (YLeaf(YType.uint32, 'rpf-multicast-next-hop'), ['int'])),
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ])
                                                self.rpf_multicast_next_hop = None
                                                self.interface_name = None
                                                self._segment_path = lambda: "rpf-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath, [u'rpf_multicast_next_hop', u'interface_name'], name, value)


                                        class Link(Entity):
                                            """
                                            List of links in this LSA
                                            
                                            .. attribute:: link_type
                                            
                                            	Type of link
                                            	**type**\:  :py:class:`Ospfv3Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Link>`
                                            
                                            .. attribute:: link_metric
                                            
                                            	LSA link metric 
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: link_interface_id
                                            
                                            	LSA link interface ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_neighbor_interface_id
                                            
                                            	LSA link neighbor interface ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_neighbor_router_id
                                            
                                            	LSA link neigbhor router id 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link, self).__init__()

                                                self.yang_name = "link"
                                                self.yang_parent_name = "router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Link', '')])),
                                                    ('link_metric', (YLeaf(YType.uint16, 'link-metric'), ['int'])),
                                                    ('link_interface_id', (YLeaf(YType.uint32, 'link-interface-id'), ['int'])),
                                                    ('link_neighbor_interface_id', (YLeaf(YType.uint32, 'link-neighbor-interface-id'), ['int'])),
                                                    ('link_neighbor_router_id', (YLeaf(YType.uint32, 'link-neighbor-router-id'), ['int'])),
                                                ])
                                                self.link_type = None
                                                self.link_metric = None
                                                self.link_interface_id = None
                                                self.link_neighbor_interface_id = None
                                                self.link_neighbor_router_id = None
                                                self._segment_path = lambda: "link"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link, [u'link_type', u'link_metric', u'link_interface_id', u'link_neighbor_interface_id', u'link_neighbor_router_id'], name, value)


                                    class NetworkLsaType(Entity):
                                        """
                                        Network LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                        
                                        .. attribute:: neighbor_router
                                        
                                        	Neighbor router list
                                        	**type**\: list of str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType, self).__init__()

                                            self.yang_name = "network-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('neighbor_router', (YLeafList(YType.str, 'neighbor-router'), ['str'])),
                                            ])
                                            self.neighbor_router = []

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "network-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType, [u'neighbor_router'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "network-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "network-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class InterAreaPrefixLsaType(Entity):
                                        """
                                        Inter Area Prefix LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA Information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                        
                                        .. attribute:: prefix
                                        
                                        	LSA address prefix 
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType, self).__init__()

                                            self.yang_name = "inter-area-prefix-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                            ])
                                            self.prefix = None
                                            self.prefix_length = None
                                            self.priority = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "inter-area-prefix-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType, [u'prefix', u'prefix_length', u'priority'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class InterAreaRouterLsaType(Entity):
                                        """
                                        Inter Area Router LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_router_id
                                        
                                        	LSA router ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType, self).__init__()

                                            self.yang_name = "inter-area-router-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('lsa_router_id', (YLeaf(YType.uint32, 'lsa-router-id'), ['int'])),
                                            ])
                                            self.lsa_router_id = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "inter-area-router-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType, [u'lsa_router_id'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "inter-area-router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "inter-area-router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class ExternalLsaType(Entity):
                                        """
                                        External LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA Information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                        
                                        .. attribute:: prefix
                                        
                                        	IPV6 address prefix 
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: metric_type
                                        
                                        	Metric type 
                                        	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                        
                                        .. attribute:: tos_cost
                                        
                                        	Type of service cost metric 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_forwarding_address_set
                                        
                                        	If true, forwarding address is set 
                                        	**type**\: bool
                                        
                                        .. attribute:: forwarding_address
                                        
                                        	Forwarding Address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: external_tag
                                        
                                        	Route Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType, self).__init__()

                                            self.yang_name = "external-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                                ('tos_cost', (YLeaf(YType.uint32, 'tos-cost'), ['int'])),
                                                ('is_forwarding_address_set', (YLeaf(YType.boolean, 'is-forwarding-address-set'), ['bool'])),
                                                ('forwarding_address', (YLeaf(YType.str, 'forwarding-address'), ['str'])),
                                                ('external_tag', (YLeaf(YType.uint32, 'external-tag'), ['int'])),
                                                ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                            ])
                                            self.prefix = None
                                            self.prefix_length = None
                                            self.metric_type = None
                                            self.tos_cost = None
                                            self.is_forwarding_address_set = None
                                            self.forwarding_address = None
                                            self.external_tag = None
                                            self.priority = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "external-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType, [u'prefix', u'prefix_length', u'metric_type', u'tos_cost', u'is_forwarding_address_set', u'forwarding_address', u'external_tag', u'priority'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "external-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "external-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class NssalsaType(Entity):
                                        """
                                        NSSA External LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA Information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                        
                                        .. attribute:: prefix
                                        
                                        	IPV6 address prefix 
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: metric_type
                                        
                                        	Metric type 
                                        	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                        
                                        .. attribute:: tos_cost
                                        
                                        	Type of service cost metric 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_forwarding_address_set
                                        
                                        	If true, forwarding address is set 
                                        	**type**\: bool
                                        
                                        .. attribute:: forwarding_address
                                        
                                        	Forwarding Address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: external_tag
                                        
                                        	Route Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType, self).__init__()

                                            self.yang_name = "nssalsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                                ('tos_cost', (YLeaf(YType.uint32, 'tos-cost'), ['int'])),
                                                ('is_forwarding_address_set', (YLeaf(YType.boolean, 'is-forwarding-address-set'), ['bool'])),
                                                ('forwarding_address', (YLeaf(YType.str, 'forwarding-address'), ['str'])),
                                                ('external_tag', (YLeaf(YType.uint32, 'external-tag'), ['int'])),
                                                ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                            ])
                                            self.prefix = None
                                            self.prefix_length = None
                                            self.metric_type = None
                                            self.tos_cost = None
                                            self.is_forwarding_address_set = None
                                            self.forwarding_address = None
                                            self.external_tag = None
                                            self.priority = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "nssalsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType, [u'prefix', u'prefix_length', u'metric_type', u'tos_cost', u'is_forwarding_address_set', u'forwarding_address', u'external_tag', u'priority'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "nssalsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "nssalsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class LinkLsaType(Entity):
                                        """
                                        Link LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface handle
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link
                                        	**type**\: bool
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link
                                        	**type**\: bool
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Sham link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_link_local
                                        
                                        	LSA link local 
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: router_priority
                                        
                                        	Router priority 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\: list of  		 :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType, self).__init__()

                                            self.yang_name = "link-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail)), ("prefix", ("prefix", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                ('lsa_link_local', (YLeaf(YType.str, 'lsa-link-local'), ['str'])),
                                                ('router_priority', (YLeaf(YType.uint8, 'router-priority'), ['int'])),
                                            ])
                                            self.interface_name = None
                                            self.is_virtual_link = None
                                            self.virtual_link_id = None
                                            self.is_sham_link = None
                                            self.sham_link_id = None
                                            self.lsa_link_local = None
                                            self.router_priority = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"

                                            self.prefix = YList(self)
                                            self._segment_path = lambda: "link-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id', u'lsa_link_local', u'router_priority'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class Prefix(Entity):
                                            """
                                            OSPFv3 prefix 
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ospfv3_prefix_length
                                            
                                            	OSPFv3 prefix length 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ospfv3_prefix_options
                                            
                                            	OSPFv3 prefix options 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ospfv3_prefix_metric
                                            
                                            	OSPFv3 prefix metric 
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('ospfv3_prefix_length', (YLeaf(YType.uint8, 'ospfv3-prefix-length'), ['int'])),
                                                    ('ospfv3_prefix_options', (YLeaf(YType.uint8, 'ospfv3-prefix-options'), ['int'])),
                                                    ('ospfv3_prefix_metric', (YLeaf(YType.uint16, 'ospfv3-prefix-metric'), ['int'])),
                                                    ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                ])
                                                self.prefix = None
                                                self.ospfv3_prefix_length = None
                                                self.ospfv3_prefix_options = None
                                                self.ospfv3_prefix_metric = None
                                                self.priority = None
                                                self._segment_path = lambda: "prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix, [u'prefix', u'ospfv3_prefix_length', u'ospfv3_prefix_options', u'ospfv3_prefix_metric', u'priority'], name, value)


                                    class IntraAreaPrefixLsaType(Entity):
                                        """
                                        Intra Area Prefix LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                        
                                        .. attribute:: reference_type
                                        
                                        	Reference type 
                                        	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                        
                                        .. attribute:: reference_lsa_id
                                        
                                        	Reference LSA ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reference_advertised_router
                                        
                                        	Reference advertised router 
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\: list of  		 :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, self).__init__()

                                            self.yang_name = "intra-area-prefix-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail)), ("prefix", ("prefix", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix))])
                                            self._leafs = OrderedDict([
                                                ('reference_type', (YLeaf(YType.enumeration, 'reference-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                                ('reference_lsa_id', (YLeaf(YType.uint32, 'reference-lsa-id'), ['int'])),
                                                ('reference_advertised_router', (YLeaf(YType.str, 'reference-advertised-router'), ['str'])),
                                            ])
                                            self.reference_type = None
                                            self.reference_lsa_id = None
                                            self.reference_advertised_router = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"

                                            self.prefix = YList(self)
                                            self._segment_path = lambda: "intra-area-prefix-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, [u'reference_type', u'reference_lsa_id', u'reference_advertised_router'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class Prefix(Entity):
                                            """
                                            OSPFv3 prefix 
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ospfv3_prefix_length
                                            
                                            	OSPFv3 prefix length 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ospfv3_prefix_options
                                            
                                            	OSPFv3 prefix options 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ospfv3_prefix_metric
                                            
                                            	OSPFv3 prefix metric 
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('ospfv3_prefix_length', (YLeaf(YType.uint8, 'ospfv3-prefix-length'), ['int'])),
                                                    ('ospfv3_prefix_options', (YLeaf(YType.uint8, 'ospfv3-prefix-options'), ['int'])),
                                                    ('ospfv3_prefix_metric', (YLeaf(YType.uint16, 'ospfv3-prefix-metric'), ['int'])),
                                                    ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                ])
                                                self.prefix = None
                                                self.ospfv3_prefix_length = None
                                                self.ospfv3_prefix_options = None
                                                self.ospfv3_prefix_metric = None
                                                self.priority = None
                                                self._segment_path = lambda: "prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, [u'prefix', u'ospfv3_prefix_length', u'ospfv3_prefix_options', u'ospfv3_prefix_metric', u'priority'], name, value)


                                    class GraceLsa(Entity):
                                        """
                                        Grace LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface handle
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link
                                        	**type**\: bool
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link
                                        	**type**\: bool
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Sham link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: grace_period
                                        
                                        	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: grace_reason
                                        
                                        	Reason for router restart
                                        	**type**\:  :py:class:`Ospfv3GracefulRestartReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReason>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa, self).__init__()

                                            self.yang_name = "grace-lsa"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                ('grace_period', (YLeaf(YType.uint32, 'grace-period'), ['int'])),
                                                ('grace_reason', (YLeaf(YType.enumeration, 'grace-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3GracefulRestartReason', '')])),
                                            ])
                                            self.interface_name = None
                                            self.is_virtual_link = None
                                            self.virtual_link_id = None
                                            self.is_sham_link = None
                                            self.sham_link_id = None
                                            self.grace_period = None
                                            self.grace_reason = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "grace-lsa"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id', u'grace_period', u'grace_reason'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "grace-lsa"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "grace-lsa"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class UnknownLinkLsaType(Entity):
                                        """
                                        Unknown Link Scope LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\: bool
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\: bool
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType, self).__init__()

                                            self.yang_name = "unknown-link-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                            ])
                                            self.interface_name = None
                                            self.is_virtual_link = None
                                            self.virtual_link_id = None
                                            self.is_sham_link = None
                                            self.sham_link_id = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "unknown-link-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "unknown-link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "unknown-link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class UnknownAreaLsaType(Entity):
                                        """
                                        Unknown\-Area scope LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\: bool
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\: bool
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType, self).__init__()

                                            self.yang_name = "unknown-area-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                            ])
                                            self.interface_name = None
                                            self.is_virtual_link = None
                                            self.virtual_link_id = None
                                            self.is_sham_link = None
                                            self.sham_link_id = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "unknown-area-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "unknown-area-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "unknown-area-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class UnknownAslsaType(Entity):
                                        """
                                        Unknown\-AS scope LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\: bool
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\: bool
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType, self).__init__()

                                            self.yang_name = "unknown-aslsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                            ])
                                            self.interface_name = None
                                            self.is_virtual_link = None
                                            self.virtual_link_id = None
                                            self.is_sham_link = None
                                            self.sham_link_id = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "unknown-aslsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "unknown-aslsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "unknown-aslsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class UnknownLsaType(Entity):
                                        """
                                        Unknown LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\: bool
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\: bool
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType, self).__init__()

                                            self.yang_name = "unknown-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                            ])
                                            self.interface_name = None
                                            self.is_virtual_link = None
                                            self.virtual_link_id = None
                                            self.is_sham_link = None
                                            self.sham_link_id = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "unknown-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "unknown-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "unknown-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                        class LsaInternalTable(Entity):
                            """
                            Database LSA information
                            
                            .. attribute:: lsa
                            
                            	Database LSA information
                            	**type**\: list of  		 :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable, self).__init__()

                                self.yang_name = "lsa-internal-table"
                                self.yang_parent_name = "database-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lsa", ("lsa", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa))])
                                self._leafs = OrderedDict()

                                self.lsa = YList(self)
                                self._segment_path = lambda: "lsa-internal-table"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable, [], name, value)


                            class Lsa(Entity):
                                """
                                Database LSA information
                                
                                .. attribute:: area_id
                                
                                	Area ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ls_type
                                
                                	LSA type
                                	**type**\:  :py:class:`Ospfv3Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa>`
                                
                                .. attribute:: advertising_router
                                
                                	Advertising Router ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ls_id
                                
                                	Link state ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name
                                
                                	InterfaceName
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: lsa_info
                                
                                	Summary of all LSAs or LSA specific information 
                                	**type**\:  :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa, self).__init__()

                                    self.yang_name = "lsa"
                                    self.yang_parent_name = "lsa-internal-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lsa-info", ("lsa_info", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo))])
                                    self._leafs = OrderedDict([
                                        ('area_id', (YLeaf(YType.uint32, 'area-id'), ['int'])),
                                        ('ls_type', (YLeaf(YType.enumeration, 'ls-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa', '')])),
                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ])
                                    self.area_id = None
                                    self.ls_type = None
                                    self.advertising_router = None
                                    self.ls_id = None
                                    self.interface_name = None

                                    self.lsa_info = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo()
                                    self.lsa_info.parent = self
                                    self._children_name_map["lsa_info"] = "lsa-info"
                                    self._segment_path = lambda: "lsa"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa, ['area_id', 'ls_type', 'advertising_router', 'ls_id', 'interface_name'], name, value)


                                class LsaInfo(Entity):
                                    """
                                    Summary of all LSAs or LSA specific information 
                                    
                                    .. attribute:: lsa_summary_info
                                    
                                    	Summary information of LSAs
                                    	**type**\:  :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                    
                                    .. attribute:: router_lsa_type
                                    
                                    	Router LSA
                                    	**type**\:  :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType>`
                                    
                                    .. attribute:: network_lsa_type
                                    
                                    	Network LSA
                                    	**type**\:  :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType>`
                                    
                                    .. attribute:: inter_area_prefix_lsa_type
                                    
                                    	Inter Area Prefix LSA
                                    	**type**\:  :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                    
                                    .. attribute:: inter_area_router_lsa_type
                                    
                                    	Inter Area Router LSA
                                    	**type**\:  :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                    
                                    .. attribute:: external_lsa_type
                                    
                                    	External LSA
                                    	**type**\:  :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType>`
                                    
                                    .. attribute:: nssalsa_type
                                    
                                    	NSSA External LSA
                                    	**type**\:  :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType>`
                                    
                                    .. attribute:: link_lsa_type
                                    
                                    	Link LSA
                                    	**type**\:  :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType>`
                                    
                                    .. attribute:: intra_area_prefix_lsa_type
                                    
                                    	Intra Area Prefix LSA
                                    	**type**\:  :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                    
                                    .. attribute:: grace_lsa
                                    
                                    	Grace LSA
                                    	**type**\:  :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa>`
                                    
                                    .. attribute:: unknown_link_lsa_type
                                    
                                    	Unknown Link Scope LSA
                                    	**type**\:  :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                    
                                    .. attribute:: unknown_area_lsa_type
                                    
                                    	Unknown\-Area scope LSA
                                    	**type**\:  :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                    
                                    .. attribute:: unknown_aslsa_type
                                    
                                    	Unknown\-AS scope LSA
                                    	**type**\:  :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType>`
                                    
                                    .. attribute:: unknown_lsa_type
                                    
                                    	Unknown LSA
                                    	**type**\:  :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType>`
                                    
                                    .. attribute:: lsa_info_type
                                    
                                    	LSAInfoType
                                    	**type**\:  :py:class:`Ospfv3LsaInfoTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypes>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo, self).__init__()

                                        self.yang_name = "lsa-info"
                                        self.yang_parent_name = "lsa"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-summary-info", ("lsa_summary_info", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo)), ("router-lsa-type", ("router_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType)), ("network-lsa-type", ("network_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType)), ("inter-area-prefix-lsa-type", ("inter_area_prefix_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType)), ("inter-area-router-lsa-type", ("inter_area_router_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType)), ("external-lsa-type", ("external_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType)), ("nssalsa-type", ("nssalsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType)), ("link-lsa-type", ("link_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType)), ("intra-area-prefix-lsa-type", ("intra_area_prefix_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType)), ("grace-lsa", ("grace_lsa", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa)), ("unknown-link-lsa-type", ("unknown_link_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType)), ("unknown-area-lsa-type", ("unknown_area_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType)), ("unknown-aslsa-type", ("unknown_aslsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType)), ("unknown-lsa-type", ("unknown_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType))])
                                        self._leafs = OrderedDict([
                                            ('lsa_info_type', (YLeaf(YType.enumeration, 'lsa-info-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3LsaInfoTypes', '')])),
                                        ])
                                        self.lsa_info_type = None

                                        self.lsa_summary_info = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo()
                                        self.lsa_summary_info.parent = self
                                        self._children_name_map["lsa_summary_info"] = "lsa-summary-info"

                                        self.router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType()
                                        self.router_lsa_type.parent = self
                                        self._children_name_map["router_lsa_type"] = "router-lsa-type"

                                        self.network_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType()
                                        self.network_lsa_type.parent = self
                                        self._children_name_map["network_lsa_type"] = "network-lsa-type"

                                        self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                        self.inter_area_prefix_lsa_type.parent = self
                                        self._children_name_map["inter_area_prefix_lsa_type"] = "inter-area-prefix-lsa-type"

                                        self.inter_area_router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                        self.inter_area_router_lsa_type.parent = self
                                        self._children_name_map["inter_area_router_lsa_type"] = "inter-area-router-lsa-type"

                                        self.external_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType()
                                        self.external_lsa_type.parent = self
                                        self._children_name_map["external_lsa_type"] = "external-lsa-type"

                                        self.nssalsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType()
                                        self.nssalsa_type.parent = self
                                        self._children_name_map["nssalsa_type"] = "nssalsa-type"

                                        self.link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType()
                                        self.link_lsa_type.parent = self
                                        self._children_name_map["link_lsa_type"] = "link-lsa-type"

                                        self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                        self.intra_area_prefix_lsa_type.parent = self
                                        self._children_name_map["intra_area_prefix_lsa_type"] = "intra-area-prefix-lsa-type"

                                        self.grace_lsa = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa()
                                        self.grace_lsa.parent = self
                                        self._children_name_map["grace_lsa"] = "grace-lsa"

                                        self.unknown_link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                        self.unknown_link_lsa_type.parent = self
                                        self._children_name_map["unknown_link_lsa_type"] = "unknown-link-lsa-type"

                                        self.unknown_area_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                        self.unknown_area_lsa_type.parent = self
                                        self._children_name_map["unknown_area_lsa_type"] = "unknown-area-lsa-type"

                                        self.unknown_aslsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType()
                                        self.unknown_aslsa_type.parent = self
                                        self._children_name_map["unknown_aslsa_type"] = "unknown-aslsa-type"

                                        self.unknown_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType()
                                        self.unknown_lsa_type.parent = self
                                        self._children_name_map["unknown_lsa_type"] = "unknown-lsa-type"
                                        self._segment_path = lambda: "lsa-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo, [u'lsa_info_type'], name, value)


                                    class LsaSummaryInfo(Entity):
                                        """
                                        Summary information of LSAs
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                        
                                        .. attribute:: links
                                        
                                        	Number of links
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: router_la_bits
                                        
                                        	Router LA bits 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: reference_type
                                        
                                        	Reference type 
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: reference_lsa_id
                                        
                                        	Reference LSA ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_router_id
                                        
                                        	LSA router ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 address Prefix 
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\: bool
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\: bool
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Sham link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo, self).__init__()

                                            self.yang_name = "lsa-summary-info"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('links', (YLeaf(YType.uint16, 'links'), ['int'])),
                                                ('router_la_bits', (YLeaf(YType.uint8, 'router-la-bits'), ['int'])),
                                                ('reference_type', (YLeaf(YType.uint16, 'reference-type'), ['int'])),
                                                ('reference_lsa_id', (YLeaf(YType.uint32, 'reference-lsa-id'), ['int'])),
                                                ('lsa_router_id', (YLeaf(YType.uint32, 'lsa-router-id'), ['int'])),
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                            ])
                                            self.links = None
                                            self.router_la_bits = None
                                            self.reference_type = None
                                            self.reference_lsa_id = None
                                            self.lsa_router_id = None
                                            self.prefix = None
                                            self.prefix_length = None
                                            self.interface_name = None
                                            self.is_virtual_link = None
                                            self.virtual_link_id = None
                                            self.is_sham_link = None
                                            self.sham_link_id = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "lsa-summary-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo, [u'links', u'router_la_bits', u'reference_type', u'reference_lsa_id', u'lsa_router_id', u'prefix', u'prefix_length', u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "lsa-summary-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "lsa-summary-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class RouterLsaType(Entity):
                                        """
                                        Router LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                        
                                        .. attribute:: rpf_path
                                        
                                        	Router LSA Reverse\-Path Forwarding information 
                                        	**type**\:  :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                        
                                        .. attribute:: router_la_bits
                                        
                                        	Router LA bits 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: link
                                        
                                        	List of links in this LSA
                                        	**type**\: list of  		 :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType, self).__init__()

                                            self.yang_name = "router-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail)), ("rpf-path", ("rpf_path", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath)), ("link", ("link", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link))])
                                            self._leafs = OrderedDict([
                                                ('router_la_bits', (YLeaf(YType.uint8, 'router-la-bits'), ['int'])),
                                            ])
                                            self.router_la_bits = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"

                                            self.rpf_path = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                            self.rpf_path.parent = self
                                            self._children_name_map["rpf_path"] = "rpf-path"

                                            self.link = YList(self)
                                            self._segment_path = lambda: "router-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType, [u'router_la_bits'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class RpfPath(Entity):
                                            """
                                            Router LSA Reverse\-Path Forwarding information 
                                            
                                            .. attribute:: rpf_multicast_next_hop
                                            
                                            	RPF multicast next hop 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_name
                                            
                                            	RPF multicast IDB 
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath, self).__init__()

                                                self.yang_name = "rpf-path"
                                                self.yang_parent_name = "router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('rpf_multicast_next_hop', (YLeaf(YType.uint32, 'rpf-multicast-next-hop'), ['int'])),
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ])
                                                self.rpf_multicast_next_hop = None
                                                self.interface_name = None
                                                self._segment_path = lambda: "rpf-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath, [u'rpf_multicast_next_hop', u'interface_name'], name, value)


                                        class Link(Entity):
                                            """
                                            List of links in this LSA
                                            
                                            .. attribute:: link_type
                                            
                                            	Type of link
                                            	**type**\:  :py:class:`Ospfv3Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Link>`
                                            
                                            .. attribute:: link_metric
                                            
                                            	LSA link metric 
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: link_interface_id
                                            
                                            	LSA link interface ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_neighbor_interface_id
                                            
                                            	LSA link neighbor interface ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_neighbor_router_id
                                            
                                            	LSA link neigbhor router id 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link, self).__init__()

                                                self.yang_name = "link"
                                                self.yang_parent_name = "router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Link', '')])),
                                                    ('link_metric', (YLeaf(YType.uint16, 'link-metric'), ['int'])),
                                                    ('link_interface_id', (YLeaf(YType.uint32, 'link-interface-id'), ['int'])),
                                                    ('link_neighbor_interface_id', (YLeaf(YType.uint32, 'link-neighbor-interface-id'), ['int'])),
                                                    ('link_neighbor_router_id', (YLeaf(YType.uint32, 'link-neighbor-router-id'), ['int'])),
                                                ])
                                                self.link_type = None
                                                self.link_metric = None
                                                self.link_interface_id = None
                                                self.link_neighbor_interface_id = None
                                                self.link_neighbor_router_id = None
                                                self._segment_path = lambda: "link"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link, [u'link_type', u'link_metric', u'link_interface_id', u'link_neighbor_interface_id', u'link_neighbor_router_id'], name, value)


                                    class NetworkLsaType(Entity):
                                        """
                                        Network LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                        
                                        .. attribute:: neighbor_router
                                        
                                        	Neighbor router list
                                        	**type**\: list of str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType, self).__init__()

                                            self.yang_name = "network-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('neighbor_router', (YLeafList(YType.str, 'neighbor-router'), ['str'])),
                                            ])
                                            self.neighbor_router = []

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "network-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType, [u'neighbor_router'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "network-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "network-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class InterAreaPrefixLsaType(Entity):
                                        """
                                        Inter Area Prefix LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA Information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                        
                                        .. attribute:: prefix
                                        
                                        	LSA address prefix 
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType, self).__init__()

                                            self.yang_name = "inter-area-prefix-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                            ])
                                            self.prefix = None
                                            self.prefix_length = None
                                            self.priority = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "inter-area-prefix-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType, [u'prefix', u'prefix_length', u'priority'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class InterAreaRouterLsaType(Entity):
                                        """
                                        Inter Area Router LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                        
                                        .. attribute:: lsa_router_id
                                        
                                        	LSA router ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType, self).__init__()

                                            self.yang_name = "inter-area-router-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('lsa_router_id', (YLeaf(YType.uint32, 'lsa-router-id'), ['int'])),
                                            ])
                                            self.lsa_router_id = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "inter-area-router-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType, [u'lsa_router_id'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "inter-area-router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "inter-area-router-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class ExternalLsaType(Entity):
                                        """
                                        External LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA Information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                        
                                        .. attribute:: prefix
                                        
                                        	IPV6 address prefix 
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: metric_type
                                        
                                        	Metric type 
                                        	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                        
                                        .. attribute:: tos_cost
                                        
                                        	Type of service cost metric 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_forwarding_address_set
                                        
                                        	If true, forwarding address is set 
                                        	**type**\: bool
                                        
                                        .. attribute:: forwarding_address
                                        
                                        	Forwarding Address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: external_tag
                                        
                                        	Route Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType, self).__init__()

                                            self.yang_name = "external-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                                ('tos_cost', (YLeaf(YType.uint32, 'tos-cost'), ['int'])),
                                                ('is_forwarding_address_set', (YLeaf(YType.boolean, 'is-forwarding-address-set'), ['bool'])),
                                                ('forwarding_address', (YLeaf(YType.str, 'forwarding-address'), ['str'])),
                                                ('external_tag', (YLeaf(YType.uint32, 'external-tag'), ['int'])),
                                                ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                            ])
                                            self.prefix = None
                                            self.prefix_length = None
                                            self.metric_type = None
                                            self.tos_cost = None
                                            self.is_forwarding_address_set = None
                                            self.forwarding_address = None
                                            self.external_tag = None
                                            self.priority = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "external-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType, [u'prefix', u'prefix_length', u'metric_type', u'tos_cost', u'is_forwarding_address_set', u'forwarding_address', u'external_tag', u'priority'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "external-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "external-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class NssalsaType(Entity):
                                        """
                                        NSSA External LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA Information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                        
                                        .. attribute:: prefix
                                        
                                        	IPV6 address prefix 
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	Prefix length 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: metric_type
                                        
                                        	Metric type 
                                        	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                        
                                        .. attribute:: tos_cost
                                        
                                        	Type of service cost metric 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_forwarding_address_set
                                        
                                        	If true, forwarding address is set 
                                        	**type**\: bool
                                        
                                        .. attribute:: forwarding_address
                                        
                                        	Forwarding Address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: external_tag
                                        
                                        	Route Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType, self).__init__()

                                            self.yang_name = "nssalsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                                ('tos_cost', (YLeaf(YType.uint32, 'tos-cost'), ['int'])),
                                                ('is_forwarding_address_set', (YLeaf(YType.boolean, 'is-forwarding-address-set'), ['bool'])),
                                                ('forwarding_address', (YLeaf(YType.str, 'forwarding-address'), ['str'])),
                                                ('external_tag', (YLeaf(YType.uint32, 'external-tag'), ['int'])),
                                                ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                            ])
                                            self.prefix = None
                                            self.prefix_length = None
                                            self.metric_type = None
                                            self.tos_cost = None
                                            self.is_forwarding_address_set = None
                                            self.forwarding_address = None
                                            self.external_tag = None
                                            self.priority = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "nssalsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType, [u'prefix', u'prefix_length', u'metric_type', u'tos_cost', u'is_forwarding_address_set', u'forwarding_address', u'external_tag', u'priority'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "nssalsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA Information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "nssalsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class LinkLsaType(Entity):
                                        """
                                        Link LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface handle
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link
                                        	**type**\: bool
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link
                                        	**type**\: bool
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Sham link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_link_local
                                        
                                        	LSA link local 
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: router_priority
                                        
                                        	Router priority 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\: list of  		 :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType, self).__init__()

                                            self.yang_name = "link-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail)), ("prefix", ("prefix", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                ('lsa_link_local', (YLeaf(YType.str, 'lsa-link-local'), ['str'])),
                                                ('router_priority', (YLeaf(YType.uint8, 'router-priority'), ['int'])),
                                            ])
                                            self.interface_name = None
                                            self.is_virtual_link = None
                                            self.virtual_link_id = None
                                            self.is_sham_link = None
                                            self.sham_link_id = None
                                            self.lsa_link_local = None
                                            self.router_priority = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"

                                            self.prefix = YList(self)
                                            self._segment_path = lambda: "link-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id', u'lsa_link_local', u'router_priority'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class Prefix(Entity):
                                            """
                                            OSPFv3 prefix 
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ospfv3_prefix_length
                                            
                                            	OSPFv3 prefix length 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ospfv3_prefix_options
                                            
                                            	OSPFv3 prefix options 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ospfv3_prefix_metric
                                            
                                            	OSPFv3 prefix metric 
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('ospfv3_prefix_length', (YLeaf(YType.uint8, 'ospfv3-prefix-length'), ['int'])),
                                                    ('ospfv3_prefix_options', (YLeaf(YType.uint8, 'ospfv3-prefix-options'), ['int'])),
                                                    ('ospfv3_prefix_metric', (YLeaf(YType.uint16, 'ospfv3-prefix-metric'), ['int'])),
                                                    ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                ])
                                                self.prefix = None
                                                self.ospfv3_prefix_length = None
                                                self.ospfv3_prefix_options = None
                                                self.ospfv3_prefix_metric = None
                                                self.priority = None
                                                self._segment_path = lambda: "prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix, [u'prefix', u'ospfv3_prefix_length', u'ospfv3_prefix_options', u'ospfv3_prefix_metric', u'priority'], name, value)


                                    class IntraAreaPrefixLsaType(Entity):
                                        """
                                        Intra Area Prefix LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                        
                                        .. attribute:: reference_type
                                        
                                        	Reference type 
                                        	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                        
                                        .. attribute:: reference_lsa_id
                                        
                                        	Reference LSA ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: reference_advertised_router
                                        
                                        	Reference advertised router 
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\: list of  		 :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, self).__init__()

                                            self.yang_name = "intra-area-prefix-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail)), ("prefix", ("prefix", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix))])
                                            self._leafs = OrderedDict([
                                                ('reference_type', (YLeaf(YType.enumeration, 'reference-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                                ('reference_lsa_id', (YLeaf(YType.uint32, 'reference-lsa-id'), ['int'])),
                                                ('reference_advertised_router', (YLeaf(YType.str, 'reference-advertised-router'), ['str'])),
                                            ])
                                            self.reference_type = None
                                            self.reference_lsa_id = None
                                            self.reference_advertised_router = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"

                                            self.prefix = YList(self)
                                            self._segment_path = lambda: "intra-area-prefix-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, [u'reference_type', u'reference_lsa_id', u'reference_advertised_router'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class Prefix(Entity):
                                            """
                                            OSPFv3 prefix 
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ospfv3_prefix_length
                                            
                                            	OSPFv3 prefix length 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ospfv3_prefix_options
                                            
                                            	OSPFv3 prefix options 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ospfv3_prefix_metric
                                            
                                            	OSPFv3 prefix metric 
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, self).__init__()

                                                self.yang_name = "prefix"
                                                self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('ospfv3_prefix_length', (YLeaf(YType.uint8, 'ospfv3-prefix-length'), ['int'])),
                                                    ('ospfv3_prefix_options', (YLeaf(YType.uint8, 'ospfv3-prefix-options'), ['int'])),
                                                    ('ospfv3_prefix_metric', (YLeaf(YType.uint16, 'ospfv3-prefix-metric'), ['int'])),
                                                    ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                ])
                                                self.prefix = None
                                                self.ospfv3_prefix_length = None
                                                self.ospfv3_prefix_options = None
                                                self.ospfv3_prefix_metric = None
                                                self.priority = None
                                                self._segment_path = lambda: "prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, [u'prefix', u'ospfv3_prefix_length', u'ospfv3_prefix_options', u'ospfv3_prefix_metric', u'priority'], name, value)


                                    class GraceLsa(Entity):
                                        """
                                        Grace LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface handle
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link
                                        	**type**\: bool
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link
                                        	**type**\: bool
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Sham link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: grace_period
                                        
                                        	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: grace_reason
                                        
                                        	Reason for router restart
                                        	**type**\:  :py:class:`Ospfv3GracefulRestartReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReason>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa, self).__init__()

                                            self.yang_name = "grace-lsa"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                ('grace_period', (YLeaf(YType.uint32, 'grace-period'), ['int'])),
                                                ('grace_reason', (YLeaf(YType.enumeration, 'grace-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3GracefulRestartReason', '')])),
                                            ])
                                            self.interface_name = None
                                            self.is_virtual_link = None
                                            self.virtual_link_id = None
                                            self.is_sham_link = None
                                            self.sham_link_id = None
                                            self.grace_period = None
                                            self.grace_reason = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "grace-lsa"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id', u'grace_period', u'grace_reason'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "grace-lsa"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "grace-lsa"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class UnknownLinkLsaType(Entity):
                                        """
                                        Unknown Link Scope LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\: bool
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\: bool
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType, self).__init__()

                                            self.yang_name = "unknown-link-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                            ])
                                            self.interface_name = None
                                            self.is_virtual_link = None
                                            self.virtual_link_id = None
                                            self.is_sham_link = None
                                            self.sham_link_id = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "unknown-link-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "unknown-link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "unknown-link-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class UnknownAreaLsaType(Entity):
                                        """
                                        Unknown\-Area scope LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\: bool
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\: bool
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType, self).__init__()

                                            self.yang_name = "unknown-area-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                            ])
                                            self.interface_name = None
                                            self.is_virtual_link = None
                                            self.virtual_link_id = None
                                            self.is_sham_link = None
                                            self.sham_link_id = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "unknown-area-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "unknown-area-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "unknown-area-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class UnknownAslsaType(Entity):
                                        """
                                        Unknown\-AS scope LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\: bool
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\: bool
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType, self).__init__()

                                            self.yang_name = "unknown-aslsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                            ])
                                            self.interface_name = None
                                            self.is_virtual_link = None
                                            self.virtual_link_id = None
                                            self.is_sham_link = None
                                            self.sham_link_id = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "unknown-aslsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "unknown-aslsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "unknown-aslsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class UnknownLsaType(Entity):
                                        """
                                        Unknown LSA
                                        
                                        .. attribute:: lsa_header
                                        
                                        	Header information 
                                        	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                        
                                        .. attribute:: lsa_detail
                                        
                                        	Detailed LSA information
                                        	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                        
                                        .. attribute:: interface_name
                                        
                                        	LSA interface name 
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: is_virtual_link
                                        
                                        	If true, it is a virtual link 
                                        	**type**\: bool
                                        
                                        .. attribute:: virtual_link_id
                                        
                                        	Virtual link ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_sham_link
                                        
                                        	If true, it is a sham link 
                                        	**type**\: bool
                                        
                                        .. attribute:: sham_link_id
                                        
                                        	Shamlink ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType, self).__init__()

                                            self.yang_name = "unknown-lsa-type"
                                            self.yang_parent_name = "lsa-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail))])
                                            self._leafs = OrderedDict([
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                            ])
                                            self.interface_name = None
                                            self.is_virtual_link = None
                                            self.virtual_link_id = None
                                            self.is_sham_link = None
                                            self.sham_link_id = None

                                            self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                            self.lsa_header.parent = self
                                            self._children_name_map["lsa_header"] = "lsa-header"

                                            self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                            self.lsa_detail.parent = self
                                            self._children_name_map["lsa_detail"] = "lsa-detail"
                                            self._segment_path = lambda: "unknown-lsa-type"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                        class LsaHeader(Entity):
                                            """
                                            Header information 
                                            
                                            .. attribute:: lsa_type
                                            
                                            	LSA type
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_area_id
                                            
                                            	Area ID in decimal or dotted\-decimal format
                                            	**type**\: str
                                            
                                            	**length:** 0..16
                                            
                                            .. attribute:: lsa_age
                                            
                                            	LSA's Age (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_do_not_age_lsa
                                            
                                            	If true, Do Not Age this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: ls_id
                                            
                                            	LS ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: advertising_router
                                            
                                            	Router ID of Advertising Router
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Current Sequence number
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum value
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_graceful_restart_active
                                            
                                            	If true, if grace restart is active 
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, self).__init__()

                                                self.yang_name = "lsa-header"
                                                self.yang_parent_name = "unknown-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                    ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                    ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                ])
                                                self.lsa_type = None
                                                self.lsa_area_id = None
                                                self.lsa_age = None
                                                self.is_do_not_age_lsa = None
                                                self.ls_id = None
                                                self.advertising_router = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.is_graceful_restart_active = None
                                                self._segment_path = lambda: "lsa-header"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                        class LsaDetail(Entity):
                                            """
                                            Detailed LSA information
                                            
                                            .. attribute:: second_table_index
                                            
                                            	Second table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: minute_table_index
                                            
                                            	Minute table index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: free_time
                                            
                                            	The amount of time since the last check was made to free this LSA (s)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_deleted
                                            
                                            	If true, flag is set to delete this LSA 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_bit
                                            
                                            	If true, Routing Bit set on the LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_advertising_router_reachable
                                            
                                            	If true, Advertising Router is reachable
                                            	**type**\: bool
                                            
                                            .. attribute:: is_no_delete
                                            
                                            	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                            	**type**\: bool
                                            
                                            .. attribute:: is_neighbor_exchange
                                            
                                            	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                            	**type**\: bool
                                            
                                            .. attribute:: is_routing_table
                                            
                                            	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_acknowledged
                                            
                                            	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                            	**type**\: bool
                                            
                                            .. attribute:: is_maximum_aged
                                            
                                            	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_partial_spf
                                            
                                            	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                            	**type**\: bool
                                            
                                            .. attribute:: is_flood_pending
                                            
                                            	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                            	**type**\: bool
                                            
                                            .. attribute:: rate_limit
                                            
                                            	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                            	**type**\: bool
                                            
                                            .. attribute:: is_nsr_ack_pending
                                            
                                            	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                            	**type**\: bool
                                            
                                            .. attribute:: nsr_flood_required
                                            
                                            	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_flood_required_post_fail_over
                                            
                                            	LSA flood required after FO
                                            	**type**\: bool
                                            
                                            .. attribute:: lsa_length
                                            
                                            	Length of the LSA
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: lsa_sync_state
                                            
                                            	State of LSA sync with active
                                            	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, self).__init__()

                                                self.yang_name = "lsa-detail"
                                                self.yang_parent_name = "unknown-lsa-type"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                    ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                    ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                    ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                    ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                    ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                    ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                    ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                    ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                    ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                    ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                    ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                    ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                    ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                    ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                    ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                    ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                    ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                    ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                ])
                                                self.second_table_index = None
                                                self.minute_table_index = None
                                                self.free_time = None
                                                self.is_deleted = None
                                                self.is_routing_bit = None
                                                self.is_advertising_router_reachable = None
                                                self.is_no_delete = None
                                                self.is_neighbor_exchange = None
                                                self.is_routing_table = None
                                                self.is_acknowledged = None
                                                self.is_maximum_aged = None
                                                self.is_partial_spf = None
                                                self.is_flood_pending = None
                                                self.rate_limit = None
                                                self.is_nsr_ack_pending = None
                                                self.nsr_flood_required = None
                                                self.lsa_flood_required_post_fail_over = None
                                                self.lsa_length = None
                                                self.lsa_sync_state = None
                                                self._segment_path = lambda: "lsa-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                    class InterfaceProcessTable(Entity):
                        """
                        OSPFv3 interface information table for all areas
                        
                        .. attribute:: interface
                        
                        	OSPFv3 interface information
                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable, self).__init__()

                            self.yang_name = "interface-process-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface))])
                            self._leafs = OrderedDict()

                            self.interface = YList(self)
                            self._segment_path = lambda: "interface-process-table"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable, [], name, value)


                        class Interface(Entity):
                            """
                            OSPFv3 interface information
                            
                            .. attribute:: interface_name  (key)
                            
                            	Interface name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: active_interface
                            
                            	Active interface details 
                            	**type**\:  :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.ActiveInterface>`
                            
                            .. attribute:: interface_bfd
                            
                            	BFD information 
                            	**type**\:  :py:class:`InterfaceBfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceBfd>`
                            
                            .. attribute:: interface_state
                            
                            	Interface state
                            	**type**\:  :py:class:`ImStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.ImStateEnum>`
                            
                            .. attribute:: is_interface_line_up
                            
                            	If true, line protocol is up 
                            	**type**\: bool
                            
                            .. attribute:: is_interface_ip_security_required
                            
                            	If true, interface IP security is required 
                            	**type**\: bool
                            
                            .. attribute:: is_interface_ip_security_active
                            
                            	If true, interface IP security is active 
                            	**type**\: bool
                            
                            .. attribute:: interface_address
                            
                            	Interface IPv6 address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_number
                            
                            	Interface number 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_router_id
                            
                            	Interface router ID 
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: network_type
                            
                            	Network type
                            	**type**\:  :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                            
                            .. attribute:: interface_link_cost
                            
                            	Interface link cost
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: is_interface_flood_reduction
                            
                            	If true, interface flood reduction is active 
                            	**type**\: bool
                            
                            .. attribute:: is_demand_circuit_configured
                            
                            	If true, configured as demand circuit 
                            	**type**\: bool
                            
                            .. attribute:: is_interface_demand_circuit
                            
                            	If true, interface running as demand circuit
                            	**type**\: bool
                            
                            .. attribute:: interface_dc_bitless_ls_as
                            
                            	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transmission_delay
                            
                            	Interface transmission delay (sec)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ospf_interface_state
                            
                            	Interface state
                            	**type**\:  :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                            
                            .. attribute:: interface_priority
                            
                            	Interface priority
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: is_designated_router
                            
                            	If true, designated router
                            	**type**\: bool
                            
                            .. attribute:: designated_router_id
                            
                            	Designated router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: designated_router_address
                            
                            	Designated router interface address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: backup_designated_router_id
                            
                            	Backup designated router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: backup_designated_router_address
                            
                            	Backup designated router interface address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: network_lsa_flush_timer
                            
                            	The amount of time in seconds before flush timer for old network LSA expires 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: is_interface_lsa_filtered
                            
                            	Filter is configured for out going LSAs 
                            	**type**\: bool
                            
                            .. attribute:: hello_interval
                            
                            	Configured hello interval (s)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dead_interval
                            
                            	Configured dead interval (s) 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: wait_interval
                            
                            	Configured wait interval (s) 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_retransmission_interval
                            
                            	Configured retransmit interval (s) 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hello_time
                            
                            	Time until next Hello (s) 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_authentication_spi
                            
                            	Interface authentication spi 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_authentication_transmit
                            
                            	Interface authentication transmit 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_interface_encryption_enabled
                            
                            	If true, interface encryption is enabled 
                            	**type**\: bool
                            
                            .. attribute:: is_prefix_suppress
                            
                            	If true prefix suppression is enabled
                            	**type**\: bool
                            
                            .. attribute:: interface_encryption_spi
                            
                            	Interface encryption spi
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_encryption_transmitted
                            
                            	Interface encryption transmitted 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_encrypted_authentication_transmitted
                            
                            	Interface encrypted authentication transmitted 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adjacent_neighbor
                            
                            	Number of adjacent neighbors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_references
                            
                            	Interface reference count 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: configured_ldp_sync
                            
                            	If true, configured as LDP sync
                            	**type**\: bool
                            
                            .. attribute:: interface_ldp_sync
                            
                            	If true, interface LDP sync is achieved
                            	**type**\: bool
                            
                            .. attribute:: interface_neighbor
                            
                            	Information for neighbors on the interface
                            	**type**\: list of  		 :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceNeighbor>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "interface-process-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['interface_name']
                                self._child_classes = OrderedDict([("active-interface", ("active_interface", Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.ActiveInterface)), ("interface-bfd", ("interface_bfd", Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceBfd)), ("interface-neighbor", ("interface_neighbor", Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceNeighbor))])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('interface_state', (YLeaf(YType.enumeration, 'interface-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'ImStateEnum', '')])),
                                    ('is_interface_line_up', (YLeaf(YType.boolean, 'is-interface-line-up'), ['bool'])),
                                    ('is_interface_ip_security_required', (YLeaf(YType.boolean, 'is-interface-ip-security-required'), ['bool'])),
                                    ('is_interface_ip_security_active', (YLeaf(YType.boolean, 'is-interface-ip-security-active'), ['bool'])),
                                    ('interface_address', (YLeaf(YType.str, 'interface-address'), ['str'])),
                                    ('interface_number', (YLeaf(YType.uint32, 'interface-number'), ['int'])),
                                    ('interface_router_id', (YLeaf(YType.str, 'interface-router-id'), ['str'])),
                                    ('network_type', (YLeaf(YType.enumeration, 'network-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Interface', '')])),
                                    ('interface_link_cost', (YLeaf(YType.uint16, 'interface-link-cost'), ['int'])),
                                    ('is_interface_flood_reduction', (YLeaf(YType.boolean, 'is-interface-flood-reduction'), ['bool'])),
                                    ('is_demand_circuit_configured', (YLeaf(YType.boolean, 'is-demand-circuit-configured'), ['bool'])),
                                    ('is_interface_demand_circuit', (YLeaf(YType.boolean, 'is-interface-demand-circuit'), ['bool'])),
                                    ('interface_dc_bitless_ls_as', (YLeaf(YType.uint32, 'interface-dc-bitless-ls-as'), ['int'])),
                                    ('transmission_delay', (YLeaf(YType.uint16, 'transmission-delay'), ['int'])),
                                    ('ospf_interface_state', (YLeaf(YType.enumeration, 'ospf-interface-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3InterfaceState', '')])),
                                    ('interface_priority', (YLeaf(YType.uint8, 'interface-priority'), ['int'])),
                                    ('is_designated_router', (YLeaf(YType.boolean, 'is-designated-router'), ['bool'])),
                                    ('designated_router_id', (YLeaf(YType.str, 'designated-router-id'), ['str'])),
                                    ('designated_router_address', (YLeaf(YType.str, 'designated-router-address'), ['str'])),
                                    ('backup_designated_router_id', (YLeaf(YType.str, 'backup-designated-router-id'), ['str'])),
                                    ('backup_designated_router_address', (YLeaf(YType.str, 'backup-designated-router-address'), ['str'])),
                                    ('network_lsa_flush_timer', (YLeaf(YType.uint32, 'network-lsa-flush-timer'), ['int'])),
                                    ('is_interface_lsa_filtered', (YLeaf(YType.boolean, 'is-interface-lsa-filtered'), ['bool'])),
                                    ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                    ('dead_interval', (YLeaf(YType.uint32, 'dead-interval'), ['int'])),
                                    ('wait_interval', (YLeaf(YType.uint32, 'wait-interval'), ['int'])),
                                    ('interface_retransmission_interval', (YLeaf(YType.uint32, 'interface-retransmission-interval'), ['int'])),
                                    ('next_hello_time', (YLeaf(YType.uint32, 'next-hello-time'), ['int'])),
                                    ('interface_authentication_spi', (YLeaf(YType.uint32, 'interface-authentication-spi'), ['int'])),
                                    ('interface_authentication_transmit', (YLeaf(YType.uint32, 'interface-authentication-transmit'), ['int'])),
                                    ('is_interface_encryption_enabled', (YLeaf(YType.boolean, 'is-interface-encryption-enabled'), ['bool'])),
                                    ('is_prefix_suppress', (YLeaf(YType.boolean, 'is-prefix-suppress'), ['bool'])),
                                    ('interface_encryption_spi', (YLeaf(YType.uint32, 'interface-encryption-spi'), ['int'])),
                                    ('interface_encryption_transmitted', (YLeaf(YType.uint32, 'interface-encryption-transmitted'), ['int'])),
                                    ('interface_encrypted_authentication_transmitted', (YLeaf(YType.uint32, 'interface-encrypted-authentication-transmitted'), ['int'])),
                                    ('adjacent_neighbor', (YLeaf(YType.uint32, 'adjacent-neighbor'), ['int'])),
                                    ('interface_references', (YLeaf(YType.uint32, 'interface-references'), ['int'])),
                                    ('configured_ldp_sync', (YLeaf(YType.boolean, 'configured-ldp-sync'), ['bool'])),
                                    ('interface_ldp_sync', (YLeaf(YType.boolean, 'interface-ldp-sync'), ['bool'])),
                                ])
                                self.interface_name = None
                                self.interface_state = None
                                self.is_interface_line_up = None
                                self.is_interface_ip_security_required = None
                                self.is_interface_ip_security_active = None
                                self.interface_address = None
                                self.interface_number = None
                                self.interface_router_id = None
                                self.network_type = None
                                self.interface_link_cost = None
                                self.is_interface_flood_reduction = None
                                self.is_demand_circuit_configured = None
                                self.is_interface_demand_circuit = None
                                self.interface_dc_bitless_ls_as = None
                                self.transmission_delay = None
                                self.ospf_interface_state = None
                                self.interface_priority = None
                                self.is_designated_router = None
                                self.designated_router_id = None
                                self.designated_router_address = None
                                self.backup_designated_router_id = None
                                self.backup_designated_router_address = None
                                self.network_lsa_flush_timer = None
                                self.is_interface_lsa_filtered = None
                                self.hello_interval = None
                                self.dead_interval = None
                                self.wait_interval = None
                                self.interface_retransmission_interval = None
                                self.next_hello_time = None
                                self.interface_authentication_spi = None
                                self.interface_authentication_transmit = None
                                self.is_interface_encryption_enabled = None
                                self.is_prefix_suppress = None
                                self.interface_encryption_spi = None
                                self.interface_encryption_transmitted = None
                                self.interface_encrypted_authentication_transmitted = None
                                self.adjacent_neighbor = None
                                self.interface_references = None
                                self.configured_ldp_sync = None
                                self.interface_ldp_sync = None

                                self.active_interface = Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.ActiveInterface()
                                self.active_interface.parent = self
                                self._children_name_map["active_interface"] = "active-interface"

                                self.interface_bfd = Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceBfd()
                                self.interface_bfd.parent = self
                                self._children_name_map["interface_bfd"] = "interface-bfd"

                                self.interface_neighbor = YList(self)
                                self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface, ['interface_name', u'interface_state', u'is_interface_line_up', u'is_interface_ip_security_required', u'is_interface_ip_security_active', u'interface_address', u'interface_number', u'interface_router_id', u'network_type', u'interface_link_cost', u'is_interface_flood_reduction', u'is_demand_circuit_configured', u'is_interface_demand_circuit', u'interface_dc_bitless_ls_as', u'transmission_delay', u'ospf_interface_state', u'interface_priority', u'is_designated_router', u'designated_router_id', u'designated_router_address', u'backup_designated_router_id', u'backup_designated_router_address', u'network_lsa_flush_timer', u'is_interface_lsa_filtered', u'hello_interval', u'dead_interval', u'wait_interval', u'interface_retransmission_interval', u'next_hello_time', u'interface_authentication_spi', u'interface_authentication_transmit', u'is_interface_encryption_enabled', u'is_prefix_suppress', u'interface_encryption_spi', u'interface_encryption_transmitted', u'interface_encrypted_authentication_transmitted', u'adjacent_neighbor', u'interface_references', u'configured_ldp_sync', u'interface_ldp_sync'], name, value)


                            class ActiveInterface(Entity):
                                """
                                Active interface details 
                                
                                .. attribute:: wait_time
                                
                                	Wait time for DR/BDR selection (s)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_area_flood_index
                                
                                	Area scope LSAs flood index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_as_flood_index
                                
                                	AS scope LSAs flood index 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_link_flood_index
                                
                                	Interface flood link index 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flood_queue_length
                                
                                	Flood queue length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_area_next_flood
                                
                                	Next LSA to flood (Area scope)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_area_next_flood_index
                                
                                	Index of next LSA to flood (Area scope) 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_as_next_flood
                                
                                	Next LSA to flood (AS scope)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_as_next_flood_index
                                
                                	Index of next LSA to flood (AS scope)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_link_next_flood
                                
                                	Interface link next flood information 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_link_next_index
                                
                                	Interface link next information index 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flood_scan_length
                                
                                	Last flood scan length 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_flood_length
                                
                                	Maximum flood length 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_flood_time
                                
                                	Last flood scan time (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_flood_time
                                
                                	Maximum flood time (ms) 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_flood_pacing_timer
                                
                                	Time until next flood pacing timer (ms) 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_neighbors
                                
                                	Total number of neighbors 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: suppressed_hellos
                                
                                	Number of neighbors for which hellos are suppressed 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.ActiveInterface, self).__init__()

                                    self.yang_name = "active-interface"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('wait_time', (YLeaf(YType.uint32, 'wait-time'), ['int'])),
                                        ('interface_area_flood_index', (YLeaf(YType.uint32, 'interface-area-flood-index'), ['int'])),
                                        ('interface_as_flood_index', (YLeaf(YType.uint32, 'interface-as-flood-index'), ['int'])),
                                        ('interface_link_flood_index', (YLeaf(YType.uint32, 'interface-link-flood-index'), ['int'])),
                                        ('flood_queue_length', (YLeaf(YType.uint32, 'flood-queue-length'), ['int'])),
                                        ('interface_area_next_flood', (YLeaf(YType.uint32, 'interface-area-next-flood'), ['int'])),
                                        ('interface_area_next_flood_index', (YLeaf(YType.uint32, 'interface-area-next-flood-index'), ['int'])),
                                        ('interface_as_next_flood', (YLeaf(YType.uint32, 'interface-as-next-flood'), ['int'])),
                                        ('interface_as_next_flood_index', (YLeaf(YType.uint32, 'interface-as-next-flood-index'), ['int'])),
                                        ('interface_link_next_flood', (YLeaf(YType.uint32, 'interface-link-next-flood'), ['int'])),
                                        ('interface_link_next_index', (YLeaf(YType.uint32, 'interface-link-next-index'), ['int'])),
                                        ('flood_scan_length', (YLeaf(YType.uint32, 'flood-scan-length'), ['int'])),
                                        ('maximum_flood_length', (YLeaf(YType.uint32, 'maximum-flood-length'), ['int'])),
                                        ('last_flood_time', (YLeaf(YType.uint32, 'last-flood-time'), ['int'])),
                                        ('maximum_flood_time', (YLeaf(YType.uint32, 'maximum-flood-time'), ['int'])),
                                        ('interface_flood_pacing_timer', (YLeaf(YType.uint32, 'interface-flood-pacing-timer'), ['int'])),
                                        ('interface_neighbors', (YLeaf(YType.uint16, 'interface-neighbors'), ['int'])),
                                        ('suppressed_hellos', (YLeaf(YType.uint16, 'suppressed-hellos'), ['int'])),
                                    ])
                                    self.wait_time = None
                                    self.interface_area_flood_index = None
                                    self.interface_as_flood_index = None
                                    self.interface_link_flood_index = None
                                    self.flood_queue_length = None
                                    self.interface_area_next_flood = None
                                    self.interface_area_next_flood_index = None
                                    self.interface_as_next_flood = None
                                    self.interface_as_next_flood_index = None
                                    self.interface_link_next_flood = None
                                    self.interface_link_next_index = None
                                    self.flood_scan_length = None
                                    self.maximum_flood_length = None
                                    self.last_flood_time = None
                                    self.maximum_flood_time = None
                                    self.interface_flood_pacing_timer = None
                                    self.interface_neighbors = None
                                    self.suppressed_hellos = None
                                    self._segment_path = lambda: "active-interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.ActiveInterface, [u'wait_time', u'interface_area_flood_index', u'interface_as_flood_index', u'interface_link_flood_index', u'flood_queue_length', u'interface_area_next_flood', u'interface_area_next_flood_index', u'interface_as_next_flood', u'interface_as_next_flood_index', u'interface_link_next_flood', u'interface_link_next_index', u'flood_scan_length', u'maximum_flood_length', u'last_flood_time', u'maximum_flood_time', u'interface_flood_pacing_timer', u'interface_neighbors', u'suppressed_hellos'], name, value)


                            class InterfaceBfd(Entity):
                                """
                                BFD information 
                                
                                .. attribute:: bfd_intf_enable_mode
                                
                                	BFD Enable Mode on the interface \- Default/Strict
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_interval
                                
                                	BFD interval (ms) 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_detection_multiplier
                                
                                	BFD detection multiplier 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceBfd, self).__init__()

                                    self.yang_name = "interface-bfd"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('bfd_intf_enable_mode', (YLeaf(YType.uint32, 'bfd-intf-enable-mode'), ['int'])),
                                        ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                                        ('bfd_detection_multiplier', (YLeaf(YType.uint32, 'bfd-detection-multiplier'), ['int'])),
                                    ])
                                    self.bfd_intf_enable_mode = None
                                    self.bfd_interval = None
                                    self.bfd_detection_multiplier = None
                                    self._segment_path = lambda: "interface-bfd"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceBfd, [u'bfd_intf_enable_mode', u'bfd_interval', u'bfd_detection_multiplier'], name, value)


                            class InterfaceNeighbor(Entity):
                                """
                                Information for neighbors on the interface
                                
                                .. attribute:: interface_neighbor_id
                                
                                	Neighbor router ID 
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_neighbor_cost
                                
                                	Cost of link to neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_neighbor_dr
                                
                                	If true, designated router is found 
                                	**type**\: bool
                                
                                .. attribute:: is_neighbor_bdr
                                
                                	If true, backup designated router is found 
                                	**type**\: bool
                                
                                .. attribute:: is_hello_suppressed
                                
                                	If true, hello is suppressed 
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceNeighbor, self).__init__()

                                    self.yang_name = "interface-neighbor"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface_neighbor_id', (YLeaf(YType.str, 'interface-neighbor-id'), ['str'])),
                                        ('interface_neighbor_cost', (YLeaf(YType.uint32, 'interface-neighbor-cost'), ['int'])),
                                        ('is_neighbor_dr', (YLeaf(YType.boolean, 'is-neighbor-dr'), ['bool'])),
                                        ('is_neighbor_bdr', (YLeaf(YType.boolean, 'is-neighbor-bdr'), ['bool'])),
                                        ('is_hello_suppressed', (YLeaf(YType.boolean, 'is-hello-suppressed'), ['bool'])),
                                    ])
                                    self.interface_neighbor_id = None
                                    self.interface_neighbor_cost = None
                                    self.is_neighbor_dr = None
                                    self.is_neighbor_bdr = None
                                    self.is_hello_suppressed = None
                                    self._segment_path = lambda: "interface-neighbor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceProcessTable.Interface.InterfaceNeighbor, [u'interface_neighbor_id', u'interface_neighbor_cost', u'is_neighbor_dr', u'is_neighbor_bdr', u'is_hello_suppressed'], name, value)


                    class Redistributions(Entity):
                        """
                        Redistribution information table
                        
                        .. attribute:: redistribution
                        
                        	Redistribution information
                        	**type**\: list of  		 :py:class:`Redistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions.Redistribution>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions, self).__init__()

                            self.yang_name = "redistributions"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("redistribution", ("redistribution", Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions.Redistribution))])
                            self._leafs = OrderedDict()

                            self.redistribution = YList(self)
                            self._segment_path = lambda: "redistributions"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions, [], name, value)


                        class Redistribution(Entity):
                            """
                            Redistribution information
                            
                            .. attribute:: protocol_name
                            
                            	Protocol name that is redistributed
                            	**type**\: str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: process_name
                            
                            	Process name of a protocolbeing redistributed 
                            	**type**\: str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: protocol_name_xr
                            
                            	Protocol name 
                            	**type**\: str
                            
                            	**length:** 0..40
                            
                            .. attribute:: process_id
                            
                            	Process ID 
                            	**type**\: str
                            
                            	**length:** 0..40
                            
                            .. attribute:: red_metric_flag
                            
                            	red metric flag
                            	**type**\: bool
                            
                            .. attribute:: red_metric
                            
                            	red metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: red_mtype_flag
                            
                            	red mtype flag
                            	**type**\: bool
                            
                            .. attribute:: red_metric_type
                            
                            	red metric type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: red_tag
                            
                            	red tag
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: policy_name
                            
                            	Route policy name 
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions.Redistribution, self).__init__()

                                self.yang_name = "redistribution"
                                self.yang_parent_name = "redistributions"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                    ('process_name', (YLeaf(YType.str, 'process-name'), ['str'])),
                                    ('protocol_name_xr', (YLeaf(YType.str, 'protocol-name-xr'), ['str'])),
                                    ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                    ('red_metric_flag', (YLeaf(YType.boolean, 'red-metric-flag'), ['bool'])),
                                    ('red_metric', (YLeaf(YType.uint32, 'red-metric'), ['int'])),
                                    ('red_mtype_flag', (YLeaf(YType.boolean, 'red-mtype-flag'), ['bool'])),
                                    ('red_metric_type', (YLeaf(YType.uint8, 'red-metric-type'), ['int'])),
                                    ('red_tag', (YLeaf(YType.uint32, 'red-tag'), ['int'])),
                                    ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                                ])
                                self.protocol_name = None
                                self.process_name = None
                                self.protocol_name_xr = None
                                self.process_id = None
                                self.red_metric_flag = None
                                self.red_metric = None
                                self.red_mtype_flag = None
                                self.red_metric_type = None
                                self.red_tag = None
                                self.policy_name = None
                                self._segment_path = lambda: "redistribution"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Redistributions.Redistribution, ['protocol_name', 'process_name', u'protocol_name_xr', u'process_id', u'red_metric_flag', u'red_metric', u'red_mtype_flag', u'red_metric_type', u'red_tag', u'policy_name'], name, value)


                    class ExternalRoutes(Entity):
                        """
                        OSPFv3 external route information table
                        
                        .. attribute:: external_route
                        
                        	OSPFv3 external route information
                        	**type**\: list of  		 :py:class:`ExternalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes, self).__init__()

                            self.yang_name = "external-routes"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("external-route", ("external_route", Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute))])
                            self._leafs = OrderedDict()

                            self.external_route = YList(self)
                            self._segment_path = lambda: "external-routes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes, [], name, value)


                        class ExternalRoute(Entity):
                            """
                            OSPFv3 external route information
                            
                            .. attribute:: prefix
                            
                            	Route prefix
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\: int
                            
                            	**range:** 0..128
                            
                            .. attribute:: route_topology
                            
                            	Common Route topology information
                            	**type**\:  :py:class:`RouteTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteTopology>`
                            
                            .. attribute:: route_extended_community
                            
                            	Extended communities in the route
                            	**type**\:  :py:class:`RouteExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity>`
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of  		 :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute, self).__init__()

                                self.yang_name = "external-route"
                                self.yang_parent_name = "external-routes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("route-topology", ("route_topology", Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteTopology)), ("route-extended-community", ("route_extended_community", Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity)), ("route-path", ("route_path", Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath))])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                ])
                                self.prefix = None
                                self.prefix_length = None

                                self.route_topology = Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteTopology()
                                self.route_topology.parent = self
                                self._children_name_map["route_topology"] = "route-topology"

                                self.route_extended_community = Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity()
                                self.route_extended_community.parent = self
                                self._children_name_map["route_extended_community"] = "route-extended-community"

                                self.route_path = YList(self)
                                self._segment_path = lambda: "external-route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute, ['prefix', 'prefix_length'], name, value)


                            class RouteTopology(Entity):
                                """
                                Common Route topology information
                                
                                .. attribute:: route_id
                                
                                	Route ID 
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_distance
                                
                                	Route distance 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_cost
                                
                                	Route cost 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteTopology, self).__init__()

                                    self.yang_name = "route-topology"
                                    self.yang_parent_name = "external-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_id', (YLeaf(YType.str, 'route-id'), ['str'])),
                                        ('route_distance', (YLeaf(YType.uint32, 'route-distance'), ['int'])),
                                        ('route_cost', (YLeaf(YType.uint32, 'route-cost'), ['int'])),
                                        ('route_type', (YLeaf(YType.uint32, 'route-type'), ['int'])),
                                    ])
                                    self.route_id = None
                                    self.route_distance = None
                                    self.route_cost = None
                                    self.route_type = None
                                    self._segment_path = lambda: "route-topology"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteTopology, [u'route_id', u'route_distance', u'route_cost', u'route_type'], name, value)


                            class RouteExtendedCommunity(Entity):
                                """
                                Extended communities in the route
                                
                                .. attribute:: extended_community_domain_id_value
                                
                                	Domain ID value
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: extended_communityl_domain_id_type
                                
                                	Domain ID type
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: extended_community_area_id
                                
                                	Area id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: extended_community_router_id
                                
                                	Router id
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: extended_community_route_type
                                
                                	Route type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: extended_community_options
                                
                                	Route Options
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity, self).__init__()

                                    self.yang_name = "route-extended-community"
                                    self.yang_parent_name = "external-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('extended_community_domain_id_value', (YLeaf(YType.str, 'extended-community-domain-id-value'), ['str'])),
                                        ('extended_communityl_domain_id_type', (YLeaf(YType.uint16, 'extended-communityl-domain-id-type'), ['int'])),
                                        ('extended_community_area_id', (YLeaf(YType.uint32, 'extended-community-area-id'), ['int'])),
                                        ('extended_community_router_id', (YLeaf(YType.str, 'extended-community-router-id'), ['str'])),
                                        ('extended_community_route_type', (YLeaf(YType.uint8, 'extended-community-route-type'), ['int'])),
                                        ('extended_community_options', (YLeaf(YType.uint8, 'extended-community-options'), ['int'])),
                                    ])
                                    self.extended_community_domain_id_value = None
                                    self.extended_communityl_domain_id_type = None
                                    self.extended_community_area_id = None
                                    self.extended_community_router_id = None
                                    self.extended_community_route_type = None
                                    self.extended_community_options = None
                                    self._segment_path = lambda: "route-extended-community"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity, [u'extended_community_domain_id_value', u'extended_communityl_domain_id_type', u'extended_community_area_id', u'extended_community_router_id', u'extended_community_route_type', u'extended_community_options'], name, value)


                            class RoutePath(Entity):
                                """
                                List of paths to this route
                                
                                .. attribute:: route_backup_path
                                
                                	Backup Path Info
                                	**type**\:  :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath>`
                                
                                .. attribute:: interface_name
                                
                                	Route path interface name 
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: interface_index
                                
                                	Route path interface Index 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_path_next_hop
                                
                                	Route path next hop 
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_path_id
                                
                                	Path ID of path
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_next_hop
                                
                                	NeighborNextHop
                                	**type**\: list of  		 :py:class:`NeighborNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath.NeighborNextHop>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath, self).__init__()

                                    self.yang_name = "route-path"
                                    self.yang_parent_name = "external-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("route-backup-path", ("route_backup_path", Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath)), ("neighbor-next-hop", ("neighbor_next_hop", Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath.NeighborNextHop))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                        ('route_path_next_hop', (YLeaf(YType.str, 'route-path-next-hop'), ['str'])),
                                        ('route_path_id', (YLeaf(YType.uint16, 'route-path-id'), ['int'])),
                                    ])
                                    self.interface_name = None
                                    self.interface_index = None
                                    self.route_path_next_hop = None
                                    self.route_path_id = None

                                    self.route_backup_path = Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath()
                                    self.route_backup_path.parent = self
                                    self._children_name_map["route_backup_path"] = "route-backup-path"

                                    self.neighbor_next_hop = YList(self)
                                    self._segment_path = lambda: "route-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath, [u'interface_name', u'interface_index', u'route_path_next_hop', u'route_path_id'], name, value)


                                class RouteBackupPath(Entity):
                                    """
                                    Backup Path Info
                                    
                                    .. attribute:: backup_route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: backup_route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_route_source
                                    
                                    	IP address of source of route
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_metric
                                    
                                    	Metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: primary_path
                                    
                                    	Primary Path
                                    	**type**\: bool
                                    
                                    .. attribute:: line_card_disjoint
                                    
                                    	Line Card Disjoint
                                    	**type**\: bool
                                    
                                    .. attribute:: downstream
                                    
                                    	Downstream
                                    	**type**\: bool
                                    
                                    .. attribute:: node_protect
                                    
                                    	Node Protect
                                    	**type**\: bool
                                    
                                    .. attribute:: srlg_disjoint
                                    
                                    	SRLG Disjoint
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath, self).__init__()

                                        self.yang_name = "route-backup-path"
                                        self.yang_parent_name = "route-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('backup_route_interface_name', (YLeaf(YType.str, 'backup-route-interface-name'), ['str'])),
                                            ('backup_route_next_hop_address', (YLeaf(YType.str, 'backup-route-next-hop-address'), ['str'])),
                                            ('backup_route_source', (YLeaf(YType.str, 'backup-route-source'), ['str'])),
                                            ('backup_metric', (YLeaf(YType.uint32, 'backup-metric'), ['int'])),
                                            ('primary_path', (YLeaf(YType.boolean, 'primary-path'), ['bool'])),
                                            ('line_card_disjoint', (YLeaf(YType.boolean, 'line-card-disjoint'), ['bool'])),
                                            ('downstream', (YLeaf(YType.boolean, 'downstream'), ['bool'])),
                                            ('node_protect', (YLeaf(YType.boolean, 'node-protect'), ['bool'])),
                                            ('srlg_disjoint', (YLeaf(YType.boolean, 'srlg-disjoint'), ['bool'])),
                                        ])
                                        self.backup_route_interface_name = None
                                        self.backup_route_next_hop_address = None
                                        self.backup_route_source = None
                                        self.backup_metric = None
                                        self.primary_path = None
                                        self.line_card_disjoint = None
                                        self.downstream = None
                                        self.node_protect = None
                                        self.srlg_disjoint = None
                                        self._segment_path = lambda: "route-backup-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath, [u'backup_route_interface_name', u'backup_route_next_hop_address', u'backup_route_source', u'backup_metric', u'primary_path', u'line_card_disjoint', u'downstream', u'node_protect', u'srlg_disjoint'], name, value)


                                class NeighborNextHop(Entity):
                                    """
                                    NeighborNextHop
                                    
                                    .. attribute:: neighbor_next_hop_intf_index
                                    
                                    	Neighbor NextHop Interface Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath.NeighborNextHop, self).__init__()

                                        self.yang_name = "neighbor-next-hop"
                                        self.yang_parent_name = "route-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('neighbor_next_hop_intf_index', (YLeaf(YType.uint32, 'neighbor-next-hop-intf-index'), ['int'])),
                                        ])
                                        self.neighbor_next_hop_intf_index = None
                                        self._segment_path = lambda: "neighbor-next-hop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ExternalRoutes.ExternalRoute.RoutePath.NeighborNextHop, [u'neighbor_next_hop_intf_index'], name, value)


                    class RequestListProcessTable(Entity):
                        """
                        OSPFv3 request list information for all areas
                        
                        .. attribute:: request
                        
                        	OSPFv3 request list information
                        	**type**\: list of  		 :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable, self).__init__()

                            self.yang_name = "request-list-process-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("request", ("request", Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request))])
                            self._leafs = OrderedDict()

                            self.request = YList(self)
                            self._segment_path = lambda: "request-list-process-table"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable, [], name, value)


                        class Request(Entity):
                            """
                            OSPFv3 request list information
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: request_neighbor_address
                            
                            	Neighbor IP address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_request_virtual_link
                            
                            	If true, virtual link is requested 
                            	**type**\: bool
                            
                            .. attribute:: request_virtual_link_id
                            
                            	Request virtual link ID 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_request_sham_link
                            
                            	If true, sham link is requested 
                            	**type**\: bool
                            
                            .. attribute:: request_sham_link_id
                            
                            	Request sham link ID 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: request
                            
                            	List of request list entries
                            	**type**\: list of  		 :py:class:`Request_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request.Request_>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "request-list-process-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("request", ("request", Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request.Request_))])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                    ('request_neighbor_address', (YLeaf(YType.str, 'request-neighbor-address'), ['str'])),
                                    ('is_request_virtual_link', (YLeaf(YType.boolean, 'is-request-virtual-link'), ['bool'])),
                                    ('request_virtual_link_id', (YLeaf(YType.uint32, 'request-virtual-link-id'), ['int'])),
                                    ('is_request_sham_link', (YLeaf(YType.boolean, 'is-request-sham-link'), ['bool'])),
                                    ('request_sham_link_id', (YLeaf(YType.uint32, 'request-sham-link-id'), ['int'])),
                                ])
                                self.interface_name = None
                                self.neighbor_address = None
                                self.request_neighbor_address = None
                                self.is_request_virtual_link = None
                                self.request_virtual_link_id = None
                                self.is_request_sham_link = None
                                self.request_sham_link_id = None

                                self.request = YList(self)
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request, ['interface_name', 'neighbor_address', u'request_neighbor_address', u'is_request_virtual_link', u'request_virtual_link_id', u'is_request_sham_link', u'request_sham_link_id'], name, value)


                            class Request_(Entity):
                                """
                                List of request list entries
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request.Request_, self).__init__()

                                    self.yang_name = "request"
                                    self.yang_parent_name = "request"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                        ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                        ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                        ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                        ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                    ])
                                    self.header_lsa_type = None
                                    self.header_lsa_age = None
                                    self.header_lsa_id = None
                                    self.header_advertising_router = None
                                    self.header_sequence_number = None
                                    self._segment_path = lambda: "request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.RequestListProcessTable.Request.Request_, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                    class VirtualLink(Entity):
                        """
                        Virtual link information
                        
                        .. attribute:: virtual_link_neighbor
                        
                        	Neighbor information 
                        	**type**\:  :py:class:`VirtualLinkNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor>`
                        
                        .. attribute:: virtual_link_neighbor_id
                        
                        	Neighbor on other end of this virtual link
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: virtual_link_interface_number
                        
                        	Virtual link interface number 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_state
                        
                        	OSPF interface state for the virtual link
                        	**type**\:  :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                        
                        .. attribute:: is_virtual_link_ip_security_required
                        
                        	If true, virtual link IP security is required 
                        	**type**\: bool
                        
                        .. attribute:: is_virtual_link_ip_security_active
                        
                        	If true, Virtual link IP security is active 
                        	**type**\: bool
                        
                        .. attribute:: virtual_link_neighbor_address
                        
                        	Virtual link neighbor addresss 
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_virtual_link_demand_circuit
                        
                        	If true, the link runs as demand circuit
                        	**type**\: bool
                        
                        .. attribute:: virtual_link_dc_bitless_lsa
                        
                        	Number of LSA's with demand circuit bit not set 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transit_area_id
                        
                        	Transit area id 
                        	**type**\: str
                        
                        .. attribute:: interface_name
                        
                        	Interface on which this virtual link is formed
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: virtual_link_cost
                        
                        	Cost of the virtual link
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: virual_link_transmission_delay
                        
                        	Transmission delay in seconds
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: virtual_link_hello_interval
                        
                        	Hello interval (s)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_dead_interval
                        
                        	Dead interval (s)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_wait_interval
                        
                        	Wait interval (s)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_retransmission_interval
                        
                        	Retransmission interval (s)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_next_hello
                        
                        	Time until next hello (s)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_virtual_link_passive
                        
                        	If true, interface is passive
                        	**type**\: bool
                        
                        .. attribute:: is_virtual_link_authentication_enabled
                        
                        	If true, virtual link authentication is enabled 
                        	**type**\: bool
                        
                        .. attribute:: virtual_link_authentication_spi
                        
                        	Virtual link authentication spi 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_authentication_transmit
                        
                        	Virtual link authentication transmit 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_virtual_link_encryption_enabled
                        
                        	If true, virtual link encryption is enabled 
                        	**type**\: bool
                        
                        .. attribute:: virtual_link_encryption_spi
                        
                        	Virtual link encryption spi
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_encryption_transmitted
                        
                        	Virtual link encryption transmitted 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: virtual_link_encrypted_authentication_transmitted
                        
                        	Virtual link encrypted authentication transmitted 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink, self).__init__()

                            self.yang_name = "virtual-link"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("virtual-link-neighbor", ("virtual_link_neighbor", Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor))])
                            self._leafs = OrderedDict([
                                ('virtual_link_neighbor_id', (YLeaf(YType.str, 'virtual-link-neighbor-id'), ['str'])),
                                ('virtual_link_interface_number', (YLeaf(YType.uint32, 'virtual-link-interface-number'), ['int'])),
                                ('virtual_link_state', (YLeaf(YType.enumeration, 'virtual-link-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3InterfaceState', '')])),
                                ('is_virtual_link_ip_security_required', (YLeaf(YType.boolean, 'is-virtual-link-ip-security-required'), ['bool'])),
                                ('is_virtual_link_ip_security_active', (YLeaf(YType.boolean, 'is-virtual-link-ip-security-active'), ['bool'])),
                                ('virtual_link_neighbor_address', (YLeaf(YType.str, 'virtual-link-neighbor-address'), ['str'])),
                                ('is_virtual_link_demand_circuit', (YLeaf(YType.boolean, 'is-virtual-link-demand-circuit'), ['bool'])),
                                ('virtual_link_dc_bitless_lsa', (YLeaf(YType.uint32, 'virtual-link-dc-bitless-lsa'), ['int'])),
                                ('transit_area_id', (YLeaf(YType.str, 'transit-area-id'), ['str'])),
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('virtual_link_cost', (YLeaf(YType.uint16, 'virtual-link-cost'), ['int'])),
                                ('virual_link_transmission_delay', (YLeaf(YType.uint16, 'virual-link-transmission-delay'), ['int'])),
                                ('virtual_link_hello_interval', (YLeaf(YType.uint32, 'virtual-link-hello-interval'), ['int'])),
                                ('virtual_link_dead_interval', (YLeaf(YType.uint32, 'virtual-link-dead-interval'), ['int'])),
                                ('virtual_link_wait_interval', (YLeaf(YType.uint32, 'virtual-link-wait-interval'), ['int'])),
                                ('virtual_link_retransmission_interval', (YLeaf(YType.uint32, 'virtual-link-retransmission-interval'), ['int'])),
                                ('virtual_link_next_hello', (YLeaf(YType.uint32, 'virtual-link-next-hello'), ['int'])),
                                ('is_virtual_link_passive', (YLeaf(YType.boolean, 'is-virtual-link-passive'), ['bool'])),
                                ('is_virtual_link_authentication_enabled', (YLeaf(YType.boolean, 'is-virtual-link-authentication-enabled'), ['bool'])),
                                ('virtual_link_authentication_spi', (YLeaf(YType.uint32, 'virtual-link-authentication-spi'), ['int'])),
                                ('virtual_link_authentication_transmit', (YLeaf(YType.uint32, 'virtual-link-authentication-transmit'), ['int'])),
                                ('is_virtual_link_encryption_enabled', (YLeaf(YType.boolean, 'is-virtual-link-encryption-enabled'), ['bool'])),
                                ('virtual_link_encryption_spi', (YLeaf(YType.uint32, 'virtual-link-encryption-spi'), ['int'])),
                                ('virtual_link_encryption_transmitted', (YLeaf(YType.uint32, 'virtual-link-encryption-transmitted'), ['int'])),
                                ('virtual_link_encrypted_authentication_transmitted', (YLeaf(YType.uint32, 'virtual-link-encrypted-authentication-transmitted'), ['int'])),
                            ])
                            self.virtual_link_neighbor_id = None
                            self.virtual_link_interface_number = None
                            self.virtual_link_state = None
                            self.is_virtual_link_ip_security_required = None
                            self.is_virtual_link_ip_security_active = None
                            self.virtual_link_neighbor_address = None
                            self.is_virtual_link_demand_circuit = None
                            self.virtual_link_dc_bitless_lsa = None
                            self.transit_area_id = None
                            self.interface_name = None
                            self.virtual_link_cost = None
                            self.virual_link_transmission_delay = None
                            self.virtual_link_hello_interval = None
                            self.virtual_link_dead_interval = None
                            self.virtual_link_wait_interval = None
                            self.virtual_link_retransmission_interval = None
                            self.virtual_link_next_hello = None
                            self.is_virtual_link_passive = None
                            self.is_virtual_link_authentication_enabled = None
                            self.virtual_link_authentication_spi = None
                            self.virtual_link_authentication_transmit = None
                            self.is_virtual_link_encryption_enabled = None
                            self.virtual_link_encryption_spi = None
                            self.virtual_link_encryption_transmitted = None
                            self.virtual_link_encrypted_authentication_transmitted = None

                            self.virtual_link_neighbor = Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor()
                            self.virtual_link_neighbor.parent = self
                            self._children_name_map["virtual_link_neighbor"] = "virtual-link-neighbor"
                            self._segment_path = lambda: "virtual-link"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink, [u'virtual_link_neighbor_id', u'virtual_link_interface_number', u'virtual_link_state', u'is_virtual_link_ip_security_required', u'is_virtual_link_ip_security_active', u'virtual_link_neighbor_address', u'is_virtual_link_demand_circuit', u'virtual_link_dc_bitless_lsa', u'transit_area_id', u'interface_name', u'virtual_link_cost', u'virual_link_transmission_delay', u'virtual_link_hello_interval', u'virtual_link_dead_interval', u'virtual_link_wait_interval', u'virtual_link_retransmission_interval', u'virtual_link_next_hello', u'is_virtual_link_passive', u'is_virtual_link_authentication_enabled', u'virtual_link_authentication_spi', u'virtual_link_authentication_transmit', u'is_virtual_link_encryption_enabled', u'virtual_link_encryption_spi', u'virtual_link_encryption_transmitted', u'virtual_link_encrypted_authentication_transmitted'], name, value)


                        class VirtualLinkNeighbor(Entity):
                            """
                            Neighbor information 
                            
                            .. attribute:: virtual_link_retransmission
                            
                            	Virtual link retransmission information 
                            	**type**\:  :py:class:`VirtualLinkRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission>`
                            
                            .. attribute:: is_virtual_link_hello_suppressed
                            
                            	If true, hello suppressed 
                            	**type**\: bool
                            
                            .. attribute:: virtual_link_state
                            
                            	OSPF interface state for the virtual link
                            	**type**\:  :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor, self).__init__()

                                self.yang_name = "virtual-link-neighbor"
                                self.yang_parent_name = "virtual-link"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("virtual-link-retransmission", ("virtual_link_retransmission", Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission))])
                                self._leafs = OrderedDict([
                                    ('is_virtual_link_hello_suppressed', (YLeaf(YType.boolean, 'is-virtual-link-hello-suppressed'), ['bool'])),
                                    ('virtual_link_state', (YLeaf(YType.enumeration, 'virtual-link-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3InterfaceState', '')])),
                                ])
                                self.is_virtual_link_hello_suppressed = None
                                self.virtual_link_state = None

                                self.virtual_link_retransmission = Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission()
                                self.virtual_link_retransmission.parent = self
                                self._children_name_map["virtual_link_retransmission"] = "virtual-link-retransmission"
                                self._segment_path = lambda: "virtual-link-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor, [u'is_virtual_link_hello_suppressed', u'virtual_link_state'], name, value)


                            class VirtualLinkRetransmission(Entity):
                                """
                                Virtual link retransmission information 
                                
                                .. attribute:: database_descriptor_retransmissions
                                
                                	Number of database descriptor retransmissions during last exchange
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_flood_index
                                
                                	Area scope LSA's flood index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_flood_index
                                
                                	AS scope LSA's flood index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_flood_index
                                
                                	Link flood index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_retransmissions
                                
                                	Number of neighbor retransmissions 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmissions
                                
                                	Number of retransmissions for this neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_first_flood
                                
                                	First flood item for area scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_first_flood_index
                                
                                	Index of the first flood item for area scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood
                                
                                	First flood item for AS scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood_index
                                
                                	Index for first flood item for AS scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood
                                
                                	Link first flood information 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood_index
                                
                                	Link first flood information index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood
                                
                                	Next flood item for area scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood_index
                                
                                	Index of next flood item for Area scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood
                                
                                	Next flood item for AS scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood_index
                                
                                	Index of next flood item for AS scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood
                                
                                	Link next flood information 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood_index
                                
                                	Link next flood information index 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_length
                                
                                	Number of LSAs sent in last retransmission
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_length
                                
                                	Maximum number of LSAs sent in a retransmission
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_time
                                
                                	Last retransmission scan time (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_time
                                
                                	Maximum retransmission scan time (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_retransmission_timer
                                
                                	Time until next LSA retransmission (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission, self).__init__()

                                    self.yang_name = "virtual-link-retransmission"
                                    self.yang_parent_name = "virtual-link-neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('database_descriptor_retransmissions', (YLeaf(YType.uint32, 'database-descriptor-retransmissions'), ['int'])),
                                        ('area_flood_index', (YLeaf(YType.uint32, 'area-flood-index'), ['int'])),
                                        ('as_flood_index', (YLeaf(YType.uint32, 'as-flood-index'), ['int'])),
                                        ('link_flood_index', (YLeaf(YType.uint32, 'link-flood-index'), ['int'])),
                                        ('neighbor_retransmissions', (YLeaf(YType.uint32, 'neighbor-retransmissions'), ['int'])),
                                        ('retransmissions', (YLeaf(YType.uint32, 'retransmissions'), ['int'])),
                                        ('area_first_flood', (YLeaf(YType.uint32, 'area-first-flood'), ['int'])),
                                        ('area_first_flood_index', (YLeaf(YType.uint32, 'area-first-flood-index'), ['int'])),
                                        ('as_first_flood', (YLeaf(YType.uint32, 'as-first-flood'), ['int'])),
                                        ('as_first_flood_index', (YLeaf(YType.uint32, 'as-first-flood-index'), ['int'])),
                                        ('link_first_flood', (YLeaf(YType.uint32, 'link-first-flood'), ['int'])),
                                        ('link_first_flood_index', (YLeaf(YType.uint32, 'link-first-flood-index'), ['int'])),
                                        ('area_next_flood', (YLeaf(YType.uint32, 'area-next-flood'), ['int'])),
                                        ('area_next_flood_index', (YLeaf(YType.uint32, 'area-next-flood-index'), ['int'])),
                                        ('as_next_flood', (YLeaf(YType.uint32, 'as-next-flood'), ['int'])),
                                        ('as_next_flood_index', (YLeaf(YType.uint32, 'as-next-flood-index'), ['int'])),
                                        ('link_next_flood', (YLeaf(YType.uint32, 'link-next-flood'), ['int'])),
                                        ('link_next_flood_index', (YLeaf(YType.uint32, 'link-next-flood-index'), ['int'])),
                                        ('last_retransmission_length', (YLeaf(YType.uint32, 'last-retransmission-length'), ['int'])),
                                        ('maximum_retransmission_length', (YLeaf(YType.uint32, 'maximum-retransmission-length'), ['int'])),
                                        ('last_retransmission_time', (YLeaf(YType.uint32, 'last-retransmission-time'), ['int'])),
                                        ('maximum_retransmission_time', (YLeaf(YType.uint32, 'maximum-retransmission-time'), ['int'])),
                                        ('lsa_retransmission_timer', (YLeaf(YType.uint32, 'lsa-retransmission-timer'), ['int'])),
                                    ])
                                    self.database_descriptor_retransmissions = None
                                    self.area_flood_index = None
                                    self.as_flood_index = None
                                    self.link_flood_index = None
                                    self.neighbor_retransmissions = None
                                    self.retransmissions = None
                                    self.area_first_flood = None
                                    self.area_first_flood_index = None
                                    self.as_first_flood = None
                                    self.as_first_flood_index = None
                                    self.link_first_flood = None
                                    self.link_first_flood_index = None
                                    self.area_next_flood = None
                                    self.area_next_flood_index = None
                                    self.as_next_flood = None
                                    self.as_next_flood_index = None
                                    self.link_next_flood = None
                                    self.link_next_flood_index = None
                                    self.last_retransmission_length = None
                                    self.maximum_retransmission_length = None
                                    self.last_retransmission_time = None
                                    self.maximum_retransmission_time = None
                                    self.lsa_retransmission_timer = None
                                    self._segment_path = lambda: "virtual-link-retransmission"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission, [u'database_descriptor_retransmissions', u'area_flood_index', u'as_flood_index', u'link_flood_index', u'neighbor_retransmissions', u'retransmissions', u'area_first_flood', u'area_first_flood_index', u'as_first_flood', u'as_first_flood_index', u'link_first_flood', u'link_first_flood_index', u'area_next_flood', u'area_next_flood_index', u'as_next_flood', u'as_next_flood_index', u'link_next_flood', u'link_next_flood_index', u'last_retransmission_length', u'maximum_retransmission_length', u'last_retransmission_time', u'maximum_retransmission_time', u'lsa_retransmission_timer'], name, value)


                    class FloodListProcessTable(Entity):
                        """
                        OSPFv3 flood list information table for all
                        areas
                        
                        .. attribute:: flood
                        
                        	OSPFv3 flood list information
                        	**type**\: list of  		 :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable, self).__init__()

                            self.yang_name = "flood-list-process-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("flood", ("flood", Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood))])
                            self._leafs = OrderedDict()

                            self.flood = YList(self)
                            self._segment_path = lambda: "flood-list-process-table"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable, [], name, value)


                        class Flood(Entity):
                            """
                            OSPFv3 flood list information
                            
                            .. attribute:: interface_name  (key)
                            
                            	Interface name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: ls_transmission_timer
                            
                            	Time until next LS transmission (ms) 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: queue_length
                            
                            	Number of LSAs currently being flooded 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_flood
                            
                            	Link floodlist
                            	**type**\: list of  		 :py:class:`LinkFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.LinkFlood>`
                            
                            .. attribute:: area_flood
                            
                            	Area scope floodlist
                            	**type**\: list of  		 :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AreaFlood>`
                            
                            .. attribute:: as_flood
                            
                            	AS scope floodlist
                            	**type**\: list of  		 :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AsFlood>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood, self).__init__()

                                self.yang_name = "flood"
                                self.yang_parent_name = "flood-list-process-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['interface_name']
                                self._child_classes = OrderedDict([("link-flood", ("link_flood", Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.LinkFlood)), ("area-flood", ("area_flood", Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AreaFlood)), ("as-flood", ("as_flood", Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AsFlood))])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('ls_transmission_timer', (YLeaf(YType.uint32, 'ls-transmission-timer'), ['int'])),
                                    ('queue_length', (YLeaf(YType.uint32, 'queue-length'), ['int'])),
                                ])
                                self.interface_name = None
                                self.ls_transmission_timer = None
                                self.queue_length = None

                                self.link_flood = YList(self)
                                self.area_flood = YList(self)
                                self.as_flood = YList(self)
                                self._segment_path = lambda: "flood" + "[interface-name='" + str(self.interface_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood, ['interface_name', u'ls_transmission_timer', u'queue_length'], name, value)


                            class LinkFlood(Entity):
                                """
                                Link floodlist
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.LinkFlood, self).__init__()

                                    self.yang_name = "link-flood"
                                    self.yang_parent_name = "flood"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                        ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                        ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                        ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                        ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                    ])
                                    self.header_lsa_type = None
                                    self.header_lsa_age = None
                                    self.header_lsa_id = None
                                    self.header_advertising_router = None
                                    self.header_sequence_number = None
                                    self._segment_path = lambda: "link-flood"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.LinkFlood, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                            class AreaFlood(Entity):
                                """
                                Area scope floodlist
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AreaFlood, self).__init__()

                                    self.yang_name = "area-flood"
                                    self.yang_parent_name = "flood"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                        ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                        ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                        ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                        ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                    ])
                                    self.header_lsa_type = None
                                    self.header_lsa_age = None
                                    self.header_lsa_id = None
                                    self.header_advertising_router = None
                                    self.header_sequence_number = None
                                    self._segment_path = lambda: "area-flood"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AreaFlood, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                            class AsFlood(Entity):
                                """
                                AS scope floodlist
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AsFlood, self).__init__()

                                    self.yang_name = "as-flood"
                                    self.yang_parent_name = "flood"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                        ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                        ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                        ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                        ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                    ])
                                    self.header_lsa_type = None
                                    self.header_lsa_age = None
                                    self.header_lsa_id = None
                                    self.header_advertising_router = None
                                    self.header_sequence_number = None
                                    self._segment_path = lambda: "as-flood"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.FloodListProcessTable.Flood.AsFlood, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                    class RouteSummary(Entity):
                        """
                        Summarize OSPFv3 local RIB tables
                        
                        .. attribute:: route_id
                        
                        	Route summary of a route ID 
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: intra_area_route
                        
                        	Intra route summary 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: inter_area_route
                        
                        	Inter route summary 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: extern_one_route
                        
                        	Extern 1 route summary 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: extern_two_route
                        
                        	Extern 2 route summary 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nssa_one_route
                        
                        	NSSA 1 route summary 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nssa_two_route
                        
                        	NSSA 2 route summary 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_sent_route
                        
                        	Total route summary 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_connected
                        
                        	Route connected 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redistribution_route
                        
                        	Redistribution route summary 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_received_route
                        
                        	Total route received summary
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.RouteSummary, self).__init__()

                            self.yang_name = "route-summary"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route_id', (YLeaf(YType.str, 'route-id'), ['str'])),
                                ('intra_area_route', (YLeaf(YType.uint32, 'intra-area-route'), ['int'])),
                                ('inter_area_route', (YLeaf(YType.uint32, 'inter-area-route'), ['int'])),
                                ('extern_one_route', (YLeaf(YType.uint32, 'extern-one-route'), ['int'])),
                                ('extern_two_route', (YLeaf(YType.uint32, 'extern-two-route'), ['int'])),
                                ('nssa_one_route', (YLeaf(YType.uint32, 'nssa-one-route'), ['int'])),
                                ('nssa_two_route', (YLeaf(YType.uint32, 'nssa-two-route'), ['int'])),
                                ('total_sent_route', (YLeaf(YType.uint32, 'total-sent-route'), ['int'])),
                                ('route_connected', (YLeaf(YType.uint32, 'route-connected'), ['int'])),
                                ('redistribution_route', (YLeaf(YType.uint32, 'redistribution-route'), ['int'])),
                                ('total_received_route', (YLeaf(YType.uint32, 'total-received-route'), ['int'])),
                            ])
                            self.route_id = None
                            self.intra_area_route = None
                            self.inter_area_route = None
                            self.extern_one_route = None
                            self.extern_two_route = None
                            self.nssa_one_route = None
                            self.nssa_two_route = None
                            self.total_sent_route = None
                            self.route_connected = None
                            self.redistribution_route = None
                            self.total_received_route = None
                            self._segment_path = lambda: "route-summary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.RouteSummary, [u'route_id', u'intra_area_route', u'inter_area_route', u'extern_one_route', u'extern_two_route', u'nssa_one_route', u'nssa_two_route', u'total_sent_route', u'route_connected', u'redistribution_route', u'total_received_route'], name, value)


                    class Areas(Entity):
                        """
                        OSPFv3 area table
                        
                        .. attribute:: area
                        
                        	Per\-area information
                        	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas, self).__init__()

                            self.yang_name = "areas"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area", ("area", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area))])
                            self._leafs = OrderedDict()

                            self.area = YList(self)
                            self._segment_path = lambda: "areas"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas, [], name, value)


                        class Area(Entity):
                            """
                            Per\-area information
                            
                            .. attribute:: area_id  (key)
                            
                            	Area ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_detail_table
                            
                            	OSPFv3 area neighbor information table
                            	**type**\:  :py:class:`NeighborDetailTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable>`
                            
                            .. attribute:: interface_brief_table
                            
                            	OSPFv3 interface brief information table for an area
                            	**type**\:  :py:class:`InterfaceBriefTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable>`
                            
                            .. attribute:: request_list_table
                            
                            	OSPFv3 request list information in an area
                            	**type**\:  :py:class:`RequestListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable>`
                            
                            .. attribute:: neighbor_table
                            
                            	OSPFv3 neighbor information table
                            	**type**\:  :py:class:`NeighborTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable>`
                            
                            .. attribute:: interface_table
                            
                            	OSPFv3 interface information table for an area
                            	**type**\:  :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable>`
                            
                            .. attribute:: flood_list_table
                            
                            	OSPFv3 flood list information table for an area
                            	**type**\:  :py:class:`FloodListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable>`
                            
                            .. attribute:: retransmission_list_table
                            
                            	OSPFv3 retransmission list information table in an area
                            	**type**\:  :py:class:`RetransmissionListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable>`
                            
                            .. attribute:: database_table
                            
                            	OSPF Link State Database
                            	**type**\:  :py:class:`DatabaseTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable>`
                            
                            .. attribute:: database_summary_table
                            
                            	Database summary table
                            	**type**\:  :py:class:`DatabaseSummaryTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area, self).__init__()

                                self.yang_name = "area"
                                self.yang_parent_name = "areas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['area_id']
                                self._child_classes = OrderedDict([("neighbor-detail-table", ("neighbor_detail_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable)), ("interface-brief-table", ("interface_brief_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable)), ("request-list-table", ("request_list_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable)), ("neighbor-table", ("neighbor_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable)), ("interface-table", ("interface_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable)), ("flood-list-table", ("flood_list_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable)), ("retransmission-list-table", ("retransmission_list_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable)), ("database-table", ("database_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable)), ("database-summary-table", ("database_summary_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable))])
                                self._leafs = OrderedDict([
                                    ('area_id', (YLeaf(YType.uint32, 'area-id'), ['int'])),
                                ])
                                self.area_id = None

                                self.neighbor_detail_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable()
                                self.neighbor_detail_table.parent = self
                                self._children_name_map["neighbor_detail_table"] = "neighbor-detail-table"

                                self.interface_brief_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable()
                                self.interface_brief_table.parent = self
                                self._children_name_map["interface_brief_table"] = "interface-brief-table"

                                self.request_list_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable()
                                self.request_list_table.parent = self
                                self._children_name_map["request_list_table"] = "request-list-table"

                                self.neighbor_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable()
                                self.neighbor_table.parent = self
                                self._children_name_map["neighbor_table"] = "neighbor-table"

                                self.interface_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable()
                                self.interface_table.parent = self
                                self._children_name_map["interface_table"] = "interface-table"

                                self.flood_list_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable()
                                self.flood_list_table.parent = self
                                self._children_name_map["flood_list_table"] = "flood-list-table"

                                self.retransmission_list_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable()
                                self.retransmission_list_table.parent = self
                                self._children_name_map["retransmission_list_table"] = "retransmission-list-table"

                                self.database_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable()
                                self.database_table.parent = self
                                self._children_name_map["database_table"] = "database-table"

                                self.database_summary_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable()
                                self.database_summary_table.parent = self
                                self._children_name_map["database_summary_table"] = "database-summary-table"
                                self._segment_path = lambda: "area" + "[area-id='" + str(self.area_id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area, ['area_id'], name, value)


                            class NeighborDetailTable(Entity):
                                """
                                OSPFv3 area neighbor information table
                                
                                .. attribute:: neighbor_detail
                                
                                	OSPFv3 neighbor detail information
                                	**type**\: list of  		 :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable, self).__init__()

                                    self.yang_name = "neighbor-detail-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor-detail", ("neighbor_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail))])
                                    self._leafs = OrderedDict()

                                    self.neighbor_detail = YList(self)
                                    self._segment_path = lambda: "neighbor-detail-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable, [], name, value)


                                class NeighborDetail(Entity):
                                    """
                                    OSPFv3 neighbor detail information
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_detail
                                    
                                    	Detailed OSPFv3 neighbor information 
                                    	**type**\:  :py:class:`NeighborDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_>`
                                    
                                    .. attribute:: neighbor_bfd_info
                                    
                                    	Neighbor BFD information
                                    	**type**\:  :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo>`
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor IP Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_interface_id
                                    
                                    	Neighbor interface ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_dr_priority
                                    
                                    	Neighbor's DR priority
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: neighbor_state
                                    
                                    	Neighbor's state
                                    	**type**\:  :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                                    
                                    .. attribute:: neighbor_designated_router
                                    
                                    	Designated router 
                                    	**type**\: str
                                    
                                    	**length:** 0..9
                                    
                                    .. attribute:: neighbor_dead_timer
                                    
                                    	Time until neighbor's dead timer expires (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_up_time
                                    
                                    	Amount of time since the adjacency is up (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_virtual_link_id
                                    
                                    	Neighbor virtual link id 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_neighbor_virtual_link
                                    
                                    	If true, neighbor is on a virtual link 
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor_sham_link_id
                                    
                                    	Neighbor sham link id 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_neighbor_sham_link
                                    
                                    	If true, neighbor is on a sham link 
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail, self).__init__()

                                        self.yang_name = "neighbor-detail"
                                        self.yang_parent_name = "neighbor-detail-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor-detail", ("neighbor_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_)), ("neighbor-bfd-info", ("neighbor_bfd_info", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                            ('neighbor_address_xr', (YLeaf(YType.str, 'neighbor-address-xr'), ['str'])),
                                            ('neighbor_interface_id', (YLeaf(YType.uint32, 'neighbor-interface-id'), ['int'])),
                                            ('neighbor_dr_priority', (YLeaf(YType.uint8, 'neighbor-dr-priority'), ['int'])),
                                            ('neighbor_state', (YLeaf(YType.enumeration, 'neighbor-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3NeighborState', '')])),
                                            ('neighbor_designated_router', (YLeaf(YType.str, 'neighbor-designated-router'), ['str'])),
                                            ('neighbor_dead_timer', (YLeaf(YType.uint32, 'neighbor-dead-timer'), ['int'])),
                                            ('neighbor_up_time', (YLeaf(YType.uint32, 'neighbor-up-time'), ['int'])),
                                            ('neighbor_virtual_link_id', (YLeaf(YType.uint32, 'neighbor-virtual-link-id'), ['int'])),
                                            ('is_neighbor_virtual_link', (YLeaf(YType.boolean, 'is-neighbor-virtual-link'), ['bool'])),
                                            ('neighbor_sham_link_id', (YLeaf(YType.uint32, 'neighbor-sham-link-id'), ['int'])),
                                            ('is_neighbor_sham_link', (YLeaf(YType.boolean, 'is-neighbor-sham-link'), ['bool'])),
                                        ])
                                        self.interface_name = None
                                        self.neighbor_address = None
                                        self.neighbor_address_xr = None
                                        self.neighbor_interface_id = None
                                        self.neighbor_dr_priority = None
                                        self.neighbor_state = None
                                        self.neighbor_designated_router = None
                                        self.neighbor_dead_timer = None
                                        self.neighbor_up_time = None
                                        self.neighbor_virtual_link_id = None
                                        self.is_neighbor_virtual_link = None
                                        self.neighbor_sham_link_id = None
                                        self.is_neighbor_sham_link = None

                                        self.neighbor_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_()
                                        self.neighbor_detail.parent = self
                                        self._children_name_map["neighbor_detail"] = "neighbor-detail"

                                        self.neighbor_bfd_info = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo()
                                        self.neighbor_bfd_info.parent = self
                                        self._children_name_map["neighbor_bfd_info"] = "neighbor-bfd-info"
                                        self._segment_path = lambda: "neighbor-detail"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail, ['interface_name', 'neighbor_address', u'neighbor_address_xr', u'neighbor_interface_id', u'neighbor_dr_priority', u'neighbor_state', u'neighbor_designated_router', u'neighbor_dead_timer', u'neighbor_up_time', u'neighbor_virtual_link_id', u'is_neighbor_virtual_link', u'neighbor_sham_link_id', u'is_neighbor_sham_link'], name, value)


                                    class NeighborDetail_(Entity):
                                        """
                                        Detailed OSPFv3 neighbor information 
                                        
                                        .. attribute:: neighbor_retransmission
                                        
                                        	Retransmission information with this neighbor
                                        	**type**\:  :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_.NeighborRetransmission>`
                                        
                                        .. attribute:: state_changes
                                        
                                        	Number of state changes 
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_cost
                                        
                                        	Cost of path to this neighbor 
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_neighbor_filtered
                                        
                                        	If true, filter outgoing LSAs 
                                        	**type**\: bool
                                        
                                        .. attribute:: neighbor_designated_router_address
                                        
                                        	Address of designated router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_backup_designated_router_address
                                        
                                        	Address of backup designated router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: interface_type
                                        
                                        	Interface type
                                        	**type**\:  :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                        
                                        .. attribute:: poll_interval
                                        
                                        	Poll interval (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_poll_interval
                                        
                                        	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: neighbor_ignore_timer
                                        
                                        	Remaining time when ignore timer is running 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_option
                                        
                                        	 This is bitmask of neighbor's option field received 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pending_events
                                        
                                        	Number of pending events 
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_, self).__init__()

                                            self.yang_name = "neighbor-detail"
                                            self.yang_parent_name = "neighbor-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-retransmission", ("neighbor_retransmission", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_.NeighborRetransmission))])
                                            self._leafs = OrderedDict([
                                                ('state_changes', (YLeaf(YType.uint16, 'state-changes'), ['int'])),
                                                ('neighbor_cost', (YLeaf(YType.uint16, 'neighbor-cost'), ['int'])),
                                                ('is_neighbor_filtered', (YLeaf(YType.boolean, 'is-neighbor-filtered'), ['bool'])),
                                                ('neighbor_designated_router_address', (YLeaf(YType.str, 'neighbor-designated-router-address'), ['str'])),
                                                ('neighbor_backup_designated_router_address', (YLeaf(YType.str, 'neighbor-backup-designated-router-address'), ['str'])),
                                                ('interface_type', (YLeaf(YType.enumeration, 'interface-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Interface', '')])),
                                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                                ('next_poll_interval', (YLeaf(YType.uint32, 'next-poll-interval'), ['int'])),
                                                ('neighbor_ignore_timer', (YLeaf(YType.uint32, 'neighbor-ignore-timer'), ['int'])),
                                                ('neighbor_option', (YLeaf(YType.uint32, 'neighbor-option'), ['int'])),
                                                ('pending_events', (YLeaf(YType.uint16, 'pending-events'), ['int'])),
                                            ])
                                            self.state_changes = None
                                            self.neighbor_cost = None
                                            self.is_neighbor_filtered = None
                                            self.neighbor_designated_router_address = None
                                            self.neighbor_backup_designated_router_address = None
                                            self.interface_type = None
                                            self.poll_interval = None
                                            self.next_poll_interval = None
                                            self.neighbor_ignore_timer = None
                                            self.neighbor_option = None
                                            self.pending_events = None

                                            self.neighbor_retransmission = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_.NeighborRetransmission()
                                            self.neighbor_retransmission.parent = self
                                            self._children_name_map["neighbor_retransmission"] = "neighbor-retransmission"
                                            self._segment_path = lambda: "neighbor-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_, [u'state_changes', u'neighbor_cost', u'is_neighbor_filtered', u'neighbor_designated_router_address', u'neighbor_backup_designated_router_address', u'interface_type', u'poll_interval', u'next_poll_interval', u'neighbor_ignore_timer', u'neighbor_option', u'pending_events'], name, value)


                                        class NeighborRetransmission(Entity):
                                            """
                                            Retransmission information with this neighbor
                                            
                                            .. attribute:: database_descriptor_retransmissions
                                            
                                            	Number of database descriptor retransmissions during last exchange
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_flood_index
                                            
                                            	Area scope LSA's flood index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_flood_index
                                            
                                            	AS scope LSA's flood index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_flood_index
                                            
                                            	Link flood index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_retransmissions
                                            
                                            	Number of neighbor retransmissions 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: retransmissions
                                            
                                            	Number of retransmissions for this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_first_flood
                                            
                                            	First flood item for area scope LSAs
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_first_flood_index
                                            
                                            	Index of the first flood item for area scope LSAs
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_first_flood
                                            
                                            	First flood item for AS scope LSAs
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_first_flood_index
                                            
                                            	Index for first flood item for AS scope LSAs
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_first_flood
                                            
                                            	Link first flood information 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_first_flood_index
                                            
                                            	Link first flood information index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_next_flood
                                            
                                            	Next flood item for area scope LSAs
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_next_flood_index
                                            
                                            	Index of next flood item for Area scope LSAs
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_next_flood
                                            
                                            	Next flood item for AS scope LSAs
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_next_flood_index
                                            
                                            	Index of next flood item for AS scope LSAs
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_next_flood
                                            
                                            	Link next flood information 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_next_flood_index
                                            
                                            	Link next flood information index 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_retransmission_length
                                            
                                            	Number of LSAs sent in last retransmission
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_retransmission_length
                                            
                                            	Maximum number of LSAs sent in a retransmission
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_retransmission_time
                                            
                                            	Last retransmission scan time (ms)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_retransmission_time
                                            
                                            	Maximum retransmission scan time (ms)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_retransmission_timer
                                            
                                            	Time until next LSA retransmission (ms)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_.NeighborRetransmission, self).__init__()

                                                self.yang_name = "neighbor-retransmission"
                                                self.yang_parent_name = "neighbor-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('database_descriptor_retransmissions', (YLeaf(YType.uint32, 'database-descriptor-retransmissions'), ['int'])),
                                                    ('area_flood_index', (YLeaf(YType.uint32, 'area-flood-index'), ['int'])),
                                                    ('as_flood_index', (YLeaf(YType.uint32, 'as-flood-index'), ['int'])),
                                                    ('link_flood_index', (YLeaf(YType.uint32, 'link-flood-index'), ['int'])),
                                                    ('neighbor_retransmissions', (YLeaf(YType.uint32, 'neighbor-retransmissions'), ['int'])),
                                                    ('retransmissions', (YLeaf(YType.uint32, 'retransmissions'), ['int'])),
                                                    ('area_first_flood', (YLeaf(YType.uint32, 'area-first-flood'), ['int'])),
                                                    ('area_first_flood_index', (YLeaf(YType.uint32, 'area-first-flood-index'), ['int'])),
                                                    ('as_first_flood', (YLeaf(YType.uint32, 'as-first-flood'), ['int'])),
                                                    ('as_first_flood_index', (YLeaf(YType.uint32, 'as-first-flood-index'), ['int'])),
                                                    ('link_first_flood', (YLeaf(YType.uint32, 'link-first-flood'), ['int'])),
                                                    ('link_first_flood_index', (YLeaf(YType.uint32, 'link-first-flood-index'), ['int'])),
                                                    ('area_next_flood', (YLeaf(YType.uint32, 'area-next-flood'), ['int'])),
                                                    ('area_next_flood_index', (YLeaf(YType.uint32, 'area-next-flood-index'), ['int'])),
                                                    ('as_next_flood', (YLeaf(YType.uint32, 'as-next-flood'), ['int'])),
                                                    ('as_next_flood_index', (YLeaf(YType.uint32, 'as-next-flood-index'), ['int'])),
                                                    ('link_next_flood', (YLeaf(YType.uint32, 'link-next-flood'), ['int'])),
                                                    ('link_next_flood_index', (YLeaf(YType.uint32, 'link-next-flood-index'), ['int'])),
                                                    ('last_retransmission_length', (YLeaf(YType.uint32, 'last-retransmission-length'), ['int'])),
                                                    ('maximum_retransmission_length', (YLeaf(YType.uint32, 'maximum-retransmission-length'), ['int'])),
                                                    ('last_retransmission_time', (YLeaf(YType.uint32, 'last-retransmission-time'), ['int'])),
                                                    ('maximum_retransmission_time', (YLeaf(YType.uint32, 'maximum-retransmission-time'), ['int'])),
                                                    ('lsa_retransmission_timer', (YLeaf(YType.uint32, 'lsa-retransmission-timer'), ['int'])),
                                                ])
                                                self.database_descriptor_retransmissions = None
                                                self.area_flood_index = None
                                                self.as_flood_index = None
                                                self.link_flood_index = None
                                                self.neighbor_retransmissions = None
                                                self.retransmissions = None
                                                self.area_first_flood = None
                                                self.area_first_flood_index = None
                                                self.as_first_flood = None
                                                self.as_first_flood_index = None
                                                self.link_first_flood = None
                                                self.link_first_flood_index = None
                                                self.area_next_flood = None
                                                self.area_next_flood_index = None
                                                self.as_next_flood = None
                                                self.as_next_flood_index = None
                                                self.link_next_flood = None
                                                self.link_next_flood_index = None
                                                self.last_retransmission_length = None
                                                self.maximum_retransmission_length = None
                                                self.last_retransmission_time = None
                                                self.maximum_retransmission_time = None
                                                self.lsa_retransmission_timer = None
                                                self._segment_path = lambda: "neighbor-retransmission"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_.NeighborRetransmission, [u'database_descriptor_retransmissions', u'area_flood_index', u'as_flood_index', u'link_flood_index', u'neighbor_retransmissions', u'retransmissions', u'area_first_flood', u'area_first_flood_index', u'as_first_flood', u'as_first_flood_index', u'link_first_flood', u'link_first_flood_index', u'area_next_flood', u'area_next_flood_index', u'as_next_flood', u'as_next_flood_index', u'link_next_flood', u'link_next_flood_index', u'last_retransmission_length', u'maximum_retransmission_length', u'last_retransmission_time', u'maximum_retransmission_time', u'lsa_retransmission_timer'], name, value)


                                    class NeighborBfdInfo(Entity):
                                        """
                                        Neighbor BFD information
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD enable mode \- Default/Strict
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_status_flag
                                        
                                        	Status of the BFD Session
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo, self).__init__()

                                            self.yang_name = "neighbor-bfd-info"
                                            self.yang_parent_name = "neighbor-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bfd_intf_enable_mode', (YLeaf(YType.uint32, 'bfd-intf-enable-mode'), ['int'])),
                                                ('bfd_status_flag', (YLeaf(YType.uint8, 'bfd-status-flag'), ['int'])),
                                            ])
                                            self.bfd_intf_enable_mode = None
                                            self.bfd_status_flag = None
                                            self._segment_path = lambda: "neighbor-bfd-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo, [u'bfd_intf_enable_mode', u'bfd_status_flag'], name, value)


                            class InterfaceBriefTable(Entity):
                                """
                                OSPFv3 interface brief information table for
                                an area
                                
                                .. attribute:: interface_brief
                                
                                	Interface brief information
                                	**type**\: list of  		 :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable.InterfaceBrief>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable, self).__init__()

                                    self.yang_name = "interface-brief-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("interface-brief", ("interface_brief", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable.InterfaceBrief))])
                                    self._leafs = OrderedDict()

                                    self.interface_brief = YList(self)
                                    self._segment_path = lambda: "interface-brief-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable, [], name, value)


                                class InterfaceBrief(Entity):
                                    """
                                    Interface brief information
                                    
                                    .. attribute:: interface_name  (key)
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: interface_address
                                    
                                    	Interface IP address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_link_cost
                                    
                                    	Interface link cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ospf_interface_state
                                    
                                    	Interface OSPF state
                                    	**type**\:  :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                                    
                                    .. attribute:: interface_neighbors
                                    
                                    	Total number of neighbors 
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interface_adjacent_neighbors
                                    
                                    	Total number of adjacent neighbors
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: network_type
                                    
                                    	Network type
                                    	**type**\:  :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable.InterfaceBrief, self).__init__()

                                        self.yang_name = "interface-brief"
                                        self.yang_parent_name = "interface-brief-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['interface_name']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('interface_address', (YLeaf(YType.str, 'interface-address'), ['str'])),
                                            ('interface_link_cost', (YLeaf(YType.uint16, 'interface-link-cost'), ['int'])),
                                            ('ospf_interface_state', (YLeaf(YType.enumeration, 'ospf-interface-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3InterfaceState', '')])),
                                            ('interface_neighbors', (YLeaf(YType.uint16, 'interface-neighbors'), ['int'])),
                                            ('interface_adjacent_neighbors', (YLeaf(YType.uint16, 'interface-adjacent-neighbors'), ['int'])),
                                            ('network_type', (YLeaf(YType.enumeration, 'network-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Interface', '')])),
                                        ])
                                        self.interface_name = None
                                        self.interface_address = None
                                        self.interface_link_cost = None
                                        self.ospf_interface_state = None
                                        self.interface_neighbors = None
                                        self.interface_adjacent_neighbors = None
                                        self.network_type = None
                                        self._segment_path = lambda: "interface-brief" + "[interface-name='" + str(self.interface_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceBriefTable.InterfaceBrief, ['interface_name', u'interface_address', u'interface_link_cost', u'ospf_interface_state', u'interface_neighbors', u'interface_adjacent_neighbors', u'network_type'], name, value)


                            class RequestListTable(Entity):
                                """
                                OSPFv3 request list information in an area
                                
                                .. attribute:: request
                                
                                	OSPFv3 request list information
                                	**type**\: list of  		 :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable, self).__init__()

                                    self.yang_name = "request-list-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("request", ("request", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request))])
                                    self._leafs = OrderedDict()

                                    self.request = YList(self)
                                    self._segment_path = lambda: "request-list-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable, [], name, value)


                                class Request(Entity):
                                    """
                                    OSPFv3 request list information
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: request_neighbor_address
                                    
                                    	Neighbor IP address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_request_virtual_link
                                    
                                    	If true, virtual link is requested 
                                    	**type**\: bool
                                    
                                    .. attribute:: request_virtual_link_id
                                    
                                    	Request virtual link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_request_sham_link
                                    
                                    	If true, sham link is requested 
                                    	**type**\: bool
                                    
                                    .. attribute:: request_sham_link_id
                                    
                                    	Request sham link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: request
                                    
                                    	List of request list entries
                                    	**type**\: list of  		 :py:class:`Request_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request.Request_>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request, self).__init__()

                                        self.yang_name = "request"
                                        self.yang_parent_name = "request-list-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("request", ("request", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request.Request_))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                            ('request_neighbor_address', (YLeaf(YType.str, 'request-neighbor-address'), ['str'])),
                                            ('is_request_virtual_link', (YLeaf(YType.boolean, 'is-request-virtual-link'), ['bool'])),
                                            ('request_virtual_link_id', (YLeaf(YType.uint32, 'request-virtual-link-id'), ['int'])),
                                            ('is_request_sham_link', (YLeaf(YType.boolean, 'is-request-sham-link'), ['bool'])),
                                            ('request_sham_link_id', (YLeaf(YType.uint32, 'request-sham-link-id'), ['int'])),
                                        ])
                                        self.interface_name = None
                                        self.neighbor_address = None
                                        self.request_neighbor_address = None
                                        self.is_request_virtual_link = None
                                        self.request_virtual_link_id = None
                                        self.is_request_sham_link = None
                                        self.request_sham_link_id = None

                                        self.request = YList(self)
                                        self._segment_path = lambda: "request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request, ['interface_name', 'neighbor_address', u'request_neighbor_address', u'is_request_virtual_link', u'request_virtual_link_id', u'is_request_sham_link', u'request_sham_link_id'], name, value)


                                    class Request_(Entity):
                                        """
                                        List of request list entries
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request.Request_, self).__init__()

                                            self.yang_name = "request"
                                            self.yang_parent_name = "request"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                                ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                                ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                                ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                                ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                            ])
                                            self.header_lsa_type = None
                                            self.header_lsa_age = None
                                            self.header_lsa_id = None
                                            self.header_advertising_router = None
                                            self.header_sequence_number = None
                                            self._segment_path = lambda: "request"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RequestListTable.Request.Request_, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                            class NeighborTable(Entity):
                                """
                                OSPFv3 neighbor information table
                                
                                .. attribute:: neighbor
                                
                                	OSPFv3 neighbor detail information
                                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable, self).__init__()

                                    self.yang_name = "neighbor-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor))])
                                    self._leafs = OrderedDict()

                                    self.neighbor = YList(self)
                                    self._segment_path = lambda: "neighbor-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable, [], name, value)


                                class Neighbor(Entity):
                                    """
                                    OSPFv3 neighbor detail information
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_detail
                                    
                                    	Detailed OSPFv3 neighbor information 
                                    	**type**\:  :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail>`
                                    
                                    .. attribute:: neighbor_bfd_info
                                    
                                    	Neighbor BFD information
                                    	**type**\:  :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo>`
                                    
                                    .. attribute:: neighbor_address_xr
                                    
                                    	Neighbor IP Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_interface_id
                                    
                                    	Neighbor interface ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_dr_priority
                                    
                                    	Neighbor's DR priority
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: neighbor_state
                                    
                                    	Neighbor's state
                                    	**type**\:  :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                                    
                                    .. attribute:: neighbor_designated_router
                                    
                                    	Designated router 
                                    	**type**\: str
                                    
                                    	**length:** 0..9
                                    
                                    .. attribute:: neighbor_dead_timer
                                    
                                    	Time until neighbor's dead timer expires (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_up_time
                                    
                                    	Amount of time since the adjacency is up (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_virtual_link_id
                                    
                                    	Neighbor virtual link id 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_neighbor_virtual_link
                                    
                                    	If true, neighbor is on a virtual link 
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor_sham_link_id
                                    
                                    	Neighbor sham link id 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_neighbor_sham_link
                                    
                                    	If true, neighbor is on a sham link 
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor, self).__init__()

                                        self.yang_name = "neighbor"
                                        self.yang_parent_name = "neighbor-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor-detail", ("neighbor_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail)), ("neighbor-bfd-info", ("neighbor_bfd_info", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                            ('neighbor_address_xr', (YLeaf(YType.str, 'neighbor-address-xr'), ['str'])),
                                            ('neighbor_interface_id', (YLeaf(YType.uint32, 'neighbor-interface-id'), ['int'])),
                                            ('neighbor_dr_priority', (YLeaf(YType.uint8, 'neighbor-dr-priority'), ['int'])),
                                            ('neighbor_state', (YLeaf(YType.enumeration, 'neighbor-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3NeighborState', '')])),
                                            ('neighbor_designated_router', (YLeaf(YType.str, 'neighbor-designated-router'), ['str'])),
                                            ('neighbor_dead_timer', (YLeaf(YType.uint32, 'neighbor-dead-timer'), ['int'])),
                                            ('neighbor_up_time', (YLeaf(YType.uint32, 'neighbor-up-time'), ['int'])),
                                            ('neighbor_virtual_link_id', (YLeaf(YType.uint32, 'neighbor-virtual-link-id'), ['int'])),
                                            ('is_neighbor_virtual_link', (YLeaf(YType.boolean, 'is-neighbor-virtual-link'), ['bool'])),
                                            ('neighbor_sham_link_id', (YLeaf(YType.uint32, 'neighbor-sham-link-id'), ['int'])),
                                            ('is_neighbor_sham_link', (YLeaf(YType.boolean, 'is-neighbor-sham-link'), ['bool'])),
                                        ])
                                        self.interface_name = None
                                        self.neighbor_address = None
                                        self.neighbor_address_xr = None
                                        self.neighbor_interface_id = None
                                        self.neighbor_dr_priority = None
                                        self.neighbor_state = None
                                        self.neighbor_designated_router = None
                                        self.neighbor_dead_timer = None
                                        self.neighbor_up_time = None
                                        self.neighbor_virtual_link_id = None
                                        self.is_neighbor_virtual_link = None
                                        self.neighbor_sham_link_id = None
                                        self.is_neighbor_sham_link = None

                                        self.neighbor_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail()
                                        self.neighbor_detail.parent = self
                                        self._children_name_map["neighbor_detail"] = "neighbor-detail"

                                        self.neighbor_bfd_info = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo()
                                        self.neighbor_bfd_info.parent = self
                                        self._children_name_map["neighbor_bfd_info"] = "neighbor-bfd-info"
                                        self._segment_path = lambda: "neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor, ['interface_name', 'neighbor_address', u'neighbor_address_xr', u'neighbor_interface_id', u'neighbor_dr_priority', u'neighbor_state', u'neighbor_designated_router', u'neighbor_dead_timer', u'neighbor_up_time', u'neighbor_virtual_link_id', u'is_neighbor_virtual_link', u'neighbor_sham_link_id', u'is_neighbor_sham_link'], name, value)


                                    class NeighborDetail(Entity):
                                        """
                                        Detailed OSPFv3 neighbor information 
                                        
                                        .. attribute:: neighbor_retransmission
                                        
                                        	Retransmission information with this neighbor
                                        	**type**\:  :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission>`
                                        
                                        .. attribute:: state_changes
                                        
                                        	Number of state changes 
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: neighbor_cost
                                        
                                        	Cost of path to this neighbor 
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_neighbor_filtered
                                        
                                        	If true, filter outgoing LSAs 
                                        	**type**\: bool
                                        
                                        .. attribute:: neighbor_designated_router_address
                                        
                                        	Address of designated router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: neighbor_backup_designated_router_address
                                        
                                        	Address of backup designated router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: interface_type
                                        
                                        	Interface type
                                        	**type**\:  :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                        
                                        .. attribute:: poll_interval
                                        
                                        	Poll interval (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_poll_interval
                                        
                                        	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: neighbor_ignore_timer
                                        
                                        	Remaining time when ignore timer is running 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_option
                                        
                                        	 This is bitmask of neighbor's option field received 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: pending_events
                                        
                                        	Number of pending events 
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail, self).__init__()

                                            self.yang_name = "neighbor-detail"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("neighbor-retransmission", ("neighbor_retransmission", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission))])
                                            self._leafs = OrderedDict([
                                                ('state_changes', (YLeaf(YType.uint16, 'state-changes'), ['int'])),
                                                ('neighbor_cost', (YLeaf(YType.uint16, 'neighbor-cost'), ['int'])),
                                                ('is_neighbor_filtered', (YLeaf(YType.boolean, 'is-neighbor-filtered'), ['bool'])),
                                                ('neighbor_designated_router_address', (YLeaf(YType.str, 'neighbor-designated-router-address'), ['str'])),
                                                ('neighbor_backup_designated_router_address', (YLeaf(YType.str, 'neighbor-backup-designated-router-address'), ['str'])),
                                                ('interface_type', (YLeaf(YType.enumeration, 'interface-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Interface', '')])),
                                                ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                                ('next_poll_interval', (YLeaf(YType.uint32, 'next-poll-interval'), ['int'])),
                                                ('neighbor_ignore_timer', (YLeaf(YType.uint32, 'neighbor-ignore-timer'), ['int'])),
                                                ('neighbor_option', (YLeaf(YType.uint32, 'neighbor-option'), ['int'])),
                                                ('pending_events', (YLeaf(YType.uint16, 'pending-events'), ['int'])),
                                            ])
                                            self.state_changes = None
                                            self.neighbor_cost = None
                                            self.is_neighbor_filtered = None
                                            self.neighbor_designated_router_address = None
                                            self.neighbor_backup_designated_router_address = None
                                            self.interface_type = None
                                            self.poll_interval = None
                                            self.next_poll_interval = None
                                            self.neighbor_ignore_timer = None
                                            self.neighbor_option = None
                                            self.pending_events = None

                                            self.neighbor_retransmission = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission()
                                            self.neighbor_retransmission.parent = self
                                            self._children_name_map["neighbor_retransmission"] = "neighbor-retransmission"
                                            self._segment_path = lambda: "neighbor-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail, [u'state_changes', u'neighbor_cost', u'is_neighbor_filtered', u'neighbor_designated_router_address', u'neighbor_backup_designated_router_address', u'interface_type', u'poll_interval', u'next_poll_interval', u'neighbor_ignore_timer', u'neighbor_option', u'pending_events'], name, value)


                                        class NeighborRetransmission(Entity):
                                            """
                                            Retransmission information with this neighbor
                                            
                                            .. attribute:: database_descriptor_retransmissions
                                            
                                            	Number of database descriptor retransmissions during last exchange
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_flood_index
                                            
                                            	Area scope LSA's flood index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_flood_index
                                            
                                            	AS scope LSA's flood index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_flood_index
                                            
                                            	Link flood index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: neighbor_retransmissions
                                            
                                            	Number of neighbor retransmissions 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: retransmissions
                                            
                                            	Number of retransmissions for this neighbor
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_first_flood
                                            
                                            	First flood item for area scope LSAs
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_first_flood_index
                                            
                                            	Index of the first flood item for area scope LSAs
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_first_flood
                                            
                                            	First flood item for AS scope LSAs
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_first_flood_index
                                            
                                            	Index for first flood item for AS scope LSAs
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_first_flood
                                            
                                            	Link first flood information 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_first_flood_index
                                            
                                            	Link first flood information index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_next_flood
                                            
                                            	Next flood item for area scope LSAs
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: area_next_flood_index
                                            
                                            	Index of next flood item for Area scope LSAs
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_next_flood
                                            
                                            	Next flood item for AS scope LSAs
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_next_flood_index
                                            
                                            	Index of next flood item for AS scope LSAs
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_next_flood
                                            
                                            	Link next flood information 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: link_next_flood_index
                                            
                                            	Link next flood information index 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_retransmission_length
                                            
                                            	Number of LSAs sent in last retransmission
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_retransmission_length
                                            
                                            	Maximum number of LSAs sent in a retransmission
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: last_retransmission_time
                                            
                                            	Last retransmission scan time (ms)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: maximum_retransmission_time
                                            
                                            	Maximum retransmission scan time (ms)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_retransmission_timer
                                            
                                            	Time until next LSA retransmission (ms)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission, self).__init__()

                                                self.yang_name = "neighbor-retransmission"
                                                self.yang_parent_name = "neighbor-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('database_descriptor_retransmissions', (YLeaf(YType.uint32, 'database-descriptor-retransmissions'), ['int'])),
                                                    ('area_flood_index', (YLeaf(YType.uint32, 'area-flood-index'), ['int'])),
                                                    ('as_flood_index', (YLeaf(YType.uint32, 'as-flood-index'), ['int'])),
                                                    ('link_flood_index', (YLeaf(YType.uint32, 'link-flood-index'), ['int'])),
                                                    ('neighbor_retransmissions', (YLeaf(YType.uint32, 'neighbor-retransmissions'), ['int'])),
                                                    ('retransmissions', (YLeaf(YType.uint32, 'retransmissions'), ['int'])),
                                                    ('area_first_flood', (YLeaf(YType.uint32, 'area-first-flood'), ['int'])),
                                                    ('area_first_flood_index', (YLeaf(YType.uint32, 'area-first-flood-index'), ['int'])),
                                                    ('as_first_flood', (YLeaf(YType.uint32, 'as-first-flood'), ['int'])),
                                                    ('as_first_flood_index', (YLeaf(YType.uint32, 'as-first-flood-index'), ['int'])),
                                                    ('link_first_flood', (YLeaf(YType.uint32, 'link-first-flood'), ['int'])),
                                                    ('link_first_flood_index', (YLeaf(YType.uint32, 'link-first-flood-index'), ['int'])),
                                                    ('area_next_flood', (YLeaf(YType.uint32, 'area-next-flood'), ['int'])),
                                                    ('area_next_flood_index', (YLeaf(YType.uint32, 'area-next-flood-index'), ['int'])),
                                                    ('as_next_flood', (YLeaf(YType.uint32, 'as-next-flood'), ['int'])),
                                                    ('as_next_flood_index', (YLeaf(YType.uint32, 'as-next-flood-index'), ['int'])),
                                                    ('link_next_flood', (YLeaf(YType.uint32, 'link-next-flood'), ['int'])),
                                                    ('link_next_flood_index', (YLeaf(YType.uint32, 'link-next-flood-index'), ['int'])),
                                                    ('last_retransmission_length', (YLeaf(YType.uint32, 'last-retransmission-length'), ['int'])),
                                                    ('maximum_retransmission_length', (YLeaf(YType.uint32, 'maximum-retransmission-length'), ['int'])),
                                                    ('last_retransmission_time', (YLeaf(YType.uint32, 'last-retransmission-time'), ['int'])),
                                                    ('maximum_retransmission_time', (YLeaf(YType.uint32, 'maximum-retransmission-time'), ['int'])),
                                                    ('lsa_retransmission_timer', (YLeaf(YType.uint32, 'lsa-retransmission-timer'), ['int'])),
                                                ])
                                                self.database_descriptor_retransmissions = None
                                                self.area_flood_index = None
                                                self.as_flood_index = None
                                                self.link_flood_index = None
                                                self.neighbor_retransmissions = None
                                                self.retransmissions = None
                                                self.area_first_flood = None
                                                self.area_first_flood_index = None
                                                self.as_first_flood = None
                                                self.as_first_flood_index = None
                                                self.link_first_flood = None
                                                self.link_first_flood_index = None
                                                self.area_next_flood = None
                                                self.area_next_flood_index = None
                                                self.as_next_flood = None
                                                self.as_next_flood_index = None
                                                self.link_next_flood = None
                                                self.link_next_flood_index = None
                                                self.last_retransmission_length = None
                                                self.maximum_retransmission_length = None
                                                self.last_retransmission_time = None
                                                self.maximum_retransmission_time = None
                                                self.lsa_retransmission_timer = None
                                                self._segment_path = lambda: "neighbor-retransmission"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission, [u'database_descriptor_retransmissions', u'area_flood_index', u'as_flood_index', u'link_flood_index', u'neighbor_retransmissions', u'retransmissions', u'area_first_flood', u'area_first_flood_index', u'as_first_flood', u'as_first_flood_index', u'link_first_flood', u'link_first_flood_index', u'area_next_flood', u'area_next_flood_index', u'as_next_flood', u'as_next_flood_index', u'link_next_flood', u'link_next_flood_index', u'last_retransmission_length', u'maximum_retransmission_length', u'last_retransmission_time', u'maximum_retransmission_time', u'lsa_retransmission_timer'], name, value)


                                    class NeighborBfdInfo(Entity):
                                        """
                                        Neighbor BFD information
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD enable mode \- Default/Strict
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_status_flag
                                        
                                        	Status of the BFD Session
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo, self).__init__()

                                            self.yang_name = "neighbor-bfd-info"
                                            self.yang_parent_name = "neighbor"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bfd_intf_enable_mode', (YLeaf(YType.uint32, 'bfd-intf-enable-mode'), ['int'])),
                                                ('bfd_status_flag', (YLeaf(YType.uint8, 'bfd-status-flag'), ['int'])),
                                            ])
                                            self.bfd_intf_enable_mode = None
                                            self.bfd_status_flag = None
                                            self._segment_path = lambda: "neighbor-bfd-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo, [u'bfd_intf_enable_mode', u'bfd_status_flag'], name, value)


                            class InterfaceTable(Entity):
                                """
                                OSPFv3 interface information table for an area
                                
                                .. attribute:: interface
                                
                                	OSPFv3 interface information
                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable, self).__init__()

                                    self.yang_name = "interface-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("interface", ("interface", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface))])
                                    self._leafs = OrderedDict()

                                    self.interface = YList(self)
                                    self._segment_path = lambda: "interface-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable, [], name, value)


                                class Interface(Entity):
                                    """
                                    OSPFv3 interface information
                                    
                                    .. attribute:: interface_name  (key)
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: active_interface
                                    
                                    	Active interface details 
                                    	**type**\:  :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.ActiveInterface>`
                                    
                                    .. attribute:: interface_bfd
                                    
                                    	BFD information 
                                    	**type**\:  :py:class:`InterfaceBfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd>`
                                    
                                    .. attribute:: interface_state
                                    
                                    	Interface state
                                    	**type**\:  :py:class:`ImStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.ImStateEnum>`
                                    
                                    .. attribute:: is_interface_line_up
                                    
                                    	If true, line protocol is up 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_interface_ip_security_required
                                    
                                    	If true, interface IP security is required 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_interface_ip_security_active
                                    
                                    	If true, interface IP security is active 
                                    	**type**\: bool
                                    
                                    .. attribute:: interface_address
                                    
                                    	Interface IPv6 address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_number
                                    
                                    	Interface number 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_router_id
                                    
                                    	Interface router ID 
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: network_type
                                    
                                    	Network type
                                    	**type**\:  :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                    
                                    .. attribute:: interface_link_cost
                                    
                                    	Interface link cost
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: is_interface_flood_reduction
                                    
                                    	If true, interface flood reduction is active 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_demand_circuit_configured
                                    
                                    	If true, configured as demand circuit 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_interface_demand_circuit
                                    
                                    	If true, interface running as demand circuit
                                    	**type**\: bool
                                    
                                    .. attribute:: interface_dc_bitless_ls_as
                                    
                                    	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: transmission_delay
                                    
                                    	Interface transmission delay (sec)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: ospf_interface_state
                                    
                                    	Interface state
                                    	**type**\:  :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                                    
                                    .. attribute:: interface_priority
                                    
                                    	Interface priority
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: is_designated_router
                                    
                                    	If true, designated router
                                    	**type**\: bool
                                    
                                    .. attribute:: designated_router_id
                                    
                                    	Designated router ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: designated_router_address
                                    
                                    	Designated router interface address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_designated_router_id
                                    
                                    	Backup designated router ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_designated_router_address
                                    
                                    	Backup designated router interface address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: network_lsa_flush_timer
                                    
                                    	The amount of time in seconds before flush timer for old network LSA expires 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: is_interface_lsa_filtered
                                    
                                    	Filter is configured for out going LSAs 
                                    	**type**\: bool
                                    
                                    .. attribute:: hello_interval
                                    
                                    	Configured hello interval (s)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: dead_interval
                                    
                                    	Configured dead interval (s) 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: wait_interval
                                    
                                    	Configured wait interval (s) 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_retransmission_interval
                                    
                                    	Configured retransmit interval (s) 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hello_time
                                    
                                    	Time until next Hello (s) 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_authentication_spi
                                    
                                    	Interface authentication spi 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_authentication_transmit
                                    
                                    	Interface authentication transmit 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_interface_encryption_enabled
                                    
                                    	If true, interface encryption is enabled 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_prefix_suppress
                                    
                                    	If true prefix suppression is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: interface_encryption_spi
                                    
                                    	Interface encryption spi
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_encryption_transmitted
                                    
                                    	Interface encryption transmitted 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_encrypted_authentication_transmitted
                                    
                                    	Interface encrypted authentication transmitted 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: adjacent_neighbor
                                    
                                    	Number of adjacent neighbors
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_references
                                    
                                    	Interface reference count 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: configured_ldp_sync
                                    
                                    	If true, configured as LDP sync
                                    	**type**\: bool
                                    
                                    .. attribute:: interface_ldp_sync
                                    
                                    	If true, interface LDP sync is achieved
                                    	**type**\: bool
                                    
                                    .. attribute:: interface_neighbor
                                    
                                    	Information for neighbors on the interface
                                    	**type**\: list of  		 :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface, self).__init__()

                                        self.yang_name = "interface"
                                        self.yang_parent_name = "interface-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['interface_name']
                                        self._child_classes = OrderedDict([("active-interface", ("active_interface", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.ActiveInterface)), ("interface-bfd", ("interface_bfd", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd)), ("interface-neighbor", ("interface_neighbor", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('interface_state', (YLeaf(YType.enumeration, 'interface-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'ImStateEnum', '')])),
                                            ('is_interface_line_up', (YLeaf(YType.boolean, 'is-interface-line-up'), ['bool'])),
                                            ('is_interface_ip_security_required', (YLeaf(YType.boolean, 'is-interface-ip-security-required'), ['bool'])),
                                            ('is_interface_ip_security_active', (YLeaf(YType.boolean, 'is-interface-ip-security-active'), ['bool'])),
                                            ('interface_address', (YLeaf(YType.str, 'interface-address'), ['str'])),
                                            ('interface_number', (YLeaf(YType.uint32, 'interface-number'), ['int'])),
                                            ('interface_router_id', (YLeaf(YType.str, 'interface-router-id'), ['str'])),
                                            ('network_type', (YLeaf(YType.enumeration, 'network-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Interface', '')])),
                                            ('interface_link_cost', (YLeaf(YType.uint16, 'interface-link-cost'), ['int'])),
                                            ('is_interface_flood_reduction', (YLeaf(YType.boolean, 'is-interface-flood-reduction'), ['bool'])),
                                            ('is_demand_circuit_configured', (YLeaf(YType.boolean, 'is-demand-circuit-configured'), ['bool'])),
                                            ('is_interface_demand_circuit', (YLeaf(YType.boolean, 'is-interface-demand-circuit'), ['bool'])),
                                            ('interface_dc_bitless_ls_as', (YLeaf(YType.uint32, 'interface-dc-bitless-ls-as'), ['int'])),
                                            ('transmission_delay', (YLeaf(YType.uint16, 'transmission-delay'), ['int'])),
                                            ('ospf_interface_state', (YLeaf(YType.enumeration, 'ospf-interface-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3InterfaceState', '')])),
                                            ('interface_priority', (YLeaf(YType.uint8, 'interface-priority'), ['int'])),
                                            ('is_designated_router', (YLeaf(YType.boolean, 'is-designated-router'), ['bool'])),
                                            ('designated_router_id', (YLeaf(YType.str, 'designated-router-id'), ['str'])),
                                            ('designated_router_address', (YLeaf(YType.str, 'designated-router-address'), ['str'])),
                                            ('backup_designated_router_id', (YLeaf(YType.str, 'backup-designated-router-id'), ['str'])),
                                            ('backup_designated_router_address', (YLeaf(YType.str, 'backup-designated-router-address'), ['str'])),
                                            ('network_lsa_flush_timer', (YLeaf(YType.uint32, 'network-lsa-flush-timer'), ['int'])),
                                            ('is_interface_lsa_filtered', (YLeaf(YType.boolean, 'is-interface-lsa-filtered'), ['bool'])),
                                            ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                            ('dead_interval', (YLeaf(YType.uint32, 'dead-interval'), ['int'])),
                                            ('wait_interval', (YLeaf(YType.uint32, 'wait-interval'), ['int'])),
                                            ('interface_retransmission_interval', (YLeaf(YType.uint32, 'interface-retransmission-interval'), ['int'])),
                                            ('next_hello_time', (YLeaf(YType.uint32, 'next-hello-time'), ['int'])),
                                            ('interface_authentication_spi', (YLeaf(YType.uint32, 'interface-authentication-spi'), ['int'])),
                                            ('interface_authentication_transmit', (YLeaf(YType.uint32, 'interface-authentication-transmit'), ['int'])),
                                            ('is_interface_encryption_enabled', (YLeaf(YType.boolean, 'is-interface-encryption-enabled'), ['bool'])),
                                            ('is_prefix_suppress', (YLeaf(YType.boolean, 'is-prefix-suppress'), ['bool'])),
                                            ('interface_encryption_spi', (YLeaf(YType.uint32, 'interface-encryption-spi'), ['int'])),
                                            ('interface_encryption_transmitted', (YLeaf(YType.uint32, 'interface-encryption-transmitted'), ['int'])),
                                            ('interface_encrypted_authentication_transmitted', (YLeaf(YType.uint32, 'interface-encrypted-authentication-transmitted'), ['int'])),
                                            ('adjacent_neighbor', (YLeaf(YType.uint32, 'adjacent-neighbor'), ['int'])),
                                            ('interface_references', (YLeaf(YType.uint32, 'interface-references'), ['int'])),
                                            ('configured_ldp_sync', (YLeaf(YType.boolean, 'configured-ldp-sync'), ['bool'])),
                                            ('interface_ldp_sync', (YLeaf(YType.boolean, 'interface-ldp-sync'), ['bool'])),
                                        ])
                                        self.interface_name = None
                                        self.interface_state = None
                                        self.is_interface_line_up = None
                                        self.is_interface_ip_security_required = None
                                        self.is_interface_ip_security_active = None
                                        self.interface_address = None
                                        self.interface_number = None
                                        self.interface_router_id = None
                                        self.network_type = None
                                        self.interface_link_cost = None
                                        self.is_interface_flood_reduction = None
                                        self.is_demand_circuit_configured = None
                                        self.is_interface_demand_circuit = None
                                        self.interface_dc_bitless_ls_as = None
                                        self.transmission_delay = None
                                        self.ospf_interface_state = None
                                        self.interface_priority = None
                                        self.is_designated_router = None
                                        self.designated_router_id = None
                                        self.designated_router_address = None
                                        self.backup_designated_router_id = None
                                        self.backup_designated_router_address = None
                                        self.network_lsa_flush_timer = None
                                        self.is_interface_lsa_filtered = None
                                        self.hello_interval = None
                                        self.dead_interval = None
                                        self.wait_interval = None
                                        self.interface_retransmission_interval = None
                                        self.next_hello_time = None
                                        self.interface_authentication_spi = None
                                        self.interface_authentication_transmit = None
                                        self.is_interface_encryption_enabled = None
                                        self.is_prefix_suppress = None
                                        self.interface_encryption_spi = None
                                        self.interface_encryption_transmitted = None
                                        self.interface_encrypted_authentication_transmitted = None
                                        self.adjacent_neighbor = None
                                        self.interface_references = None
                                        self.configured_ldp_sync = None
                                        self.interface_ldp_sync = None

                                        self.active_interface = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.ActiveInterface()
                                        self.active_interface.parent = self
                                        self._children_name_map["active_interface"] = "active-interface"

                                        self.interface_bfd = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd()
                                        self.interface_bfd.parent = self
                                        self._children_name_map["interface_bfd"] = "interface-bfd"

                                        self.interface_neighbor = YList(self)
                                        self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface, ['interface_name', u'interface_state', u'is_interface_line_up', u'is_interface_ip_security_required', u'is_interface_ip_security_active', u'interface_address', u'interface_number', u'interface_router_id', u'network_type', u'interface_link_cost', u'is_interface_flood_reduction', u'is_demand_circuit_configured', u'is_interface_demand_circuit', u'interface_dc_bitless_ls_as', u'transmission_delay', u'ospf_interface_state', u'interface_priority', u'is_designated_router', u'designated_router_id', u'designated_router_address', u'backup_designated_router_id', u'backup_designated_router_address', u'network_lsa_flush_timer', u'is_interface_lsa_filtered', u'hello_interval', u'dead_interval', u'wait_interval', u'interface_retransmission_interval', u'next_hello_time', u'interface_authentication_spi', u'interface_authentication_transmit', u'is_interface_encryption_enabled', u'is_prefix_suppress', u'interface_encryption_spi', u'interface_encryption_transmitted', u'interface_encrypted_authentication_transmitted', u'adjacent_neighbor', u'interface_references', u'configured_ldp_sync', u'interface_ldp_sync'], name, value)


                                    class ActiveInterface(Entity):
                                        """
                                        Active interface details 
                                        
                                        .. attribute:: wait_time
                                        
                                        	Wait time for DR/BDR selection (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_area_flood_index
                                        
                                        	Area scope LSAs flood index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_as_flood_index
                                        
                                        	AS scope LSAs flood index 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_link_flood_index
                                        
                                        	Interface flood link index 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: flood_queue_length
                                        
                                        	Flood queue length
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_area_next_flood
                                        
                                        	Next LSA to flood (Area scope)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_area_next_flood_index
                                        
                                        	Index of next LSA to flood (Area scope) 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_as_next_flood
                                        
                                        	Next LSA to flood (AS scope)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_as_next_flood_index
                                        
                                        	Index of next LSA to flood (AS scope)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_link_next_flood
                                        
                                        	Interface link next flood information 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_link_next_index
                                        
                                        	Interface link next information index 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: flood_scan_length
                                        
                                        	Last flood scan length 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_flood_length
                                        
                                        	Maximum flood length 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_flood_time
                                        
                                        	Last flood scan time (ms)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_flood_time
                                        
                                        	Maximum flood time (ms) 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_flood_pacing_timer
                                        
                                        	Time until next flood pacing timer (ms) 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_neighbors
                                        
                                        	Total number of neighbors 
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: suppressed_hellos
                                        
                                        	Number of neighbors for which hellos are suppressed 
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.ActiveInterface, self).__init__()

                                            self.yang_name = "active-interface"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('wait_time', (YLeaf(YType.uint32, 'wait-time'), ['int'])),
                                                ('interface_area_flood_index', (YLeaf(YType.uint32, 'interface-area-flood-index'), ['int'])),
                                                ('interface_as_flood_index', (YLeaf(YType.uint32, 'interface-as-flood-index'), ['int'])),
                                                ('interface_link_flood_index', (YLeaf(YType.uint32, 'interface-link-flood-index'), ['int'])),
                                                ('flood_queue_length', (YLeaf(YType.uint32, 'flood-queue-length'), ['int'])),
                                                ('interface_area_next_flood', (YLeaf(YType.uint32, 'interface-area-next-flood'), ['int'])),
                                                ('interface_area_next_flood_index', (YLeaf(YType.uint32, 'interface-area-next-flood-index'), ['int'])),
                                                ('interface_as_next_flood', (YLeaf(YType.uint32, 'interface-as-next-flood'), ['int'])),
                                                ('interface_as_next_flood_index', (YLeaf(YType.uint32, 'interface-as-next-flood-index'), ['int'])),
                                                ('interface_link_next_flood', (YLeaf(YType.uint32, 'interface-link-next-flood'), ['int'])),
                                                ('interface_link_next_index', (YLeaf(YType.uint32, 'interface-link-next-index'), ['int'])),
                                                ('flood_scan_length', (YLeaf(YType.uint32, 'flood-scan-length'), ['int'])),
                                                ('maximum_flood_length', (YLeaf(YType.uint32, 'maximum-flood-length'), ['int'])),
                                                ('last_flood_time', (YLeaf(YType.uint32, 'last-flood-time'), ['int'])),
                                                ('maximum_flood_time', (YLeaf(YType.uint32, 'maximum-flood-time'), ['int'])),
                                                ('interface_flood_pacing_timer', (YLeaf(YType.uint32, 'interface-flood-pacing-timer'), ['int'])),
                                                ('interface_neighbors', (YLeaf(YType.uint16, 'interface-neighbors'), ['int'])),
                                                ('suppressed_hellos', (YLeaf(YType.uint16, 'suppressed-hellos'), ['int'])),
                                            ])
                                            self.wait_time = None
                                            self.interface_area_flood_index = None
                                            self.interface_as_flood_index = None
                                            self.interface_link_flood_index = None
                                            self.flood_queue_length = None
                                            self.interface_area_next_flood = None
                                            self.interface_area_next_flood_index = None
                                            self.interface_as_next_flood = None
                                            self.interface_as_next_flood_index = None
                                            self.interface_link_next_flood = None
                                            self.interface_link_next_index = None
                                            self.flood_scan_length = None
                                            self.maximum_flood_length = None
                                            self.last_flood_time = None
                                            self.maximum_flood_time = None
                                            self.interface_flood_pacing_timer = None
                                            self.interface_neighbors = None
                                            self.suppressed_hellos = None
                                            self._segment_path = lambda: "active-interface"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.ActiveInterface, [u'wait_time', u'interface_area_flood_index', u'interface_as_flood_index', u'interface_link_flood_index', u'flood_queue_length', u'interface_area_next_flood', u'interface_area_next_flood_index', u'interface_as_next_flood', u'interface_as_next_flood_index', u'interface_link_next_flood', u'interface_link_next_index', u'flood_scan_length', u'maximum_flood_length', u'last_flood_time', u'maximum_flood_time', u'interface_flood_pacing_timer', u'interface_neighbors', u'suppressed_hellos'], name, value)


                                    class InterfaceBfd(Entity):
                                        """
                                        BFD information 
                                        
                                        .. attribute:: bfd_intf_enable_mode
                                        
                                        	BFD Enable Mode on the interface \- Default/Strict
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_interval
                                        
                                        	BFD interval (ms) 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bfd_detection_multiplier
                                        
                                        	BFD detection multiplier 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd, self).__init__()

                                            self.yang_name = "interface-bfd"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bfd_intf_enable_mode', (YLeaf(YType.uint32, 'bfd-intf-enable-mode'), ['int'])),
                                                ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                                                ('bfd_detection_multiplier', (YLeaf(YType.uint32, 'bfd-detection-multiplier'), ['int'])),
                                            ])
                                            self.bfd_intf_enable_mode = None
                                            self.bfd_interval = None
                                            self.bfd_detection_multiplier = None
                                            self._segment_path = lambda: "interface-bfd"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd, [u'bfd_intf_enable_mode', u'bfd_interval', u'bfd_detection_multiplier'], name, value)


                                    class InterfaceNeighbor(Entity):
                                        """
                                        Information for neighbors on the interface
                                        
                                        .. attribute:: interface_neighbor_id
                                        
                                        	Neighbor router ID 
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: interface_neighbor_cost
                                        
                                        	Cost of link to neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_neighbor_dr
                                        
                                        	If true, designated router is found 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_bdr
                                        
                                        	If true, backup designated router is found 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_hello_suppressed
                                        
                                        	If true, hello is suppressed 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor, self).__init__()

                                            self.yang_name = "interface-neighbor"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_neighbor_id', (YLeaf(YType.str, 'interface-neighbor-id'), ['str'])),
                                                ('interface_neighbor_cost', (YLeaf(YType.uint32, 'interface-neighbor-cost'), ['int'])),
                                                ('is_neighbor_dr', (YLeaf(YType.boolean, 'is-neighbor-dr'), ['bool'])),
                                                ('is_neighbor_bdr', (YLeaf(YType.boolean, 'is-neighbor-bdr'), ['bool'])),
                                                ('is_hello_suppressed', (YLeaf(YType.boolean, 'is-hello-suppressed'), ['bool'])),
                                            ])
                                            self.interface_neighbor_id = None
                                            self.interface_neighbor_cost = None
                                            self.is_neighbor_dr = None
                                            self.is_neighbor_bdr = None
                                            self.is_hello_suppressed = None
                                            self._segment_path = lambda: "interface-neighbor"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor, [u'interface_neighbor_id', u'interface_neighbor_cost', u'is_neighbor_dr', u'is_neighbor_bdr', u'is_hello_suppressed'], name, value)


                            class FloodListTable(Entity):
                                """
                                OSPFv3 flood list information table for an
                                area
                                
                                .. attribute:: flood
                                
                                	OSPFv3 flood list information
                                	**type**\: list of  		 :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable, self).__init__()

                                    self.yang_name = "flood-list-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("flood", ("flood", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood))])
                                    self._leafs = OrderedDict()

                                    self.flood = YList(self)
                                    self._segment_path = lambda: "flood-list-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable, [], name, value)


                                class Flood(Entity):
                                    """
                                    OSPFv3 flood list information
                                    
                                    .. attribute:: interface_name  (key)
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: ls_transmission_timer
                                    
                                    	Time until next LS transmission (ms) 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: queue_length
                                    
                                    	Number of LSAs currently being flooded 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_flood
                                    
                                    	Link floodlist
                                    	**type**\: list of  		 :py:class:`LinkFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.LinkFlood>`
                                    
                                    .. attribute:: area_flood
                                    
                                    	Area scope floodlist
                                    	**type**\: list of  		 :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AreaFlood>`
                                    
                                    .. attribute:: as_flood
                                    
                                    	AS scope floodlist
                                    	**type**\: list of  		 :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AsFlood>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood, self).__init__()

                                        self.yang_name = "flood"
                                        self.yang_parent_name = "flood-list-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['interface_name']
                                        self._child_classes = OrderedDict([("link-flood", ("link_flood", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.LinkFlood)), ("area-flood", ("area_flood", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AreaFlood)), ("as-flood", ("as_flood", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AsFlood))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('ls_transmission_timer', (YLeaf(YType.uint32, 'ls-transmission-timer'), ['int'])),
                                            ('queue_length', (YLeaf(YType.uint32, 'queue-length'), ['int'])),
                                        ])
                                        self.interface_name = None
                                        self.ls_transmission_timer = None
                                        self.queue_length = None

                                        self.link_flood = YList(self)
                                        self.area_flood = YList(self)
                                        self.as_flood = YList(self)
                                        self._segment_path = lambda: "flood" + "[interface-name='" + str(self.interface_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood, ['interface_name', u'ls_transmission_timer', u'queue_length'], name, value)


                                    class LinkFlood(Entity):
                                        """
                                        Link floodlist
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.LinkFlood, self).__init__()

                                            self.yang_name = "link-flood"
                                            self.yang_parent_name = "flood"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                                ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                                ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                                ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                                ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                            ])
                                            self.header_lsa_type = None
                                            self.header_lsa_age = None
                                            self.header_lsa_id = None
                                            self.header_advertising_router = None
                                            self.header_sequence_number = None
                                            self._segment_path = lambda: "link-flood"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.LinkFlood, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                                    class AreaFlood(Entity):
                                        """
                                        Area scope floodlist
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AreaFlood, self).__init__()

                                            self.yang_name = "area-flood"
                                            self.yang_parent_name = "flood"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                                ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                                ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                                ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                                ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                            ])
                                            self.header_lsa_type = None
                                            self.header_lsa_age = None
                                            self.header_lsa_id = None
                                            self.header_advertising_router = None
                                            self.header_sequence_number = None
                                            self._segment_path = lambda: "area-flood"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AreaFlood, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                                    class AsFlood(Entity):
                                        """
                                        AS scope floodlist
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AsFlood, self).__init__()

                                            self.yang_name = "as-flood"
                                            self.yang_parent_name = "flood"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                                ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                                ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                                ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                                ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                            ])
                                            self.header_lsa_type = None
                                            self.header_lsa_age = None
                                            self.header_lsa_id = None
                                            self.header_advertising_router = None
                                            self.header_sequence_number = None
                                            self._segment_path = lambda: "as-flood"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.FloodListTable.Flood.AsFlood, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                            class RetransmissionListTable(Entity):
                                """
                                OSPFv3 retransmission list information table
                                in an area
                                
                                .. attribute:: retransmission
                                
                                	OSPFv3 retransmission list information
                                	**type**\: list of  		 :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable, self).__init__()

                                    self.yang_name = "retransmission-list-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("retransmission", ("retransmission", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission))])
                                    self._leafs = OrderedDict()

                                    self.retransmission = YList(self)
                                    self._segment_path = lambda: "retransmission-list-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable, [], name, value)


                                class Retransmission(Entity):
                                    """
                                    OSPFv3 retransmission list information
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: neighbor_address
                                    
                                    	Neighbor address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: retransmission_neighbor_address
                                    
                                    	Neighbor IP address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_retransmissionvirtual_link
                                    
                                    	If true, virtual link is retransmitted 
                                    	**type**\: bool
                                    
                                    .. attribute:: retransmissionvirtual_link_id
                                    
                                    	Retransmission virtual link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_retransmission_sham_link
                                    
                                    	If true, sham link is retransmitted 
                                    	**type**\: bool
                                    
                                    .. attribute:: retransmission_sham_link_id
                                    
                                    	Retransmission sham link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retransmission_timer
                                    
                                    	Amount of time remaining on retransmission timer (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retransmission_length
                                    
                                    	Retransmission queue length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retransmissionvirtual_link_db
                                    
                                    	List of virtual link scope entries 
                                    	**type**\: list of  		 :py:class:`RetransmissionvirtualLinkDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb>`
                                    
                                    .. attribute:: retransmission_area_db
                                    
                                    	List of area scope entries
                                    	**type**\: list of  		 :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb>`
                                    
                                    .. attribute:: retransmission_asdb
                                    
                                    	List of AS scope entries
                                    	**type**\: list of  		 :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission, self).__init__()

                                        self.yang_name = "retransmission"
                                        self.yang_parent_name = "retransmission-list-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("retransmissionvirtual-link-db", ("retransmissionvirtual_link_db", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb)), ("retransmission-area-db", ("retransmission_area_db", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb)), ("retransmission-asdb", ("retransmission_asdb", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                            ('retransmission_neighbor_address', (YLeaf(YType.str, 'retransmission-neighbor-address'), ['str'])),
                                            ('is_retransmissionvirtual_link', (YLeaf(YType.boolean, 'is-retransmissionvirtual-link'), ['bool'])),
                                            ('retransmissionvirtual_link_id', (YLeaf(YType.uint32, 'retransmissionvirtual-link-id'), ['int'])),
                                            ('is_retransmission_sham_link', (YLeaf(YType.boolean, 'is-retransmission-sham-link'), ['bool'])),
                                            ('retransmission_sham_link_id', (YLeaf(YType.uint32, 'retransmission-sham-link-id'), ['int'])),
                                            ('retransmission_timer', (YLeaf(YType.uint32, 'retransmission-timer'), ['int'])),
                                            ('retransmission_length', (YLeaf(YType.uint32, 'retransmission-length'), ['int'])),
                                        ])
                                        self.interface_name = None
                                        self.neighbor_address = None
                                        self.retransmission_neighbor_address = None
                                        self.is_retransmissionvirtual_link = None
                                        self.retransmissionvirtual_link_id = None
                                        self.is_retransmission_sham_link = None
                                        self.retransmission_sham_link_id = None
                                        self.retransmission_timer = None
                                        self.retransmission_length = None

                                        self.retransmissionvirtual_link_db = YList(self)
                                        self.retransmission_area_db = YList(self)
                                        self.retransmission_asdb = YList(self)
                                        self._segment_path = lambda: "retransmission"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission, ['interface_name', 'neighbor_address', u'retransmission_neighbor_address', u'is_retransmissionvirtual_link', u'retransmissionvirtual_link_id', u'is_retransmission_sham_link', u'retransmission_sham_link_id', u'retransmission_timer', u'retransmission_length'], name, value)


                                    class RetransmissionvirtualLinkDb(Entity):
                                        """
                                        List of virtual link scope entries 
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb, self).__init__()

                                            self.yang_name = "retransmissionvirtual-link-db"
                                            self.yang_parent_name = "retransmission"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                                ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                                ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                                ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                                ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                            ])
                                            self.header_lsa_type = None
                                            self.header_lsa_age = None
                                            self.header_lsa_id = None
                                            self.header_advertising_router = None
                                            self.header_sequence_number = None
                                            self._segment_path = lambda: "retransmissionvirtual-link-db"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                                    class RetransmissionAreaDb(Entity):
                                        """
                                        List of area scope entries
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb, self).__init__()

                                            self.yang_name = "retransmission-area-db"
                                            self.yang_parent_name = "retransmission"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                                ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                                ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                                ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                                ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                            ])
                                            self.header_lsa_type = None
                                            self.header_lsa_age = None
                                            self.header_lsa_id = None
                                            self.header_advertising_router = None
                                            self.header_sequence_number = None
                                            self._segment_path = lambda: "retransmission-area-db"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                                    class RetransmissionAsdb(Entity):
                                        """
                                        List of AS scope entries
                                        
                                        .. attribute:: header_lsa_type
                                        
                                        	LSA type
                                        	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                        
                                        .. attribute:: header_lsa_age
                                        
                                        	Age of the LSA (seconds)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: header_lsa_id
                                        
                                        	LSA ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_advertising_router
                                        
                                        	Router ID of the advertising router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: header_sequence_number
                                        
                                        	Current LSA sequence number
                                        	**type**\: int
                                        
                                        	**range:** \-2147483648..2147483647
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb, self).__init__()

                                            self.yang_name = "retransmission-asdb"
                                            self.yang_parent_name = "retransmission"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                                ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                                ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                                ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                                ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                            ])
                                            self.header_lsa_type = None
                                            self.header_lsa_age = None
                                            self.header_lsa_id = None
                                            self.header_advertising_router = None
                                            self.header_sequence_number = None
                                            self._segment_path = lambda: "retransmission-asdb"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                            class DatabaseTable(Entity):
                                """
                                OSPF Link State Database
                                
                                .. attribute:: lsa_table
                                
                                	Database LSA information
                                	**type**\:  :py:class:`LsaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable>`
                                
                                .. attribute:: lsa_internal_table
                                
                                	Database LSA information
                                	**type**\:  :py:class:`LsaInternalTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable, self).__init__()

                                    self.yang_name = "database-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lsa-table", ("lsa_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable)), ("lsa-internal-table", ("lsa_internal_table", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable))])
                                    self._leafs = OrderedDict()

                                    self.lsa_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable()
                                    self.lsa_table.parent = self
                                    self._children_name_map["lsa_table"] = "lsa-table"

                                    self.lsa_internal_table = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable()
                                    self.lsa_internal_table.parent = self
                                    self._children_name_map["lsa_internal_table"] = "lsa-internal-table"
                                    self._segment_path = lambda: "database-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable, [], name, value)


                                class LsaTable(Entity):
                                    """
                                    Database LSA information
                                    
                                    .. attribute:: lsa
                                    
                                    	Database LSA information
                                    	**type**\: list of  		 :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable, self).__init__()

                                        self.yang_name = "lsa-table"
                                        self.yang_parent_name = "database-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa", ("lsa", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa))])
                                        self._leafs = OrderedDict()

                                        self.lsa = YList(self)
                                        self._segment_path = lambda: "lsa-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable, [], name, value)


                                    class Lsa(Entity):
                                        """
                                        Database LSA information
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ls_type
                                        
                                        	LSA type
                                        	**type**\:  :py:class:`Ospfv3Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa>`
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Advertising Router ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ls_id
                                        
                                        	Link state ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_name
                                        
                                        	InterfaceName
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: lsa_info
                                        
                                        	Summary of all LSAs or LSA specific information 
                                        	**type**\:  :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa, self).__init__()

                                            self.yang_name = "lsa"
                                            self.yang_parent_name = "lsa-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-info", ("lsa_info", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo))])
                                            self._leafs = OrderedDict([
                                                ('area_id', (YLeaf(YType.uint32, 'area-id'), ['int'])),
                                                ('ls_type', (YLeaf(YType.enumeration, 'ls-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa', '')])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ])
                                            self.area_id = None
                                            self.ls_type = None
                                            self.advertising_router = None
                                            self.ls_id = None
                                            self.interface_name = None

                                            self.lsa_info = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo()
                                            self.lsa_info.parent = self
                                            self._children_name_map["lsa_info"] = "lsa-info"
                                            self._segment_path = lambda: "lsa"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa, ['area_id', 'ls_type', 'advertising_router', 'ls_id', 'interface_name'], name, value)


                                        class LsaInfo(Entity):
                                            """
                                            Summary of all LSAs or LSA specific information 
                                            
                                            .. attribute:: lsa_summary_info
                                            
                                            	Summary information of LSAs
                                            	**type**\:  :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                            
                                            .. attribute:: router_lsa_type
                                            
                                            	Router LSA
                                            	**type**\:  :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType>`
                                            
                                            .. attribute:: network_lsa_type
                                            
                                            	Network LSA
                                            	**type**\:  :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType>`
                                            
                                            .. attribute:: inter_area_prefix_lsa_type
                                            
                                            	Inter Area Prefix LSA
                                            	**type**\:  :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                            
                                            .. attribute:: inter_area_router_lsa_type
                                            
                                            	Inter Area Router LSA
                                            	**type**\:  :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                            
                                            .. attribute:: external_lsa_type
                                            
                                            	External LSA
                                            	**type**\:  :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType>`
                                            
                                            .. attribute:: nssalsa_type
                                            
                                            	NSSA External LSA
                                            	**type**\:  :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType>`
                                            
                                            .. attribute:: link_lsa_type
                                            
                                            	Link LSA
                                            	**type**\:  :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType>`
                                            
                                            .. attribute:: intra_area_prefix_lsa_type
                                            
                                            	Intra Area Prefix LSA
                                            	**type**\:  :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                            
                                            .. attribute:: grace_lsa
                                            
                                            	Grace LSA
                                            	**type**\:  :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa>`
                                            
                                            .. attribute:: unknown_link_lsa_type
                                            
                                            	Unknown Link Scope LSA
                                            	**type**\:  :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                            
                                            .. attribute:: unknown_area_lsa_type
                                            
                                            	Unknown\-Area scope LSA
                                            	**type**\:  :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                            
                                            .. attribute:: unknown_aslsa_type
                                            
                                            	Unknown\-AS scope LSA
                                            	**type**\:  :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType>`
                                            
                                            .. attribute:: unknown_lsa_type
                                            
                                            	Unknown LSA
                                            	**type**\:  :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType>`
                                            
                                            .. attribute:: lsa_info_type
                                            
                                            	LSAInfoType
                                            	**type**\:  :py:class:`Ospfv3LsaInfoTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypes>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo, self).__init__()

                                                self.yang_name = "lsa-info"
                                                self.yang_parent_name = "lsa"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-summary-info", ("lsa_summary_info", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo)), ("router-lsa-type", ("router_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType)), ("network-lsa-type", ("network_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType)), ("inter-area-prefix-lsa-type", ("inter_area_prefix_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType)), ("inter-area-router-lsa-type", ("inter_area_router_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType)), ("external-lsa-type", ("external_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType)), ("nssalsa-type", ("nssalsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType)), ("link-lsa-type", ("link_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType)), ("intra-area-prefix-lsa-type", ("intra_area_prefix_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType)), ("grace-lsa", ("grace_lsa", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa)), ("unknown-link-lsa-type", ("unknown_link_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType)), ("unknown-area-lsa-type", ("unknown_area_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType)), ("unknown-aslsa-type", ("unknown_aslsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType)), ("unknown-lsa-type", ("unknown_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType))])
                                                self._leafs = OrderedDict([
                                                    ('lsa_info_type', (YLeaf(YType.enumeration, 'lsa-info-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3LsaInfoTypes', '')])),
                                                ])
                                                self.lsa_info_type = None

                                                self.lsa_summary_info = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo()
                                                self.lsa_summary_info.parent = self
                                                self._children_name_map["lsa_summary_info"] = "lsa-summary-info"

                                                self.router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType()
                                                self.router_lsa_type.parent = self
                                                self._children_name_map["router_lsa_type"] = "router-lsa-type"

                                                self.network_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType()
                                                self.network_lsa_type.parent = self
                                                self._children_name_map["network_lsa_type"] = "network-lsa-type"

                                                self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                                self.inter_area_prefix_lsa_type.parent = self
                                                self._children_name_map["inter_area_prefix_lsa_type"] = "inter-area-prefix-lsa-type"

                                                self.inter_area_router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                                self.inter_area_router_lsa_type.parent = self
                                                self._children_name_map["inter_area_router_lsa_type"] = "inter-area-router-lsa-type"

                                                self.external_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType()
                                                self.external_lsa_type.parent = self
                                                self._children_name_map["external_lsa_type"] = "external-lsa-type"

                                                self.nssalsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType()
                                                self.nssalsa_type.parent = self
                                                self._children_name_map["nssalsa_type"] = "nssalsa-type"

                                                self.link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType()
                                                self.link_lsa_type.parent = self
                                                self._children_name_map["link_lsa_type"] = "link-lsa-type"

                                                self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                                self.intra_area_prefix_lsa_type.parent = self
                                                self._children_name_map["intra_area_prefix_lsa_type"] = "intra-area-prefix-lsa-type"

                                                self.grace_lsa = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa()
                                                self.grace_lsa.parent = self
                                                self._children_name_map["grace_lsa"] = "grace-lsa"

                                                self.unknown_link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                                self.unknown_link_lsa_type.parent = self
                                                self._children_name_map["unknown_link_lsa_type"] = "unknown-link-lsa-type"

                                                self.unknown_area_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                                self.unknown_area_lsa_type.parent = self
                                                self._children_name_map["unknown_area_lsa_type"] = "unknown-area-lsa-type"

                                                self.unknown_aslsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType()
                                                self.unknown_aslsa_type.parent = self
                                                self._children_name_map["unknown_aslsa_type"] = "unknown-aslsa-type"

                                                self.unknown_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType()
                                                self.unknown_lsa_type.parent = self
                                                self._children_name_map["unknown_lsa_type"] = "unknown-lsa-type"
                                                self._segment_path = lambda: "lsa-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo, [u'lsa_info_type'], name, value)


                                            class LsaSummaryInfo(Entity):
                                                """
                                                Summary information of LSAs
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                                
                                                .. attribute:: links
                                                
                                                	Number of links
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: router_la_bits
                                                
                                                	Router LA bits 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: reference_type
                                                
                                                	Reference type 
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: reference_lsa_id
                                                
                                                	Reference LSA ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_router_id
                                                
                                                	LSA router ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 address Prefix 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\: bool
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\: bool
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Sham link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo, self).__init__()

                                                    self.yang_name = "lsa-summary-info"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('links', (YLeaf(YType.uint16, 'links'), ['int'])),
                                                        ('router_la_bits', (YLeaf(YType.uint8, 'router-la-bits'), ['int'])),
                                                        ('reference_type', (YLeaf(YType.uint16, 'reference-type'), ['int'])),
                                                        ('reference_lsa_id', (YLeaf(YType.uint32, 'reference-lsa-id'), ['int'])),
                                                        ('lsa_router_id', (YLeaf(YType.uint32, 'lsa-router-id'), ['int'])),
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                        ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                        ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                        ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                    ])
                                                    self.links = None
                                                    self.router_la_bits = None
                                                    self.reference_type = None
                                                    self.reference_lsa_id = None
                                                    self.lsa_router_id = None
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.interface_name = None
                                                    self.is_virtual_link = None
                                                    self.virtual_link_id = None
                                                    self.is_sham_link = None
                                                    self.sham_link_id = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "lsa-summary-info"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo, [u'links', u'router_la_bits', u'reference_type', u'reference_lsa_id', u'lsa_router_id', u'prefix', u'prefix_length', u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "lsa-summary-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "lsa-summary-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class RouterLsaType(Entity):
                                                """
                                                Router LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                                
                                                .. attribute:: rpf_path
                                                
                                                	Router LSA Reverse\-Path Forwarding information 
                                                	**type**\:  :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                                
                                                .. attribute:: router_la_bits
                                                
                                                	Router LA bits 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: link
                                                
                                                	List of links in this LSA
                                                	**type**\: list of  		 :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType, self).__init__()

                                                    self.yang_name = "router-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail)), ("rpf-path", ("rpf_path", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath)), ("link", ("link", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link))])
                                                    self._leafs = OrderedDict([
                                                        ('router_la_bits', (YLeaf(YType.uint8, 'router-la-bits'), ['int'])),
                                                    ])
                                                    self.router_la_bits = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"

                                                    self.rpf_path = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                                    self.rpf_path.parent = self
                                                    self._children_name_map["rpf_path"] = "rpf-path"

                                                    self.link = YList(self)
                                                    self._segment_path = lambda: "router-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType, [u'router_la_bits'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                                class RpfPath(Entity):
                                                    """
                                                    Router LSA Reverse\-Path Forwarding information 
                                                    
                                                    .. attribute:: rpf_multicast_next_hop
                                                    
                                                    	RPF multicast next hop 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	RPF multicast IDB 
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath, self).__init__()

                                                        self.yang_name = "rpf-path"
                                                        self.yang_parent_name = "router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('rpf_multicast_next_hop', (YLeaf(YType.uint32, 'rpf-multicast-next-hop'), ['int'])),
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ])
                                                        self.rpf_multicast_next_hop = None
                                                        self.interface_name = None
                                                        self._segment_path = lambda: "rpf-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath, [u'rpf_multicast_next_hop', u'interface_name'], name, value)


                                                class Link(Entity):
                                                    """
                                                    List of links in this LSA
                                                    
                                                    .. attribute:: link_type
                                                    
                                                    	Type of link
                                                    	**type**\:  :py:class:`Ospfv3Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Link>`
                                                    
                                                    .. attribute:: link_metric
                                                    
                                                    	LSA link metric 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: link_interface_id
                                                    
                                                    	LSA link interface ID 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: link_neighbor_interface_id
                                                    
                                                    	LSA link neighbor interface ID 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: link_neighbor_router_id
                                                    
                                                    	LSA link neigbhor router id 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link, self).__init__()

                                                        self.yang_name = "link"
                                                        self.yang_parent_name = "router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Link', '')])),
                                                            ('link_metric', (YLeaf(YType.uint16, 'link-metric'), ['int'])),
                                                            ('link_interface_id', (YLeaf(YType.uint32, 'link-interface-id'), ['int'])),
                                                            ('link_neighbor_interface_id', (YLeaf(YType.uint32, 'link-neighbor-interface-id'), ['int'])),
                                                            ('link_neighbor_router_id', (YLeaf(YType.uint32, 'link-neighbor-router-id'), ['int'])),
                                                        ])
                                                        self.link_type = None
                                                        self.link_metric = None
                                                        self.link_interface_id = None
                                                        self.link_neighbor_interface_id = None
                                                        self.link_neighbor_router_id = None
                                                        self._segment_path = lambda: "link"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link, [u'link_type', u'link_metric', u'link_interface_id', u'link_neighbor_interface_id', u'link_neighbor_router_id'], name, value)


                                            class NetworkLsaType(Entity):
                                                """
                                                Network LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                                
                                                .. attribute:: neighbor_router
                                                
                                                	Neighbor router list
                                                	**type**\: list of str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType, self).__init__()

                                                    self.yang_name = "network-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_router', (YLeafList(YType.str, 'neighbor-router'), ['str'])),
                                                    ])
                                                    self.neighbor_router = []

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "network-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType, [u'neighbor_router'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "network-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "network-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class InterAreaPrefixLsaType(Entity):
                                                """
                                                Inter Area Prefix LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA Information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                                
                                                .. attribute:: prefix
                                                
                                                	LSA address prefix 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType, self).__init__()

                                                    self.yang_name = "inter-area-prefix-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                        ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                    ])
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.priority = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "inter-area-prefix-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType, [u'prefix', u'prefix_length', u'priority'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA Information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class InterAreaRouterLsaType(Entity):
                                                """
                                                Inter Area Router LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_router_id
                                                
                                                	LSA router ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType, self).__init__()

                                                    self.yang_name = "inter-area-router-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_router_id', (YLeaf(YType.uint32, 'lsa-router-id'), ['int'])),
                                                    ])
                                                    self.lsa_router_id = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "inter-area-router-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType, [u'lsa_router_id'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "inter-area-router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "inter-area-router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class ExternalLsaType(Entity):
                                                """
                                                External LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA Information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                                
                                                .. attribute:: prefix
                                                
                                                	IPV6 address prefix 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: metric_type
                                                
                                                	Metric type 
                                                	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                                
                                                .. attribute:: tos_cost
                                                
                                                	Type of service cost metric 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_forwarding_address_set
                                                
                                                	If true, forwarding address is set 
                                                	**type**\: bool
                                                
                                                .. attribute:: forwarding_address
                                                
                                                	Forwarding Address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: external_tag
                                                
                                                	Route Tag
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType, self).__init__()

                                                    self.yang_name = "external-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                                        ('tos_cost', (YLeaf(YType.uint32, 'tos-cost'), ['int'])),
                                                        ('is_forwarding_address_set', (YLeaf(YType.boolean, 'is-forwarding-address-set'), ['bool'])),
                                                        ('forwarding_address', (YLeaf(YType.str, 'forwarding-address'), ['str'])),
                                                        ('external_tag', (YLeaf(YType.uint32, 'external-tag'), ['int'])),
                                                        ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                    ])
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.metric_type = None
                                                    self.tos_cost = None
                                                    self.is_forwarding_address_set = None
                                                    self.forwarding_address = None
                                                    self.external_tag = None
                                                    self.priority = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "external-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType, [u'prefix', u'prefix_length', u'metric_type', u'tos_cost', u'is_forwarding_address_set', u'forwarding_address', u'external_tag', u'priority'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "external-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA Information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "external-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class NssalsaType(Entity):
                                                """
                                                NSSA External LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA Information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                                
                                                .. attribute:: prefix
                                                
                                                	IPV6 address prefix 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: metric_type
                                                
                                                	Metric type 
                                                	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                                
                                                .. attribute:: tos_cost
                                                
                                                	Type of service cost metric 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_forwarding_address_set
                                                
                                                	If true, forwarding address is set 
                                                	**type**\: bool
                                                
                                                .. attribute:: forwarding_address
                                                
                                                	Forwarding Address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: external_tag
                                                
                                                	Route Tag
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType, self).__init__()

                                                    self.yang_name = "nssalsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                                        ('tos_cost', (YLeaf(YType.uint32, 'tos-cost'), ['int'])),
                                                        ('is_forwarding_address_set', (YLeaf(YType.boolean, 'is-forwarding-address-set'), ['bool'])),
                                                        ('forwarding_address', (YLeaf(YType.str, 'forwarding-address'), ['str'])),
                                                        ('external_tag', (YLeaf(YType.uint32, 'external-tag'), ['int'])),
                                                        ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                    ])
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.metric_type = None
                                                    self.tos_cost = None
                                                    self.is_forwarding_address_set = None
                                                    self.forwarding_address = None
                                                    self.external_tag = None
                                                    self.priority = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "nssalsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType, [u'prefix', u'prefix_length', u'metric_type', u'tos_cost', u'is_forwarding_address_set', u'forwarding_address', u'external_tag', u'priority'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "nssalsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA Information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "nssalsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class LinkLsaType(Entity):
                                                """
                                                Link LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface handle
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link
                                                	**type**\: bool
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link
                                                	**type**\: bool
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Sham link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_link_local
                                                
                                                	LSA link local 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: router_priority
                                                
                                                	Router priority 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\: list of  		 :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType, self).__init__()

                                                    self.yang_name = "link-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail)), ("prefix", ("prefix", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                        ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                        ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                        ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                        ('lsa_link_local', (YLeaf(YType.str, 'lsa-link-local'), ['str'])),
                                                        ('router_priority', (YLeaf(YType.uint8, 'router-priority'), ['int'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.is_virtual_link = None
                                                    self.virtual_link_id = None
                                                    self.is_sham_link = None
                                                    self.sham_link_id = None
                                                    self.lsa_link_local = None
                                                    self.router_priority = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"

                                                    self.prefix = YList(self)
                                                    self._segment_path = lambda: "link-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id', u'lsa_link_local', u'router_priority'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    OSPFv3 prefix 
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	OSPFv3 prefix 
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ospfv3_prefix_length
                                                    
                                                    	OSPFv3 prefix length 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ospfv3_prefix_options
                                                    
                                                    	OSPFv3 prefix options 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ospfv3_prefix_metric
                                                    
                                                    	OSPFv3 prefix metric 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Prefix priority
                                                    	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                            ('ospfv3_prefix_length', (YLeaf(YType.uint8, 'ospfv3-prefix-length'), ['int'])),
                                                            ('ospfv3_prefix_options', (YLeaf(YType.uint8, 'ospfv3-prefix-options'), ['int'])),
                                                            ('ospfv3_prefix_metric', (YLeaf(YType.uint16, 'ospfv3-prefix-metric'), ['int'])),
                                                            ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                        ])
                                                        self.prefix = None
                                                        self.ospfv3_prefix_length = None
                                                        self.ospfv3_prefix_options = None
                                                        self.ospfv3_prefix_metric = None
                                                        self.priority = None
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix, [u'prefix', u'ospfv3_prefix_length', u'ospfv3_prefix_options', u'ospfv3_prefix_metric', u'priority'], name, value)


                                            class IntraAreaPrefixLsaType(Entity):
                                                """
                                                Intra Area Prefix LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                                
                                                .. attribute:: reference_type
                                                
                                                	Reference type 
                                                	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                                
                                                .. attribute:: reference_lsa_id
                                                
                                                	Reference LSA ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reference_advertised_router
                                                
                                                	Reference advertised router 
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\: list of  		 :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, self).__init__()

                                                    self.yang_name = "intra-area-prefix-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail)), ("prefix", ("prefix", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('reference_type', (YLeaf(YType.enumeration, 'reference-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                                        ('reference_lsa_id', (YLeaf(YType.uint32, 'reference-lsa-id'), ['int'])),
                                                        ('reference_advertised_router', (YLeaf(YType.str, 'reference-advertised-router'), ['str'])),
                                                    ])
                                                    self.reference_type = None
                                                    self.reference_lsa_id = None
                                                    self.reference_advertised_router = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"

                                                    self.prefix = YList(self)
                                                    self._segment_path = lambda: "intra-area-prefix-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, [u'reference_type', u'reference_lsa_id', u'reference_advertised_router'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    OSPFv3 prefix 
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	OSPFv3 prefix 
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ospfv3_prefix_length
                                                    
                                                    	OSPFv3 prefix length 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ospfv3_prefix_options
                                                    
                                                    	OSPFv3 prefix options 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ospfv3_prefix_metric
                                                    
                                                    	OSPFv3 prefix metric 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Prefix priority
                                                    	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                            ('ospfv3_prefix_length', (YLeaf(YType.uint8, 'ospfv3-prefix-length'), ['int'])),
                                                            ('ospfv3_prefix_options', (YLeaf(YType.uint8, 'ospfv3-prefix-options'), ['int'])),
                                                            ('ospfv3_prefix_metric', (YLeaf(YType.uint16, 'ospfv3-prefix-metric'), ['int'])),
                                                            ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                        ])
                                                        self.prefix = None
                                                        self.ospfv3_prefix_length = None
                                                        self.ospfv3_prefix_options = None
                                                        self.ospfv3_prefix_metric = None
                                                        self.priority = None
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, [u'prefix', u'ospfv3_prefix_length', u'ospfv3_prefix_options', u'ospfv3_prefix_metric', u'priority'], name, value)


                                            class GraceLsa(Entity):
                                                """
                                                Grace LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface handle
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link
                                                	**type**\: bool
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link
                                                	**type**\: bool
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Sham link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: grace_period
                                                
                                                	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: grace_reason
                                                
                                                	Reason for router restart
                                                	**type**\:  :py:class:`Ospfv3GracefulRestartReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReason>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa, self).__init__()

                                                    self.yang_name = "grace-lsa"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                        ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                        ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                        ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                        ('grace_period', (YLeaf(YType.uint32, 'grace-period'), ['int'])),
                                                        ('grace_reason', (YLeaf(YType.enumeration, 'grace-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3GracefulRestartReason', '')])),
                                                    ])
                                                    self.interface_name = None
                                                    self.is_virtual_link = None
                                                    self.virtual_link_id = None
                                                    self.is_sham_link = None
                                                    self.sham_link_id = None
                                                    self.grace_period = None
                                                    self.grace_reason = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "grace-lsa"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id', u'grace_period', u'grace_reason'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "grace-lsa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "grace-lsa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class UnknownLinkLsaType(Entity):
                                                """
                                                Unknown Link Scope LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\: bool
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\: bool
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType, self).__init__()

                                                    self.yang_name = "unknown-link-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                        ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                        ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                        ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.is_virtual_link = None
                                                    self.virtual_link_id = None
                                                    self.is_sham_link = None
                                                    self.sham_link_id = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "unknown-link-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "unknown-link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "unknown-link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class UnknownAreaLsaType(Entity):
                                                """
                                                Unknown\-Area scope LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\: bool
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\: bool
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType, self).__init__()

                                                    self.yang_name = "unknown-area-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                        ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                        ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                        ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.is_virtual_link = None
                                                    self.virtual_link_id = None
                                                    self.is_sham_link = None
                                                    self.sham_link_id = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "unknown-area-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "unknown-area-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "unknown-area-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class UnknownAslsaType(Entity):
                                                """
                                                Unknown\-AS scope LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\: bool
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\: bool
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType, self).__init__()

                                                    self.yang_name = "unknown-aslsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                        ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                        ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                        ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.is_virtual_link = None
                                                    self.virtual_link_id = None
                                                    self.is_sham_link = None
                                                    self.sham_link_id = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "unknown-aslsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "unknown-aslsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "unknown-aslsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class UnknownLsaType(Entity):
                                                """
                                                Unknown LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\: bool
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\: bool
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType, self).__init__()

                                                    self.yang_name = "unknown-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                        ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                        ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                        ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.is_virtual_link = None
                                                    self.virtual_link_id = None
                                                    self.is_sham_link = None
                                                    self.sham_link_id = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "unknown-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "unknown-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "unknown-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class LsaInternalTable(Entity):
                                    """
                                    Database LSA information
                                    
                                    .. attribute:: lsa
                                    
                                    	Database LSA information
                                    	**type**\: list of  		 :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable, self).__init__()

                                        self.yang_name = "lsa-internal-table"
                                        self.yang_parent_name = "database-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa", ("lsa", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa))])
                                        self._leafs = OrderedDict()

                                        self.lsa = YList(self)
                                        self._segment_path = lambda: "lsa-internal-table"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable, [], name, value)


                                    class Lsa(Entity):
                                        """
                                        Database LSA information
                                        
                                        .. attribute:: area_id
                                        
                                        	Area ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ls_type
                                        
                                        	LSA type
                                        	**type**\:  :py:class:`Ospfv3Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa>`
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Advertising Router ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ls_id
                                        
                                        	Link state ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_name
                                        
                                        	InterfaceName
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        .. attribute:: lsa_info
                                        
                                        	Summary of all LSAs or LSA specific information 
                                        	**type**\:  :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa, self).__init__()

                                            self.yang_name = "lsa"
                                            self.yang_parent_name = "lsa-internal-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-info", ("lsa_info", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo))])
                                            self._leafs = OrderedDict([
                                                ('area_id', (YLeaf(YType.uint32, 'area-id'), ['int'])),
                                                ('ls_type', (YLeaf(YType.enumeration, 'ls-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa', '')])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ])
                                            self.area_id = None
                                            self.ls_type = None
                                            self.advertising_router = None
                                            self.ls_id = None
                                            self.interface_name = None

                                            self.lsa_info = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo()
                                            self.lsa_info.parent = self
                                            self._children_name_map["lsa_info"] = "lsa-info"
                                            self._segment_path = lambda: "lsa"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa, ['area_id', 'ls_type', 'advertising_router', 'ls_id', 'interface_name'], name, value)


                                        class LsaInfo(Entity):
                                            """
                                            Summary of all LSAs or LSA specific information 
                                            
                                            .. attribute:: lsa_summary_info
                                            
                                            	Summary information of LSAs
                                            	**type**\:  :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                            
                                            .. attribute:: router_lsa_type
                                            
                                            	Router LSA
                                            	**type**\:  :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType>`
                                            
                                            .. attribute:: network_lsa_type
                                            
                                            	Network LSA
                                            	**type**\:  :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType>`
                                            
                                            .. attribute:: inter_area_prefix_lsa_type
                                            
                                            	Inter Area Prefix LSA
                                            	**type**\:  :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                            
                                            .. attribute:: inter_area_router_lsa_type
                                            
                                            	Inter Area Router LSA
                                            	**type**\:  :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                            
                                            .. attribute:: external_lsa_type
                                            
                                            	External LSA
                                            	**type**\:  :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType>`
                                            
                                            .. attribute:: nssalsa_type
                                            
                                            	NSSA External LSA
                                            	**type**\:  :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType>`
                                            
                                            .. attribute:: link_lsa_type
                                            
                                            	Link LSA
                                            	**type**\:  :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType>`
                                            
                                            .. attribute:: intra_area_prefix_lsa_type
                                            
                                            	Intra Area Prefix LSA
                                            	**type**\:  :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                            
                                            .. attribute:: grace_lsa
                                            
                                            	Grace LSA
                                            	**type**\:  :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa>`
                                            
                                            .. attribute:: unknown_link_lsa_type
                                            
                                            	Unknown Link Scope LSA
                                            	**type**\:  :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                            
                                            .. attribute:: unknown_area_lsa_type
                                            
                                            	Unknown\-Area scope LSA
                                            	**type**\:  :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                            
                                            .. attribute:: unknown_aslsa_type
                                            
                                            	Unknown\-AS scope LSA
                                            	**type**\:  :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType>`
                                            
                                            .. attribute:: unknown_lsa_type
                                            
                                            	Unknown LSA
                                            	**type**\:  :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType>`
                                            
                                            .. attribute:: lsa_info_type
                                            
                                            	LSAInfoType
                                            	**type**\:  :py:class:`Ospfv3LsaInfoTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypes>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo, self).__init__()

                                                self.yang_name = "lsa-info"
                                                self.yang_parent_name = "lsa"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-summary-info", ("lsa_summary_info", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo)), ("router-lsa-type", ("router_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType)), ("network-lsa-type", ("network_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType)), ("inter-area-prefix-lsa-type", ("inter_area_prefix_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType)), ("inter-area-router-lsa-type", ("inter_area_router_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType)), ("external-lsa-type", ("external_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType)), ("nssalsa-type", ("nssalsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType)), ("link-lsa-type", ("link_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType)), ("intra-area-prefix-lsa-type", ("intra_area_prefix_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType)), ("grace-lsa", ("grace_lsa", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa)), ("unknown-link-lsa-type", ("unknown_link_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType)), ("unknown-area-lsa-type", ("unknown_area_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType)), ("unknown-aslsa-type", ("unknown_aslsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType)), ("unknown-lsa-type", ("unknown_lsa_type", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType))])
                                                self._leafs = OrderedDict([
                                                    ('lsa_info_type', (YLeaf(YType.enumeration, 'lsa-info-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3LsaInfoTypes', '')])),
                                                ])
                                                self.lsa_info_type = None

                                                self.lsa_summary_info = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo()
                                                self.lsa_summary_info.parent = self
                                                self._children_name_map["lsa_summary_info"] = "lsa-summary-info"

                                                self.router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType()
                                                self.router_lsa_type.parent = self
                                                self._children_name_map["router_lsa_type"] = "router-lsa-type"

                                                self.network_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType()
                                                self.network_lsa_type.parent = self
                                                self._children_name_map["network_lsa_type"] = "network-lsa-type"

                                                self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                                self.inter_area_prefix_lsa_type.parent = self
                                                self._children_name_map["inter_area_prefix_lsa_type"] = "inter-area-prefix-lsa-type"

                                                self.inter_area_router_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                                self.inter_area_router_lsa_type.parent = self
                                                self._children_name_map["inter_area_router_lsa_type"] = "inter-area-router-lsa-type"

                                                self.external_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType()
                                                self.external_lsa_type.parent = self
                                                self._children_name_map["external_lsa_type"] = "external-lsa-type"

                                                self.nssalsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType()
                                                self.nssalsa_type.parent = self
                                                self._children_name_map["nssalsa_type"] = "nssalsa-type"

                                                self.link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType()
                                                self.link_lsa_type.parent = self
                                                self._children_name_map["link_lsa_type"] = "link-lsa-type"

                                                self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                                self.intra_area_prefix_lsa_type.parent = self
                                                self._children_name_map["intra_area_prefix_lsa_type"] = "intra-area-prefix-lsa-type"

                                                self.grace_lsa = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa()
                                                self.grace_lsa.parent = self
                                                self._children_name_map["grace_lsa"] = "grace-lsa"

                                                self.unknown_link_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                                self.unknown_link_lsa_type.parent = self
                                                self._children_name_map["unknown_link_lsa_type"] = "unknown-link-lsa-type"

                                                self.unknown_area_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                                self.unknown_area_lsa_type.parent = self
                                                self._children_name_map["unknown_area_lsa_type"] = "unknown-area-lsa-type"

                                                self.unknown_aslsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType()
                                                self.unknown_aslsa_type.parent = self
                                                self._children_name_map["unknown_aslsa_type"] = "unknown-aslsa-type"

                                                self.unknown_lsa_type = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType()
                                                self.unknown_lsa_type.parent = self
                                                self._children_name_map["unknown_lsa_type"] = "unknown-lsa-type"
                                                self._segment_path = lambda: "lsa-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo, [u'lsa_info_type'], name, value)


                                            class LsaSummaryInfo(Entity):
                                                """
                                                Summary information of LSAs
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                                
                                                .. attribute:: links
                                                
                                                	Number of links
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: router_la_bits
                                                
                                                	Router LA bits 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: reference_type
                                                
                                                	Reference type 
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: reference_lsa_id
                                                
                                                	Reference LSA ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_router_id
                                                
                                                	LSA router ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 address Prefix 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\: bool
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\: bool
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Sham link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo, self).__init__()

                                                    self.yang_name = "lsa-summary-info"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('links', (YLeaf(YType.uint16, 'links'), ['int'])),
                                                        ('router_la_bits', (YLeaf(YType.uint8, 'router-la-bits'), ['int'])),
                                                        ('reference_type', (YLeaf(YType.uint16, 'reference-type'), ['int'])),
                                                        ('reference_lsa_id', (YLeaf(YType.uint32, 'reference-lsa-id'), ['int'])),
                                                        ('lsa_router_id', (YLeaf(YType.uint32, 'lsa-router-id'), ['int'])),
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                        ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                        ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                        ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                    ])
                                                    self.links = None
                                                    self.router_la_bits = None
                                                    self.reference_type = None
                                                    self.reference_lsa_id = None
                                                    self.lsa_router_id = None
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.interface_name = None
                                                    self.is_virtual_link = None
                                                    self.virtual_link_id = None
                                                    self.is_sham_link = None
                                                    self.sham_link_id = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "lsa-summary-info"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo, [u'links', u'router_la_bits', u'reference_type', u'reference_lsa_id', u'lsa_router_id', u'prefix', u'prefix_length', u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "lsa-summary-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "lsa-summary-info"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class RouterLsaType(Entity):
                                                """
                                                Router LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                                
                                                .. attribute:: rpf_path
                                                
                                                	Router LSA Reverse\-Path Forwarding information 
                                                	**type**\:  :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                                
                                                .. attribute:: router_la_bits
                                                
                                                	Router LA bits 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: link
                                                
                                                	List of links in this LSA
                                                	**type**\: list of  		 :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType, self).__init__()

                                                    self.yang_name = "router-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail)), ("rpf-path", ("rpf_path", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath)), ("link", ("link", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link))])
                                                    self._leafs = OrderedDict([
                                                        ('router_la_bits', (YLeaf(YType.uint8, 'router-la-bits'), ['int'])),
                                                    ])
                                                    self.router_la_bits = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"

                                                    self.rpf_path = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                                    self.rpf_path.parent = self
                                                    self._children_name_map["rpf_path"] = "rpf-path"

                                                    self.link = YList(self)
                                                    self._segment_path = lambda: "router-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType, [u'router_la_bits'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                                class RpfPath(Entity):
                                                    """
                                                    Router LSA Reverse\-Path Forwarding information 
                                                    
                                                    .. attribute:: rpf_multicast_next_hop
                                                    
                                                    	RPF multicast next hop 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	RPF multicast IDB 
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath, self).__init__()

                                                        self.yang_name = "rpf-path"
                                                        self.yang_parent_name = "router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('rpf_multicast_next_hop', (YLeaf(YType.uint32, 'rpf-multicast-next-hop'), ['int'])),
                                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ])
                                                        self.rpf_multicast_next_hop = None
                                                        self.interface_name = None
                                                        self._segment_path = lambda: "rpf-path"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath, [u'rpf_multicast_next_hop', u'interface_name'], name, value)


                                                class Link(Entity):
                                                    """
                                                    List of links in this LSA
                                                    
                                                    .. attribute:: link_type
                                                    
                                                    	Type of link
                                                    	**type**\:  :py:class:`Ospfv3Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Link>`
                                                    
                                                    .. attribute:: link_metric
                                                    
                                                    	LSA link metric 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: link_interface_id
                                                    
                                                    	LSA link interface ID 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: link_neighbor_interface_id
                                                    
                                                    	LSA link neighbor interface ID 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: link_neighbor_router_id
                                                    
                                                    	LSA link neigbhor router id 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link, self).__init__()

                                                        self.yang_name = "link"
                                                        self.yang_parent_name = "router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Link', '')])),
                                                            ('link_metric', (YLeaf(YType.uint16, 'link-metric'), ['int'])),
                                                            ('link_interface_id', (YLeaf(YType.uint32, 'link-interface-id'), ['int'])),
                                                            ('link_neighbor_interface_id', (YLeaf(YType.uint32, 'link-neighbor-interface-id'), ['int'])),
                                                            ('link_neighbor_router_id', (YLeaf(YType.uint32, 'link-neighbor-router-id'), ['int'])),
                                                        ])
                                                        self.link_type = None
                                                        self.link_metric = None
                                                        self.link_interface_id = None
                                                        self.link_neighbor_interface_id = None
                                                        self.link_neighbor_router_id = None
                                                        self._segment_path = lambda: "link"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link, [u'link_type', u'link_metric', u'link_interface_id', u'link_neighbor_interface_id', u'link_neighbor_router_id'], name, value)


                                            class NetworkLsaType(Entity):
                                                """
                                                Network LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                                
                                                .. attribute:: neighbor_router
                                                
                                                	Neighbor router list
                                                	**type**\: list of str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType, self).__init__()

                                                    self.yang_name = "network-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_router', (YLeafList(YType.str, 'neighbor-router'), ['str'])),
                                                    ])
                                                    self.neighbor_router = []

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "network-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType, [u'neighbor_router'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "network-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "network-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class InterAreaPrefixLsaType(Entity):
                                                """
                                                Inter Area Prefix LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA Information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                                
                                                .. attribute:: prefix
                                                
                                                	LSA address prefix 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType, self).__init__()

                                                    self.yang_name = "inter-area-prefix-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                        ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                    ])
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.priority = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "inter-area-prefix-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType, [u'prefix', u'prefix_length', u'priority'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA Information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class InterAreaRouterLsaType(Entity):
                                                """
                                                Inter Area Router LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                                
                                                .. attribute:: lsa_router_id
                                                
                                                	LSA router ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType, self).__init__()

                                                    self.yang_name = "inter-area-router-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_router_id', (YLeaf(YType.uint32, 'lsa-router-id'), ['int'])),
                                                    ])
                                                    self.lsa_router_id = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "inter-area-router-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType, [u'lsa_router_id'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "inter-area-router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "inter-area-router-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class ExternalLsaType(Entity):
                                                """
                                                External LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA Information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                                
                                                .. attribute:: prefix
                                                
                                                	IPV6 address prefix 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: metric_type
                                                
                                                	Metric type 
                                                	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                                
                                                .. attribute:: tos_cost
                                                
                                                	Type of service cost metric 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_forwarding_address_set
                                                
                                                	If true, forwarding address is set 
                                                	**type**\: bool
                                                
                                                .. attribute:: forwarding_address
                                                
                                                	Forwarding Address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: external_tag
                                                
                                                	Route Tag
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType, self).__init__()

                                                    self.yang_name = "external-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                                        ('tos_cost', (YLeaf(YType.uint32, 'tos-cost'), ['int'])),
                                                        ('is_forwarding_address_set', (YLeaf(YType.boolean, 'is-forwarding-address-set'), ['bool'])),
                                                        ('forwarding_address', (YLeaf(YType.str, 'forwarding-address'), ['str'])),
                                                        ('external_tag', (YLeaf(YType.uint32, 'external-tag'), ['int'])),
                                                        ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                    ])
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.metric_type = None
                                                    self.tos_cost = None
                                                    self.is_forwarding_address_set = None
                                                    self.forwarding_address = None
                                                    self.external_tag = None
                                                    self.priority = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "external-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType, [u'prefix', u'prefix_length', u'metric_type', u'tos_cost', u'is_forwarding_address_set', u'forwarding_address', u'external_tag', u'priority'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "external-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA Information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "external-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class NssalsaType(Entity):
                                                """
                                                NSSA External LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA Information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                                
                                                .. attribute:: prefix
                                                
                                                	IPV6 address prefix 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix length 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: metric_type
                                                
                                                	Metric type 
                                                	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                                
                                                .. attribute:: tos_cost
                                                
                                                	Type of service cost metric 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_forwarding_address_set
                                                
                                                	If true, forwarding address is set 
                                                	**type**\: bool
                                                
                                                .. attribute:: forwarding_address
                                                
                                                	Forwarding Address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: external_tag
                                                
                                                	Route Tag
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType, self).__init__()

                                                    self.yang_name = "nssalsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                        ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                                        ('tos_cost', (YLeaf(YType.uint32, 'tos-cost'), ['int'])),
                                                        ('is_forwarding_address_set', (YLeaf(YType.boolean, 'is-forwarding-address-set'), ['bool'])),
                                                        ('forwarding_address', (YLeaf(YType.str, 'forwarding-address'), ['str'])),
                                                        ('external_tag', (YLeaf(YType.uint32, 'external-tag'), ['int'])),
                                                        ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                    ])
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self.metric_type = None
                                                    self.tos_cost = None
                                                    self.is_forwarding_address_set = None
                                                    self.forwarding_address = None
                                                    self.external_tag = None
                                                    self.priority = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "nssalsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType, [u'prefix', u'prefix_length', u'metric_type', u'tos_cost', u'is_forwarding_address_set', u'forwarding_address', u'external_tag', u'priority'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "nssalsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA Information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "nssalsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class LinkLsaType(Entity):
                                                """
                                                Link LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface handle
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link
                                                	**type**\: bool
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link
                                                	**type**\: bool
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Sham link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: lsa_link_local
                                                
                                                	LSA link local 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: router_priority
                                                
                                                	Router priority 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\: list of  		 :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType, self).__init__()

                                                    self.yang_name = "link-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail)), ("prefix", ("prefix", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                        ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                        ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                        ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                        ('lsa_link_local', (YLeaf(YType.str, 'lsa-link-local'), ['str'])),
                                                        ('router_priority', (YLeaf(YType.uint8, 'router-priority'), ['int'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.is_virtual_link = None
                                                    self.virtual_link_id = None
                                                    self.is_sham_link = None
                                                    self.sham_link_id = None
                                                    self.lsa_link_local = None
                                                    self.router_priority = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"

                                                    self.prefix = YList(self)
                                                    self._segment_path = lambda: "link-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id', u'lsa_link_local', u'router_priority'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    OSPFv3 prefix 
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	OSPFv3 prefix 
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ospfv3_prefix_length
                                                    
                                                    	OSPFv3 prefix length 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ospfv3_prefix_options
                                                    
                                                    	OSPFv3 prefix options 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ospfv3_prefix_metric
                                                    
                                                    	OSPFv3 prefix metric 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Prefix priority
                                                    	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                            ('ospfv3_prefix_length', (YLeaf(YType.uint8, 'ospfv3-prefix-length'), ['int'])),
                                                            ('ospfv3_prefix_options', (YLeaf(YType.uint8, 'ospfv3-prefix-options'), ['int'])),
                                                            ('ospfv3_prefix_metric', (YLeaf(YType.uint16, 'ospfv3-prefix-metric'), ['int'])),
                                                            ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                        ])
                                                        self.prefix = None
                                                        self.ospfv3_prefix_length = None
                                                        self.ospfv3_prefix_options = None
                                                        self.ospfv3_prefix_metric = None
                                                        self.priority = None
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix, [u'prefix', u'ospfv3_prefix_length', u'ospfv3_prefix_options', u'ospfv3_prefix_metric', u'priority'], name, value)


                                            class IntraAreaPrefixLsaType(Entity):
                                                """
                                                Intra Area Prefix LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                                
                                                .. attribute:: reference_type
                                                
                                                	Reference type 
                                                	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                                
                                                .. attribute:: reference_lsa_id
                                                
                                                	Reference LSA ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: reference_advertised_router
                                                
                                                	Reference advertised router 
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\: list of  		 :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, self).__init__()

                                                    self.yang_name = "intra-area-prefix-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail)), ("prefix", ("prefix", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('reference_type', (YLeaf(YType.enumeration, 'reference-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                                        ('reference_lsa_id', (YLeaf(YType.uint32, 'reference-lsa-id'), ['int'])),
                                                        ('reference_advertised_router', (YLeaf(YType.str, 'reference-advertised-router'), ['str'])),
                                                    ])
                                                    self.reference_type = None
                                                    self.reference_lsa_id = None
                                                    self.reference_advertised_router = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"

                                                    self.prefix = YList(self)
                                                    self._segment_path = lambda: "intra-area-prefix-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, [u'reference_type', u'reference_lsa_id', u'reference_advertised_router'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    OSPFv3 prefix 
                                                    
                                                    .. attribute:: prefix
                                                    
                                                    	OSPFv3 prefix 
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ospfv3_prefix_length
                                                    
                                                    	OSPFv3 prefix length 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ospfv3_prefix_options
                                                    
                                                    	OSPFv3 prefix options 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ospfv3_prefix_metric
                                                    
                                                    	OSPFv3 prefix metric 
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Prefix priority
                                                    	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                            ('ospfv3_prefix_length', (YLeaf(YType.uint8, 'ospfv3-prefix-length'), ['int'])),
                                                            ('ospfv3_prefix_options', (YLeaf(YType.uint8, 'ospfv3-prefix-options'), ['int'])),
                                                            ('ospfv3_prefix_metric', (YLeaf(YType.uint16, 'ospfv3-prefix-metric'), ['int'])),
                                                            ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                        ])
                                                        self.prefix = None
                                                        self.ospfv3_prefix_length = None
                                                        self.ospfv3_prefix_options = None
                                                        self.ospfv3_prefix_metric = None
                                                        self.priority = None
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, [u'prefix', u'ospfv3_prefix_length', u'ospfv3_prefix_options', u'ospfv3_prefix_metric', u'priority'], name, value)


                                            class GraceLsa(Entity):
                                                """
                                                Grace LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface handle
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link
                                                	**type**\: bool
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link
                                                	**type**\: bool
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Sham link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: grace_period
                                                
                                                	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: grace_reason
                                                
                                                	Reason for router restart
                                                	**type**\:  :py:class:`Ospfv3GracefulRestartReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReason>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa, self).__init__()

                                                    self.yang_name = "grace-lsa"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                        ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                        ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                        ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                        ('grace_period', (YLeaf(YType.uint32, 'grace-period'), ['int'])),
                                                        ('grace_reason', (YLeaf(YType.enumeration, 'grace-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3GracefulRestartReason', '')])),
                                                    ])
                                                    self.interface_name = None
                                                    self.is_virtual_link = None
                                                    self.virtual_link_id = None
                                                    self.is_sham_link = None
                                                    self.sham_link_id = None
                                                    self.grace_period = None
                                                    self.grace_reason = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "grace-lsa"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id', u'grace_period', u'grace_reason'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "grace-lsa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "grace-lsa"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class UnknownLinkLsaType(Entity):
                                                """
                                                Unknown Link Scope LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\: bool
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\: bool
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType, self).__init__()

                                                    self.yang_name = "unknown-link-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                        ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                        ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                        ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.is_virtual_link = None
                                                    self.virtual_link_id = None
                                                    self.is_sham_link = None
                                                    self.sham_link_id = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "unknown-link-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "unknown-link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "unknown-link-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class UnknownAreaLsaType(Entity):
                                                """
                                                Unknown\-Area scope LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\: bool
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\: bool
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType, self).__init__()

                                                    self.yang_name = "unknown-area-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                        ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                        ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                        ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.is_virtual_link = None
                                                    self.virtual_link_id = None
                                                    self.is_sham_link = None
                                                    self.sham_link_id = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "unknown-area-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "unknown-area-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "unknown-area-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class UnknownAslsaType(Entity):
                                                """
                                                Unknown\-AS scope LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\: bool
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\: bool
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType, self).__init__()

                                                    self.yang_name = "unknown-aslsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                        ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                        ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                        ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.is_virtual_link = None
                                                    self.virtual_link_id = None
                                                    self.is_sham_link = None
                                                    self.sham_link_id = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "unknown-aslsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "unknown-aslsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "unknown-aslsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class UnknownLsaType(Entity):
                                                """
                                                Unknown LSA
                                                
                                                .. attribute:: lsa_header
                                                
                                                	Header information 
                                                	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                                
                                                .. attribute:: lsa_detail
                                                
                                                	Detailed LSA information
                                                	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                                
                                                .. attribute:: interface_name
                                                
                                                	LSA interface name 
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                .. attribute:: is_virtual_link
                                                
                                                	If true, it is a virtual link 
                                                	**type**\: bool
                                                
                                                .. attribute:: virtual_link_id
                                                
                                                	Virtual link ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_sham_link
                                                
                                                	If true, it is a sham link 
                                                	**type**\: bool
                                                
                                                .. attribute:: sham_link_id
                                                
                                                	Shamlink ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType, self).__init__()

                                                    self.yang_name = "unknown-lsa-type"
                                                    self.yang_parent_name = "lsa-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                        ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                        ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                        ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                        ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                    ])
                                                    self.interface_name = None
                                                    self.is_virtual_link = None
                                                    self.virtual_link_id = None
                                                    self.is_sham_link = None
                                                    self.sham_link_id = None

                                                    self.lsa_header = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                                    self.lsa_header.parent = self
                                                    self._children_name_map["lsa_header"] = "lsa-header"

                                                    self.lsa_detail = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                                    self.lsa_detail.parent = self
                                                    self._children_name_map["lsa_detail"] = "lsa-detail"
                                                    self._segment_path = lambda: "unknown-lsa-type"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                                class LsaHeader(Entity):
                                                    """
                                                    Header information 
                                                    
                                                    .. attribute:: lsa_type
                                                    
                                                    	LSA type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_area_id
                                                    
                                                    	Area ID in decimal or dotted\-decimal format
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..16
                                                    
                                                    .. attribute:: lsa_age
                                                    
                                                    	LSA's Age (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_do_not_age_lsa
                                                    
                                                    	If true, Do Not Age this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ls_id
                                                    
                                                    	LS ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: advertising_router
                                                    
                                                    	Router ID of Advertising Router
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: sequence_number
                                                    
                                                    	Current Sequence number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: checksum
                                                    
                                                    	Checksum value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: is_graceful_restart_active
                                                    
                                                    	If true, if grace restart is active 
                                                    	**type**\: bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, self).__init__()

                                                        self.yang_name = "lsa-header"
                                                        self.yang_parent_name = "unknown-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                            ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                            ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                            ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                            ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                            ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                        ])
                                                        self.lsa_type = None
                                                        self.lsa_area_id = None
                                                        self.lsa_age = None
                                                        self.is_do_not_age_lsa = None
                                                        self.ls_id = None
                                                        self.advertising_router = None
                                                        self.sequence_number = None
                                                        self.checksum = None
                                                        self.is_graceful_restart_active = None
                                                        self._segment_path = lambda: "lsa-header"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                                class LsaDetail(Entity):
                                                    """
                                                    Detailed LSA information
                                                    
                                                    .. attribute:: second_table_index
                                                    
                                                    	Second table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: minute_table_index
                                                    
                                                    	Minute table index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: free_time
                                                    
                                                    	The amount of time since the last check was made to free this LSA (s)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: is_deleted
                                                    
                                                    	If true, flag is set to delete this LSA 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_bit
                                                    
                                                    	If true, Routing Bit set on the LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_advertising_router_reachable
                                                    
                                                    	If true, Advertising Router is reachable
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_no_delete
                                                    
                                                    	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_neighbor_exchange
                                                    
                                                    	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_routing_table
                                                    
                                                    	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_acknowledged
                                                    
                                                    	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_maximum_aged
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_partial_spf
                                                    
                                                    	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_flood_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: rate_limit
                                                    
                                                    	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_nsr_ack_pending
                                                    
                                                    	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: nsr_flood_required
                                                    
                                                    	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_flood_required_post_fail_over
                                                    
                                                    	LSA flood required after FO
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: lsa_length
                                                    
                                                    	Length of the LSA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: lsa_sync_state
                                                    
                                                    	State of LSA sync with active
                                                    	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ipv6-ospfv3-oper'
                                                    _revision = '2017-10-30'

                                                    def __init__(self):
                                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, self).__init__()

                                                        self.yang_name = "lsa-detail"
                                                        self.yang_parent_name = "unknown-lsa-type"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                            ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                            ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                            ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                            ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                            ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                            ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                            ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                            ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                            ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                            ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                            ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                            ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                            ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                            ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                            ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                            ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                            ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                            ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                        ])
                                                        self.second_table_index = None
                                                        self.minute_table_index = None
                                                        self.free_time = None
                                                        self.is_deleted = None
                                                        self.is_routing_bit = None
                                                        self.is_advertising_router_reachable = None
                                                        self.is_no_delete = None
                                                        self.is_neighbor_exchange = None
                                                        self.is_routing_table = None
                                                        self.is_acknowledged = None
                                                        self.is_maximum_aged = None
                                                        self.is_partial_spf = None
                                                        self.is_flood_pending = None
                                                        self.rate_limit = None
                                                        self.is_nsr_ack_pending = None
                                                        self.nsr_flood_required = None
                                                        self.lsa_flood_required_post_fail_over = None
                                                        self.lsa_length = None
                                                        self.lsa_sync_state = None
                                                        self._segment_path = lambda: "lsa-detail"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                            class DatabaseSummaryTable(Entity):
                                """
                                Database summary table
                                
                                .. attribute:: database_summary
                                
                                	Database Summary information
                                	**type**\:  :py:class:`DatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable, self).__init__()

                                    self.yang_name = "database-summary-table"
                                    self.yang_parent_name = "area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("database-summary", ("database_summary", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary))])
                                    self._leafs = OrderedDict()

                                    self.database_summary = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary()
                                    self.database_summary.parent = self
                                    self._children_name_map["database_summary"] = "database-summary"
                                    self._segment_path = lambda: "database-summary-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable, [], name, value)


                                class DatabaseSummary(Entity):
                                    """
                                    Database Summary information
                                    
                                    .. attribute:: database_counters
                                    
                                    	OSPFv3 database counters 
                                    	**type**\:  :py:class:`DatabaseCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters>`
                                    
                                    .. attribute:: database_router_id
                                    
                                    	Database router ID 
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_opaque_database_capable
                                    
                                    	If true, opaque database is capable 
                                    	**type**\: bool
                                    
                                    .. attribute:: area_database
                                    
                                    	OSPFv3 Area Database list 
                                    	**type**\: list of  		 :py:class:`AreaDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary, self).__init__()

                                        self.yang_name = "database-summary"
                                        self.yang_parent_name = "database-summary-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("database-counters", ("database_counters", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters)), ("area-database", ("area_database", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase))])
                                        self._leafs = OrderedDict([
                                            ('database_router_id', (YLeaf(YType.str, 'database-router-id'), ['str'])),
                                            ('is_opaque_database_capable', (YLeaf(YType.boolean, 'is-opaque-database-capable'), ['bool'])),
                                        ])
                                        self.database_router_id = None
                                        self.is_opaque_database_capable = None

                                        self.database_counters = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters()
                                        self.database_counters.parent = self
                                        self._children_name_map["database_counters"] = "database-counters"

                                        self.area_database = YList(self)
                                        self._segment_path = lambda: "database-summary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary, [u'database_router_id', u'is_opaque_database_capable'], name, value)


                                    class DatabaseCounters(Entity):
                                        """
                                        OSPFv3 database counters 
                                        
                                        .. attribute:: lsa
                                        
                                        	lsa
                                        	**type**\: list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: deleted_lsa
                                        
                                        	deleted lsa
                                        	**type**\: list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_age_lsa
                                        
                                        	max age lsa
                                        	**type**\: list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_checksum
                                        
                                        	lsa checksum
                                        	**type**\: list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters, self).__init__()

                                            self.yang_name = "database-counters"
                                            self.yang_parent_name = "database-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa', (YLeafList(YType.uint32, 'lsa'), ['int'])),
                                                ('deleted_lsa', (YLeafList(YType.uint32, 'deleted-lsa'), ['int'])),
                                                ('max_age_lsa', (YLeafList(YType.uint32, 'max-age-lsa'), ['int'])),
                                                ('lsa_checksum', (YLeafList(YType.uint32, 'lsa-checksum'), ['int'])),
                                            ])
                                            self.lsa = []
                                            self.deleted_lsa = []
                                            self.max_age_lsa = []
                                            self.lsa_checksum = []
                                            self._segment_path = lambda: "database-counters"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters, [u'lsa', u'deleted_lsa', u'max_age_lsa', u'lsa_checksum'], name, value)


                                    class AreaDatabase(Entity):
                                        """
                                        OSPFv3 Area Database list 
                                        
                                        .. attribute:: area_database_summary
                                        
                                        	Area database summary 
                                        	**type**\:  :py:class:`AreaDatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary>`
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase, self).__init__()

                                            self.yang_name = "area-database"
                                            self.yang_parent_name = "database-summary"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("area-database-summary", ("area_database_summary", Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary))])
                                            self._leafs = OrderedDict([
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                            ])
                                            self.lsa_area_id = None

                                            self.area_database_summary = Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary()
                                            self.area_database_summary.parent = self
                                            self._children_name_map["area_database_summary"] = "area-database-summary"
                                            self._segment_path = lambda: "area-database"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase, [u'lsa_area_id'], name, value)


                                        class AreaDatabaseSummary(Entity):
                                            """
                                            Area database summary 
                                            
                                            .. attribute:: lsa
                                            
                                            	lsa
                                            	**type**\: list of int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: deleted_lsa
                                            
                                            	deleted lsa
                                            	**type**\: list of int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: max_age_lsa
                                            
                                            	max age lsa
                                            	**type**\: list of int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_checksum
                                            
                                            	lsa checksum
                                            	**type**\: list of int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary, self).__init__()

                                                self.yang_name = "area-database-summary"
                                                self.yang_parent_name = "area-database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsa', (YLeafList(YType.uint32, 'lsa'), ['int'])),
                                                    ('deleted_lsa', (YLeafList(YType.uint32, 'deleted-lsa'), ['int'])),
                                                    ('max_age_lsa', (YLeafList(YType.uint32, 'max-age-lsa'), ['int'])),
                                                    ('lsa_checksum', (YLeafList(YType.uint32, 'lsa-checksum'), ['int'])),
                                                ])
                                                self.lsa = []
                                                self.deleted_lsa = []
                                                self.max_age_lsa = []
                                                self.lsa_checksum = []
                                                self._segment_path = lambda: "area-database-summary"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary, [u'lsa', u'deleted_lsa', u'max_age_lsa', u'lsa_checksum'], name, value)


                    class InternalRoutes(Entity):
                        """
                        OSPFv3 internal route information table
                        
                        .. attribute:: internal_route
                        
                        	OSPFv3 internal route information
                        	**type**\: list of  		 :py:class:`InternalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes, self).__init__()

                            self.yang_name = "internal-routes"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("internal-route", ("internal_route", Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute))])
                            self._leafs = OrderedDict()

                            self.internal_route = YList(self)
                            self._segment_path = lambda: "internal-routes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes, [], name, value)


                        class InternalRoute(Entity):
                            """
                            OSPFv3 internal route information
                            
                            .. attribute:: prefix
                            
                            	Route prefix
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\: int
                            
                            	**range:** 0..128
                            
                            .. attribute:: route_topology
                            
                            	Common Route topology information
                            	**type**\:  :py:class:`RouteTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteTopology>`
                            
                            .. attribute:: route_area_id
                            
                            	Route area ID 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_source
                            
                            	List of topology source information
                            	**type**\: list of  		 :py:class:`RouteSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteSource>`
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of  		 :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute, self).__init__()

                                self.yang_name = "internal-route"
                                self.yang_parent_name = "internal-routes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("route-topology", ("route_topology", Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteTopology)), ("route-source", ("route_source", Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteSource)), ("route-path", ("route_path", Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath))])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                    ('route_area_id', (YLeaf(YType.uint32, 'route-area-id'), ['int'])),
                                ])
                                self.prefix = None
                                self.prefix_length = None
                                self.route_area_id = None

                                self.route_topology = Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteTopology()
                                self.route_topology.parent = self
                                self._children_name_map["route_topology"] = "route-topology"

                                self.route_source = YList(self)
                                self.route_path = YList(self)
                                self._segment_path = lambda: "internal-route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute, ['prefix', 'prefix_length', u'route_area_id'], name, value)


                            class RouteTopology(Entity):
                                """
                                Common Route topology information
                                
                                .. attribute:: route_id
                                
                                	Route ID 
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_distance
                                
                                	Route distance 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_cost
                                
                                	Route cost 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteTopology, self).__init__()

                                    self.yang_name = "route-topology"
                                    self.yang_parent_name = "internal-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_id', (YLeaf(YType.str, 'route-id'), ['str'])),
                                        ('route_distance', (YLeaf(YType.uint32, 'route-distance'), ['int'])),
                                        ('route_cost', (YLeaf(YType.uint32, 'route-cost'), ['int'])),
                                        ('route_type', (YLeaf(YType.uint32, 'route-type'), ['int'])),
                                    ])
                                    self.route_id = None
                                    self.route_distance = None
                                    self.route_cost = None
                                    self.route_type = None
                                    self._segment_path = lambda: "route-topology"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteTopology, [u'route_id', u'route_distance', u'route_cost', u'route_type'], name, value)


                            class RouteSource(Entity):
                                """
                                List of topology source information
                                
                                .. attribute:: route_source_adversting_router
                                
                                	Route source of the advertising router 
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_source_id
                                
                                	Route source ID 
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_source_lsa_type
                                
                                	Type of LSA advertising the prefix, see RFC5340
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteSource, self).__init__()

                                    self.yang_name = "route-source"
                                    self.yang_parent_name = "internal-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_source_adversting_router', (YLeaf(YType.str, 'route-source-adversting-router'), ['str'])),
                                        ('route_source_id', (YLeaf(YType.str, 'route-source-id'), ['str'])),
                                        ('route_source_lsa_type', (YLeaf(YType.uint32, 'route-source-lsa-type'), ['int'])),
                                    ])
                                    self.route_source_adversting_router = None
                                    self.route_source_id = None
                                    self.route_source_lsa_type = None
                                    self._segment_path = lambda: "route-source"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RouteSource, [u'route_source_adversting_router', u'route_source_id', u'route_source_lsa_type'], name, value)


                            class RoutePath(Entity):
                                """
                                List of paths to this route
                                
                                .. attribute:: route_backup_path
                                
                                	Backup Path Info
                                	**type**\:  :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath>`
                                
                                .. attribute:: interface_name
                                
                                	Route path interface name 
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: interface_index
                                
                                	Route path interface Index 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_path_next_hop
                                
                                	Route path next hop 
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_path_id
                                
                                	Path ID of path
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_next_hop
                                
                                	NeighborNextHop
                                	**type**\: list of  		 :py:class:`NeighborNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath.NeighborNextHop>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath, self).__init__()

                                    self.yang_name = "route-path"
                                    self.yang_parent_name = "internal-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("route-backup-path", ("route_backup_path", Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath)), ("neighbor-next-hop", ("neighbor_next_hop", Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath.NeighborNextHop))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                        ('route_path_next_hop', (YLeaf(YType.str, 'route-path-next-hop'), ['str'])),
                                        ('route_path_id', (YLeaf(YType.uint16, 'route-path-id'), ['int'])),
                                    ])
                                    self.interface_name = None
                                    self.interface_index = None
                                    self.route_path_next_hop = None
                                    self.route_path_id = None

                                    self.route_backup_path = Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath()
                                    self.route_backup_path.parent = self
                                    self._children_name_map["route_backup_path"] = "route-backup-path"

                                    self.neighbor_next_hop = YList(self)
                                    self._segment_path = lambda: "route-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath, [u'interface_name', u'interface_index', u'route_path_next_hop', u'route_path_id'], name, value)


                                class RouteBackupPath(Entity):
                                    """
                                    Backup Path Info
                                    
                                    .. attribute:: backup_route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: backup_route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_route_source
                                    
                                    	IP address of source of route
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_metric
                                    
                                    	Metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: primary_path
                                    
                                    	Primary Path
                                    	**type**\: bool
                                    
                                    .. attribute:: line_card_disjoint
                                    
                                    	Line Card Disjoint
                                    	**type**\: bool
                                    
                                    .. attribute:: downstream
                                    
                                    	Downstream
                                    	**type**\: bool
                                    
                                    .. attribute:: node_protect
                                    
                                    	Node Protect
                                    	**type**\: bool
                                    
                                    .. attribute:: srlg_disjoint
                                    
                                    	SRLG Disjoint
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath, self).__init__()

                                        self.yang_name = "route-backup-path"
                                        self.yang_parent_name = "route-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('backup_route_interface_name', (YLeaf(YType.str, 'backup-route-interface-name'), ['str'])),
                                            ('backup_route_next_hop_address', (YLeaf(YType.str, 'backup-route-next-hop-address'), ['str'])),
                                            ('backup_route_source', (YLeaf(YType.str, 'backup-route-source'), ['str'])),
                                            ('backup_metric', (YLeaf(YType.uint32, 'backup-metric'), ['int'])),
                                            ('primary_path', (YLeaf(YType.boolean, 'primary-path'), ['bool'])),
                                            ('line_card_disjoint', (YLeaf(YType.boolean, 'line-card-disjoint'), ['bool'])),
                                            ('downstream', (YLeaf(YType.boolean, 'downstream'), ['bool'])),
                                            ('node_protect', (YLeaf(YType.boolean, 'node-protect'), ['bool'])),
                                            ('srlg_disjoint', (YLeaf(YType.boolean, 'srlg-disjoint'), ['bool'])),
                                        ])
                                        self.backup_route_interface_name = None
                                        self.backup_route_next_hop_address = None
                                        self.backup_route_source = None
                                        self.backup_metric = None
                                        self.primary_path = None
                                        self.line_card_disjoint = None
                                        self.downstream = None
                                        self.node_protect = None
                                        self.srlg_disjoint = None
                                        self._segment_path = lambda: "route-backup-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath, [u'backup_route_interface_name', u'backup_route_next_hop_address', u'backup_route_source', u'backup_metric', u'primary_path', u'line_card_disjoint', u'downstream', u'node_protect', u'srlg_disjoint'], name, value)


                                class NeighborNextHop(Entity):
                                    """
                                    NeighborNextHop
                                    
                                    .. attribute:: neighbor_next_hop_intf_index
                                    
                                    	Neighbor NextHop Interface Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath.NeighborNextHop, self).__init__()

                                        self.yang_name = "neighbor-next-hop"
                                        self.yang_parent_name = "route-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('neighbor_next_hop_intf_index', (YLeaf(YType.uint32, 'neighbor-next-hop-intf-index'), ['int'])),
                                        ])
                                        self.neighbor_next_hop_intf_index = None
                                        self._segment_path = lambda: "neighbor-next-hop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InternalRoutes.InternalRoute.RoutePath.NeighborNextHop, [u'neighbor_next_hop_intf_index'], name, value)


                    class ProtocolAreas(Entity):
                        """
                        Protocol area table 
                        
                        .. attribute:: protocol_area
                        
                        	Area information 
                        	**type**\: list of  		 :py:class:`ProtocolArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas, self).__init__()

                            self.yang_name = "protocol-areas"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("protocol-area", ("protocol_area", Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea))])
                            self._leafs = OrderedDict()

                            self.protocol_area = YList(self)
                            self._segment_path = lambda: "protocol-areas"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas, [], name, value)


                        class ProtocolArea(Entity):
                            """
                            Area information 
                            
                            .. attribute:: area_id  (key)
                            
                            	Area ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: protocol_area_id
                            
                            	Area ID string in decimal and dotted\-decimal format
                            	**type**\: str
                            
                            	**length:** 0..16
                            
                            .. attribute:: distribute_list_in
                            
                            	Distribute List In
                            	**type**\: str
                            
                            .. attribute:: protocol_interface
                            
                            	Interface list
                            	**type**\: list of  		 :py:class:`ProtocolInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea.ProtocolInterface>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea, self).__init__()

                                self.yang_name = "protocol-area"
                                self.yang_parent_name = "protocol-areas"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['area_id']
                                self._child_classes = OrderedDict([("protocol-interface", ("protocol_interface", Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea.ProtocolInterface))])
                                self._leafs = OrderedDict([
                                    ('area_id', (YLeaf(YType.str, 'area-id'), ['str'])),
                                    ('protocol_area_id', (YLeaf(YType.str, 'protocol-area-id'), ['str'])),
                                    ('distribute_list_in', (YLeaf(YType.str, 'distribute-list-in'), ['str'])),
                                ])
                                self.area_id = None
                                self.protocol_area_id = None
                                self.distribute_list_in = None

                                self.protocol_interface = YList(self)
                                self._segment_path = lambda: "protocol-area" + "[area-id='" + str(self.area_id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea, ['area_id', u'protocol_area_id', u'distribute_list_in'], name, value)


                            class ProtocolInterface(Entity):
                                """
                                Interface list
                                
                                .. attribute:: interface_name
                                
                                	Protocol interface name 
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: distribute_list_in
                                
                                	Distribute List In
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea.ProtocolInterface, self).__init__()

                                    self.yang_name = "protocol-interface"
                                    self.yang_parent_name = "protocol-area"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('distribute_list_in', (YLeaf(YType.str, 'distribute-list-in'), ['str'])),
                                    ])
                                    self.interface_name = None
                                    self.distribute_list_in = None
                                    self._segment_path = lambda: "protocol-interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ProtocolAreas.ProtocolArea.ProtocolInterface, [u'interface_name', u'distribute_list_in'], name, value)


                    class ConnectedRoutes(Entity):
                        """
                        OSPFv3 connected route information table
                        
                        .. attribute:: connected_route
                        
                        	OSPFv3 connected route information
                        	**type**\: list of  		 :py:class:`ConnectedRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes, self).__init__()

                            self.yang_name = "connected-routes"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("connected-route", ("connected_route", Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute))])
                            self._leafs = OrderedDict()

                            self.connected_route = YList(self)
                            self._segment_path = lambda: "connected-routes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes, [], name, value)


                        class ConnectedRoute(Entity):
                            """
                            OSPFv3 connected route information
                            
                            .. attribute:: prefix
                            
                            	Route prefix
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\: int
                            
                            	**range:** 0..128
                            
                            .. attribute:: route_topology
                            
                            	Common Route topology information
                            	**type**\:  :py:class:`RouteTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RouteTopology>`
                            
                            .. attribute:: route_path
                            
                            	List of paths to this route
                            	**type**\: list of  		 :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute, self).__init__()

                                self.yang_name = "connected-route"
                                self.yang_parent_name = "connected-routes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("route-topology", ("route_topology", Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RouteTopology)), ("route-path", ("route_path", Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath))])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                ])
                                self.prefix = None
                                self.prefix_length = None

                                self.route_topology = Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RouteTopology()
                                self.route_topology.parent = self
                                self._children_name_map["route_topology"] = "route-topology"

                                self.route_path = YList(self)
                                self._segment_path = lambda: "connected-route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute, ['prefix', 'prefix_length'], name, value)


                            class RouteTopology(Entity):
                                """
                                Common Route topology information
                                
                                .. attribute:: route_id
                                
                                	Route ID 
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_distance
                                
                                	Route distance 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_cost
                                
                                	Route cost 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_type
                                
                                	Route type
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RouteTopology, self).__init__()

                                    self.yang_name = "route-topology"
                                    self.yang_parent_name = "connected-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('route_id', (YLeaf(YType.str, 'route-id'), ['str'])),
                                        ('route_distance', (YLeaf(YType.uint32, 'route-distance'), ['int'])),
                                        ('route_cost', (YLeaf(YType.uint32, 'route-cost'), ['int'])),
                                        ('route_type', (YLeaf(YType.uint32, 'route-type'), ['int'])),
                                    ])
                                    self.route_id = None
                                    self.route_distance = None
                                    self.route_cost = None
                                    self.route_type = None
                                    self._segment_path = lambda: "route-topology"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RouteTopology, [u'route_id', u'route_distance', u'route_cost', u'route_type'], name, value)


                            class RoutePath(Entity):
                                """
                                List of paths to this route
                                
                                .. attribute:: route_backup_path
                                
                                	Backup Path Info
                                	**type**\:  :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath>`
                                
                                .. attribute:: interface_name
                                
                                	Route path interface name 
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: interface_index
                                
                                	Route path interface Index 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_path_next_hop
                                
                                	Route path next hop 
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: route_path_id
                                
                                	Path ID of path
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_next_hop
                                
                                	NeighborNextHop
                                	**type**\: list of  		 :py:class:`NeighborNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath.NeighborNextHop>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath, self).__init__()

                                    self.yang_name = "route-path"
                                    self.yang_parent_name = "connected-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("route-backup-path", ("route_backup_path", Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath)), ("neighbor-next-hop", ("neighbor_next_hop", Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath.NeighborNextHop))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                        ('route_path_next_hop', (YLeaf(YType.str, 'route-path-next-hop'), ['str'])),
                                        ('route_path_id', (YLeaf(YType.uint16, 'route-path-id'), ['int'])),
                                    ])
                                    self.interface_name = None
                                    self.interface_index = None
                                    self.route_path_next_hop = None
                                    self.route_path_id = None

                                    self.route_backup_path = Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath()
                                    self.route_backup_path.parent = self
                                    self._children_name_map["route_backup_path"] = "route-backup-path"

                                    self.neighbor_next_hop = YList(self)
                                    self._segment_path = lambda: "route-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath, [u'interface_name', u'interface_index', u'route_path_next_hop', u'route_path_id'], name, value)


                                class RouteBackupPath(Entity):
                                    """
                                    Backup Path Info
                                    
                                    .. attribute:: backup_route_interface_name
                                    
                                    	Next hop Interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: backup_route_next_hop_address
                                    
                                    	Nexthop IP address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_route_source
                                    
                                    	IP address of source of route
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_metric
                                    
                                    	Metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: primary_path
                                    
                                    	Primary Path
                                    	**type**\: bool
                                    
                                    .. attribute:: line_card_disjoint
                                    
                                    	Line Card Disjoint
                                    	**type**\: bool
                                    
                                    .. attribute:: downstream
                                    
                                    	Downstream
                                    	**type**\: bool
                                    
                                    .. attribute:: node_protect
                                    
                                    	Node Protect
                                    	**type**\: bool
                                    
                                    .. attribute:: srlg_disjoint
                                    
                                    	SRLG Disjoint
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath, self).__init__()

                                        self.yang_name = "route-backup-path"
                                        self.yang_parent_name = "route-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('backup_route_interface_name', (YLeaf(YType.str, 'backup-route-interface-name'), ['str'])),
                                            ('backup_route_next_hop_address', (YLeaf(YType.str, 'backup-route-next-hop-address'), ['str'])),
                                            ('backup_route_source', (YLeaf(YType.str, 'backup-route-source'), ['str'])),
                                            ('backup_metric', (YLeaf(YType.uint32, 'backup-metric'), ['int'])),
                                            ('primary_path', (YLeaf(YType.boolean, 'primary-path'), ['bool'])),
                                            ('line_card_disjoint', (YLeaf(YType.boolean, 'line-card-disjoint'), ['bool'])),
                                            ('downstream', (YLeaf(YType.boolean, 'downstream'), ['bool'])),
                                            ('node_protect', (YLeaf(YType.boolean, 'node-protect'), ['bool'])),
                                            ('srlg_disjoint', (YLeaf(YType.boolean, 'srlg-disjoint'), ['bool'])),
                                        ])
                                        self.backup_route_interface_name = None
                                        self.backup_route_next_hop_address = None
                                        self.backup_route_source = None
                                        self.backup_metric = None
                                        self.primary_path = None
                                        self.line_card_disjoint = None
                                        self.downstream = None
                                        self.node_protect = None
                                        self.srlg_disjoint = None
                                        self._segment_path = lambda: "route-backup-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath, [u'backup_route_interface_name', u'backup_route_next_hop_address', u'backup_route_source', u'backup_metric', u'primary_path', u'line_card_disjoint', u'downstream', u'node_protect', u'srlg_disjoint'], name, value)


                                class NeighborNextHop(Entity):
                                    """
                                    NeighborNextHop
                                    
                                    .. attribute:: neighbor_next_hop_intf_index
                                    
                                    	Neighbor NextHop Interface Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath.NeighborNextHop, self).__init__()

                                        self.yang_name = "neighbor-next-hop"
                                        self.yang_parent_name = "route-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('neighbor_next_hop_intf_index', (YLeaf(YType.uint32, 'neighbor-next-hop-intf-index'), ['int'])),
                                        ])
                                        self.neighbor_next_hop_intf_index = None
                                        self._segment_path = lambda: "neighbor-next-hop"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.ConnectedRoutes.ConnectedRoute.RoutePath.NeighborNextHop, [u'neighbor_next_hop_intf_index'], name, value)


                    class VrfStatistics(Entity):
                        """
                        Container for Statistics
                        
                        .. attribute:: protocol_stats
                        
                        	Protocol table
                        	**type**\:  :py:class:`ProtocolStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats>`
                        
                        .. attribute:: spf_stats
                        
                        	OSPFv3 RIB batch statistics
                        	**type**\:  :py:class:`SpfStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats>`
                        
                        .. attribute:: rawio_stats
                        
                        	OSPF Prefix SPF Prioritization statistics
                        	**type**\:  :py:class:`RawioStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.RawioStats>`
                        
                        .. attribute:: prefix_priority_stats
                        
                        	OSPF Prefix SPF Prioritization statistics
                        	**type**\:  :py:class:`PrefixPriorityStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.PrefixPriorityStats>`
                        
                        .. attribute:: vrf_rib_batch_stats
                        
                        	OSPFv3 RIB batch statistics
                        	**type**\:  :py:class:`VrfRibBatchStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.VrfRibBatchStats>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics, self).__init__()

                            self.yang_name = "vrf-statistics"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("protocol-stats", ("protocol_stats", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats)), ("spf-stats", ("spf_stats", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats)), ("rawio-stats", ("rawio_stats", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.RawioStats)), ("prefix-priority-stats", ("prefix_priority_stats", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.PrefixPriorityStats)), ("vrf-rib-batch-stats", ("vrf_rib_batch_stats", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.VrfRibBatchStats))])
                            self._leafs = OrderedDict()

                            self.protocol_stats = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats()
                            self.protocol_stats.parent = self
                            self._children_name_map["protocol_stats"] = "protocol-stats"

                            self.spf_stats = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats()
                            self.spf_stats.parent = self
                            self._children_name_map["spf_stats"] = "spf-stats"

                            self.rawio_stats = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.RawioStats()
                            self.rawio_stats.parent = self
                            self._children_name_map["rawio_stats"] = "rawio-stats"

                            self.prefix_priority_stats = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.PrefixPriorityStats()
                            self.prefix_priority_stats.parent = self
                            self._children_name_map["prefix_priority_stats"] = "prefix-priority-stats"

                            self.vrf_rib_batch_stats = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.VrfRibBatchStats()
                            self.vrf_rib_batch_stats.parent = self
                            self._children_name_map["vrf_rib_batch_stats"] = "vrf-rib-batch-stats"
                            self._segment_path = lambda: "vrf-statistics"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics, [], name, value)


                        class ProtocolStats(Entity):
                            """
                            Protocol table
                            
                            .. attribute:: protocol_stat
                            
                            	Protocol statistics for an interface
                            	**type**\: list of  		 :py:class:`ProtocolStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats.ProtocolStat>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats, self).__init__()

                                self.yang_name = "protocol-stats"
                                self.yang_parent_name = "vrf-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("protocol-stat", ("protocol_stat", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats.ProtocolStat))])
                                self._leafs = OrderedDict()

                                self.protocol_stat = YList(self)
                                self._segment_path = lambda: "protocol-stats"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats, [], name, value)


                            class ProtocolStat(Entity):
                                """
                                Protocol statistics for an interface
                                
                                .. attribute:: interface_name  (key)
                                
                                	Interface name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: total_in_packets
                                
                                	Total inputs packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: hello_in_packets
                                
                                	Hello packets in
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: dbdes_in_packets
                                
                                	Database Description Packets in
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: dbdes_in_ls_as
                                
                                	Database Description LSAs in
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_req_in_packets
                                
                                	LSA Requests in
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_req_in_ls_as
                                
                                	LS Requests in
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_upd_in_packets
                                
                                	LS Updates Packets in
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_upd_in_ignored
                                
                                	LS Updates ignored
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_upd_in_ls_as
                                
                                	LS Updates LSAs in
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_ack_in_packets
                                
                                	LS Acks Packets in
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_ack_in_ls_as
                                
                                	LS Ack LSAs in
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: total_out_packets
                                
                                	Total Out Packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: hello_out_packets
                                
                                	Hello Out Packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: dbdes_out_packets
                                
                                	Database Description Packets out
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: dbdes_out_ls_as
                                
                                	Database Description LSAs out
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_req_out_packets
                                
                                	LS Request Packets out
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_req_out_ls_as
                                
                                	LS Reuqests LSAs out
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_upd_out_packets
                                
                                	LS Update Packets out
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_upd_out_ls_as
                                
                                	LS Update LSAs out
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_ack_out_packets
                                
                                	LS Ack Packets out
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: ls_ack_out_ls_as
                                
                                	LS Ack LSAs out
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: dropped_in_gs
                                
                                	Dropped in GS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: checksum_err
                                
                                	Checksum Errors
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats.ProtocolStat, self).__init__()

                                    self.yang_name = "protocol-stat"
                                    self.yang_parent_name = "protocol-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['interface_name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('total_in_packets', (YLeaf(YType.uint64, 'total-in-packets'), ['int'])),
                                        ('hello_in_packets', (YLeaf(YType.uint64, 'hello-in-packets'), ['int'])),
                                        ('dbdes_in_packets', (YLeaf(YType.uint64, 'dbdes-in-packets'), ['int'])),
                                        ('dbdes_in_ls_as', (YLeaf(YType.uint64, 'dbdes-in-ls-as'), ['int'])),
                                        ('ls_req_in_packets', (YLeaf(YType.uint64, 'ls-req-in-packets'), ['int'])),
                                        ('ls_req_in_ls_as', (YLeaf(YType.uint64, 'ls-req-in-ls-as'), ['int'])),
                                        ('ls_upd_in_packets', (YLeaf(YType.uint64, 'ls-upd-in-packets'), ['int'])),
                                        ('ls_upd_in_ignored', (YLeaf(YType.uint64, 'ls-upd-in-ignored'), ['int'])),
                                        ('ls_upd_in_ls_as', (YLeaf(YType.uint64, 'ls-upd-in-ls-as'), ['int'])),
                                        ('ls_ack_in_packets', (YLeaf(YType.uint64, 'ls-ack-in-packets'), ['int'])),
                                        ('ls_ack_in_ls_as', (YLeaf(YType.uint64, 'ls-ack-in-ls-as'), ['int'])),
                                        ('total_out_packets', (YLeaf(YType.uint64, 'total-out-packets'), ['int'])),
                                        ('hello_out_packets', (YLeaf(YType.uint64, 'hello-out-packets'), ['int'])),
                                        ('dbdes_out_packets', (YLeaf(YType.uint64, 'dbdes-out-packets'), ['int'])),
                                        ('dbdes_out_ls_as', (YLeaf(YType.uint64, 'dbdes-out-ls-as'), ['int'])),
                                        ('ls_req_out_packets', (YLeaf(YType.uint64, 'ls-req-out-packets'), ['int'])),
                                        ('ls_req_out_ls_as', (YLeaf(YType.uint64, 'ls-req-out-ls-as'), ['int'])),
                                        ('ls_upd_out_packets', (YLeaf(YType.uint64, 'ls-upd-out-packets'), ['int'])),
                                        ('ls_upd_out_ls_as', (YLeaf(YType.uint64, 'ls-upd-out-ls-as'), ['int'])),
                                        ('ls_ack_out_packets', (YLeaf(YType.uint64, 'ls-ack-out-packets'), ['int'])),
                                        ('ls_ack_out_ls_as', (YLeaf(YType.uint64, 'ls-ack-out-ls-as'), ['int'])),
                                        ('dropped_in_gs', (YLeaf(YType.uint64, 'dropped-in-gs'), ['int'])),
                                        ('checksum_err', (YLeaf(YType.uint64, 'checksum-err'), ['int'])),
                                    ])
                                    self.interface_name = None
                                    self.total_in_packets = None
                                    self.hello_in_packets = None
                                    self.dbdes_in_packets = None
                                    self.dbdes_in_ls_as = None
                                    self.ls_req_in_packets = None
                                    self.ls_req_in_ls_as = None
                                    self.ls_upd_in_packets = None
                                    self.ls_upd_in_ignored = None
                                    self.ls_upd_in_ls_as = None
                                    self.ls_ack_in_packets = None
                                    self.ls_ack_in_ls_as = None
                                    self.total_out_packets = None
                                    self.hello_out_packets = None
                                    self.dbdes_out_packets = None
                                    self.dbdes_out_ls_as = None
                                    self.ls_req_out_packets = None
                                    self.ls_req_out_ls_as = None
                                    self.ls_upd_out_packets = None
                                    self.ls_upd_out_ls_as = None
                                    self.ls_ack_out_packets = None
                                    self.ls_ack_out_ls_as = None
                                    self.dropped_in_gs = None
                                    self.checksum_err = None
                                    self._segment_path = lambda: "protocol-stat" + "[interface-name='" + str(self.interface_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.ProtocolStats.ProtocolStat, ['interface_name', u'total_in_packets', u'hello_in_packets', u'dbdes_in_packets', u'dbdes_in_ls_as', u'ls_req_in_packets', u'ls_req_in_ls_as', u'ls_upd_in_packets', u'ls_upd_in_ignored', u'ls_upd_in_ls_as', u'ls_ack_in_packets', u'ls_ack_in_ls_as', u'total_out_packets', u'hello_out_packets', u'dbdes_out_packets', u'dbdes_out_ls_as', u'ls_req_out_packets', u'ls_req_out_ls_as', u'ls_upd_out_packets', u'ls_upd_out_ls_as', u'ls_ack_out_packets', u'ls_ack_out_ls_as', u'dropped_in_gs', u'checksum_err'], name, value)


                        class SpfStats(Entity):
                            """
                            OSPFv3 RIB batch statistics
                            
                            .. attribute:: spf_header
                            
                            	SPF statistics header
                            	**type**\:  :py:class:`SpfHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader>`
                            
                            .. attribute:: spf_runtime
                            
                            	List of SPF run\-time statistics
                            	**type**\: list of  		 :py:class:`SpfRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats, self).__init__()

                                self.yang_name = "spf-stats"
                                self.yang_parent_name = "vrf-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("spf-header", ("spf_header", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader)), ("spf-runtime", ("spf_runtime", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime))])
                                self._leafs = OrderedDict()

                                self.spf_header = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader()
                                self.spf_header.parent = self
                                self._children_name_map["spf_header"] = "spf-header"

                                self.spf_runtime = YList(self)
                                self._segment_path = lambda: "spf-stats"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats, [], name, value)


                            class SpfHeader(Entity):
                                """
                                SPF statistics header
                                
                                .. attribute:: header_router_id
                                
                                	Router ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_sp_fs
                                
                                	Number of SPF calculations
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_summary
                                
                                	List of Areas with SPF statistics
                                	**type**\: list of  		 :py:class:`AreaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader, self).__init__()

                                    self.yang_name = "spf-header"
                                    self.yang_parent_name = "spf-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("area-summary", ("area_summary", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary))])
                                    self._leafs = OrderedDict([
                                        ('header_router_id', (YLeaf(YType.str, 'header-router-id'), ['str'])),
                                        ('header_sp_fs', (YLeaf(YType.uint32, 'header-sp-fs'), ['int'])),
                                    ])
                                    self.header_router_id = None
                                    self.header_sp_fs = None

                                    self.area_summary = YList(self)
                                    self._segment_path = lambda: "spf-header"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader, [u'header_router_id', u'header_sp_fs'], name, value)


                                class AreaSummary(Entity):
                                    """
                                    List of Areas with SPF statistics
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID of the area SPF statistics
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sp_fs
                                    
                                    	Number of SPF calculations
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary, self).__init__()

                                        self.yang_name = "area-summary"
                                        self.yang_parent_name = "spf-header"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('area_id', (YLeaf(YType.uint32, 'area-id'), ['int'])),
                                            ('sp_fs', (YLeaf(YType.uint32, 'sp-fs'), ['int'])),
                                        ])
                                        self.area_id = None
                                        self.sp_fs = None
                                        self._segment_path = lambda: "area-summary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary, [u'area_id', u'sp_fs'], name, value)


                            class SpfRuntime(Entity):
                                """
                                List of SPF run\-time statistics
                                
                                .. attribute:: global_time
                                
                                	Global SPF times
                                	**type**\:  :py:class:`GlobalTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime>`
                                
                                .. attribute:: start_time
                                
                                	SPF calculation start time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_add_routes
                                
                                	Number of routes added to RIB
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_delete_routes
                                
                                	Number of routes deleted from RIB
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reason_flags
                                
                                	Reasons for triggering an SPF calculation Bit 1 \- Router LSA update Bit 2 \- Network LSA update Bit 3 \- Inter\-Area Prefix LSA update Bit 4 \- Inter\-Area Router LSA update Bit 5 \- AS External LSA update Bit 6 \- MOSPF LSA update Bit 7 \- Type 7 AS External LSA update Bit 8 \- Link LSA update Bit 9 \- Prefix LSA update
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: lsa_changes
                                
                                	Number of LSA changes triggering an SPF calculation
                                	**type**\: int
                                
                                	**range:** \-32768..32767
                                
                                .. attribute:: lsa
                                
                                	List of LSAs triggering the SPF calculation
                                	**type**\: list of  		 :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.Lsa>`
                                
                                .. attribute:: area_stat
                                
                                	List of per\-area SPF statistics
                                	**type**\: list of  		 :py:class:`AreaStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime, self).__init__()

                                    self.yang_name = "spf-runtime"
                                    self.yang_parent_name = "spf-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("global-time", ("global_time", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime)), ("lsa", ("lsa", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.Lsa)), ("area-stat", ("area_stat", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat))])
                                    self._leafs = OrderedDict([
                                        ('start_time', (YLeaf(YType.uint32, 'start-time'), ['int'])),
                                        ('rib_add_routes', (YLeaf(YType.uint32, 'rib-add-routes'), ['int'])),
                                        ('rib_delete_routes', (YLeaf(YType.uint32, 'rib-delete-routes'), ['int'])),
                                        ('reason_flags', (YLeaf(YType.str, 'reason-flags'), ['str'])),
                                        ('lsa_changes', (YLeaf(YType.int16, 'lsa-changes'), ['int'])),
                                    ])
                                    self.start_time = None
                                    self.rib_add_routes = None
                                    self.rib_delete_routes = None
                                    self.reason_flags = None
                                    self.lsa_changes = None

                                    self.global_time = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime()
                                    self.global_time.parent = self
                                    self._children_name_map["global_time"] = "global-time"

                                    self.lsa = YList(self)
                                    self.area_stat = YList(self)
                                    self._segment_path = lambda: "spf-runtime"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime, [u'start_time', u'rib_add_routes', u'rib_delete_routes', u'reason_flags', u'lsa_changes'], name, value)


                                class GlobalTime(Entity):
                                    """
                                    Global SPF times
                                    
                                    .. attribute:: dijkstra
                                    
                                    	Dijkstra time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: intra_prefix
                                    
                                    	Intra\-prefix processing time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: intra_prefix_del
                                    
                                    	Intra\-prefix deletion time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inter_prefix
                                    
                                    	Inter\-prefix processing time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inter_prefix_del
                                    
                                    	Intra\-prefix deletion time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_prefix
                                    
                                    	External prefix processing time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_prefix_del
                                    
                                    	External prefix deletion time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_add
                                    
                                    	RIB add processing time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_del
                                    
                                    	RIB deletion time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime, self).__init__()

                                        self.yang_name = "global-time"
                                        self.yang_parent_name = "spf-runtime"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dijkstra', (YLeaf(YType.uint32, 'dijkstra'), ['int'])),
                                            ('intra_prefix', (YLeaf(YType.uint32, 'intra-prefix'), ['int'])),
                                            ('intra_prefix_del', (YLeaf(YType.uint32, 'intra-prefix-del'), ['int'])),
                                            ('inter_prefix', (YLeaf(YType.uint32, 'inter-prefix'), ['int'])),
                                            ('inter_prefix_del', (YLeaf(YType.uint32, 'inter-prefix-del'), ['int'])),
                                            ('external_prefix', (YLeaf(YType.uint32, 'external-prefix'), ['int'])),
                                            ('external_prefix_del', (YLeaf(YType.uint32, 'external-prefix-del'), ['int'])),
                                            ('rib_add', (YLeaf(YType.uint32, 'rib-add'), ['int'])),
                                            ('rib_del', (YLeaf(YType.uint32, 'rib-del'), ['int'])),
                                        ])
                                        self.dijkstra = None
                                        self.intra_prefix = None
                                        self.intra_prefix_del = None
                                        self.inter_prefix = None
                                        self.inter_prefix_del = None
                                        self.external_prefix = None
                                        self.external_prefix_del = None
                                        self.rib_add = None
                                        self.rib_del = None
                                        self._segment_path = lambda: "global-time"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime, [u'dijkstra', u'intra_prefix', u'intra_prefix_del', u'inter_prefix', u'inter_prefix_del', u'external_prefix', u'external_prefix_del', u'rib_add', u'rib_del'], name, value)


                                class Lsa(Entity):
                                    """
                                    List of LSAs triggering the SPF calculation
                                    
                                    .. attribute:: lsa_area_id
                                    
                                    	Area ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_advertising_router
                                    
                                    	Advertising router ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsa_id
                                    
                                    	LSA ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsa_type
                                    
                                    	LSA type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: lsa_flush
                                    
                                    	If true, the LSA change is a flush
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.Lsa, self).__init__()

                                        self.yang_name = "lsa"
                                        self.yang_parent_name = "spf-runtime"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsa_area_id', (YLeaf(YType.uint32, 'lsa-area-id'), ['int'])),
                                            ('lsa_advertising_router', (YLeaf(YType.str, 'lsa-advertising-router'), ['str'])),
                                            ('lsa_id', (YLeaf(YType.str, 'lsa-id'), ['str'])),
                                            ('lsa_type', (YLeaf(YType.uint8, 'lsa-type'), ['int'])),
                                            ('lsa_flush', (YLeaf(YType.boolean, 'lsa-flush'), ['bool'])),
                                        ])
                                        self.lsa_area_id = None
                                        self.lsa_advertising_router = None
                                        self.lsa_id = None
                                        self.lsa_type = None
                                        self.lsa_flush = None
                                        self._segment_path = lambda: "lsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.Lsa, [u'lsa_area_id', u'lsa_advertising_router', u'lsa_id', u'lsa_type', u'lsa_flush'], name, value)


                                class AreaStat(Entity):
                                    """
                                    List of per\-area SPF statistics
                                    
                                    .. attribute:: spf_stat_time
                                    
                                    	SPF time calculations
                                    	**type**\:  :py:class:`SpfStatTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime>`
                                    
                                    .. attribute:: spf_stat_area_id
                                    
                                    	Area ID for area of these SPF statistics
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: spf_stat_lsa_type_count
                                    
                                    	Counts of LSA types triggering an SPF calculation
                                    	**type**\: list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat, self).__init__()

                                        self.yang_name = "area-stat"
                                        self.yang_parent_name = "spf-runtime"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("spf-stat-time", ("spf_stat_time", Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime))])
                                        self._leafs = OrderedDict([
                                            ('spf_stat_area_id', (YLeaf(YType.uint32, 'spf-stat-area-id'), ['int'])),
                                            ('spf_stat_lsa_type_count', (YLeafList(YType.uint32, 'spf-stat-lsa-type-count'), ['int'])),
                                        ])
                                        self.spf_stat_area_id = None
                                        self.spf_stat_lsa_type_count = []

                                        self.spf_stat_time = Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime()
                                        self.spf_stat_time.parent = self
                                        self._children_name_map["spf_stat_time"] = "spf-stat-time"
                                        self._segment_path = lambda: "area-stat"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat, [u'spf_stat_area_id', u'spf_stat_lsa_type_count'], name, value)


                                    class SpfStatTime(Entity):
                                        """
                                        SPF time calculations
                                        
                                        .. attribute:: dijkstra
                                        
                                        	Dijkstra time in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: intra_prefix
                                        
                                        	Intra\-prefix processing time in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: intra_prefix_del
                                        
                                        	Intra\-prefix deletion time in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inter_prefix
                                        
                                        	Inter\-prefix processing time in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: inter_prefix_del
                                        
                                        	Intra\-prefix deletion time in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: external_prefix
                                        
                                        	External prefix processing time in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: external_prefix_del
                                        
                                        	External prefix deletion time in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_add
                                        
                                        	RIB add processing time in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rib_del
                                        
                                        	RIB deletion time in msec
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime, self).__init__()

                                            self.yang_name = "spf-stat-time"
                                            self.yang_parent_name = "area-stat"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('dijkstra', (YLeaf(YType.uint32, 'dijkstra'), ['int'])),
                                                ('intra_prefix', (YLeaf(YType.uint32, 'intra-prefix'), ['int'])),
                                                ('intra_prefix_del', (YLeaf(YType.uint32, 'intra-prefix-del'), ['int'])),
                                                ('inter_prefix', (YLeaf(YType.uint32, 'inter-prefix'), ['int'])),
                                                ('inter_prefix_del', (YLeaf(YType.uint32, 'inter-prefix-del'), ['int'])),
                                                ('external_prefix', (YLeaf(YType.uint32, 'external-prefix'), ['int'])),
                                                ('external_prefix_del', (YLeaf(YType.uint32, 'external-prefix-del'), ['int'])),
                                                ('rib_add', (YLeaf(YType.uint32, 'rib-add'), ['int'])),
                                                ('rib_del', (YLeaf(YType.uint32, 'rib-del'), ['int'])),
                                            ])
                                            self.dijkstra = None
                                            self.intra_prefix = None
                                            self.intra_prefix_del = None
                                            self.inter_prefix = None
                                            self.inter_prefix_del = None
                                            self.external_prefix = None
                                            self.external_prefix_del = None
                                            self.rib_add = None
                                            self.rib_del = None
                                            self._segment_path = lambda: "spf-stat-time"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime, [u'dijkstra', u'intra_prefix', u'intra_prefix_del', u'inter_prefix', u'inter_prefix_del', u'external_prefix', u'external_prefix_del', u'rib_add', u'rib_del'], name, value)


                        class RawioStats(Entity):
                            """
                            OSPF Prefix SPF Prioritization statistics
                            
                            .. attribute:: raw_conn_open
                            
                            	Raw Connections Open
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: raw_conn_close
                            
                            	Raw Connections Close
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: raw_conn_error
                            
                            	Raw Connections Error
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_packets
                            
                            	Received Packets
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_bytes
                            
                            	Received Bytes
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: byte
                            
                            .. attribute:: in_long_packets
                            
                            	Received Long Packets
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_malloc_drops
                            
                            	In Malloc Drops
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_handle_drops
                            
                            	In Handle Drops
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_short_drops
                            
                            	In Short Drops
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_error_drops
                            
                            	In Error Drops
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_ipsec_drops
                            
                            	In IPSEC Drops
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: in_queue_drops
                            
                            	In Queue Drops
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: out_packets
                            
                            	Packets Sent
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: out_bytes
                            
                            	Sent Bytes
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: byte
                            
                            .. attribute:: out_nofd_drops
                            
                            	No FileDescriptor Drops
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: out_error_drops
                            
                            	Error Drops
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: out_ipsec_drops
                            
                            	Out IPSEC Drops
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: out_nopak_drops
                            
                            	No Packet Buffers
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: out_pakapi_errors
                            
                            	PAK API Errors
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: raw_conn_state
                            
                            	Raw Connection State
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.RawioStats, self).__init__()

                                self.yang_name = "rawio-stats"
                                self.yang_parent_name = "vrf-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('raw_conn_open', (YLeaf(YType.uint64, 'raw-conn-open'), ['int'])),
                                    ('raw_conn_close', (YLeaf(YType.uint64, 'raw-conn-close'), ['int'])),
                                    ('raw_conn_error', (YLeaf(YType.uint64, 'raw-conn-error'), ['int'])),
                                    ('in_packets', (YLeaf(YType.uint64, 'in-packets'), ['int'])),
                                    ('in_bytes', (YLeaf(YType.uint64, 'in-bytes'), ['int'])),
                                    ('in_long_packets', (YLeaf(YType.uint64, 'in-long-packets'), ['int'])),
                                    ('in_malloc_drops', (YLeaf(YType.uint64, 'in-malloc-drops'), ['int'])),
                                    ('in_handle_drops', (YLeaf(YType.uint64, 'in-handle-drops'), ['int'])),
                                    ('in_short_drops', (YLeaf(YType.uint64, 'in-short-drops'), ['int'])),
                                    ('in_error_drops', (YLeaf(YType.uint64, 'in-error-drops'), ['int'])),
                                    ('in_ipsec_drops', (YLeaf(YType.uint64, 'in-ipsec-drops'), ['int'])),
                                    ('in_queue_drops', (YLeaf(YType.uint64, 'in-queue-drops'), ['int'])),
                                    ('out_packets', (YLeaf(YType.uint64, 'out-packets'), ['int'])),
                                    ('out_bytes', (YLeaf(YType.uint64, 'out-bytes'), ['int'])),
                                    ('out_nofd_drops', (YLeaf(YType.uint64, 'out-nofd-drops'), ['int'])),
                                    ('out_error_drops', (YLeaf(YType.uint64, 'out-error-drops'), ['int'])),
                                    ('out_ipsec_drops', (YLeaf(YType.uint64, 'out-ipsec-drops'), ['int'])),
                                    ('out_nopak_drops', (YLeaf(YType.uint64, 'out-nopak-drops'), ['int'])),
                                    ('out_pakapi_errors', (YLeaf(YType.uint64, 'out-pakapi-errors'), ['int'])),
                                    ('raw_conn_state', (YLeaf(YType.uint32, 'raw-conn-state'), ['int'])),
                                ])
                                self.raw_conn_open = None
                                self.raw_conn_close = None
                                self.raw_conn_error = None
                                self.in_packets = None
                                self.in_bytes = None
                                self.in_long_packets = None
                                self.in_malloc_drops = None
                                self.in_handle_drops = None
                                self.in_short_drops = None
                                self.in_error_drops = None
                                self.in_ipsec_drops = None
                                self.in_queue_drops = None
                                self.out_packets = None
                                self.out_bytes = None
                                self.out_nofd_drops = None
                                self.out_error_drops = None
                                self.out_ipsec_drops = None
                                self.out_nopak_drops = None
                                self.out_pakapi_errors = None
                                self.raw_conn_state = None
                                self._segment_path = lambda: "rawio-stats"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.RawioStats, [u'raw_conn_open', u'raw_conn_close', u'raw_conn_error', u'in_packets', u'in_bytes', u'in_long_packets', u'in_malloc_drops', u'in_handle_drops', u'in_short_drops', u'in_error_drops', u'in_ipsec_drops', u'in_queue_drops', u'out_packets', u'out_bytes', u'out_nofd_drops', u'out_error_drops', u'out_ipsec_drops', u'out_nopak_drops', u'out_pakapi_errors', u'raw_conn_state'], name, value)


                        class PrefixPriorityStats(Entity):
                            """
                            OSPF Prefix SPF Prioritization statistics
                            
                            .. attribute:: critical
                            
                            	Critical priority classifications
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high
                            
                            	High priority classifications
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: medium
                            
                            	Medium priority classifications
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: low
                            
                            	Low priority classifications
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.PrefixPriorityStats, self).__init__()

                                self.yang_name = "prefix-priority-stats"
                                self.yang_parent_name = "vrf-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                    ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                    ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                    ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                ])
                                self.critical = None
                                self.high = None
                                self.medium = None
                                self.low = None
                                self._segment_path = lambda: "prefix-priority-stats"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.PrefixPriorityStats, [u'critical', u'high', u'medium', u'low'], name, value)


                        class VrfRibBatchStats(Entity):
                            """
                            OSPFv3 RIB batch statistics
                            
                            .. attribute:: batches_sent
                            
                            	No. of RIB batches sent
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: routes_sent
                            
                            	No. of Routes sent to RIB
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: routes_pending
                            
                            	No of Pending Routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_routes
                            
                            	Max No. of Routes in a batch
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_sent
                            
                            	No. of Paths sent to RIB
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_pending
                            
                            	No. of paths waiting to be sent to RIB
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_add
                            
                            	No. of paths added to RIB
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_add_errs
                            
                            	No. of paths add errors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_del
                            
                            	No. of paths del sent to RIB
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: paths_del_errs
                            
                            	No. of Paths del errors
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.VrfRibBatchStats, self).__init__()

                                self.yang_name = "vrf-rib-batch-stats"
                                self.yang_parent_name = "vrf-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('batches_sent', (YLeaf(YType.uint32, 'batches-sent'), ['int'])),
                                    ('routes_sent', (YLeaf(YType.uint32, 'routes-sent'), ['int'])),
                                    ('routes_pending', (YLeaf(YType.uint32, 'routes-pending'), ['int'])),
                                    ('max_routes', (YLeaf(YType.uint32, 'max-routes'), ['int'])),
                                    ('paths_sent', (YLeaf(YType.uint32, 'paths-sent'), ['int'])),
                                    ('paths_pending', (YLeaf(YType.uint32, 'paths-pending'), ['int'])),
                                    ('paths_add', (YLeaf(YType.uint32, 'paths-add'), ['int'])),
                                    ('paths_add_errs', (YLeaf(YType.uint32, 'paths-add-errs'), ['int'])),
                                    ('paths_del', (YLeaf(YType.uint32, 'paths-del'), ['int'])),
                                    ('paths_del_errs', (YLeaf(YType.uint32, 'paths-del-errs'), ['int'])),
                                ])
                                self.batches_sent = None
                                self.routes_sent = None
                                self.routes_pending = None
                                self.max_routes = None
                                self.paths_sent = None
                                self.paths_pending = None
                                self.paths_add = None
                                self.paths_add_errs = None
                                self.paths_del = None
                                self.paths_del_errs = None
                                self._segment_path = lambda: "vrf-rib-batch-stats"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.VrfStatistics.VrfRibBatchStats, [u'batches_sent', u'routes_sent', u'routes_pending', u'max_routes', u'paths_sent', u'paths_pending', u'paths_add', u'paths_add_errs', u'paths_del', u'paths_del_errs'], name, value)


                    class Summary(Entity):
                        """
                        OSPFv3 summary
                        
                        .. attribute:: protocol
                        
                        	OSPFv3 protocol summary
                        	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Protocol>`
                        
                        .. attribute:: ospfv3
                        
                        	OSPFv3 summary
                        	**type**\:  :py:class:`Ospfv3_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_>`
                        
                        .. attribute:: route
                        
                        	OSPFv3 route summary
                        	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Route>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary, self).__init__()

                            self.yang_name = "summary"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("protocol", ("protocol", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Protocol)), ("ospfv3", ("ospfv3", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_)), ("route", ("route", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Route))])
                            self._leafs = OrderedDict()

                            self.protocol = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Protocol()
                            self.protocol.parent = self
                            self._children_name_map["protocol"] = "protocol"

                            self.ospfv3 = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_()
                            self.ospfv3.parent = self
                            self._children_name_map["ospfv3"] = "ospfv3"

                            self.route = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Route()
                            self.route.parent = self
                            self._children_name_map["route"] = "route"
                            self._segment_path = lambda: "summary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary, [], name, value)


                        class Protocol(Entity):
                            """
                            OSPFv3 protocol summary
                            
                            .. attribute:: protocol_router_id
                            
                            	Protocol router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: administrative_distance
                            
                            	Administrative distance
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: administrative_distance_inter_area
                            
                            	Administrative Distance for Inter Area routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: administrative_distance_external
                            
                            	Administrative Distance for External routes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_graceful_restart
                            
                            	If true, Graceful restart is enabled 
                            	**type**\: bool
                            
                            .. attribute:: distribute_list_in
                            
                            	Distribute List In
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Protocol, self).__init__()

                                self.yang_name = "protocol"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('protocol_router_id', (YLeaf(YType.str, 'protocol-router-id'), ['str'])),
                                    ('administrative_distance', (YLeaf(YType.uint32, 'administrative-distance'), ['int'])),
                                    ('administrative_distance_inter_area', (YLeaf(YType.uint32, 'administrative-distance-inter-area'), ['int'])),
                                    ('administrative_distance_external', (YLeaf(YType.uint32, 'administrative-distance-external'), ['int'])),
                                    ('is_graceful_restart', (YLeaf(YType.boolean, 'is-graceful-restart'), ['bool'])),
                                    ('distribute_list_in', (YLeaf(YType.str, 'distribute-list-in'), ['str'])),
                                ])
                                self.protocol_router_id = None
                                self.administrative_distance = None
                                self.administrative_distance_inter_area = None
                                self.administrative_distance_external = None
                                self.is_graceful_restart = None
                                self.distribute_list_in = None
                                self._segment_path = lambda: "protocol"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Protocol, [u'protocol_router_id', u'administrative_distance', u'administrative_distance_inter_area', u'administrative_distance_external', u'is_graceful_restart', u'distribute_list_in'], name, value)


                        class Ospfv3_(Entity):
                            """
                            OSPFv3 summary
                            
                            .. attribute:: domain_id
                            
                            	Domain ID information
                            	**type**\:  :py:class:`DomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId>`
                            
                            .. attribute:: router_id
                            
                            	Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_role_standby
                            
                            	If true, the process is running as stanby role
                            	**type**\: bool
                            
                            .. attribute:: role
                            
                            	Role, V1/V2 Active/Standby
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_nsr_enabled
                            
                            	If true, NSR is enabled
                            	**type**\: bool
                            
                            .. attribute:: is_nsr_switchover_on_restart
                            
                            	Trigger RP Switchover on detectable process restart
                            	**type**\: bool
                            
                            .. attribute:: is_router_id_stalled
                            
                            	Stalled Router ID 
                            	**type**\: bool
                            
                            .. attribute:: is_opaque_capable
                            
                            	Opaque LSA capable 
                            	**type**\: bool
                            
                            .. attribute:: is_area_border_router
                            
                            	If true, is an area border router
                            	**type**\: bool
                            
                            .. attribute:: is_as_border_router
                            
                            	If true, is an AS border router
                            	**type**\: bool
                            
                            .. attribute:: capability_prefer_type7
                            
                            	If true, prefer type 7 LSAs over type 5
                            	**type**\: bool
                            
                            .. attribute:: metric
                            
                            	Redistribution metric 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_default_originated
                            
                            	If true, origin is by default 
                            	**type**\: bool
                            
                            .. attribute:: is_default_always
                            
                            	If true, default always 
                            	**type**\: bool
                            
                            .. attribute:: default_metric
                            
                            	Default metric 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: default_metric_type
                            
                            	Default metric type 
                            	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                            
                            .. attribute:: default_tag
                            
                            	Default tag 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_default_policy
                            
                            	If true, is a default policy 
                            	**type**\: bool
                            
                            .. attribute:: default_policy_name
                            
                            	Default policy name 
                            	**type**\: str
                            
                            .. attribute:: spf_start_time
                            
                            	Scheduling delay for SPF (ms)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: spf_hold_time
                            
                            	Minimum delay time between SPF runs (ms)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: spf_maximum_time
                            
                            	Maximum delay time between SPF runs (ms)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_start_time
                            
                            	Initial LSA throttle delay (ms)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_hold_time
                            
                            	Second delay before generating next LSA (ms)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_maximum_time
                            
                            	Maximum delay before generating an LSA (ms)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: minimum_lsa_interval
                            
                            	Minimum time between LSA regeneration (ms)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_group_interval
                            
                            	LSA refresh interval (sec)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_flood_pacing_interval
                            
                            	LSA flood pacing timer (ms)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_retransmission_pacing_interval
                            
                            	LSA retransmission pacing timer (ms)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_ls_as
                            
                            	Number of AS scope LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: opaque_lsas
                            
                            	Number of opaque LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: opaque_lsa_checksum
                            
                            	Sum of opaque LSA checksum
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_dc_bitless_ls_as
                            
                            	Number of external and AS opaque LSAs with demand circut bit not set
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_do_not_age_ls_as
                            
                            	Number of external and AS opaque LSAs with do not age set 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: areas
                            
                            	Number of areas
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: normal_areas
                            
                            	Number of normal areas
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: stub_areas
                            
                            	Number of stub and total stub areas
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nssa_areas
                            
                            	Number of NSSA areas
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: as_lsa_flood_list_length
                            
                            	Length of AS LSAs flood list
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_grace_restart_enabled
                            
                            	If true, grace restart is enabled 
                            	**type**\: bool
                            
                            .. attribute:: last_nsf_time
                            
                            	 Length of time since the last NSF (s)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: grace_resync_time
                            
                            	Grace time to resync 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_interfaces
                            
                            	Maximum number of interfaces
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_paths
                            
                            	Maximum number of paths
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redistribution_limit
                            
                            	The number of redistributed prefixes allowed
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redistribution_threshold
                            
                            	When the number of redistributed prefixes reaches this threshold, a warning message is issued 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_auto_cost
                            
                            	If true, auto cost is enabled
                            	**type**\: bool
                            
                            .. attribute:: reference_bandwidth
                            
                            	Reference Bandwdith
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: context_name
                            
                            	Context name
                            	**type**\: str
                            
                            	**length:** 0..32
                            
                            .. attribute:: snmp_trap_enabled
                            
                            	If true, snmp trap is enabled
                            	**type**\: bool
                            
                            .. attribute:: graceful_shutdown_state
                            
                            	Graceful shutdown state
                            	**type**\:  :py:class:`Ospfv3GracefulShutdownState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulShutdownState>`
                            
                            .. attribute:: stub_router
                            
                            	Stub Router Information
                            	**type**\: list of  		 :py:class:`StubRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter>`
                            
                            .. attribute:: ipfrr_tiebreakers
                            
                            	IPFRR\-Tiebreakers list
                            	**type**\: list of  		 :py:class:`IpfrrTiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.IpfrrTiebreakers>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_, self).__init__()

                                self.yang_name = "ospfv3"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("domain-id", ("domain_id", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId)), ("stub-router", ("stub_router", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter)), ("ipfrr-tiebreakers", ("ipfrr_tiebreakers", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.IpfrrTiebreakers))])
                                self._leafs = OrderedDict([
                                    ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                    ('is_role_standby', (YLeaf(YType.boolean, 'is-role-standby'), ['bool'])),
                                    ('role', (YLeaf(YType.uint32, 'role'), ['int'])),
                                    ('is_nsr_enabled', (YLeaf(YType.boolean, 'is-nsr-enabled'), ['bool'])),
                                    ('is_nsr_switchover_on_restart', (YLeaf(YType.boolean, 'is-nsr-switchover-on-restart'), ['bool'])),
                                    ('is_router_id_stalled', (YLeaf(YType.boolean, 'is-router-id-stalled'), ['bool'])),
                                    ('is_opaque_capable', (YLeaf(YType.boolean, 'is-opaque-capable'), ['bool'])),
                                    ('is_area_border_router', (YLeaf(YType.boolean, 'is-area-border-router'), ['bool'])),
                                    ('is_as_border_router', (YLeaf(YType.boolean, 'is-as-border-router'), ['bool'])),
                                    ('capability_prefer_type7', (YLeaf(YType.boolean, 'capability-prefer-type7'), ['bool'])),
                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                    ('is_default_originated', (YLeaf(YType.boolean, 'is-default-originated'), ['bool'])),
                                    ('is_default_always', (YLeaf(YType.boolean, 'is-default-always'), ['bool'])),
                                    ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                    ('default_metric_type', (YLeaf(YType.enumeration, 'default-metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                    ('default_tag', (YLeaf(YType.uint32, 'default-tag'), ['int'])),
                                    ('is_default_policy', (YLeaf(YType.boolean, 'is-default-policy'), ['bool'])),
                                    ('default_policy_name', (YLeaf(YType.str, 'default-policy-name'), ['str'])),
                                    ('spf_start_time', (YLeaf(YType.uint32, 'spf-start-time'), ['int'])),
                                    ('spf_hold_time', (YLeaf(YType.uint32, 'spf-hold-time'), ['int'])),
                                    ('spf_maximum_time', (YLeaf(YType.uint32, 'spf-maximum-time'), ['int'])),
                                    ('lsa_start_time', (YLeaf(YType.uint32, 'lsa-start-time'), ['int'])),
                                    ('lsa_hold_time', (YLeaf(YType.uint32, 'lsa-hold-time'), ['int'])),
                                    ('lsa_maximum_time', (YLeaf(YType.uint32, 'lsa-maximum-time'), ['int'])),
                                    ('minimum_lsa_interval', (YLeaf(YType.uint32, 'minimum-lsa-interval'), ['int'])),
                                    ('lsa_group_interval', (YLeaf(YType.uint32, 'lsa-group-interval'), ['int'])),
                                    ('lsa_flood_pacing_interval', (YLeaf(YType.uint32, 'lsa-flood-pacing-interval'), ['int'])),
                                    ('lsa_retransmission_pacing_interval', (YLeaf(YType.uint32, 'lsa-retransmission-pacing-interval'), ['int'])),
                                    ('as_ls_as', (YLeaf(YType.uint32, 'as-ls-as'), ['int'])),
                                    ('opaque_lsas', (YLeaf(YType.uint32, 'opaque-lsas'), ['int'])),
                                    ('opaque_lsa_checksum', (YLeaf(YType.uint32, 'opaque-lsa-checksum'), ['int'])),
                                    ('as_dc_bitless_ls_as', (YLeaf(YType.uint32, 'as-dc-bitless-ls-as'), ['int'])),
                                    ('as_do_not_age_ls_as', (YLeaf(YType.uint32, 'as-do-not-age-ls-as'), ['int'])),
                                    ('areas', (YLeaf(YType.uint16, 'areas'), ['int'])),
                                    ('normal_areas', (YLeaf(YType.uint16, 'normal-areas'), ['int'])),
                                    ('stub_areas', (YLeaf(YType.uint16, 'stub-areas'), ['int'])),
                                    ('nssa_areas', (YLeaf(YType.uint16, 'nssa-areas'), ['int'])),
                                    ('as_lsa_flood_list_length', (YLeaf(YType.uint32, 'as-lsa-flood-list-length'), ['int'])),
                                    ('is_grace_restart_enabled', (YLeaf(YType.boolean, 'is-grace-restart-enabled'), ['bool'])),
                                    ('last_nsf_time', (YLeaf(YType.uint32, 'last-nsf-time'), ['int'])),
                                    ('grace_resync_time', (YLeaf(YType.uint32, 'grace-resync-time'), ['int'])),
                                    ('maximum_interfaces', (YLeaf(YType.uint32, 'maximum-interfaces'), ['int'])),
                                    ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                    ('redistribution_limit', (YLeaf(YType.uint32, 'redistribution-limit'), ['int'])),
                                    ('redistribution_threshold', (YLeaf(YType.uint32, 'redistribution-threshold'), ['int'])),
                                    ('is_auto_cost', (YLeaf(YType.boolean, 'is-auto-cost'), ['bool'])),
                                    ('reference_bandwidth', (YLeaf(YType.uint32, 'reference-bandwidth'), ['int'])),
                                    ('context_name', (YLeaf(YType.str, 'context-name'), ['str'])),
                                    ('snmp_trap_enabled', (YLeaf(YType.boolean, 'snmp-trap-enabled'), ['bool'])),
                                    ('graceful_shutdown_state', (YLeaf(YType.enumeration, 'graceful-shutdown-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3GracefulShutdownState', '')])),
                                ])
                                self.router_id = None
                                self.is_role_standby = None
                                self.role = None
                                self.is_nsr_enabled = None
                                self.is_nsr_switchover_on_restart = None
                                self.is_router_id_stalled = None
                                self.is_opaque_capable = None
                                self.is_area_border_router = None
                                self.is_as_border_router = None
                                self.capability_prefer_type7 = None
                                self.metric = None
                                self.is_default_originated = None
                                self.is_default_always = None
                                self.default_metric = None
                                self.default_metric_type = None
                                self.default_tag = None
                                self.is_default_policy = None
                                self.default_policy_name = None
                                self.spf_start_time = None
                                self.spf_hold_time = None
                                self.spf_maximum_time = None
                                self.lsa_start_time = None
                                self.lsa_hold_time = None
                                self.lsa_maximum_time = None
                                self.minimum_lsa_interval = None
                                self.lsa_group_interval = None
                                self.lsa_flood_pacing_interval = None
                                self.lsa_retransmission_pacing_interval = None
                                self.as_ls_as = None
                                self.opaque_lsas = None
                                self.opaque_lsa_checksum = None
                                self.as_dc_bitless_ls_as = None
                                self.as_do_not_age_ls_as = None
                                self.areas = None
                                self.normal_areas = None
                                self.stub_areas = None
                                self.nssa_areas = None
                                self.as_lsa_flood_list_length = None
                                self.is_grace_restart_enabled = None
                                self.last_nsf_time = None
                                self.grace_resync_time = None
                                self.maximum_interfaces = None
                                self.maximum_paths = None
                                self.redistribution_limit = None
                                self.redistribution_threshold = None
                                self.is_auto_cost = None
                                self.reference_bandwidth = None
                                self.context_name = None
                                self.snmp_trap_enabled = None
                                self.graceful_shutdown_state = None

                                self.domain_id = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId()
                                self.domain_id.parent = self
                                self._children_name_map["domain_id"] = "domain-id"

                                self.stub_router = YList(self)
                                self.ipfrr_tiebreakers = YList(self)
                                self._segment_path = lambda: "ospfv3"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_, [u'router_id', u'is_role_standby', u'role', u'is_nsr_enabled', u'is_nsr_switchover_on_restart', u'is_router_id_stalled', u'is_opaque_capable', u'is_area_border_router', u'is_as_border_router', u'capability_prefer_type7', u'metric', u'is_default_originated', u'is_default_always', u'default_metric', u'default_metric_type', u'default_tag', u'is_default_policy', u'default_policy_name', u'spf_start_time', u'spf_hold_time', u'spf_maximum_time', u'lsa_start_time', u'lsa_hold_time', u'lsa_maximum_time', u'minimum_lsa_interval', u'lsa_group_interval', u'lsa_flood_pacing_interval', u'lsa_retransmission_pacing_interval', u'as_ls_as', u'opaque_lsas', u'opaque_lsa_checksum', u'as_dc_bitless_ls_as', u'as_do_not_age_ls_as', u'areas', u'normal_areas', u'stub_areas', u'nssa_areas', u'as_lsa_flood_list_length', u'is_grace_restart_enabled', u'last_nsf_time', u'grace_resync_time', u'maximum_interfaces', u'maximum_paths', u'redistribution_limit', u'redistribution_threshold', u'is_auto_cost', u'reference_bandwidth', u'context_name', u'snmp_trap_enabled', u'graceful_shutdown_state'], name, value)


                            class DomainId(Entity):
                                """
                                Domain ID information
                                
                                .. attribute:: primary_domain_id
                                
                                	Primary Domain ID
                                	**type**\:  :py:class:`PrimaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId.PrimaryDomainId>`
                                
                                .. attribute:: secondary_domain_id
                                
                                	List of secondary domain IDs
                                	**type**\: list of  		 :py:class:`SecondaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId.SecondaryDomainId>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId, self).__init__()

                                    self.yang_name = "domain-id"
                                    self.yang_parent_name = "ospfv3"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("primary-domain-id", ("primary_domain_id", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId.PrimaryDomainId)), ("secondary-domain-id", ("secondary_domain_id", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId.SecondaryDomainId))])
                                    self._leafs = OrderedDict()

                                    self.primary_domain_id = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId.PrimaryDomainId()
                                    self.primary_domain_id.parent = self
                                    self._children_name_map["primary_domain_id"] = "primary-domain-id"

                                    self.secondary_domain_id = YList(self)
                                    self._segment_path = lambda: "domain-id"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId, [], name, value)


                                class PrimaryDomainId(Entity):
                                    """
                                    Primary Domain ID
                                    
                                    .. attribute:: domain_id_type
                                    
                                    	Domain ID Type
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: domain_id_value
                                    
                                    	Domain ID value
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId.PrimaryDomainId, self).__init__()

                                        self.yang_name = "primary-domain-id"
                                        self.yang_parent_name = "domain-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('domain_id_type', (YLeaf(YType.uint16, 'domain-id-type'), ['int'])),
                                            ('domain_id_value', (YLeaf(YType.str, 'domain-id-value'), ['str'])),
                                        ])
                                        self.domain_id_type = None
                                        self.domain_id_value = None
                                        self._segment_path = lambda: "primary-domain-id"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId.PrimaryDomainId, [u'domain_id_type', u'domain_id_value'], name, value)


                                class SecondaryDomainId(Entity):
                                    """
                                    List of secondary domain IDs
                                    
                                    .. attribute:: domain_id_type
                                    
                                    	Domain ID Type
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: domain_id_value
                                    
                                    	Domain ID value
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId.SecondaryDomainId, self).__init__()

                                        self.yang_name = "secondary-domain-id"
                                        self.yang_parent_name = "domain-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('domain_id_type', (YLeaf(YType.uint16, 'domain-id-type'), ['int'])),
                                            ('domain_id_value', (YLeaf(YType.str, 'domain-id-value'), ['str'])),
                                        ])
                                        self.domain_id_type = None
                                        self.domain_id_value = None
                                        self._segment_path = lambda: "secondary-domain-id"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.DomainId.SecondaryDomainId, [u'domain_id_type', u'domain_id_value'], name, value)


                            class StubRouter(Entity):
                                """
                                Stub Router Information
                                
                                .. attribute:: unset_time
                                
                                	Timestamp (relative to 1970/1/1 00\:00) when stub router condition was cleared
                                	**type**\:  :py:class:`UnsetTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.UnsetTime>`
                                
                                .. attribute:: start_time
                                
                                	Timestamp (relative to 1970/1/1 00\:00) when stub router mode was activated
                                	**type**\:  :py:class:`StartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.StartTime>`
                                
                                .. attribute:: abr_resume_time
                                
                                	Timestamp (relative to 1970/1/1 00\:00) when ABR duties were resumed
                                	**type**\:  :py:class:`AbrResumeTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.AbrResumeTime>`
                                
                                .. attribute:: mode
                                
                                	Stub router mode
                                	**type**\:  :py:class:`StubRouterMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterMode>`
                                
                                .. attribute:: active
                                
                                	If true, stub router mode is active
                                	**type**\: bool
                                
                                .. attribute:: remaining_time
                                
                                	Remaining time (in seconds) in stub router mode
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: set_reason
                                
                                	Reason for entering stub router mode
                                	**type**\:  :py:class:`StubRouterTrigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterTrigger>`
                                
                                .. attribute:: unset_reason
                                
                                	Reason for clearing stub router condition
                                	**type**\:  :py:class:`StubRouterExitReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterExitReason>`
                                
                                .. attribute:: include_stub_links
                                
                                	If true, advertise maximum metric for stub links
                                	**type**\: bool
                                
                                .. attribute:: summary_lsa_metric
                                
                                	Metric for summary LSAs in max\-metric mode
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_lsa_metric
                                
                                	Metric for external LSAs in max\-metric mode
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: abr_off_reason
                                
                                	Reason for being in ABR off mode
                                	**type**\:  :py:class:`StubRouterAbrOffReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterAbrOffReason>`
                                
                                .. attribute:: trigger
                                
                                	Triggers for entering stub router mode
                                	**type**\: list of  		 :py:class:`Trigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter, self).__init__()

                                    self.yang_name = "stub-router"
                                    self.yang_parent_name = "ospfv3"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("unset-time", ("unset_time", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.UnsetTime)), ("start-time", ("start_time", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.StartTime)), ("abr-resume-time", ("abr_resume_time", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.AbrResumeTime)), ("trigger", ("trigger", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger))])
                                    self._leafs = OrderedDict([
                                        ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'StubRouterMode', '')])),
                                        ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                        ('remaining_time', (YLeaf(YType.uint32, 'remaining-time'), ['int'])),
                                        ('set_reason', (YLeaf(YType.enumeration, 'set-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'StubRouterTrigger', '')])),
                                        ('unset_reason', (YLeaf(YType.enumeration, 'unset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'StubRouterExitReason', '')])),
                                        ('include_stub_links', (YLeaf(YType.boolean, 'include-stub-links'), ['bool'])),
                                        ('summary_lsa_metric', (YLeaf(YType.uint32, 'summary-lsa-metric'), ['int'])),
                                        ('external_lsa_metric', (YLeaf(YType.uint32, 'external-lsa-metric'), ['int'])),
                                        ('abr_off_reason', (YLeaf(YType.enumeration, 'abr-off-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'StubRouterAbrOffReason', '')])),
                                    ])
                                    self.mode = None
                                    self.active = None
                                    self.remaining_time = None
                                    self.set_reason = None
                                    self.unset_reason = None
                                    self.include_stub_links = None
                                    self.summary_lsa_metric = None
                                    self.external_lsa_metric = None
                                    self.abr_off_reason = None

                                    self.unset_time = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.UnsetTime()
                                    self.unset_time.parent = self
                                    self._children_name_map["unset_time"] = "unset-time"

                                    self.start_time = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.StartTime()
                                    self.start_time.parent = self
                                    self._children_name_map["start_time"] = "start-time"

                                    self.abr_resume_time = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.AbrResumeTime()
                                    self.abr_resume_time.parent = self
                                    self._children_name_map["abr_resume_time"] = "abr-resume-time"

                                    self.trigger = YList(self)
                                    self._segment_path = lambda: "stub-router"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter, [u'mode', u'active', u'remaining_time', u'set_reason', u'unset_reason', u'include_stub_links', u'summary_lsa_metric', u'external_lsa_metric', u'abr_off_reason'], name, value)


                                class UnsetTime(Entity):
                                    """
                                    Timestamp (relative to 1970/1/1 00\:00) when stub
                                    router condition was cleared
                                    
                                    .. attribute:: second
                                    
                                    	Seconds 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nano seconds 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.UnsetTime, self).__init__()

                                        self.yang_name = "unset-time"
                                        self.yang_parent_name = "stub-router"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('second', (YLeaf(YType.uint32, 'second'), ['int'])),
                                            ('nanosecond', (YLeaf(YType.uint32, 'nanosecond'), ['int'])),
                                        ])
                                        self.second = None
                                        self.nanosecond = None
                                        self._segment_path = lambda: "unset-time"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.UnsetTime, [u'second', u'nanosecond'], name, value)


                                class StartTime(Entity):
                                    """
                                    Timestamp (relative to 1970/1/1 00\:00) when stub
                                    router mode was activated
                                    
                                    .. attribute:: second
                                    
                                    	Seconds 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nano seconds 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.StartTime, self).__init__()

                                        self.yang_name = "start-time"
                                        self.yang_parent_name = "stub-router"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('second', (YLeaf(YType.uint32, 'second'), ['int'])),
                                            ('nanosecond', (YLeaf(YType.uint32, 'nanosecond'), ['int'])),
                                        ])
                                        self.second = None
                                        self.nanosecond = None
                                        self._segment_path = lambda: "start-time"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.StartTime, [u'second', u'nanosecond'], name, value)


                                class AbrResumeTime(Entity):
                                    """
                                    Timestamp (relative to 1970/1/1 00\:00) when ABR
                                    duties were resumed
                                    
                                    .. attribute:: second
                                    
                                    	Seconds 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nano seconds 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.AbrResumeTime, self).__init__()

                                        self.yang_name = "abr-resume-time"
                                        self.yang_parent_name = "stub-router"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('second', (YLeaf(YType.uint32, 'second'), ['int'])),
                                            ('nanosecond', (YLeaf(YType.uint32, 'nanosecond'), ['int'])),
                                        ])
                                        self.second = None
                                        self.nanosecond = None
                                        self._segment_path = lambda: "abr-resume-time"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.AbrResumeTime, [u'second', u'nanosecond'], name, value)


                                class Trigger(Entity):
                                    """
                                    Triggers for entering stub router mode
                                    
                                    .. attribute:: unset_time
                                    
                                    	Timestamp (relative to 1970/1/1 00\:00) when stub router condition was cleared
                                    	**type**\:  :py:class:`UnsetTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger.UnsetTime>`
                                    
                                    .. attribute:: start_time
                                    
                                    	Timestamp (relative to 1970/1/1 00\:00) when stub router mode was activated
                                    	**type**\:  :py:class:`StartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger.StartTime>`
                                    
                                    .. attribute:: trigger
                                    
                                    	Stub Router Trigger type
                                    	**type**\:  :py:class:`StubRouterTrigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterTrigger>`
                                    
                                    .. attribute:: wait_for_bgp
                                    
                                    	If true, stub router is terminated when BGP converges
                                    	**type**\: bool
                                    
                                    .. attribute:: unset_reason
                                    
                                    	Reason for clearing stub router condition
                                    	**type**\:  :py:class:`StubRouterExitReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterExitReason>`
                                    
                                    .. attribute:: time
                                    
                                    	Time (in seconds) to stay in stub router mode
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger, self).__init__()

                                        self.yang_name = "trigger"
                                        self.yang_parent_name = "stub-router"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("unset-time", ("unset_time", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger.UnsetTime)), ("start-time", ("start_time", Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger.StartTime))])
                                        self._leafs = OrderedDict([
                                            ('trigger', (YLeaf(YType.enumeration, 'trigger'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'StubRouterTrigger', '')])),
                                            ('wait_for_bgp', (YLeaf(YType.boolean, 'wait-for-bgp'), ['bool'])),
                                            ('unset_reason', (YLeaf(YType.enumeration, 'unset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'StubRouterExitReason', '')])),
                                            ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                        ])
                                        self.trigger = None
                                        self.wait_for_bgp = None
                                        self.unset_reason = None
                                        self.time = None

                                        self.unset_time = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger.UnsetTime()
                                        self.unset_time.parent = self
                                        self._children_name_map["unset_time"] = "unset-time"

                                        self.start_time = Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger.StartTime()
                                        self.start_time.parent = self
                                        self._children_name_map["start_time"] = "start-time"
                                        self._segment_path = lambda: "trigger"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger, [u'trigger', u'wait_for_bgp', u'unset_reason', u'time'], name, value)


                                    class UnsetTime(Entity):
                                        """
                                        Timestamp (relative to 1970/1/1 00\:00) when stub
                                        router condition was cleared
                                        
                                        .. attribute:: second
                                        
                                        	Seconds 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nano seconds 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger.UnsetTime, self).__init__()

                                            self.yang_name = "unset-time"
                                            self.yang_parent_name = "trigger"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second', (YLeaf(YType.uint32, 'second'), ['int'])),
                                                ('nanosecond', (YLeaf(YType.uint32, 'nanosecond'), ['int'])),
                                            ])
                                            self.second = None
                                            self.nanosecond = None
                                            self._segment_path = lambda: "unset-time"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger.UnsetTime, [u'second', u'nanosecond'], name, value)


                                    class StartTime(Entity):
                                        """
                                        Timestamp (relative to 1970/1/1 00\:00) when stub
                                        router mode was activated
                                        
                                        .. attribute:: second
                                        
                                        	Seconds 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: nanosecond
                                        
                                        	Nano seconds 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: nanosecond
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger.StartTime, self).__init__()

                                            self.yang_name = "start-time"
                                            self.yang_parent_name = "trigger"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second', (YLeaf(YType.uint32, 'second'), ['int'])),
                                                ('nanosecond', (YLeaf(YType.uint32, 'nanosecond'), ['int'])),
                                            ])
                                            self.second = None
                                            self.nanosecond = None
                                            self._segment_path = lambda: "start-time"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.StubRouter.Trigger.StartTime, [u'second', u'nanosecond'], name, value)


                            class IpfrrTiebreakers(Entity):
                                """
                                IPFRR\-Tiebreakers list
                                
                                .. attribute:: tiebreaker_type
                                
                                	Tiebreaker Type
                                	**type**\:  :py:class:`IpfrrTbrkr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.IpfrrTbrkr>`
                                
                                .. attribute:: tiebreaker_index
                                
                                	Tiebreaker Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.IpfrrTiebreakers, self).__init__()

                                    self.yang_name = "ipfrr-tiebreakers"
                                    self.yang_parent_name = "ospfv3"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('tiebreaker_type', (YLeaf(YType.enumeration, 'tiebreaker-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'IpfrrTbrkr', '')])),
                                        ('tiebreaker_index', (YLeaf(YType.uint32, 'tiebreaker-index'), ['int'])),
                                    ])
                                    self.tiebreaker_type = None
                                    self.tiebreaker_index = None
                                    self._segment_path = lambda: "ipfrr-tiebreakers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Ospfv3_.IpfrrTiebreakers, [u'tiebreaker_type', u'tiebreaker_index'], name, value)


                        class Route(Entity):
                            """
                            OSPFv3 route summary
                            
                            .. attribute:: route_id
                            
                            	Route summary of a route ID 
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: intra_area_route
                            
                            	Intra route summary 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inter_area_route
                            
                            	Inter route summary 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: extern_one_route
                            
                            	Extern 1 route summary 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: extern_two_route
                            
                            	Extern 2 route summary 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nssa_one_route
                            
                            	NSSA 1 route summary 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nssa_two_route
                            
                            	NSSA 2 route summary 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_sent_route
                            
                            	Total route summary 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_connected
                            
                            	Route connected 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redistribution_route
                            
                            	Redistribution route summary 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_received_route
                            
                            	Total route received summary
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Route, self).__init__()

                                self.yang_name = "route"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('route_id', (YLeaf(YType.str, 'route-id'), ['str'])),
                                    ('intra_area_route', (YLeaf(YType.uint32, 'intra-area-route'), ['int'])),
                                    ('inter_area_route', (YLeaf(YType.uint32, 'inter-area-route'), ['int'])),
                                    ('extern_one_route', (YLeaf(YType.uint32, 'extern-one-route'), ['int'])),
                                    ('extern_two_route', (YLeaf(YType.uint32, 'extern-two-route'), ['int'])),
                                    ('nssa_one_route', (YLeaf(YType.uint32, 'nssa-one-route'), ['int'])),
                                    ('nssa_two_route', (YLeaf(YType.uint32, 'nssa-two-route'), ['int'])),
                                    ('total_sent_route', (YLeaf(YType.uint32, 'total-sent-route'), ['int'])),
                                    ('route_connected', (YLeaf(YType.uint32, 'route-connected'), ['int'])),
                                    ('redistribution_route', (YLeaf(YType.uint32, 'redistribution-route'), ['int'])),
                                    ('total_received_route', (YLeaf(YType.uint32, 'total-received-route'), ['int'])),
                                ])
                                self.route_id = None
                                self.intra_area_route = None
                                self.inter_area_route = None
                                self.extern_one_route = None
                                self.extern_two_route = None
                                self.nssa_one_route = None
                                self.nssa_two_route = None
                                self.total_sent_route = None
                                self.route_connected = None
                                self.redistribution_route = None
                                self.total_received_route = None
                                self._segment_path = lambda: "route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.Summary.Route, [u'route_id', u'intra_area_route', u'inter_area_route', u'extern_one_route', u'extern_two_route', u'nssa_one_route', u'nssa_two_route', u'total_sent_route', u'route_connected', u'redistribution_route', u'total_received_route'], name, value)


                    class RetransmissionListProcessTable(Entity):
                        """
                        OSPFv3 retransmission list information table for
                        all areas
                        
                        .. attribute:: retransmission
                        
                        	OSPFv3 retransmission list information
                        	**type**\: list of  		 :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable, self).__init__()

                            self.yang_name = "retransmission-list-process-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("retransmission", ("retransmission", Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission))])
                            self._leafs = OrderedDict()

                            self.retransmission = YList(self)
                            self._segment_path = lambda: "retransmission-list-process-table"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable, [], name, value)


                        class Retransmission(Entity):
                            """
                            OSPFv3 retransmission list information
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: retransmission_neighbor_address
                            
                            	Neighbor IP address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_retransmissionvirtual_link
                            
                            	If true, virtual link is retransmitted 
                            	**type**\: bool
                            
                            .. attribute:: retransmissionvirtual_link_id
                            
                            	Retransmission virtual link ID 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_retransmission_sham_link
                            
                            	If true, sham link is retransmitted 
                            	**type**\: bool
                            
                            .. attribute:: retransmission_sham_link_id
                            
                            	Retransmission sham link ID 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: retransmission_timer
                            
                            	Amount of time remaining on retransmission timer (ms)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: retransmission_length
                            
                            	Retransmission queue length
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: retransmissionvirtual_link_db
                            
                            	List of virtual link scope entries 
                            	**type**\: list of  		 :py:class:`RetransmissionvirtualLinkDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb>`
                            
                            .. attribute:: retransmission_area_db
                            
                            	List of area scope entries
                            	**type**\: list of  		 :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb>`
                            
                            .. attribute:: retransmission_asdb
                            
                            	List of AS scope entries
                            	**type**\: list of  		 :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission, self).__init__()

                                self.yang_name = "retransmission"
                                self.yang_parent_name = "retransmission-list-process-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("retransmissionvirtual-link-db", ("retransmissionvirtual_link_db", Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb)), ("retransmission-area-db", ("retransmission_area_db", Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb)), ("retransmission-asdb", ("retransmission_asdb", Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb))])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                    ('retransmission_neighbor_address', (YLeaf(YType.str, 'retransmission-neighbor-address'), ['str'])),
                                    ('is_retransmissionvirtual_link', (YLeaf(YType.boolean, 'is-retransmissionvirtual-link'), ['bool'])),
                                    ('retransmissionvirtual_link_id', (YLeaf(YType.uint32, 'retransmissionvirtual-link-id'), ['int'])),
                                    ('is_retransmission_sham_link', (YLeaf(YType.boolean, 'is-retransmission-sham-link'), ['bool'])),
                                    ('retransmission_sham_link_id', (YLeaf(YType.uint32, 'retransmission-sham-link-id'), ['int'])),
                                    ('retransmission_timer', (YLeaf(YType.uint32, 'retransmission-timer'), ['int'])),
                                    ('retransmission_length', (YLeaf(YType.uint32, 'retransmission-length'), ['int'])),
                                ])
                                self.interface_name = None
                                self.neighbor_address = None
                                self.retransmission_neighbor_address = None
                                self.is_retransmissionvirtual_link = None
                                self.retransmissionvirtual_link_id = None
                                self.is_retransmission_sham_link = None
                                self.retransmission_sham_link_id = None
                                self.retransmission_timer = None
                                self.retransmission_length = None

                                self.retransmissionvirtual_link_db = YList(self)
                                self.retransmission_area_db = YList(self)
                                self.retransmission_asdb = YList(self)
                                self._segment_path = lambda: "retransmission"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission, ['interface_name', 'neighbor_address', u'retransmission_neighbor_address', u'is_retransmissionvirtual_link', u'retransmissionvirtual_link_id', u'is_retransmission_sham_link', u'retransmission_sham_link_id', u'retransmission_timer', u'retransmission_length'], name, value)


                            class RetransmissionvirtualLinkDb(Entity):
                                """
                                List of virtual link scope entries 
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb, self).__init__()

                                    self.yang_name = "retransmissionvirtual-link-db"
                                    self.yang_parent_name = "retransmission"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                        ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                        ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                        ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                        ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                    ])
                                    self.header_lsa_type = None
                                    self.header_lsa_age = None
                                    self.header_lsa_id = None
                                    self.header_advertising_router = None
                                    self.header_sequence_number = None
                                    self._segment_path = lambda: "retransmissionvirtual-link-db"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                            class RetransmissionAreaDb(Entity):
                                """
                                List of area scope entries
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb, self).__init__()

                                    self.yang_name = "retransmission-area-db"
                                    self.yang_parent_name = "retransmission"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                        ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                        ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                        ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                        ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                    ])
                                    self.header_lsa_type = None
                                    self.header_lsa_age = None
                                    self.header_lsa_id = None
                                    self.header_advertising_router = None
                                    self.header_sequence_number = None
                                    self._segment_path = lambda: "retransmission-area-db"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                            class RetransmissionAsdb(Entity):
                                """
                                List of AS scope entries
                                
                                .. attribute:: header_lsa_type
                                
                                	LSA type
                                	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                
                                .. attribute:: header_lsa_age
                                
                                	Age of the LSA (seconds)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: header_lsa_id
                                
                                	LSA ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_advertising_router
                                
                                	Router ID of the advertising router
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: header_sequence_number
                                
                                	Current LSA sequence number
                                	**type**\: int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb, self).__init__()

                                    self.yang_name = "retransmission-asdb"
                                    self.yang_parent_name = "retransmission"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                        ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                        ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                        ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                        ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                    ])
                                    self.header_lsa_type = None
                                    self.header_lsa_age = None
                                    self.header_lsa_id = None
                                    self.header_advertising_router = None
                                    self.header_sequence_number = None
                                    self._segment_path = lambda: "retransmission-asdb"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                    class BadChecksums(Entity):
                        """
                        Bad Checksum Packets information table
                        
                        .. attribute:: bad_checksum
                        
                        	Bad Checksum Packet information
                        	**type**\: list of  		 :py:class:`BadChecksum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums, self).__init__()

                            self.yang_name = "bad-checksums"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bad-checksum", ("bad_checksum", Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum))])
                            self._leafs = OrderedDict()

                            self.bad_checksum = YList(self)
                            self._segment_path = lambda: "bad-checksums"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums, [], name, value)


                        class BadChecksum(Entity):
                            """
                            Bad Checksum Packet information
                            
                            .. attribute:: packet_number  (key)
                            
                            	Bad Checksum Packets number
                            	**type**\: int
                            
                            	**range:** 0..9
                            
                            .. attribute:: timestamp
                            
                            	Packet Timestamp (relative to 1970/1/1 00\:00)
                            	**type**\:  :py:class:`Timestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum.Timestamp>`
                            
                            .. attribute:: received_checksum
                            
                            	Received Checksum
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: computed_checksum
                            
                            	Computed Checksum
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: received_data
                            
                            	Received Hexadecimal Data
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum, self).__init__()

                                self.yang_name = "bad-checksum"
                                self.yang_parent_name = "bad-checksums"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['packet_number']
                                self._child_classes = OrderedDict([("timestamp", ("timestamp", Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum.Timestamp))])
                                self._leafs = OrderedDict([
                                    ('packet_number', (YLeaf(YType.uint32, 'packet-number'), ['int'])),
                                    ('received_checksum', (YLeaf(YType.uint16, 'received-checksum'), ['int'])),
                                    ('computed_checksum', (YLeaf(YType.uint16, 'computed-checksum'), ['int'])),
                                    ('received_data', (YLeaf(YType.str, 'received-data'), ['str'])),
                                ])
                                self.packet_number = None
                                self.received_checksum = None
                                self.computed_checksum = None
                                self.received_data = None

                                self.timestamp = Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum.Timestamp()
                                self.timestamp.parent = self
                                self._children_name_map["timestamp"] = "timestamp"
                                self._segment_path = lambda: "bad-checksum" + "[packet-number='" + str(self.packet_number) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum, ['packet_number', u'received_checksum', u'computed_checksum', u'received_data'], name, value)


                            class Timestamp(Entity):
                                """
                                Packet Timestamp (relative to 1970/1/1 00\:00)
                                
                                .. attribute:: second
                                
                                	Seconds 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanosecond
                                
                                	Nano seconds 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum.Timestamp, self).__init__()

                                    self.yang_name = "timestamp"
                                    self.yang_parent_name = "bad-checksum"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('second', (YLeaf(YType.uint32, 'second'), ['int'])),
                                        ('nanosecond', (YLeaf(YType.uint32, 'nanosecond'), ['int'])),
                                    ])
                                    self.second = None
                                    self.nanosecond = None
                                    self._segment_path = lambda: "timestamp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.BadChecksums.BadChecksum.Timestamp, [u'second', u'nanosecond'], name, value)


                    class DatabaseSummaryTable(Entity):
                        """
                        Database summary table
                        
                        .. attribute:: database_summary
                        
                        	Database Summary information
                        	**type**\:  :py:class:`DatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable, self).__init__()

                            self.yang_name = "database-summary-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("database-summary", ("database_summary", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary))])
                            self._leafs = OrderedDict()

                            self.database_summary = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary()
                            self.database_summary.parent = self
                            self._children_name_map["database_summary"] = "database-summary"
                            self._segment_path = lambda: "database-summary-table"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable, [], name, value)


                        class DatabaseSummary(Entity):
                            """
                            Database Summary information
                            
                            .. attribute:: database_counters
                            
                            	OSPFv3 database counters 
                            	**type**\:  :py:class:`DatabaseCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters>`
                            
                            .. attribute:: database_router_id
                            
                            	Database router ID 
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_opaque_database_capable
                            
                            	If true, opaque database is capable 
                            	**type**\: bool
                            
                            .. attribute:: area_database
                            
                            	OSPFv3 Area Database list 
                            	**type**\: list of  		 :py:class:`AreaDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary, self).__init__()

                                self.yang_name = "database-summary"
                                self.yang_parent_name = "database-summary-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database-counters", ("database_counters", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters)), ("area-database", ("area_database", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase))])
                                self._leafs = OrderedDict([
                                    ('database_router_id', (YLeaf(YType.str, 'database-router-id'), ['str'])),
                                    ('is_opaque_database_capable', (YLeaf(YType.boolean, 'is-opaque-database-capable'), ['bool'])),
                                ])
                                self.database_router_id = None
                                self.is_opaque_database_capable = None

                                self.database_counters = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters()
                                self.database_counters.parent = self
                                self._children_name_map["database_counters"] = "database-counters"

                                self.area_database = YList(self)
                                self._segment_path = lambda: "database-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary, [u'database_router_id', u'is_opaque_database_capable'], name, value)


                            class DatabaseCounters(Entity):
                                """
                                OSPFv3 database counters 
                                
                                .. attribute:: lsa
                                
                                	lsa
                                	**type**\: list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: deleted_lsa
                                
                                	deleted lsa
                                	**type**\: list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_age_lsa
                                
                                	max age lsa
                                	**type**\: list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_checksum
                                
                                	lsa checksum
                                	**type**\: list of int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters, self).__init__()

                                    self.yang_name = "database-counters"
                                    self.yang_parent_name = "database-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lsa', (YLeafList(YType.uint32, 'lsa'), ['int'])),
                                        ('deleted_lsa', (YLeafList(YType.uint32, 'deleted-lsa'), ['int'])),
                                        ('max_age_lsa', (YLeafList(YType.uint32, 'max-age-lsa'), ['int'])),
                                        ('lsa_checksum', (YLeafList(YType.uint32, 'lsa-checksum'), ['int'])),
                                    ])
                                    self.lsa = []
                                    self.deleted_lsa = []
                                    self.max_age_lsa = []
                                    self.lsa_checksum = []
                                    self._segment_path = lambda: "database-counters"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters, [u'lsa', u'deleted_lsa', u'max_age_lsa', u'lsa_checksum'], name, value)


                            class AreaDatabase(Entity):
                                """
                                OSPFv3 Area Database list 
                                
                                .. attribute:: area_database_summary
                                
                                	Area database summary 
                                	**type**\:  :py:class:`AreaDatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary>`
                                
                                .. attribute:: lsa_area_id
                                
                                	Area ID in decimal or dotted\-decimal format
                                	**type**\: str
                                
                                	**length:** 0..16
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase, self).__init__()

                                    self.yang_name = "area-database"
                                    self.yang_parent_name = "database-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("area-database-summary", ("area_database_summary", Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary))])
                                    self._leafs = OrderedDict([
                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                    ])
                                    self.lsa_area_id = None

                                    self.area_database_summary = Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary()
                                    self.area_database_summary.parent = self
                                    self._children_name_map["area_database_summary"] = "area-database-summary"
                                    self._segment_path = lambda: "area-database"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase, [u'lsa_area_id'], name, value)


                                class AreaDatabaseSummary(Entity):
                                    """
                                    Area database summary 
                                    
                                    .. attribute:: lsa
                                    
                                    	lsa
                                    	**type**\: list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: deleted_lsa
                                    
                                    	deleted lsa
                                    	**type**\: list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_age_lsa
                                    
                                    	max age lsa
                                    	**type**\: list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_checksum
                                    
                                    	lsa checksum
                                    	**type**\: list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary, self).__init__()

                                        self.yang_name = "area-database-summary"
                                        self.yang_parent_name = "area-database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsa', (YLeafList(YType.uint32, 'lsa'), ['int'])),
                                            ('deleted_lsa', (YLeafList(YType.uint32, 'deleted-lsa'), ['int'])),
                                            ('max_age_lsa', (YLeafList(YType.uint32, 'max-age-lsa'), ['int'])),
                                            ('lsa_checksum', (YLeafList(YType.uint32, 'lsa-checksum'), ['int'])),
                                        ])
                                        self.lsa = []
                                        self.deleted_lsa = []
                                        self.max_age_lsa = []
                                        self.lsa_checksum = []
                                        self._segment_path = lambda: "area-database-summary"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary, [u'lsa', u'deleted_lsa', u'max_age_lsa', u'lsa_checksum'], name, value)


                    class NeighborProcessTable(Entity):
                        """
                        OSPFv3 neighbor information table for all areas
                        
                        .. attribute:: neighbor
                        
                        	OSPFv3 neighbor detail information
                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable, self).__init__()

                            self.yang_name = "neighbor-process-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor", ("neighbor", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor))])
                            self._leafs = OrderedDict()

                            self.neighbor = YList(self)
                            self._segment_path = lambda: "neighbor-process-table"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable, [], name, value)


                        class Neighbor(Entity):
                            """
                            OSPFv3 neighbor detail information
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_detail
                            
                            	Detailed OSPFv3 neighbor information 
                            	**type**\:  :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail>`
                            
                            .. attribute:: neighbor_bfd_info
                            
                            	Neighbor BFD information
                            	**type**\:  :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborBfdInfo>`
                            
                            .. attribute:: neighbor_address_xr
                            
                            	Neighbor IP Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_interface_id
                            
                            	Neighbor interface ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_dr_priority
                            
                            	Neighbor's DR priority
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: neighbor_state
                            
                            	Neighbor's state
                            	**type**\:  :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                            
                            .. attribute:: neighbor_designated_router
                            
                            	Designated router 
                            	**type**\: str
                            
                            	**length:** 0..9
                            
                            .. attribute:: neighbor_dead_timer
                            
                            	Time until neighbor's dead timer expires (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: neighbor_up_time
                            
                            	Amount of time since the adjacency is up (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: neighbor_virtual_link_id
                            
                            	Neighbor virtual link id 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_neighbor_virtual_link
                            
                            	If true, neighbor is on a virtual link 
                            	**type**\: bool
                            
                            .. attribute:: neighbor_sham_link_id
                            
                            	Neighbor sham link id 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_neighbor_sham_link
                            
                            	If true, neighbor is on a sham link 
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor, self).__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "neighbor-process-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("neighbor-detail", ("neighbor_detail", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail)), ("neighbor-bfd-info", ("neighbor_bfd_info", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborBfdInfo))])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                    ('neighbor_address_xr', (YLeaf(YType.str, 'neighbor-address-xr'), ['str'])),
                                    ('neighbor_interface_id', (YLeaf(YType.uint32, 'neighbor-interface-id'), ['int'])),
                                    ('neighbor_dr_priority', (YLeaf(YType.uint8, 'neighbor-dr-priority'), ['int'])),
                                    ('neighbor_state', (YLeaf(YType.enumeration, 'neighbor-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3NeighborState', '')])),
                                    ('neighbor_designated_router', (YLeaf(YType.str, 'neighbor-designated-router'), ['str'])),
                                    ('neighbor_dead_timer', (YLeaf(YType.uint32, 'neighbor-dead-timer'), ['int'])),
                                    ('neighbor_up_time', (YLeaf(YType.uint32, 'neighbor-up-time'), ['int'])),
                                    ('neighbor_virtual_link_id', (YLeaf(YType.uint32, 'neighbor-virtual-link-id'), ['int'])),
                                    ('is_neighbor_virtual_link', (YLeaf(YType.boolean, 'is-neighbor-virtual-link'), ['bool'])),
                                    ('neighbor_sham_link_id', (YLeaf(YType.uint32, 'neighbor-sham-link-id'), ['int'])),
                                    ('is_neighbor_sham_link', (YLeaf(YType.boolean, 'is-neighbor-sham-link'), ['bool'])),
                                ])
                                self.interface_name = None
                                self.neighbor_address = None
                                self.neighbor_address_xr = None
                                self.neighbor_interface_id = None
                                self.neighbor_dr_priority = None
                                self.neighbor_state = None
                                self.neighbor_designated_router = None
                                self.neighbor_dead_timer = None
                                self.neighbor_up_time = None
                                self.neighbor_virtual_link_id = None
                                self.is_neighbor_virtual_link = None
                                self.neighbor_sham_link_id = None
                                self.is_neighbor_sham_link = None

                                self.neighbor_detail = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail()
                                self.neighbor_detail.parent = self
                                self._children_name_map["neighbor_detail"] = "neighbor-detail"

                                self.neighbor_bfd_info = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborBfdInfo()
                                self.neighbor_bfd_info.parent = self
                                self._children_name_map["neighbor_bfd_info"] = "neighbor-bfd-info"
                                self._segment_path = lambda: "neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor, ['interface_name', 'neighbor_address', u'neighbor_address_xr', u'neighbor_interface_id', u'neighbor_dr_priority', u'neighbor_state', u'neighbor_designated_router', u'neighbor_dead_timer', u'neighbor_up_time', u'neighbor_virtual_link_id', u'is_neighbor_virtual_link', u'neighbor_sham_link_id', u'is_neighbor_sham_link'], name, value)


                            class NeighborDetail(Entity):
                                """
                                Detailed OSPFv3 neighbor information 
                                
                                .. attribute:: neighbor_retransmission
                                
                                	Retransmission information with this neighbor
                                	**type**\:  :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission>`
                                
                                .. attribute:: state_changes
                                
                                	Number of state changes 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_cost
                                
                                	Cost of path to this neighbor 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: is_neighbor_filtered
                                
                                	If true, filter outgoing LSAs 
                                	**type**\: bool
                                
                                .. attribute:: neighbor_designated_router_address
                                
                                	Address of designated router
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_backup_designated_router_address
                                
                                	Address of backup designated router
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_type
                                
                                	Interface type
                                	**type**\:  :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                
                                .. attribute:: poll_interval
                                
                                	Poll interval (s)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_poll_interval
                                
                                	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_ignore_timer
                                
                                	Remaining time when ignore timer is running 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_option
                                
                                	 This is bitmask of neighbor's option field received 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pending_events
                                
                                	Number of pending events 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail, self).__init__()

                                    self.yang_name = "neighbor-detail"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor-retransmission", ("neighbor_retransmission", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission))])
                                    self._leafs = OrderedDict([
                                        ('state_changes', (YLeaf(YType.uint16, 'state-changes'), ['int'])),
                                        ('neighbor_cost', (YLeaf(YType.uint16, 'neighbor-cost'), ['int'])),
                                        ('is_neighbor_filtered', (YLeaf(YType.boolean, 'is-neighbor-filtered'), ['bool'])),
                                        ('neighbor_designated_router_address', (YLeaf(YType.str, 'neighbor-designated-router-address'), ['str'])),
                                        ('neighbor_backup_designated_router_address', (YLeaf(YType.str, 'neighbor-backup-designated-router-address'), ['str'])),
                                        ('interface_type', (YLeaf(YType.enumeration, 'interface-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Interface', '')])),
                                        ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                        ('next_poll_interval', (YLeaf(YType.uint32, 'next-poll-interval'), ['int'])),
                                        ('neighbor_ignore_timer', (YLeaf(YType.uint32, 'neighbor-ignore-timer'), ['int'])),
                                        ('neighbor_option', (YLeaf(YType.uint32, 'neighbor-option'), ['int'])),
                                        ('pending_events', (YLeaf(YType.uint16, 'pending-events'), ['int'])),
                                    ])
                                    self.state_changes = None
                                    self.neighbor_cost = None
                                    self.is_neighbor_filtered = None
                                    self.neighbor_designated_router_address = None
                                    self.neighbor_backup_designated_router_address = None
                                    self.interface_type = None
                                    self.poll_interval = None
                                    self.next_poll_interval = None
                                    self.neighbor_ignore_timer = None
                                    self.neighbor_option = None
                                    self.pending_events = None

                                    self.neighbor_retransmission = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission()
                                    self.neighbor_retransmission.parent = self
                                    self._children_name_map["neighbor_retransmission"] = "neighbor-retransmission"
                                    self._segment_path = lambda: "neighbor-detail"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail, [u'state_changes', u'neighbor_cost', u'is_neighbor_filtered', u'neighbor_designated_router_address', u'neighbor_backup_designated_router_address', u'interface_type', u'poll_interval', u'next_poll_interval', u'neighbor_ignore_timer', u'neighbor_option', u'pending_events'], name, value)


                                class NeighborRetransmission(Entity):
                                    """
                                    Retransmission information with this neighbor
                                    
                                    .. attribute:: database_descriptor_retransmissions
                                    
                                    	Number of database descriptor retransmissions during last exchange
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_flood_index
                                    
                                    	Area scope LSA's flood index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_flood_index
                                    
                                    	AS scope LSA's flood index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_flood_index
                                    
                                    	Link flood index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_retransmissions
                                    
                                    	Number of neighbor retransmissions 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retransmissions
                                    
                                    	Number of retransmissions for this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_first_flood
                                    
                                    	First flood item for area scope LSAs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_first_flood_index
                                    
                                    	Index of the first flood item for area scope LSAs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood
                                    
                                    	First flood item for AS scope LSAs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood_index
                                    
                                    	Index for first flood item for AS scope LSAs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_first_flood
                                    
                                    	Link first flood information 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_first_flood_index
                                    
                                    	Link first flood information index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood
                                    
                                    	Next flood item for area scope LSAs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood_index
                                    
                                    	Index of next flood item for Area scope LSAs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood
                                    
                                    	Next flood item for AS scope LSAs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood_index
                                    
                                    	Index of next flood item for AS scope LSAs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_next_flood
                                    
                                    	Link next flood information 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_next_flood_index
                                    
                                    	Link next flood information index 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_length
                                    
                                    	Number of LSAs sent in last retransmission
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_length
                                    
                                    	Maximum number of LSAs sent in a retransmission
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_time
                                    
                                    	Last retransmission scan time (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_time
                                    
                                    	Maximum retransmission scan time (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_retransmission_timer
                                    
                                    	Time until next LSA retransmission (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission, self).__init__()

                                        self.yang_name = "neighbor-retransmission"
                                        self.yang_parent_name = "neighbor-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('database_descriptor_retransmissions', (YLeaf(YType.uint32, 'database-descriptor-retransmissions'), ['int'])),
                                            ('area_flood_index', (YLeaf(YType.uint32, 'area-flood-index'), ['int'])),
                                            ('as_flood_index', (YLeaf(YType.uint32, 'as-flood-index'), ['int'])),
                                            ('link_flood_index', (YLeaf(YType.uint32, 'link-flood-index'), ['int'])),
                                            ('neighbor_retransmissions', (YLeaf(YType.uint32, 'neighbor-retransmissions'), ['int'])),
                                            ('retransmissions', (YLeaf(YType.uint32, 'retransmissions'), ['int'])),
                                            ('area_first_flood', (YLeaf(YType.uint32, 'area-first-flood'), ['int'])),
                                            ('area_first_flood_index', (YLeaf(YType.uint32, 'area-first-flood-index'), ['int'])),
                                            ('as_first_flood', (YLeaf(YType.uint32, 'as-first-flood'), ['int'])),
                                            ('as_first_flood_index', (YLeaf(YType.uint32, 'as-first-flood-index'), ['int'])),
                                            ('link_first_flood', (YLeaf(YType.uint32, 'link-first-flood'), ['int'])),
                                            ('link_first_flood_index', (YLeaf(YType.uint32, 'link-first-flood-index'), ['int'])),
                                            ('area_next_flood', (YLeaf(YType.uint32, 'area-next-flood'), ['int'])),
                                            ('area_next_flood_index', (YLeaf(YType.uint32, 'area-next-flood-index'), ['int'])),
                                            ('as_next_flood', (YLeaf(YType.uint32, 'as-next-flood'), ['int'])),
                                            ('as_next_flood_index', (YLeaf(YType.uint32, 'as-next-flood-index'), ['int'])),
                                            ('link_next_flood', (YLeaf(YType.uint32, 'link-next-flood'), ['int'])),
                                            ('link_next_flood_index', (YLeaf(YType.uint32, 'link-next-flood-index'), ['int'])),
                                            ('last_retransmission_length', (YLeaf(YType.uint32, 'last-retransmission-length'), ['int'])),
                                            ('maximum_retransmission_length', (YLeaf(YType.uint32, 'maximum-retransmission-length'), ['int'])),
                                            ('last_retransmission_time', (YLeaf(YType.uint32, 'last-retransmission-time'), ['int'])),
                                            ('maximum_retransmission_time', (YLeaf(YType.uint32, 'maximum-retransmission-time'), ['int'])),
                                            ('lsa_retransmission_timer', (YLeaf(YType.uint32, 'lsa-retransmission-timer'), ['int'])),
                                        ])
                                        self.database_descriptor_retransmissions = None
                                        self.area_flood_index = None
                                        self.as_flood_index = None
                                        self.link_flood_index = None
                                        self.neighbor_retransmissions = None
                                        self.retransmissions = None
                                        self.area_first_flood = None
                                        self.area_first_flood_index = None
                                        self.as_first_flood = None
                                        self.as_first_flood_index = None
                                        self.link_first_flood = None
                                        self.link_first_flood_index = None
                                        self.area_next_flood = None
                                        self.area_next_flood_index = None
                                        self.as_next_flood = None
                                        self.as_next_flood_index = None
                                        self.link_next_flood = None
                                        self.link_next_flood_index = None
                                        self.last_retransmission_length = None
                                        self.maximum_retransmission_length = None
                                        self.last_retransmission_time = None
                                        self.maximum_retransmission_time = None
                                        self.lsa_retransmission_timer = None
                                        self._segment_path = lambda: "neighbor-retransmission"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission, [u'database_descriptor_retransmissions', u'area_flood_index', u'as_flood_index', u'link_flood_index', u'neighbor_retransmissions', u'retransmissions', u'area_first_flood', u'area_first_flood_index', u'as_first_flood', u'as_first_flood_index', u'link_first_flood', u'link_first_flood_index', u'area_next_flood', u'area_next_flood_index', u'as_next_flood', u'as_next_flood_index', u'link_next_flood', u'link_next_flood_index', u'last_retransmission_length', u'maximum_retransmission_length', u'last_retransmission_time', u'maximum_retransmission_time', u'lsa_retransmission_timer'], name, value)


                            class NeighborBfdInfo(Entity):
                                """
                                Neighbor BFD information
                                
                                .. attribute:: bfd_intf_enable_mode
                                
                                	BFD enable mode \- Default/Strict
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_status_flag
                                
                                	Status of the BFD Session
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborBfdInfo, self).__init__()

                                    self.yang_name = "neighbor-bfd-info"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('bfd_intf_enable_mode', (YLeaf(YType.uint32, 'bfd-intf-enable-mode'), ['int'])),
                                        ('bfd_status_flag', (YLeaf(YType.uint8, 'bfd-status-flag'), ['int'])),
                                    ])
                                    self.bfd_intf_enable_mode = None
                                    self.bfd_status_flag = None
                                    self._segment_path = lambda: "neighbor-bfd-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborProcessTable.Neighbor.NeighborBfdInfo, [u'bfd_intf_enable_mode', u'bfd_status_flag'], name, value)


                    class FastReroutes(Entity):
                        """
                        OSPFv3 fast reroute topology information table
                        
                        .. attribute:: fast_reroute
                        
                        	OSPFv3 fast reroute topology information
                        	**type**\: list of  		 :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes, self).__init__()

                            self.yang_name = "fast-reroutes"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fast-reroute", ("fast_reroute", Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute))])
                            self._leafs = OrderedDict()

                            self.fast_reroute = YList(self)
                            self._segment_path = lambda: "fast-reroutes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes, [], name, value)


                        class FastReroute(Entity):
                            """
                            OSPFv3 fast reroute topology information
                            
                            .. attribute:: router_id
                            
                            	Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: area_id
                            
                            	AreaID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipfrr_topo_area_id
                            
                            	Area ID string in decimal or dotted decimal format
                            	**type**\: str
                            
                            	**length:** 0..16
                            
                            .. attribute:: ipfrr_router_id
                            
                            	OSPF Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipfrr_area_revision
                            
                            	IPFRR Topology Revision
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipfrr_topo
                            
                            	IPFRR Topology entries
                            	**type**\: list of  		 :py:class:`IpfrrTopo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute.IpfrrTopo>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute, self).__init__()

                                self.yang_name = "fast-reroute"
                                self.yang_parent_name = "fast-reroutes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ipfrr-topo", ("ipfrr_topo", Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute.IpfrrTopo))])
                                self._leafs = OrderedDict([
                                    ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                    ('area_id', (YLeaf(YType.uint32, 'area-id'), ['int'])),
                                    ('ipfrr_topo_area_id', (YLeaf(YType.str, 'ipfrr-topo-area-id'), ['str'])),
                                    ('ipfrr_router_id', (YLeaf(YType.str, 'ipfrr-router-id'), ['str'])),
                                    ('ipfrr_area_revision', (YLeaf(YType.uint32, 'ipfrr-area-revision'), ['int'])),
                                ])
                                self.router_id = None
                                self.area_id = None
                                self.ipfrr_topo_area_id = None
                                self.ipfrr_router_id = None
                                self.ipfrr_area_revision = None

                                self.ipfrr_topo = YList(self)
                                self._segment_path = lambda: "fast-reroute"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute, ['router_id', 'area_id', u'ipfrr_topo_area_id', u'ipfrr_router_id', u'ipfrr_area_revision'], name, value)


                            class IpfrrTopo(Entity):
                                """
                                IPFRR Topology entries
                                
                                .. attribute:: node_id
                                
                                	IPFRR Topology Node ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsaid
                                
                                	IPFRR Topology LSA ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: distance
                                
                                	IPFRR Topology Distance
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: type4
                                
                                	IPFRR Topoogy Type\-4 entry
                                	**type**\: bool
                                
                                .. attribute:: revision
                                
                                	IPFRR Topology Revision
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_sourced
                                
                                	IPFRR Topology Neighbor Sourced
                                	**type**\: bool
                                
                                .. attribute:: dr
                                
                                	IPFRR Topology DR entry
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute.IpfrrTopo, self).__init__()

                                    self.yang_name = "ipfrr-topo"
                                    self.yang_parent_name = "fast-reroute"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('node_id', (YLeaf(YType.str, 'node-id'), ['str'])),
                                        ('lsaid', (YLeaf(YType.uint32, 'lsaid'), ['int'])),
                                        ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                        ('type4', (YLeaf(YType.boolean, 'type4'), ['bool'])),
                                        ('revision', (YLeaf(YType.uint32, 'revision'), ['int'])),
                                        ('neighbor_sourced', (YLeaf(YType.boolean, 'neighbor-sourced'), ['bool'])),
                                        ('dr', (YLeaf(YType.boolean, 'dr'), ['bool'])),
                                    ])
                                    self.node_id = None
                                    self.lsaid = None
                                    self.distance = None
                                    self.type4 = None
                                    self.revision = None
                                    self.neighbor_sourced = None
                                    self.dr = None
                                    self._segment_path = lambda: "ipfrr-topo"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.FastReroutes.FastReroute.IpfrrTopo, [u'node_id', u'lsaid', u'distance', u'type4', u'revision', u'neighbor_sourced', u'dr'], name, value)


                    class InterfaceBriefProcessTable(Entity):
                        """
                        OSPFv3 interface brief information table for all
                        areas
                        
                        .. attribute:: interface_brief
                        
                        	Interface brief information
                        	**type**\: list of  		 :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable.InterfaceBrief>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable, self).__init__()

                            self.yang_name = "interface-brief-process-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface-brief", ("interface_brief", Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable.InterfaceBrief))])
                            self._leafs = OrderedDict()

                            self.interface_brief = YList(self)
                            self._segment_path = lambda: "interface-brief-process-table"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable, [], name, value)


                        class InterfaceBrief(Entity):
                            """
                            Interface brief information
                            
                            .. attribute:: interface_name  (key)
                            
                            	Interface name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: interface_address
                            
                            	Interface IP address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_link_cost
                            
                            	Interface link cost
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ospf_interface_state
                            
                            	Interface OSPF state
                            	**type**\:  :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                            
                            .. attribute:: interface_neighbors
                            
                            	Total number of neighbors 
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interface_adjacent_neighbors
                            
                            	Total number of adjacent neighbors
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: network_type
                            
                            	Network type
                            	**type**\:  :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable.InterfaceBrief, self).__init__()

                                self.yang_name = "interface-brief"
                                self.yang_parent_name = "interface-brief-process-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['interface_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('interface_address', (YLeaf(YType.str, 'interface-address'), ['str'])),
                                    ('interface_link_cost', (YLeaf(YType.uint16, 'interface-link-cost'), ['int'])),
                                    ('ospf_interface_state', (YLeaf(YType.enumeration, 'ospf-interface-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3InterfaceState', '')])),
                                    ('interface_neighbors', (YLeaf(YType.uint16, 'interface-neighbors'), ['int'])),
                                    ('interface_adjacent_neighbors', (YLeaf(YType.uint16, 'interface-adjacent-neighbors'), ['int'])),
                                    ('network_type', (YLeaf(YType.enumeration, 'network-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Interface', '')])),
                                ])
                                self.interface_name = None
                                self.interface_address = None
                                self.interface_link_cost = None
                                self.ospf_interface_state = None
                                self.interface_neighbors = None
                                self.interface_adjacent_neighbors = None
                                self.network_type = None
                                self._segment_path = lambda: "interface-brief" + "[interface-name='" + str(self.interface_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.InterfaceBriefProcessTable.InterfaceBrief, ['interface_name', u'interface_address', u'interface_link_cost', u'ospf_interface_state', u'interface_neighbors', u'interface_adjacent_neighbors', u'network_type'], name, value)


                    class NeighborDetailProcessTable(Entity):
                        """
                        OSPFv3 neighbor information table for all areas
                        
                        .. attribute:: neighbor_detail
                        
                        	OSPFv3 neighbor detail information
                        	**type**\: list of  		 :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable, self).__init__()

                            self.yang_name = "neighbor-detail-process-table"
                            self.yang_parent_name = "vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-detail", ("neighbor_detail", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail))])
                            self._leafs = OrderedDict()

                            self.neighbor_detail = YList(self)
                            self._segment_path = lambda: "neighbor-detail-process-table"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable, [], name, value)


                        class NeighborDetail(Entity):
                            """
                            OSPFv3 neighbor detail information
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: neighbor_address
                            
                            	Neighbor ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_detail
                            
                            	Detailed OSPFv3 neighbor information 
                            	**type**\:  :py:class:`NeighborDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_>`
                            
                            .. attribute:: neighbor_bfd_info
                            
                            	Neighbor BFD information
                            	**type**\:  :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo>`
                            
                            .. attribute:: neighbor_address_xr
                            
                            	Neighbor IP Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_interface_id
                            
                            	Neighbor interface ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_dr_priority
                            
                            	Neighbor's DR priority
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: neighbor_state
                            
                            	Neighbor's state
                            	**type**\:  :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                            
                            .. attribute:: neighbor_designated_router
                            
                            	Designated router 
                            	**type**\: str
                            
                            	**length:** 0..9
                            
                            .. attribute:: neighbor_dead_timer
                            
                            	Time until neighbor's dead timer expires (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: neighbor_up_time
                            
                            	Amount of time since the adjacency is up (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: neighbor_virtual_link_id
                            
                            	Neighbor virtual link id 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_neighbor_virtual_link
                            
                            	If true, neighbor is on a virtual link 
                            	**type**\: bool
                            
                            .. attribute:: neighbor_sham_link_id
                            
                            	Neighbor sham link id 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_neighbor_sham_link
                            
                            	If true, neighbor is on a sham link 
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail, self).__init__()

                                self.yang_name = "neighbor-detail"
                                self.yang_parent_name = "neighbor-detail-process-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("neighbor-detail", ("neighbor_detail", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_)), ("neighbor-bfd-info", ("neighbor_bfd_info", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo))])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                    ('neighbor_address_xr', (YLeaf(YType.str, 'neighbor-address-xr'), ['str'])),
                                    ('neighbor_interface_id', (YLeaf(YType.uint32, 'neighbor-interface-id'), ['int'])),
                                    ('neighbor_dr_priority', (YLeaf(YType.uint8, 'neighbor-dr-priority'), ['int'])),
                                    ('neighbor_state', (YLeaf(YType.enumeration, 'neighbor-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3NeighborState', '')])),
                                    ('neighbor_designated_router', (YLeaf(YType.str, 'neighbor-designated-router'), ['str'])),
                                    ('neighbor_dead_timer', (YLeaf(YType.uint32, 'neighbor-dead-timer'), ['int'])),
                                    ('neighbor_up_time', (YLeaf(YType.uint32, 'neighbor-up-time'), ['int'])),
                                    ('neighbor_virtual_link_id', (YLeaf(YType.uint32, 'neighbor-virtual-link-id'), ['int'])),
                                    ('is_neighbor_virtual_link', (YLeaf(YType.boolean, 'is-neighbor-virtual-link'), ['bool'])),
                                    ('neighbor_sham_link_id', (YLeaf(YType.uint32, 'neighbor-sham-link-id'), ['int'])),
                                    ('is_neighbor_sham_link', (YLeaf(YType.boolean, 'is-neighbor-sham-link'), ['bool'])),
                                ])
                                self.interface_name = None
                                self.neighbor_address = None
                                self.neighbor_address_xr = None
                                self.neighbor_interface_id = None
                                self.neighbor_dr_priority = None
                                self.neighbor_state = None
                                self.neighbor_designated_router = None
                                self.neighbor_dead_timer = None
                                self.neighbor_up_time = None
                                self.neighbor_virtual_link_id = None
                                self.is_neighbor_virtual_link = None
                                self.neighbor_sham_link_id = None
                                self.is_neighbor_sham_link = None

                                self.neighbor_detail = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_()
                                self.neighbor_detail.parent = self
                                self._children_name_map["neighbor_detail"] = "neighbor-detail"

                                self.neighbor_bfd_info = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo()
                                self.neighbor_bfd_info.parent = self
                                self._children_name_map["neighbor_bfd_info"] = "neighbor-bfd-info"
                                self._segment_path = lambda: "neighbor-detail"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail, ['interface_name', 'neighbor_address', u'neighbor_address_xr', u'neighbor_interface_id', u'neighbor_dr_priority', u'neighbor_state', u'neighbor_designated_router', u'neighbor_dead_timer', u'neighbor_up_time', u'neighbor_virtual_link_id', u'is_neighbor_virtual_link', u'neighbor_sham_link_id', u'is_neighbor_sham_link'], name, value)


                            class NeighborDetail_(Entity):
                                """
                                Detailed OSPFv3 neighbor information 
                                
                                .. attribute:: neighbor_retransmission
                                
                                	Retransmission information with this neighbor
                                	**type**\:  :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_.NeighborRetransmission>`
                                
                                .. attribute:: state_changes
                                
                                	Number of state changes 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: neighbor_cost
                                
                                	Cost of path to this neighbor 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: is_neighbor_filtered
                                
                                	If true, filter outgoing LSAs 
                                	**type**\: bool
                                
                                .. attribute:: neighbor_designated_router_address
                                
                                	Address of designated router
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_backup_designated_router_address
                                
                                	Address of backup designated router
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_type
                                
                                	Interface type
                                	**type**\:  :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                
                                .. attribute:: poll_interval
                                
                                	Poll interval (s)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_poll_interval
                                
                                	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_ignore_timer
                                
                                	Remaining time when ignore timer is running 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_option
                                
                                	 This is bitmask of neighbor's option field received 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pending_events
                                
                                	Number of pending events 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_, self).__init__()

                                    self.yang_name = "neighbor-detail"
                                    self.yang_parent_name = "neighbor-detail"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor-retransmission", ("neighbor_retransmission", Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_.NeighborRetransmission))])
                                    self._leafs = OrderedDict([
                                        ('state_changes', (YLeaf(YType.uint16, 'state-changes'), ['int'])),
                                        ('neighbor_cost', (YLeaf(YType.uint16, 'neighbor-cost'), ['int'])),
                                        ('is_neighbor_filtered', (YLeaf(YType.boolean, 'is-neighbor-filtered'), ['bool'])),
                                        ('neighbor_designated_router_address', (YLeaf(YType.str, 'neighbor-designated-router-address'), ['str'])),
                                        ('neighbor_backup_designated_router_address', (YLeaf(YType.str, 'neighbor-backup-designated-router-address'), ['str'])),
                                        ('interface_type', (YLeaf(YType.enumeration, 'interface-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Interface', '')])),
                                        ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                        ('next_poll_interval', (YLeaf(YType.uint32, 'next-poll-interval'), ['int'])),
                                        ('neighbor_ignore_timer', (YLeaf(YType.uint32, 'neighbor-ignore-timer'), ['int'])),
                                        ('neighbor_option', (YLeaf(YType.uint32, 'neighbor-option'), ['int'])),
                                        ('pending_events', (YLeaf(YType.uint16, 'pending-events'), ['int'])),
                                    ])
                                    self.state_changes = None
                                    self.neighbor_cost = None
                                    self.is_neighbor_filtered = None
                                    self.neighbor_designated_router_address = None
                                    self.neighbor_backup_designated_router_address = None
                                    self.interface_type = None
                                    self.poll_interval = None
                                    self.next_poll_interval = None
                                    self.neighbor_ignore_timer = None
                                    self.neighbor_option = None
                                    self.pending_events = None

                                    self.neighbor_retransmission = Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_.NeighborRetransmission()
                                    self.neighbor_retransmission.parent = self
                                    self._children_name_map["neighbor_retransmission"] = "neighbor-retransmission"
                                    self._segment_path = lambda: "neighbor-detail"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_, [u'state_changes', u'neighbor_cost', u'is_neighbor_filtered', u'neighbor_designated_router_address', u'neighbor_backup_designated_router_address', u'interface_type', u'poll_interval', u'next_poll_interval', u'neighbor_ignore_timer', u'neighbor_option', u'pending_events'], name, value)


                                class NeighborRetransmission(Entity):
                                    """
                                    Retransmission information with this neighbor
                                    
                                    .. attribute:: database_descriptor_retransmissions
                                    
                                    	Number of database descriptor retransmissions during last exchange
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_flood_index
                                    
                                    	Area scope LSA's flood index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_flood_index
                                    
                                    	AS scope LSA's flood index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_flood_index
                                    
                                    	Link flood index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_retransmissions
                                    
                                    	Number of neighbor retransmissions 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: retransmissions
                                    
                                    	Number of retransmissions for this neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_first_flood
                                    
                                    	First flood item for area scope LSAs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_first_flood_index
                                    
                                    	Index of the first flood item for area scope LSAs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood
                                    
                                    	First flood item for AS scope LSAs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_first_flood_index
                                    
                                    	Index for first flood item for AS scope LSAs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_first_flood
                                    
                                    	Link first flood information 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_first_flood_index
                                    
                                    	Link first flood information index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood
                                    
                                    	Next flood item for area scope LSAs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: area_next_flood_index
                                    
                                    	Index of next flood item for Area scope LSAs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood
                                    
                                    	Next flood item for AS scope LSAs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_next_flood_index
                                    
                                    	Index of next flood item for AS scope LSAs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_next_flood
                                    
                                    	Link next flood information 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: link_next_flood_index
                                    
                                    	Link next flood information index 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_length
                                    
                                    	Number of LSAs sent in last retransmission
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_length
                                    
                                    	Maximum number of LSAs sent in a retransmission
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_retransmission_time
                                    
                                    	Last retransmission scan time (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_retransmission_time
                                    
                                    	Maximum retransmission scan time (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_retransmission_timer
                                    
                                    	Time until next LSA retransmission (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_.NeighborRetransmission, self).__init__()

                                        self.yang_name = "neighbor-retransmission"
                                        self.yang_parent_name = "neighbor-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('database_descriptor_retransmissions', (YLeaf(YType.uint32, 'database-descriptor-retransmissions'), ['int'])),
                                            ('area_flood_index', (YLeaf(YType.uint32, 'area-flood-index'), ['int'])),
                                            ('as_flood_index', (YLeaf(YType.uint32, 'as-flood-index'), ['int'])),
                                            ('link_flood_index', (YLeaf(YType.uint32, 'link-flood-index'), ['int'])),
                                            ('neighbor_retransmissions', (YLeaf(YType.uint32, 'neighbor-retransmissions'), ['int'])),
                                            ('retransmissions', (YLeaf(YType.uint32, 'retransmissions'), ['int'])),
                                            ('area_first_flood', (YLeaf(YType.uint32, 'area-first-flood'), ['int'])),
                                            ('area_first_flood_index', (YLeaf(YType.uint32, 'area-first-flood-index'), ['int'])),
                                            ('as_first_flood', (YLeaf(YType.uint32, 'as-first-flood'), ['int'])),
                                            ('as_first_flood_index', (YLeaf(YType.uint32, 'as-first-flood-index'), ['int'])),
                                            ('link_first_flood', (YLeaf(YType.uint32, 'link-first-flood'), ['int'])),
                                            ('link_first_flood_index', (YLeaf(YType.uint32, 'link-first-flood-index'), ['int'])),
                                            ('area_next_flood', (YLeaf(YType.uint32, 'area-next-flood'), ['int'])),
                                            ('area_next_flood_index', (YLeaf(YType.uint32, 'area-next-flood-index'), ['int'])),
                                            ('as_next_flood', (YLeaf(YType.uint32, 'as-next-flood'), ['int'])),
                                            ('as_next_flood_index', (YLeaf(YType.uint32, 'as-next-flood-index'), ['int'])),
                                            ('link_next_flood', (YLeaf(YType.uint32, 'link-next-flood'), ['int'])),
                                            ('link_next_flood_index', (YLeaf(YType.uint32, 'link-next-flood-index'), ['int'])),
                                            ('last_retransmission_length', (YLeaf(YType.uint32, 'last-retransmission-length'), ['int'])),
                                            ('maximum_retransmission_length', (YLeaf(YType.uint32, 'maximum-retransmission-length'), ['int'])),
                                            ('last_retransmission_time', (YLeaf(YType.uint32, 'last-retransmission-time'), ['int'])),
                                            ('maximum_retransmission_time', (YLeaf(YType.uint32, 'maximum-retransmission-time'), ['int'])),
                                            ('lsa_retransmission_timer', (YLeaf(YType.uint32, 'lsa-retransmission-timer'), ['int'])),
                                        ])
                                        self.database_descriptor_retransmissions = None
                                        self.area_flood_index = None
                                        self.as_flood_index = None
                                        self.link_flood_index = None
                                        self.neighbor_retransmissions = None
                                        self.retransmissions = None
                                        self.area_first_flood = None
                                        self.area_first_flood_index = None
                                        self.as_first_flood = None
                                        self.as_first_flood_index = None
                                        self.link_first_flood = None
                                        self.link_first_flood_index = None
                                        self.area_next_flood = None
                                        self.area_next_flood_index = None
                                        self.as_next_flood = None
                                        self.as_next_flood_index = None
                                        self.link_next_flood = None
                                        self.link_next_flood_index = None
                                        self.last_retransmission_length = None
                                        self.maximum_retransmission_length = None
                                        self.last_retransmission_time = None
                                        self.maximum_retransmission_time = None
                                        self.lsa_retransmission_timer = None
                                        self._segment_path = lambda: "neighbor-retransmission"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_.NeighborRetransmission, [u'database_descriptor_retransmissions', u'area_flood_index', u'as_flood_index', u'link_flood_index', u'neighbor_retransmissions', u'retransmissions', u'area_first_flood', u'area_first_flood_index', u'as_first_flood', u'as_first_flood_index', u'link_first_flood', u'link_first_flood_index', u'area_next_flood', u'area_next_flood_index', u'as_next_flood', u'as_next_flood_index', u'link_next_flood', u'link_next_flood_index', u'last_retransmission_length', u'maximum_retransmission_length', u'last_retransmission_time', u'maximum_retransmission_time', u'lsa_retransmission_timer'], name, value)


                            class NeighborBfdInfo(Entity):
                                """
                                Neighbor BFD information
                                
                                .. attribute:: bfd_intf_enable_mode
                                
                                	BFD enable mode \- Default/Strict
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bfd_status_flag
                                
                                	Status of the BFD Session
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo, self).__init__()

                                    self.yang_name = "neighbor-bfd-info"
                                    self.yang_parent_name = "neighbor-detail"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('bfd_intf_enable_mode', (YLeaf(YType.uint32, 'bfd-intf-enable-mode'), ['int'])),
                                        ('bfd_status_flag', (YLeaf(YType.uint8, 'bfd-status-flag'), ['int'])),
                                    ])
                                    self.bfd_intf_enable_mode = None
                                    self.bfd_status_flag = None
                                    self._segment_path = lambda: "neighbor-bfd-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Vrfs.Vrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo, [u'bfd_intf_enable_mode', u'bfd_status_flag'], name, value)


            class Statistics(Entity):
                """
                Container for Statistics
                
                .. attribute:: nsr_stats
                
                	OSPF NSR statistics
                	**type**\:  :py:class:`NsrStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats>`
                
                .. attribute:: rib_thread_stats
                
                	OSPFv3 RIB thread statistics
                	**type**\:  :py:class:`RibThreadStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.RibThreadStats>`
                
                .. attribute:: issu_stats
                
                	OSPF ISSU statistics
                	**type**\:  :py:class:`IssuStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats>`
                
                .. attribute:: nsr_pl_stats
                
                	OSPF NSR packet library statistics
                	**type**\:  :py:class:`NsrPlStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrPlStats>`
                
                .. attribute:: protocol_stats
                
                	Protocol table
                	**type**\:  :py:class:`ProtocolStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.ProtocolStats>`
                
                .. attribute:: spf_stats
                
                	OSPFv3 RIB batch statistics
                	**type**\:  :py:class:`SpfStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats>`
                
                .. attribute:: rawio_stats
                
                	OSPF Prefix SPF Prioritization statistics
                	**type**\:  :py:class:`RawioStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.RawioStats>`
                
                .. attribute:: prefix_priority_stats
                
                	OSPF Prefix SPF Prioritization statistics
                	**type**\:  :py:class:`PrefixPriorityStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.PrefixPriorityStats>`
                
                .. attribute:: vrf_rib_batch_stats
                
                	OSPFv3 RIB batch statistics
                	**type**\:  :py:class:`VrfRibBatchStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.VrfRibBatchStats>`
                
                

                """

                _prefix = 'ipv6-ospfv3-oper'
                _revision = '2017-10-30'

                def __init__(self):
                    super(Ospfv3.Processes.Process.Statistics, self).__init__()

                    self.yang_name = "statistics"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("nsr-stats", ("nsr_stats", Ospfv3.Processes.Process.Statistics.NsrStats)), ("rib-thread-stats", ("rib_thread_stats", Ospfv3.Processes.Process.Statistics.RibThreadStats)), ("issu-stats", ("issu_stats", Ospfv3.Processes.Process.Statistics.IssuStats)), ("nsr-pl-stats", ("nsr_pl_stats", Ospfv3.Processes.Process.Statistics.NsrPlStats)), ("protocol-stats", ("protocol_stats", Ospfv3.Processes.Process.Statistics.ProtocolStats)), ("spf-stats", ("spf_stats", Ospfv3.Processes.Process.Statistics.SpfStats)), ("rawio-stats", ("rawio_stats", Ospfv3.Processes.Process.Statistics.RawioStats)), ("prefix-priority-stats", ("prefix_priority_stats", Ospfv3.Processes.Process.Statistics.PrefixPriorityStats)), ("vrf-rib-batch-stats", ("vrf_rib_batch_stats", Ospfv3.Processes.Process.Statistics.VrfRibBatchStats))])
                    self._leafs = OrderedDict()

                    self.nsr_stats = Ospfv3.Processes.Process.Statistics.NsrStats()
                    self.nsr_stats.parent = self
                    self._children_name_map["nsr_stats"] = "nsr-stats"

                    self.rib_thread_stats = Ospfv3.Processes.Process.Statistics.RibThreadStats()
                    self.rib_thread_stats.parent = self
                    self._children_name_map["rib_thread_stats"] = "rib-thread-stats"

                    self.issu_stats = Ospfv3.Processes.Process.Statistics.IssuStats()
                    self.issu_stats.parent = self
                    self._children_name_map["issu_stats"] = "issu-stats"

                    self.nsr_pl_stats = Ospfv3.Processes.Process.Statistics.NsrPlStats()
                    self.nsr_pl_stats.parent = self
                    self._children_name_map["nsr_pl_stats"] = "nsr-pl-stats"

                    self.protocol_stats = Ospfv3.Processes.Process.Statistics.ProtocolStats()
                    self.protocol_stats.parent = self
                    self._children_name_map["protocol_stats"] = "protocol-stats"

                    self.spf_stats = Ospfv3.Processes.Process.Statistics.SpfStats()
                    self.spf_stats.parent = self
                    self._children_name_map["spf_stats"] = "spf-stats"

                    self.rawio_stats = Ospfv3.Processes.Process.Statistics.RawioStats()
                    self.rawio_stats.parent = self
                    self._children_name_map["rawio_stats"] = "rawio-stats"

                    self.prefix_priority_stats = Ospfv3.Processes.Process.Statistics.PrefixPriorityStats()
                    self.prefix_priority_stats.parent = self
                    self._children_name_map["prefix_priority_stats"] = "prefix-priority-stats"

                    self.vrf_rib_batch_stats = Ospfv3.Processes.Process.Statistics.VrfRibBatchStats()
                    self.vrf_rib_batch_stats.parent = self
                    self._children_name_map["vrf_rib_batch_stats"] = "vrf-rib-batch-stats"
                    self._segment_path = lambda: "statistics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ospfv3.Processes.Process.Statistics, [], name, value)


                class NsrStats(Entity):
                    """
                    OSPF NSR statistics
                    
                    .. attribute:: nsr_thd_stats
                    
                    	NSR thread scheduler stats
                    	**type**\:  :py:class:`NsrThdStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats>`
                    
                    .. attribute:: nsr_rtr_thd_sched
                    
                    	Rtr thread NSR pulse handler stats
                    	**type**\:  :py:class:`NsrRtrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched>`
                    
                    .. attribute:: nsr_revision
                    
                    	NSR revision
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_fsm_state
                    
                    	FSM state
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_version
                    
                    	NSR version
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_node_id
                    
                    	My nodeid
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_peer_version
                    
                    	Partner NSR version
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_peer_node_id
                    
                    	Partner NodeID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_mtu
                    
                    	Fabric MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_nbr_qad_qid
                    
                    	NBR QAD queue id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_lsa_qad_qid
                    
                    	LSA QAD queue id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_nbr_qad_mdata_count
                    
                    	NBR QAD pending msg
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_lsa_qad_mdata_count
                    
                    	LSA QAD pending msgs
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_nbr_init_sync_pend_count
                    
                    	Pending init\-sync NBR msgs
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_lsa_init_sync_pend_count
                    
                    	Pending init\-sync LSA msgs
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_nbr_seq_no
                    
                    	Neighbor TLV sequence no
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_intf_seq_no
                    
                    	Interface TLV sequence no
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_tmr_quant
                    
                    	Timers processed per pulse
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_conn_to_active_attempts
                    
                    	Attempts to connect to active
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_fails
                    
                    	Failures to connect to active
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_opens
                    
                    	Conn to active opens
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_closes
                    
                    	Conn to active closes
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_errors
                    
                    	Conn to active errors
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_fsm_flag
                    
                    	Nsr Fsm Flags information
                    	**type**\: list of str
                    
                    .. attribute:: nsr_fsm_running_timer
                    
                    	Nsr Fsm Running Timers
                    	**type**\: list of str
                    
                    .. attribute:: nsr_issu_milestone
                    
                    	Nsr Issu Milestones
                    	**type**\: list of  		 :py:class:`NsrIssuMilestone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats.NsrIssuMilestone>`
                    
                    .. attribute:: nsr_err_history
                    
                    	Nsr Error History List
                    	**type**\: list of  		 :py:class:`NsrErrHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats.NsrErrHistory>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Statistics.NsrStats, self).__init__()

                        self.yang_name = "nsr-stats"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("nsr-thd-stats", ("nsr_thd_stats", Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats)), ("nsr-rtr-thd-sched", ("nsr_rtr_thd_sched", Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched)), ("nsr-issu-milestone", ("nsr_issu_milestone", Ospfv3.Processes.Process.Statistics.NsrStats.NsrIssuMilestone)), ("nsr-err-history", ("nsr_err_history", Ospfv3.Processes.Process.Statistics.NsrStats.NsrErrHistory))])
                        self._leafs = OrderedDict([
                            ('nsr_revision', (YLeaf(YType.int32, 'nsr-revision'), ['int'])),
                            ('nsr_fsm_state', (YLeaf(YType.int32, 'nsr-fsm-state'), ['int'])),
                            ('nsr_version', (YLeaf(YType.uint32, 'nsr-version'), ['int'])),
                            ('nsr_node_id', (YLeaf(YType.uint32, 'nsr-node-id'), ['int'])),
                            ('nsr_peer_version', (YLeaf(YType.uint32, 'nsr-peer-version'), ['int'])),
                            ('nsr_peer_node_id', (YLeaf(YType.uint32, 'nsr-peer-node-id'), ['int'])),
                            ('nsr_mtu', (YLeaf(YType.uint32, 'nsr-mtu'), ['int'])),
                            ('nsr_nbr_qad_qid', (YLeaf(YType.uint32, 'nsr-nbr-qad-qid'), ['int'])),
                            ('nsr_lsa_qad_qid', (YLeaf(YType.uint32, 'nsr-lsa-qad-qid'), ['int'])),
                            ('nsr_nbr_qad_mdata_count', (YLeaf(YType.uint32, 'nsr-nbr-qad-mdata-count'), ['int'])),
                            ('nsr_lsa_qad_mdata_count', (YLeaf(YType.uint32, 'nsr-lsa-qad-mdata-count'), ['int'])),
                            ('nsr_nbr_init_sync_pend_count', (YLeaf(YType.int32, 'nsr-nbr-init-sync-pend-count'), ['int'])),
                            ('nsr_lsa_init_sync_pend_count', (YLeaf(YType.int32, 'nsr-lsa-init-sync-pend-count'), ['int'])),
                            ('nsr_nbr_seq_no', (YLeaf(YType.uint32, 'nsr-nbr-seq-no'), ['int'])),
                            ('nsr_intf_seq_no', (YLeaf(YType.uint32, 'nsr-intf-seq-no'), ['int'])),
                            ('nsr_tmr_quant', (YLeaf(YType.int32, 'nsr-tmr-quant'), ['int'])),
                            ('nsr_conn_to_active_attempts', (YLeaf(YType.uint64, 'nsr-conn-to-active-attempts'), ['int'])),
                            ('nsr_conn_to_active_fails', (YLeaf(YType.uint64, 'nsr-conn-to-active-fails'), ['int'])),
                            ('nsr_conn_to_active_opens', (YLeaf(YType.uint64, 'nsr-conn-to-active-opens'), ['int'])),
                            ('nsr_conn_to_active_closes', (YLeaf(YType.uint64, 'nsr-conn-to-active-closes'), ['int'])),
                            ('nsr_conn_to_active_errors', (YLeaf(YType.uint64, 'nsr-conn-to-active-errors'), ['int'])),
                            ('nsr_fsm_flag', (YLeafList(YType.str, 'nsr-fsm-flag'), ['str'])),
                            ('nsr_fsm_running_timer', (YLeafList(YType.str, 'nsr-fsm-running-timer'), ['str'])),
                        ])
                        self.nsr_revision = None
                        self.nsr_fsm_state = None
                        self.nsr_version = None
                        self.nsr_node_id = None
                        self.nsr_peer_version = None
                        self.nsr_peer_node_id = None
                        self.nsr_mtu = None
                        self.nsr_nbr_qad_qid = None
                        self.nsr_lsa_qad_qid = None
                        self.nsr_nbr_qad_mdata_count = None
                        self.nsr_lsa_qad_mdata_count = None
                        self.nsr_nbr_init_sync_pend_count = None
                        self.nsr_lsa_init_sync_pend_count = None
                        self.nsr_nbr_seq_no = None
                        self.nsr_intf_seq_no = None
                        self.nsr_tmr_quant = None
                        self.nsr_conn_to_active_attempts = None
                        self.nsr_conn_to_active_fails = None
                        self.nsr_conn_to_active_opens = None
                        self.nsr_conn_to_active_closes = None
                        self.nsr_conn_to_active_errors = None
                        self.nsr_fsm_flag = []
                        self.nsr_fsm_running_timer = []

                        self.nsr_thd_stats = Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats()
                        self.nsr_thd_stats.parent = self
                        self._children_name_map["nsr_thd_stats"] = "nsr-thd-stats"

                        self.nsr_rtr_thd_sched = Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched()
                        self.nsr_rtr_thd_sched.parent = self
                        self._children_name_map["nsr_rtr_thd_sched"] = "nsr-rtr-thd-sched"

                        self.nsr_issu_milestone = YList(self)
                        self.nsr_err_history = YList(self)
                        self._segment_path = lambda: "nsr-stats"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrStats, [u'nsr_revision', u'nsr_fsm_state', u'nsr_version', u'nsr_node_id', u'nsr_peer_version', u'nsr_peer_node_id', u'nsr_mtu', u'nsr_nbr_qad_qid', u'nsr_lsa_qad_qid', u'nsr_nbr_qad_mdata_count', u'nsr_lsa_qad_mdata_count', u'nsr_nbr_init_sync_pend_count', u'nsr_lsa_init_sync_pend_count', u'nsr_nbr_seq_no', u'nsr_intf_seq_no', u'nsr_tmr_quant', u'nsr_conn_to_active_attempts', u'nsr_conn_to_active_fails', u'nsr_conn_to_active_opens', u'nsr_conn_to_active_closes', u'nsr_conn_to_active_errors', u'nsr_fsm_flag', u'nsr_fsm_running_timer'], name, value)


                    class NsrThdStats(Entity):
                        """
                        NSR thread scheduler stats
                        
                        .. attribute:: nsr_pulse_quant
                        
                        	Events processed per pulse
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_events_in_q
                        
                        	Events pending
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_events_tx
                        
                        	Events to Router thread
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_rx
                        
                        	Events processed
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_bad_pulses_rx
                        
                        	Bad pulses received
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_good_pulses_rx
                        
                        	Good pulses received
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pulses_tx
                        
                        	Pulses to Router thread
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pulse_tx_fails
                        
                        	Pulse send failures
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pri
                        
                        	nsr pri
                        	**type**\: list of  		 :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats.NsrPri>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats, self).__init__()

                            self.yang_name = "nsr-thd-stats"
                            self.yang_parent_name = "nsr-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nsr-pri", ("nsr_pri", Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats.NsrPri))])
                            self._leafs = OrderedDict([
                                ('nsr_pulse_quant', (YLeaf(YType.int32, 'nsr-pulse-quant'), ['int'])),
                                ('nsr_events_in_q', (YLeaf(YType.uint32, 'nsr-events-in-q'), ['int'])),
                                ('nsr_events_tx', (YLeaf(YType.uint64, 'nsr-events-tx'), ['int'])),
                                ('nsr_events_rx', (YLeaf(YType.uint64, 'nsr-events-rx'), ['int'])),
                                ('nsr_bad_pulses_rx', (YLeaf(YType.uint64, 'nsr-bad-pulses-rx'), ['int'])),
                                ('nsr_good_pulses_rx', (YLeaf(YType.uint64, 'nsr-good-pulses-rx'), ['int'])),
                                ('nsr_pulses_tx', (YLeaf(YType.uint64, 'nsr-pulses-tx'), ['int'])),
                                ('nsr_pulse_tx_fails', (YLeaf(YType.uint64, 'nsr-pulse-tx-fails'), ['int'])),
                            ])
                            self.nsr_pulse_quant = None
                            self.nsr_events_in_q = None
                            self.nsr_events_tx = None
                            self.nsr_events_rx = None
                            self.nsr_bad_pulses_rx = None
                            self.nsr_good_pulses_rx = None
                            self.nsr_pulses_tx = None
                            self.nsr_pulse_tx_fails = None

                            self.nsr_pri = YList(self)
                            self._segment_path = lambda: "nsr-thd-stats"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats, [u'nsr_pulse_quant', u'nsr_events_in_q', u'nsr_events_tx', u'nsr_events_rx', u'nsr_bad_pulses_rx', u'nsr_good_pulses_rx', u'nsr_pulses_tx', u'nsr_pulse_tx_fails'], name, value)


                        class NsrPri(Entity):
                            """
                            nsr pri
                            
                            .. attribute:: nsr_sched_pri
                            
                            	Priority Type
                            	**type**\:  :py:class:`OspfNsrSchedPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfNsrSchedPri>`
                            
                            .. attribute:: nsr_sched_quant
                            
                            	Priority Queue
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_sched_remain_quant
                            
                            	Remaining quantum
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_sched_evs_in_q
                            
                            	Events pending
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_max_evs
                            
                            	Max Queued
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_peak_q_len
                            
                            	Peak queue length
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_evs_qd
                            
                            	Events queued
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_enq_fails
                            
                            	Event enqueue fails
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_deqd
                            
                            	Events dequeued
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats.NsrPri, self).__init__()

                                self.yang_name = "nsr-pri"
                                self.yang_parent_name = "nsr-thd-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('nsr_sched_pri', (YLeaf(YType.enumeration, 'nsr-sched-pri'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfNsrSchedPri', '')])),
                                    ('nsr_sched_quant', (YLeaf(YType.uint8, 'nsr-sched-quant'), ['int'])),
                                    ('nsr_sched_remain_quant', (YLeaf(YType.uint8, 'nsr-sched-remain-quant'), ['int'])),
                                    ('nsr_sched_evs_in_q', (YLeaf(YType.uint16, 'nsr-sched-evs-in-q'), ['int'])),
                                    ('nsr_sched_max_evs', (YLeaf(YType.uint16, 'nsr-sched-max-evs'), ['int'])),
                                    ('nsr_sched_peak_q_len', (YLeaf(YType.uint16, 'nsr-sched-peak-q-len'), ['int'])),
                                    ('nsr_sched_evs_qd', (YLeaf(YType.uint64, 'nsr-sched-evs-qd'), ['int'])),
                                    ('nsr_sched_enq_fails', (YLeaf(YType.uint64, 'nsr-sched-enq-fails'), ['int'])),
                                    ('nsr_sched_evs_deqd', (YLeaf(YType.uint64, 'nsr-sched-evs-deqd'), ['int'])),
                                ])
                                self.nsr_sched_pri = None
                                self.nsr_sched_quant = None
                                self.nsr_sched_remain_quant = None
                                self.nsr_sched_evs_in_q = None
                                self.nsr_sched_max_evs = None
                                self.nsr_sched_peak_q_len = None
                                self.nsr_sched_evs_qd = None
                                self.nsr_sched_enq_fails = None
                                self.nsr_sched_evs_deqd = None
                                self._segment_path = lambda: "nsr-pri"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrStats.NsrThdStats.NsrPri, [u'nsr_sched_pri', u'nsr_sched_quant', u'nsr_sched_remain_quant', u'nsr_sched_evs_in_q', u'nsr_sched_max_evs', u'nsr_sched_peak_q_len', u'nsr_sched_evs_qd', u'nsr_sched_enq_fails', u'nsr_sched_evs_deqd'], name, value)


                    class NsrRtrThdSched(Entity):
                        """
                        Rtr thread NSR pulse handler stats
                        
                        .. attribute:: nsr_pulse_quant
                        
                        	Events processed per pulse
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_events_in_q
                        
                        	Events pending
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_events_tx
                        
                        	Events to Router thread
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_rx
                        
                        	Events processed
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_bad_pulses_rx
                        
                        	Bad pulses received
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_good_pulses_rx
                        
                        	Good pulses received
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pulses_tx
                        
                        	Pulses to Router thread
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pulse_tx_fails
                        
                        	Pulse send failures
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pri
                        
                        	nsr pri
                        	**type**\: list of  		 :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched.NsrPri>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched, self).__init__()

                            self.yang_name = "nsr-rtr-thd-sched"
                            self.yang_parent_name = "nsr-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nsr-pri", ("nsr_pri", Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched.NsrPri))])
                            self._leafs = OrderedDict([
                                ('nsr_pulse_quant', (YLeaf(YType.int32, 'nsr-pulse-quant'), ['int'])),
                                ('nsr_events_in_q', (YLeaf(YType.uint32, 'nsr-events-in-q'), ['int'])),
                                ('nsr_events_tx', (YLeaf(YType.uint64, 'nsr-events-tx'), ['int'])),
                                ('nsr_events_rx', (YLeaf(YType.uint64, 'nsr-events-rx'), ['int'])),
                                ('nsr_bad_pulses_rx', (YLeaf(YType.uint64, 'nsr-bad-pulses-rx'), ['int'])),
                                ('nsr_good_pulses_rx', (YLeaf(YType.uint64, 'nsr-good-pulses-rx'), ['int'])),
                                ('nsr_pulses_tx', (YLeaf(YType.uint64, 'nsr-pulses-tx'), ['int'])),
                                ('nsr_pulse_tx_fails', (YLeaf(YType.uint64, 'nsr-pulse-tx-fails'), ['int'])),
                            ])
                            self.nsr_pulse_quant = None
                            self.nsr_events_in_q = None
                            self.nsr_events_tx = None
                            self.nsr_events_rx = None
                            self.nsr_bad_pulses_rx = None
                            self.nsr_good_pulses_rx = None
                            self.nsr_pulses_tx = None
                            self.nsr_pulse_tx_fails = None

                            self.nsr_pri = YList(self)
                            self._segment_path = lambda: "nsr-rtr-thd-sched"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched, [u'nsr_pulse_quant', u'nsr_events_in_q', u'nsr_events_tx', u'nsr_events_rx', u'nsr_bad_pulses_rx', u'nsr_good_pulses_rx', u'nsr_pulses_tx', u'nsr_pulse_tx_fails'], name, value)


                        class NsrPri(Entity):
                            """
                            nsr pri
                            
                            .. attribute:: nsr_sched_pri
                            
                            	Priority Type
                            	**type**\:  :py:class:`OspfNsrSchedPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfNsrSchedPri>`
                            
                            .. attribute:: nsr_sched_quant
                            
                            	Priority Queue
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_sched_remain_quant
                            
                            	Remaining quantum
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_sched_evs_in_q
                            
                            	Events pending
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_max_evs
                            
                            	Max Queued
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_peak_q_len
                            
                            	Peak queue length
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_evs_qd
                            
                            	Events queued
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_enq_fails
                            
                            	Event enqueue fails
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_deqd
                            
                            	Events dequeued
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched.NsrPri, self).__init__()

                                self.yang_name = "nsr-pri"
                                self.yang_parent_name = "nsr-rtr-thd-sched"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('nsr_sched_pri', (YLeaf(YType.enumeration, 'nsr-sched-pri'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfNsrSchedPri', '')])),
                                    ('nsr_sched_quant', (YLeaf(YType.uint8, 'nsr-sched-quant'), ['int'])),
                                    ('nsr_sched_remain_quant', (YLeaf(YType.uint8, 'nsr-sched-remain-quant'), ['int'])),
                                    ('nsr_sched_evs_in_q', (YLeaf(YType.uint16, 'nsr-sched-evs-in-q'), ['int'])),
                                    ('nsr_sched_max_evs', (YLeaf(YType.uint16, 'nsr-sched-max-evs'), ['int'])),
                                    ('nsr_sched_peak_q_len', (YLeaf(YType.uint16, 'nsr-sched-peak-q-len'), ['int'])),
                                    ('nsr_sched_evs_qd', (YLeaf(YType.uint64, 'nsr-sched-evs-qd'), ['int'])),
                                    ('nsr_sched_enq_fails', (YLeaf(YType.uint64, 'nsr-sched-enq-fails'), ['int'])),
                                    ('nsr_sched_evs_deqd', (YLeaf(YType.uint64, 'nsr-sched-evs-deqd'), ['int'])),
                                ])
                                self.nsr_sched_pri = None
                                self.nsr_sched_quant = None
                                self.nsr_sched_remain_quant = None
                                self.nsr_sched_evs_in_q = None
                                self.nsr_sched_max_evs = None
                                self.nsr_sched_peak_q_len = None
                                self.nsr_sched_evs_qd = None
                                self.nsr_sched_enq_fails = None
                                self.nsr_sched_evs_deqd = None
                                self._segment_path = lambda: "nsr-pri"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrStats.NsrRtrThdSched.NsrPri, [u'nsr_sched_pri', u'nsr_sched_quant', u'nsr_sched_remain_quant', u'nsr_sched_evs_in_q', u'nsr_sched_max_evs', u'nsr_sched_peak_q_len', u'nsr_sched_evs_qd', u'nsr_sched_enq_fails', u'nsr_sched_evs_deqd'], name, value)


                    class NsrIssuMilestone(Entity):
                        """
                        Nsr Issu Milestones
                        
                        .. attribute:: milestone_name
                        
                        	Milestone Name
                        	**type**\: str
                        
                        .. attribute:: milestone_status
                        
                        	Milestone Status
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.NsrStats.NsrIssuMilestone, self).__init__()

                            self.yang_name = "nsr-issu-milestone"
                            self.yang_parent_name = "nsr-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('milestone_name', (YLeaf(YType.str, 'milestone-name'), ['str'])),
                                ('milestone_status', (YLeaf(YType.str, 'milestone-status'), ['str'])),
                            ])
                            self.milestone_name = None
                            self.milestone_status = None
                            self._segment_path = lambda: "nsr-issu-milestone"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrStats.NsrIssuMilestone, [u'milestone_name', u'milestone_status'], name, value)


                    class NsrErrHistory(Entity):
                        """
                        Nsr Error History List
                        
                        .. attribute:: nsr_revisionversion
                        
                        	Nsr Revision version
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_errors
                        
                        	Total errors for this nsr revision version
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_error_info
                        
                        	List of erros
                        	**type**\: list of  		 :py:class:`NsrErrorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats.NsrErrHistory.NsrErrorInfo>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.NsrStats.NsrErrHistory, self).__init__()

                            self.yang_name = "nsr-err-history"
                            self.yang_parent_name = "nsr-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nsr-error-info", ("nsr_error_info", Ospfv3.Processes.Process.Statistics.NsrStats.NsrErrHistory.NsrErrorInfo))])
                            self._leafs = OrderedDict([
                                ('nsr_revisionversion', (YLeaf(YType.uint32, 'nsr-revisionversion'), ['int'])),
                                ('total_errors', (YLeaf(YType.int32, 'total-errors'), ['int'])),
                            ])
                            self.nsr_revisionversion = None
                            self.total_errors = None

                            self.nsr_error_info = YList(self)
                            self._segment_path = lambda: "nsr-err-history"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrStats.NsrErrHistory, [u'nsr_revisionversion', u'total_errors'], name, value)


                        class NsrErrorInfo(Entity):
                            """
                            List of erros
                            
                            .. attribute:: last_err_time
                            
                            	Time this error was last hit
                            	**type**\:  :py:class:`LastErrTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrStats.NsrErrHistory.NsrErrorInfo.LastErrTime>`
                            
                            .. attribute:: err_count
                            
                            	Count this error hit during the Nsr Revision
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: err_info_string
                            
                            	Error Information
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.NsrStats.NsrErrHistory.NsrErrorInfo, self).__init__()

                                self.yang_name = "nsr-error-info"
                                self.yang_parent_name = "nsr-err-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("last-err-time", ("last_err_time", Ospfv3.Processes.Process.Statistics.NsrStats.NsrErrHistory.NsrErrorInfo.LastErrTime))])
                                self._leafs = OrderedDict([
                                    ('err_count', (YLeaf(YType.int32, 'err-count'), ['int'])),
                                    ('err_info_string', (YLeaf(YType.str, 'err-info-string'), ['str'])),
                                ])
                                self.err_count = None
                                self.err_info_string = None

                                self.last_err_time = Ospfv3.Processes.Process.Statistics.NsrStats.NsrErrHistory.NsrErrorInfo.LastErrTime()
                                self.last_err_time.parent = self
                                self._children_name_map["last_err_time"] = "last-err-time"
                                self._segment_path = lambda: "nsr-error-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrStats.NsrErrHistory.NsrErrorInfo, [u'err_count', u'err_info_string'], name, value)


                            class LastErrTime(Entity):
                                """
                                Time this error was last hit
                                
                                .. attribute:: second
                                
                                	Seconds 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanosecond
                                
                                	Nano seconds 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Statistics.NsrStats.NsrErrHistory.NsrErrorInfo.LastErrTime, self).__init__()

                                    self.yang_name = "last-err-time"
                                    self.yang_parent_name = "nsr-error-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('second', (YLeaf(YType.uint32, 'second'), ['int'])),
                                        ('nanosecond', (YLeaf(YType.uint32, 'nanosecond'), ['int'])),
                                    ])
                                    self.second = None
                                    self.nanosecond = None
                                    self._segment_path = lambda: "last-err-time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrStats.NsrErrHistory.NsrErrorInfo.LastErrTime, [u'second', u'nanosecond'], name, value)


                class RibThreadStats(Entity):
                    """
                    OSPFv3 RIB thread statistics
                    
                    .. attribute:: thread_q
                    
                    	Inter Thread Queue
                    	**type**\:  :py:class:`ThreadQ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.RibThreadStats.ThreadQ>`
                    
                    .. attribute:: rib_base_time
                    
                    	rib base time
                    	**type**\:  :py:class:`RibBaseTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.RibThreadStats.RibBaseTime>`
                    
                    .. attribute:: wq_thread_active
                    
                    	RIB Thread Active Indicator
                    	**type**\: bool
                    
                    .. attribute:: wq_signals
                    
                    	Signals sent to RIB Thread
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_base_clock
                    
                    	Rib Base Clock
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: rib_batch_sent
                    
                    	No. of Rib batches sent
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_purged
                    
                    	No. of Rib batches purged
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_drop_version
                    
                    	Rib drop version
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_drop_conn
                    
                    	Rib drop connections
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_ok
                    
                    	Rib Batches Ok
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_backup
                    
                    	Rib Batches Back up
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_limit
                    
                    	Rib Batches Limit
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_no_table
                    
                    	Batches no table
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_some_err
                    
                    	Batches with some error
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_batch_err
                    
                    	Batch errors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_route_limit
                    
                    	Route table limit
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_route_some_err
                    
                    	Route some errors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_route_err
                    
                    	Route Errors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_path_limit
                    
                    	Route path limits
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_path_err
                    
                    	Route path errors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rib_max_latency
                    
                    	Max time entry was in queue
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: rib_sum_latency
                    
                    	Sum latencies to calc average
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: holdq
                    
                    	holdq
                    	**type**\: list of  		 :py:class:`Holdq <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.RibThreadStats.Holdq>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Statistics.RibThreadStats, self).__init__()

                        self.yang_name = "rib-thread-stats"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("thread-q", ("thread_q", Ospfv3.Processes.Process.Statistics.RibThreadStats.ThreadQ)), ("rib-base-time", ("rib_base_time", Ospfv3.Processes.Process.Statistics.RibThreadStats.RibBaseTime)), ("holdq", ("holdq", Ospfv3.Processes.Process.Statistics.RibThreadStats.Holdq))])
                        self._leafs = OrderedDict([
                            ('wq_thread_active', (YLeaf(YType.boolean, 'wq-thread-active'), ['bool'])),
                            ('wq_signals', (YLeaf(YType.uint32, 'wq-signals'), ['int'])),
                            ('rib_base_clock', (YLeaf(YType.uint64, 'rib-base-clock'), ['int'])),
                            ('rib_batch_sent', (YLeaf(YType.uint32, 'rib-batch-sent'), ['int'])),
                            ('rib_batch_purged', (YLeaf(YType.uint32, 'rib-batch-purged'), ['int'])),
                            ('rib_drop_version', (YLeaf(YType.uint32, 'rib-drop-version'), ['int'])),
                            ('rib_drop_conn', (YLeaf(YType.uint32, 'rib-drop-conn'), ['int'])),
                            ('rib_batch_ok', (YLeaf(YType.uint32, 'rib-batch-ok'), ['int'])),
                            ('rib_batch_backup', (YLeaf(YType.uint32, 'rib-batch-backup'), ['int'])),
                            ('rib_batch_limit', (YLeaf(YType.uint32, 'rib-batch-limit'), ['int'])),
                            ('rib_batch_no_table', (YLeaf(YType.uint32, 'rib-batch-no-table'), ['int'])),
                            ('rib_batch_some_err', (YLeaf(YType.uint32, 'rib-batch-some-err'), ['int'])),
                            ('rib_batch_err', (YLeaf(YType.uint32, 'rib-batch-err'), ['int'])),
                            ('rib_route_limit', (YLeaf(YType.uint32, 'rib-route-limit'), ['int'])),
                            ('rib_route_some_err', (YLeaf(YType.uint32, 'rib-route-some-err'), ['int'])),
                            ('rib_route_err', (YLeaf(YType.uint32, 'rib-route-err'), ['int'])),
                            ('rib_path_limit', (YLeaf(YType.uint32, 'rib-path-limit'), ['int'])),
                            ('rib_path_err', (YLeaf(YType.uint32, 'rib-path-err'), ['int'])),
                            ('rib_max_latency', (YLeaf(YType.uint64, 'rib-max-latency'), ['int'])),
                            ('rib_sum_latency', (YLeaf(YType.uint64, 'rib-sum-latency'), ['int'])),
                        ])
                        self.wq_thread_active = None
                        self.wq_signals = None
                        self.rib_base_clock = None
                        self.rib_batch_sent = None
                        self.rib_batch_purged = None
                        self.rib_drop_version = None
                        self.rib_drop_conn = None
                        self.rib_batch_ok = None
                        self.rib_batch_backup = None
                        self.rib_batch_limit = None
                        self.rib_batch_no_table = None
                        self.rib_batch_some_err = None
                        self.rib_batch_err = None
                        self.rib_route_limit = None
                        self.rib_route_some_err = None
                        self.rib_route_err = None
                        self.rib_path_limit = None
                        self.rib_path_err = None
                        self.rib_max_latency = None
                        self.rib_sum_latency = None

                        self.thread_q = Ospfv3.Processes.Process.Statistics.RibThreadStats.ThreadQ()
                        self.thread_q.parent = self
                        self._children_name_map["thread_q"] = "thread-q"

                        self.rib_base_time = Ospfv3.Processes.Process.Statistics.RibThreadStats.RibBaseTime()
                        self.rib_base_time.parent = self
                        self._children_name_map["rib_base_time"] = "rib-base-time"

                        self.holdq = YList(self)
                        self._segment_path = lambda: "rib-thread-stats"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Statistics.RibThreadStats, [u'wq_thread_active', u'wq_signals', u'rib_base_clock', u'rib_batch_sent', u'rib_batch_purged', u'rib_drop_version', u'rib_drop_conn', u'rib_batch_ok', u'rib_batch_backup', u'rib_batch_limit', u'rib_batch_no_table', u'rib_batch_some_err', u'rib_batch_err', u'rib_route_limit', u'rib_route_some_err', u'rib_route_err', u'rib_path_limit', u'rib_path_err', u'rib_max_latency', u'rib_sum_latency'], name, value)


                    class ThreadQ(Entity):
                        """
                        Inter Thread Queue
                        
                        .. attribute:: wq_eqtime
                        
                        	Head Entry Enqueue
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_dqtime
                        
                        	Last Entry Dequeue
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_first_eqtime
                        
                        	First Entry Enqueue
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_len_cur
                        
                        	Current Work Queue Length
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: wq_len_max
                        
                        	Largest Work Queue Length
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: wq_total_enqueued
                        
                        	Total Entries Enqueued
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_total_dequeued
                        
                        	Total Entries Dequeued
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_eneueue_errs
                        
                        	Enqueue Errors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_dequeue_errs
                        
                        	Dequeue Errors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_max_latency
                        
                        	Max Time Entry Was In Q
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_sum_latency
                        
                        	Sum Latencies To Calc Average
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.RibThreadStats.ThreadQ, self).__init__()

                            self.yang_name = "thread-q"
                            self.yang_parent_name = "rib-thread-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('wq_eqtime', (YLeaf(YType.uint64, 'wq-eqtime'), ['int'])),
                                ('wq_dqtime', (YLeaf(YType.uint64, 'wq-dqtime'), ['int'])),
                                ('wq_first_eqtime', (YLeaf(YType.uint64, 'wq-first-eqtime'), ['int'])),
                                ('wq_len_cur', (YLeaf(YType.int32, 'wq-len-cur'), ['int'])),
                                ('wq_len_max', (YLeaf(YType.int32, 'wq-len-max'), ['int'])),
                                ('wq_total_enqueued', (YLeaf(YType.uint32, 'wq-total-enqueued'), ['int'])),
                                ('wq_total_dequeued', (YLeaf(YType.uint32, 'wq-total-dequeued'), ['int'])),
                                ('wq_eneueue_errs', (YLeaf(YType.uint32, 'wq-eneueue-errs'), ['int'])),
                                ('wq_dequeue_errs', (YLeaf(YType.uint32, 'wq-dequeue-errs'), ['int'])),
                                ('wq_max_latency', (YLeaf(YType.uint64, 'wq-max-latency'), ['int'])),
                                ('wq_sum_latency', (YLeaf(YType.uint64, 'wq-sum-latency'), ['int'])),
                            ])
                            self.wq_eqtime = None
                            self.wq_dqtime = None
                            self.wq_first_eqtime = None
                            self.wq_len_cur = None
                            self.wq_len_max = None
                            self.wq_total_enqueued = None
                            self.wq_total_dequeued = None
                            self.wq_eneueue_errs = None
                            self.wq_dequeue_errs = None
                            self.wq_max_latency = None
                            self.wq_sum_latency = None
                            self._segment_path = lambda: "thread-q"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.RibThreadStats.ThreadQ, [u'wq_eqtime', u'wq_dqtime', u'wq_first_eqtime', u'wq_len_cur', u'wq_len_max', u'wq_total_enqueued', u'wq_total_dequeued', u'wq_eneueue_errs', u'wq_dequeue_errs', u'wq_max_latency', u'wq_sum_latency'], name, value)


                    class RibBaseTime(Entity):
                        """
                        rib base time
                        
                        .. attribute:: second
                        
                        	Seconds 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: nanosecond
                        
                        	Nano seconds 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.RibThreadStats.RibBaseTime, self).__init__()

                            self.yang_name = "rib-base-time"
                            self.yang_parent_name = "rib-thread-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('second', (YLeaf(YType.uint32, 'second'), ['int'])),
                                ('nanosecond', (YLeaf(YType.uint32, 'nanosecond'), ['int'])),
                            ])
                            self.second = None
                            self.nanosecond = None
                            self._segment_path = lambda: "rib-base-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.RibThreadStats.RibBaseTime, [u'second', u'nanosecond'], name, value)


                    class Holdq(Entity):
                        """
                        holdq
                        
                        .. attribute:: wq_eqtime
                        
                        	Head Entry Enqueue
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_dqtime
                        
                        	Last Entry Dequeue
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_first_eqtime
                        
                        	First Entry Enqueue
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_len_cur
                        
                        	Current Work Queue Length
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: wq_len_max
                        
                        	Largest Work Queue Length
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: wq_total_enqueued
                        
                        	Total Entries Enqueued
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_total_dequeued
                        
                        	Total Entries Dequeued
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_eneueue_errs
                        
                        	Enqueue Errors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_dequeue_errs
                        
                        	Dequeue Errors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wq_max_latency
                        
                        	Max Time Entry Was In Q
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: wq_sum_latency
                        
                        	Sum Latencies To Calc Average
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.RibThreadStats.Holdq, self).__init__()

                            self.yang_name = "holdq"
                            self.yang_parent_name = "rib-thread-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('wq_eqtime', (YLeaf(YType.uint64, 'wq-eqtime'), ['int'])),
                                ('wq_dqtime', (YLeaf(YType.uint64, 'wq-dqtime'), ['int'])),
                                ('wq_first_eqtime', (YLeaf(YType.uint64, 'wq-first-eqtime'), ['int'])),
                                ('wq_len_cur', (YLeaf(YType.int32, 'wq-len-cur'), ['int'])),
                                ('wq_len_max', (YLeaf(YType.int32, 'wq-len-max'), ['int'])),
                                ('wq_total_enqueued', (YLeaf(YType.uint32, 'wq-total-enqueued'), ['int'])),
                                ('wq_total_dequeued', (YLeaf(YType.uint32, 'wq-total-dequeued'), ['int'])),
                                ('wq_eneueue_errs', (YLeaf(YType.uint32, 'wq-eneueue-errs'), ['int'])),
                                ('wq_dequeue_errs', (YLeaf(YType.uint32, 'wq-dequeue-errs'), ['int'])),
                                ('wq_max_latency', (YLeaf(YType.uint64, 'wq-max-latency'), ['int'])),
                                ('wq_sum_latency', (YLeaf(YType.uint64, 'wq-sum-latency'), ['int'])),
                            ])
                            self.wq_eqtime = None
                            self.wq_dqtime = None
                            self.wq_first_eqtime = None
                            self.wq_len_cur = None
                            self.wq_len_max = None
                            self.wq_total_enqueued = None
                            self.wq_total_dequeued = None
                            self.wq_eneueue_errs = None
                            self.wq_dequeue_errs = None
                            self.wq_max_latency = None
                            self.wq_sum_latency = None
                            self._segment_path = lambda: "holdq"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.RibThreadStats.Holdq, [u'wq_eqtime', u'wq_dqtime', u'wq_first_eqtime', u'wq_len_cur', u'wq_len_max', u'wq_total_enqueued', u'wq_total_dequeued', u'wq_eneueue_errs', u'wq_dequeue_errs', u'wq_max_latency', u'wq_sum_latency'], name, value)


                class IssuStats(Entity):
                    """
                    OSPF ISSU statistics
                    
                    .. attribute:: nsr_thd_stats
                    
                    	NSR thread scheduler stats
                    	**type**\:  :py:class:`NsrThdStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats>`
                    
                    .. attribute:: nsr_rtr_thd_sched
                    
                    	Rtr thread NSR pulse handler stats
                    	**type**\:  :py:class:`NsrRtrThdSched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched>`
                    
                    .. attribute:: nsr_revision
                    
                    	NSR revision
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_fsm_state
                    
                    	FSM state
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_version
                    
                    	NSR version
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_node_id
                    
                    	My nodeid
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_peer_version
                    
                    	Partner NSR version
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_peer_node_id
                    
                    	Partner NodeID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_mtu
                    
                    	Fabric MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_nbr_qad_qid
                    
                    	NBR QAD queue id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_lsa_qad_qid
                    
                    	LSA QAD queue id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_nbr_qad_mdata_count
                    
                    	NBR QAD pending msg
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_lsa_qad_mdata_count
                    
                    	LSA QAD pending msgs
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_nbr_init_sync_pend_count
                    
                    	Pending init\-sync NBR msgs
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_lsa_init_sync_pend_count
                    
                    	Pending init\-sync LSA msgs
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_nbr_seq_no
                    
                    	Neighbor TLV sequence no
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_intf_seq_no
                    
                    	Interface TLV sequence no
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_tmr_quant
                    
                    	Timers processed per pulse
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: nsr_conn_to_active_attempts
                    
                    	Attempts to connect to active
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_fails
                    
                    	Failures to connect to active
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_opens
                    
                    	Conn to active opens
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_closes
                    
                    	Conn to active closes
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_conn_to_active_errors
                    
                    	Conn to active errors
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: nsr_fsm_flag
                    
                    	Nsr Fsm Flags information
                    	**type**\: list of str
                    
                    .. attribute:: nsr_fsm_running_timer
                    
                    	Nsr Fsm Running Timers
                    	**type**\: list of str
                    
                    .. attribute:: nsr_issu_milestone
                    
                    	Nsr Issu Milestones
                    	**type**\: list of  		 :py:class:`NsrIssuMilestone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats.NsrIssuMilestone>`
                    
                    .. attribute:: nsr_err_history
                    
                    	Nsr Error History List
                    	**type**\: list of  		 :py:class:`NsrErrHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats.NsrErrHistory>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Statistics.IssuStats, self).__init__()

                        self.yang_name = "issu-stats"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("nsr-thd-stats", ("nsr_thd_stats", Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats)), ("nsr-rtr-thd-sched", ("nsr_rtr_thd_sched", Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched)), ("nsr-issu-milestone", ("nsr_issu_milestone", Ospfv3.Processes.Process.Statistics.IssuStats.NsrIssuMilestone)), ("nsr-err-history", ("nsr_err_history", Ospfv3.Processes.Process.Statistics.IssuStats.NsrErrHistory))])
                        self._leafs = OrderedDict([
                            ('nsr_revision', (YLeaf(YType.int32, 'nsr-revision'), ['int'])),
                            ('nsr_fsm_state', (YLeaf(YType.int32, 'nsr-fsm-state'), ['int'])),
                            ('nsr_version', (YLeaf(YType.uint32, 'nsr-version'), ['int'])),
                            ('nsr_node_id', (YLeaf(YType.uint32, 'nsr-node-id'), ['int'])),
                            ('nsr_peer_version', (YLeaf(YType.uint32, 'nsr-peer-version'), ['int'])),
                            ('nsr_peer_node_id', (YLeaf(YType.uint32, 'nsr-peer-node-id'), ['int'])),
                            ('nsr_mtu', (YLeaf(YType.uint32, 'nsr-mtu'), ['int'])),
                            ('nsr_nbr_qad_qid', (YLeaf(YType.uint32, 'nsr-nbr-qad-qid'), ['int'])),
                            ('nsr_lsa_qad_qid', (YLeaf(YType.uint32, 'nsr-lsa-qad-qid'), ['int'])),
                            ('nsr_nbr_qad_mdata_count', (YLeaf(YType.uint32, 'nsr-nbr-qad-mdata-count'), ['int'])),
                            ('nsr_lsa_qad_mdata_count', (YLeaf(YType.uint32, 'nsr-lsa-qad-mdata-count'), ['int'])),
                            ('nsr_nbr_init_sync_pend_count', (YLeaf(YType.int32, 'nsr-nbr-init-sync-pend-count'), ['int'])),
                            ('nsr_lsa_init_sync_pend_count', (YLeaf(YType.int32, 'nsr-lsa-init-sync-pend-count'), ['int'])),
                            ('nsr_nbr_seq_no', (YLeaf(YType.uint32, 'nsr-nbr-seq-no'), ['int'])),
                            ('nsr_intf_seq_no', (YLeaf(YType.uint32, 'nsr-intf-seq-no'), ['int'])),
                            ('nsr_tmr_quant', (YLeaf(YType.int32, 'nsr-tmr-quant'), ['int'])),
                            ('nsr_conn_to_active_attempts', (YLeaf(YType.uint64, 'nsr-conn-to-active-attempts'), ['int'])),
                            ('nsr_conn_to_active_fails', (YLeaf(YType.uint64, 'nsr-conn-to-active-fails'), ['int'])),
                            ('nsr_conn_to_active_opens', (YLeaf(YType.uint64, 'nsr-conn-to-active-opens'), ['int'])),
                            ('nsr_conn_to_active_closes', (YLeaf(YType.uint64, 'nsr-conn-to-active-closes'), ['int'])),
                            ('nsr_conn_to_active_errors', (YLeaf(YType.uint64, 'nsr-conn-to-active-errors'), ['int'])),
                            ('nsr_fsm_flag', (YLeafList(YType.str, 'nsr-fsm-flag'), ['str'])),
                            ('nsr_fsm_running_timer', (YLeafList(YType.str, 'nsr-fsm-running-timer'), ['str'])),
                        ])
                        self.nsr_revision = None
                        self.nsr_fsm_state = None
                        self.nsr_version = None
                        self.nsr_node_id = None
                        self.nsr_peer_version = None
                        self.nsr_peer_node_id = None
                        self.nsr_mtu = None
                        self.nsr_nbr_qad_qid = None
                        self.nsr_lsa_qad_qid = None
                        self.nsr_nbr_qad_mdata_count = None
                        self.nsr_lsa_qad_mdata_count = None
                        self.nsr_nbr_init_sync_pend_count = None
                        self.nsr_lsa_init_sync_pend_count = None
                        self.nsr_nbr_seq_no = None
                        self.nsr_intf_seq_no = None
                        self.nsr_tmr_quant = None
                        self.nsr_conn_to_active_attempts = None
                        self.nsr_conn_to_active_fails = None
                        self.nsr_conn_to_active_opens = None
                        self.nsr_conn_to_active_closes = None
                        self.nsr_conn_to_active_errors = None
                        self.nsr_fsm_flag = []
                        self.nsr_fsm_running_timer = []

                        self.nsr_thd_stats = Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats()
                        self.nsr_thd_stats.parent = self
                        self._children_name_map["nsr_thd_stats"] = "nsr-thd-stats"

                        self.nsr_rtr_thd_sched = Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched()
                        self.nsr_rtr_thd_sched.parent = self
                        self._children_name_map["nsr_rtr_thd_sched"] = "nsr-rtr-thd-sched"

                        self.nsr_issu_milestone = YList(self)
                        self.nsr_err_history = YList(self)
                        self._segment_path = lambda: "issu-stats"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Statistics.IssuStats, [u'nsr_revision', u'nsr_fsm_state', u'nsr_version', u'nsr_node_id', u'nsr_peer_version', u'nsr_peer_node_id', u'nsr_mtu', u'nsr_nbr_qad_qid', u'nsr_lsa_qad_qid', u'nsr_nbr_qad_mdata_count', u'nsr_lsa_qad_mdata_count', u'nsr_nbr_init_sync_pend_count', u'nsr_lsa_init_sync_pend_count', u'nsr_nbr_seq_no', u'nsr_intf_seq_no', u'nsr_tmr_quant', u'nsr_conn_to_active_attempts', u'nsr_conn_to_active_fails', u'nsr_conn_to_active_opens', u'nsr_conn_to_active_closes', u'nsr_conn_to_active_errors', u'nsr_fsm_flag', u'nsr_fsm_running_timer'], name, value)


                    class NsrThdStats(Entity):
                        """
                        NSR thread scheduler stats
                        
                        .. attribute:: nsr_pulse_quant
                        
                        	Events processed per pulse
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_events_in_q
                        
                        	Events pending
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_events_tx
                        
                        	Events to Router thread
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_rx
                        
                        	Events processed
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_bad_pulses_rx
                        
                        	Bad pulses received
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_good_pulses_rx
                        
                        	Good pulses received
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pulses_tx
                        
                        	Pulses to Router thread
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pulse_tx_fails
                        
                        	Pulse send failures
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pri
                        
                        	nsr pri
                        	**type**\: list of  		 :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats.NsrPri>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats, self).__init__()

                            self.yang_name = "nsr-thd-stats"
                            self.yang_parent_name = "issu-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nsr-pri", ("nsr_pri", Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats.NsrPri))])
                            self._leafs = OrderedDict([
                                ('nsr_pulse_quant', (YLeaf(YType.int32, 'nsr-pulse-quant'), ['int'])),
                                ('nsr_events_in_q', (YLeaf(YType.uint32, 'nsr-events-in-q'), ['int'])),
                                ('nsr_events_tx', (YLeaf(YType.uint64, 'nsr-events-tx'), ['int'])),
                                ('nsr_events_rx', (YLeaf(YType.uint64, 'nsr-events-rx'), ['int'])),
                                ('nsr_bad_pulses_rx', (YLeaf(YType.uint64, 'nsr-bad-pulses-rx'), ['int'])),
                                ('nsr_good_pulses_rx', (YLeaf(YType.uint64, 'nsr-good-pulses-rx'), ['int'])),
                                ('nsr_pulses_tx', (YLeaf(YType.uint64, 'nsr-pulses-tx'), ['int'])),
                                ('nsr_pulse_tx_fails', (YLeaf(YType.uint64, 'nsr-pulse-tx-fails'), ['int'])),
                            ])
                            self.nsr_pulse_quant = None
                            self.nsr_events_in_q = None
                            self.nsr_events_tx = None
                            self.nsr_events_rx = None
                            self.nsr_bad_pulses_rx = None
                            self.nsr_good_pulses_rx = None
                            self.nsr_pulses_tx = None
                            self.nsr_pulse_tx_fails = None

                            self.nsr_pri = YList(self)
                            self._segment_path = lambda: "nsr-thd-stats"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats, [u'nsr_pulse_quant', u'nsr_events_in_q', u'nsr_events_tx', u'nsr_events_rx', u'nsr_bad_pulses_rx', u'nsr_good_pulses_rx', u'nsr_pulses_tx', u'nsr_pulse_tx_fails'], name, value)


                        class NsrPri(Entity):
                            """
                            nsr pri
                            
                            .. attribute:: nsr_sched_pri
                            
                            	Priority Type
                            	**type**\:  :py:class:`OspfNsrSchedPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfNsrSchedPri>`
                            
                            .. attribute:: nsr_sched_quant
                            
                            	Priority Queue
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_sched_remain_quant
                            
                            	Remaining quantum
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_sched_evs_in_q
                            
                            	Events pending
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_max_evs
                            
                            	Max Queued
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_peak_q_len
                            
                            	Peak queue length
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_evs_qd
                            
                            	Events queued
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_enq_fails
                            
                            	Event enqueue fails
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_deqd
                            
                            	Events dequeued
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats.NsrPri, self).__init__()

                                self.yang_name = "nsr-pri"
                                self.yang_parent_name = "nsr-thd-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('nsr_sched_pri', (YLeaf(YType.enumeration, 'nsr-sched-pri'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfNsrSchedPri', '')])),
                                    ('nsr_sched_quant', (YLeaf(YType.uint8, 'nsr-sched-quant'), ['int'])),
                                    ('nsr_sched_remain_quant', (YLeaf(YType.uint8, 'nsr-sched-remain-quant'), ['int'])),
                                    ('nsr_sched_evs_in_q', (YLeaf(YType.uint16, 'nsr-sched-evs-in-q'), ['int'])),
                                    ('nsr_sched_max_evs', (YLeaf(YType.uint16, 'nsr-sched-max-evs'), ['int'])),
                                    ('nsr_sched_peak_q_len', (YLeaf(YType.uint16, 'nsr-sched-peak-q-len'), ['int'])),
                                    ('nsr_sched_evs_qd', (YLeaf(YType.uint64, 'nsr-sched-evs-qd'), ['int'])),
                                    ('nsr_sched_enq_fails', (YLeaf(YType.uint64, 'nsr-sched-enq-fails'), ['int'])),
                                    ('nsr_sched_evs_deqd', (YLeaf(YType.uint64, 'nsr-sched-evs-deqd'), ['int'])),
                                ])
                                self.nsr_sched_pri = None
                                self.nsr_sched_quant = None
                                self.nsr_sched_remain_quant = None
                                self.nsr_sched_evs_in_q = None
                                self.nsr_sched_max_evs = None
                                self.nsr_sched_peak_q_len = None
                                self.nsr_sched_evs_qd = None
                                self.nsr_sched_enq_fails = None
                                self.nsr_sched_evs_deqd = None
                                self._segment_path = lambda: "nsr-pri"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.IssuStats.NsrThdStats.NsrPri, [u'nsr_sched_pri', u'nsr_sched_quant', u'nsr_sched_remain_quant', u'nsr_sched_evs_in_q', u'nsr_sched_max_evs', u'nsr_sched_peak_q_len', u'nsr_sched_evs_qd', u'nsr_sched_enq_fails', u'nsr_sched_evs_deqd'], name, value)


                    class NsrRtrThdSched(Entity):
                        """
                        Rtr thread NSR pulse handler stats
                        
                        .. attribute:: nsr_pulse_quant
                        
                        	Events processed per pulse
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_events_in_q
                        
                        	Events pending
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_events_tx
                        
                        	Events to Router thread
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_events_rx
                        
                        	Events processed
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_bad_pulses_rx
                        
                        	Bad pulses received
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_good_pulses_rx
                        
                        	Good pulses received
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pulses_tx
                        
                        	Pulses to Router thread
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pulse_tx_fails
                        
                        	Pulse send failures
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: nsr_pri
                        
                        	nsr pri
                        	**type**\: list of  		 :py:class:`NsrPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched.NsrPri>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched, self).__init__()

                            self.yang_name = "nsr-rtr-thd-sched"
                            self.yang_parent_name = "issu-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nsr-pri", ("nsr_pri", Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched.NsrPri))])
                            self._leafs = OrderedDict([
                                ('nsr_pulse_quant', (YLeaf(YType.int32, 'nsr-pulse-quant'), ['int'])),
                                ('nsr_events_in_q', (YLeaf(YType.uint32, 'nsr-events-in-q'), ['int'])),
                                ('nsr_events_tx', (YLeaf(YType.uint64, 'nsr-events-tx'), ['int'])),
                                ('nsr_events_rx', (YLeaf(YType.uint64, 'nsr-events-rx'), ['int'])),
                                ('nsr_bad_pulses_rx', (YLeaf(YType.uint64, 'nsr-bad-pulses-rx'), ['int'])),
                                ('nsr_good_pulses_rx', (YLeaf(YType.uint64, 'nsr-good-pulses-rx'), ['int'])),
                                ('nsr_pulses_tx', (YLeaf(YType.uint64, 'nsr-pulses-tx'), ['int'])),
                                ('nsr_pulse_tx_fails', (YLeaf(YType.uint64, 'nsr-pulse-tx-fails'), ['int'])),
                            ])
                            self.nsr_pulse_quant = None
                            self.nsr_events_in_q = None
                            self.nsr_events_tx = None
                            self.nsr_events_rx = None
                            self.nsr_bad_pulses_rx = None
                            self.nsr_good_pulses_rx = None
                            self.nsr_pulses_tx = None
                            self.nsr_pulse_tx_fails = None

                            self.nsr_pri = YList(self)
                            self._segment_path = lambda: "nsr-rtr-thd-sched"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched, [u'nsr_pulse_quant', u'nsr_events_in_q', u'nsr_events_tx', u'nsr_events_rx', u'nsr_bad_pulses_rx', u'nsr_good_pulses_rx', u'nsr_pulses_tx', u'nsr_pulse_tx_fails'], name, value)


                        class NsrPri(Entity):
                            """
                            nsr pri
                            
                            .. attribute:: nsr_sched_pri
                            
                            	Priority Type
                            	**type**\:  :py:class:`OspfNsrSchedPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfNsrSchedPri>`
                            
                            .. attribute:: nsr_sched_quant
                            
                            	Priority Queue
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_sched_remain_quant
                            
                            	Remaining quantum
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: nsr_sched_evs_in_q
                            
                            	Events pending
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_max_evs
                            
                            	Max Queued
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_peak_q_len
                            
                            	Peak queue length
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: nsr_sched_evs_qd
                            
                            	Events queued
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_enq_fails
                            
                            	Event enqueue fails
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: nsr_sched_evs_deqd
                            
                            	Events dequeued
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched.NsrPri, self).__init__()

                                self.yang_name = "nsr-pri"
                                self.yang_parent_name = "nsr-rtr-thd-sched"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('nsr_sched_pri', (YLeaf(YType.enumeration, 'nsr-sched-pri'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfNsrSchedPri', '')])),
                                    ('nsr_sched_quant', (YLeaf(YType.uint8, 'nsr-sched-quant'), ['int'])),
                                    ('nsr_sched_remain_quant', (YLeaf(YType.uint8, 'nsr-sched-remain-quant'), ['int'])),
                                    ('nsr_sched_evs_in_q', (YLeaf(YType.uint16, 'nsr-sched-evs-in-q'), ['int'])),
                                    ('nsr_sched_max_evs', (YLeaf(YType.uint16, 'nsr-sched-max-evs'), ['int'])),
                                    ('nsr_sched_peak_q_len', (YLeaf(YType.uint16, 'nsr-sched-peak-q-len'), ['int'])),
                                    ('nsr_sched_evs_qd', (YLeaf(YType.uint64, 'nsr-sched-evs-qd'), ['int'])),
                                    ('nsr_sched_enq_fails', (YLeaf(YType.uint64, 'nsr-sched-enq-fails'), ['int'])),
                                    ('nsr_sched_evs_deqd', (YLeaf(YType.uint64, 'nsr-sched-evs-deqd'), ['int'])),
                                ])
                                self.nsr_sched_pri = None
                                self.nsr_sched_quant = None
                                self.nsr_sched_remain_quant = None
                                self.nsr_sched_evs_in_q = None
                                self.nsr_sched_max_evs = None
                                self.nsr_sched_peak_q_len = None
                                self.nsr_sched_evs_qd = None
                                self.nsr_sched_enq_fails = None
                                self.nsr_sched_evs_deqd = None
                                self._segment_path = lambda: "nsr-pri"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.IssuStats.NsrRtrThdSched.NsrPri, [u'nsr_sched_pri', u'nsr_sched_quant', u'nsr_sched_remain_quant', u'nsr_sched_evs_in_q', u'nsr_sched_max_evs', u'nsr_sched_peak_q_len', u'nsr_sched_evs_qd', u'nsr_sched_enq_fails', u'nsr_sched_evs_deqd'], name, value)


                    class NsrIssuMilestone(Entity):
                        """
                        Nsr Issu Milestones
                        
                        .. attribute:: milestone_name
                        
                        	Milestone Name
                        	**type**\: str
                        
                        .. attribute:: milestone_status
                        
                        	Milestone Status
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.IssuStats.NsrIssuMilestone, self).__init__()

                            self.yang_name = "nsr-issu-milestone"
                            self.yang_parent_name = "issu-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('milestone_name', (YLeaf(YType.str, 'milestone-name'), ['str'])),
                                ('milestone_status', (YLeaf(YType.str, 'milestone-status'), ['str'])),
                            ])
                            self.milestone_name = None
                            self.milestone_status = None
                            self._segment_path = lambda: "nsr-issu-milestone"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.IssuStats.NsrIssuMilestone, [u'milestone_name', u'milestone_status'], name, value)


                    class NsrErrHistory(Entity):
                        """
                        Nsr Error History List
                        
                        .. attribute:: nsr_revisionversion
                        
                        	Nsr Revision version
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_errors
                        
                        	Total errors for this nsr revision version
                        	**type**\: int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: nsr_error_info
                        
                        	List of erros
                        	**type**\: list of  		 :py:class:`NsrErrorInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats.NsrErrHistory.NsrErrorInfo>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.IssuStats.NsrErrHistory, self).__init__()

                            self.yang_name = "nsr-err-history"
                            self.yang_parent_name = "issu-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("nsr-error-info", ("nsr_error_info", Ospfv3.Processes.Process.Statistics.IssuStats.NsrErrHistory.NsrErrorInfo))])
                            self._leafs = OrderedDict([
                                ('nsr_revisionversion', (YLeaf(YType.uint32, 'nsr-revisionversion'), ['int'])),
                                ('total_errors', (YLeaf(YType.int32, 'total-errors'), ['int'])),
                            ])
                            self.nsr_revisionversion = None
                            self.total_errors = None

                            self.nsr_error_info = YList(self)
                            self._segment_path = lambda: "nsr-err-history"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.IssuStats.NsrErrHistory, [u'nsr_revisionversion', u'total_errors'], name, value)


                        class NsrErrorInfo(Entity):
                            """
                            List of erros
                            
                            .. attribute:: last_err_time
                            
                            	Time this error was last hit
                            	**type**\:  :py:class:`LastErrTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.IssuStats.NsrErrHistory.NsrErrorInfo.LastErrTime>`
                            
                            .. attribute:: err_count
                            
                            	Count this error hit during the Nsr Revision
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: err_info_string
                            
                            	Error Information
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.IssuStats.NsrErrHistory.NsrErrorInfo, self).__init__()

                                self.yang_name = "nsr-error-info"
                                self.yang_parent_name = "nsr-err-history"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("last-err-time", ("last_err_time", Ospfv3.Processes.Process.Statistics.IssuStats.NsrErrHistory.NsrErrorInfo.LastErrTime))])
                                self._leafs = OrderedDict([
                                    ('err_count', (YLeaf(YType.int32, 'err-count'), ['int'])),
                                    ('err_info_string', (YLeaf(YType.str, 'err-info-string'), ['str'])),
                                ])
                                self.err_count = None
                                self.err_info_string = None

                                self.last_err_time = Ospfv3.Processes.Process.Statistics.IssuStats.NsrErrHistory.NsrErrorInfo.LastErrTime()
                                self.last_err_time.parent = self
                                self._children_name_map["last_err_time"] = "last-err-time"
                                self._segment_path = lambda: "nsr-error-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.IssuStats.NsrErrHistory.NsrErrorInfo, [u'err_count', u'err_info_string'], name, value)


                            class LastErrTime(Entity):
                                """
                                Time this error was last hit
                                
                                .. attribute:: second
                                
                                	Seconds 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanosecond
                                
                                	Nano seconds 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Statistics.IssuStats.NsrErrHistory.NsrErrorInfo.LastErrTime, self).__init__()

                                    self.yang_name = "last-err-time"
                                    self.yang_parent_name = "nsr-error-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('second', (YLeaf(YType.uint32, 'second'), ['int'])),
                                        ('nanosecond', (YLeaf(YType.uint32, 'nanosecond'), ['int'])),
                                    ])
                                    self.second = None
                                    self.nanosecond = None
                                    self._segment_path = lambda: "last-err-time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Statistics.IssuStats.NsrErrHistory.NsrErrorInfo.LastErrTime, [u'second', u'nanosecond'], name, value)


                class NsrPlStats(Entity):
                    """
                    OSPF NSR packet library statistics
                    
                    .. attribute:: ncd_pri
                    
                    	ncd pri
                    	**type**\: list of  		 :py:class:`NcdPri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Statistics.NsrPlStats, self).__init__()

                        self.yang_name = "nsr-pl-stats"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ncd-pri", ("ncd_pri", Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri))])
                        self._leafs = OrderedDict()

                        self.ncd_pri = YList(self)
                        self._segment_path = lambda: "nsr-pl-stats"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrPlStats, [], name, value)


                    class NcdPri(Entity):
                        """
                        ncd pri
                        
                        .. attribute:: num_sent
                        
                        	Total sent
                        	**type**\: list of int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: num_recv
                        
                        	Total recvd
                        	**type**\: list of int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: num_sent_drop
                        
                        	Sent Error/drops
                        	**type**\: list of  		 :py:class:`NumSentDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumSentDrop>`
                        
                        .. attribute:: num_recv_drop
                        
                        	Recv Errors/drops
                        	**type**\: list of  		 :py:class:`NumRecvDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumRecvDrop>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri, self).__init__()

                            self.yang_name = "ncd-pri"
                            self.yang_parent_name = "nsr-pl-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("num-sent-drop", ("num_sent_drop", Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumSentDrop)), ("num-recv-drop", ("num_recv_drop", Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumRecvDrop))])
                            self._leafs = OrderedDict([
                                ('num_sent', (YLeafList(YType.uint64, 'num-sent'), ['int'])),
                                ('num_recv', (YLeafList(YType.uint64, 'num-recv'), ['int'])),
                            ])
                            self.num_sent = []
                            self.num_recv = []

                            self.num_sent_drop = YList(self)
                            self.num_recv_drop = YList(self)
                            self._segment_path = lambda: "ncd-pri"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri, [u'num_sent', u'num_recv'], name, value)


                        class NumSentDrop(Entity):
                            """
                            Sent Error/drops
                            
                            .. attribute:: nsr_pl_send_drop_array
                            
                            	nsr pl send drop array
                            	**type**\: list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumSentDrop, self).__init__()

                                self.yang_name = "num-sent-drop"
                                self.yang_parent_name = "ncd-pri"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('nsr_pl_send_drop_array', (YLeafList(YType.uint32, 'nsr-pl-send-drop-array'), ['int'])),
                                ])
                                self.nsr_pl_send_drop_array = []
                                self._segment_path = lambda: "num-sent-drop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumSentDrop, [u'nsr_pl_send_drop_array'], name, value)


                        class NumRecvDrop(Entity):
                            """
                            Recv Errors/drops
                            
                            .. attribute:: nsr_pl_recv_drop_array
                            
                            	nsr pl recv drop array
                            	**type**\: list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumRecvDrop, self).__init__()

                                self.yang_name = "num-recv-drop"
                                self.yang_parent_name = "ncd-pri"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('nsr_pl_recv_drop_array', (YLeafList(YType.uint32, 'nsr-pl-recv-drop-array'), ['int'])),
                                ])
                                self.nsr_pl_recv_drop_array = []
                                self._segment_path = lambda: "num-recv-drop"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.NsrPlStats.NcdPri.NumRecvDrop, [u'nsr_pl_recv_drop_array'], name, value)


                class ProtocolStats(Entity):
                    """
                    Protocol table
                    
                    .. attribute:: protocol_stat
                    
                    	Protocol statistics for an interface
                    	**type**\: list of  		 :py:class:`ProtocolStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.ProtocolStats.ProtocolStat>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Statistics.ProtocolStats, self).__init__()

                        self.yang_name = "protocol-stats"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol-stat", ("protocol_stat", Ospfv3.Processes.Process.Statistics.ProtocolStats.ProtocolStat))])
                        self._leafs = OrderedDict()

                        self.protocol_stat = YList(self)
                        self._segment_path = lambda: "protocol-stats"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Statistics.ProtocolStats, [], name, value)


                    class ProtocolStat(Entity):
                        """
                        Protocol statistics for an interface
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: total_in_packets
                        
                        	Total inputs packets
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_in_packets
                        
                        	Hello packets in
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: dbdes_in_packets
                        
                        	Database Description Packets in
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: dbdes_in_ls_as
                        
                        	Database Description LSAs in
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_req_in_packets
                        
                        	LSA Requests in
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_req_in_ls_as
                        
                        	LS Requests in
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_upd_in_packets
                        
                        	LS Updates Packets in
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_upd_in_ignored
                        
                        	LS Updates ignored
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_upd_in_ls_as
                        
                        	LS Updates LSAs in
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_ack_in_packets
                        
                        	LS Acks Packets in
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_ack_in_ls_as
                        
                        	LS Ack LSAs in
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: total_out_packets
                        
                        	Total Out Packets
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: hello_out_packets
                        
                        	Hello Out Packets
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: dbdes_out_packets
                        
                        	Database Description Packets out
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: dbdes_out_ls_as
                        
                        	Database Description LSAs out
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_req_out_packets
                        
                        	LS Request Packets out
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_req_out_ls_as
                        
                        	LS Reuqests LSAs out
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_upd_out_packets
                        
                        	LS Update Packets out
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_upd_out_ls_as
                        
                        	LS Update LSAs out
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_ack_out_packets
                        
                        	LS Ack Packets out
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: ls_ack_out_ls_as
                        
                        	LS Ack LSAs out
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: dropped_in_gs
                        
                        	Dropped in GS
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: checksum_err
                        
                        	Checksum Errors
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.ProtocolStats.ProtocolStat, self).__init__()

                            self.yang_name = "protocol-stat"
                            self.yang_parent_name = "protocol-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('total_in_packets', (YLeaf(YType.uint64, 'total-in-packets'), ['int'])),
                                ('hello_in_packets', (YLeaf(YType.uint64, 'hello-in-packets'), ['int'])),
                                ('dbdes_in_packets', (YLeaf(YType.uint64, 'dbdes-in-packets'), ['int'])),
                                ('dbdes_in_ls_as', (YLeaf(YType.uint64, 'dbdes-in-ls-as'), ['int'])),
                                ('ls_req_in_packets', (YLeaf(YType.uint64, 'ls-req-in-packets'), ['int'])),
                                ('ls_req_in_ls_as', (YLeaf(YType.uint64, 'ls-req-in-ls-as'), ['int'])),
                                ('ls_upd_in_packets', (YLeaf(YType.uint64, 'ls-upd-in-packets'), ['int'])),
                                ('ls_upd_in_ignored', (YLeaf(YType.uint64, 'ls-upd-in-ignored'), ['int'])),
                                ('ls_upd_in_ls_as', (YLeaf(YType.uint64, 'ls-upd-in-ls-as'), ['int'])),
                                ('ls_ack_in_packets', (YLeaf(YType.uint64, 'ls-ack-in-packets'), ['int'])),
                                ('ls_ack_in_ls_as', (YLeaf(YType.uint64, 'ls-ack-in-ls-as'), ['int'])),
                                ('total_out_packets', (YLeaf(YType.uint64, 'total-out-packets'), ['int'])),
                                ('hello_out_packets', (YLeaf(YType.uint64, 'hello-out-packets'), ['int'])),
                                ('dbdes_out_packets', (YLeaf(YType.uint64, 'dbdes-out-packets'), ['int'])),
                                ('dbdes_out_ls_as', (YLeaf(YType.uint64, 'dbdes-out-ls-as'), ['int'])),
                                ('ls_req_out_packets', (YLeaf(YType.uint64, 'ls-req-out-packets'), ['int'])),
                                ('ls_req_out_ls_as', (YLeaf(YType.uint64, 'ls-req-out-ls-as'), ['int'])),
                                ('ls_upd_out_packets', (YLeaf(YType.uint64, 'ls-upd-out-packets'), ['int'])),
                                ('ls_upd_out_ls_as', (YLeaf(YType.uint64, 'ls-upd-out-ls-as'), ['int'])),
                                ('ls_ack_out_packets', (YLeaf(YType.uint64, 'ls-ack-out-packets'), ['int'])),
                                ('ls_ack_out_ls_as', (YLeaf(YType.uint64, 'ls-ack-out-ls-as'), ['int'])),
                                ('dropped_in_gs', (YLeaf(YType.uint64, 'dropped-in-gs'), ['int'])),
                                ('checksum_err', (YLeaf(YType.uint64, 'checksum-err'), ['int'])),
                            ])
                            self.interface_name = None
                            self.total_in_packets = None
                            self.hello_in_packets = None
                            self.dbdes_in_packets = None
                            self.dbdes_in_ls_as = None
                            self.ls_req_in_packets = None
                            self.ls_req_in_ls_as = None
                            self.ls_upd_in_packets = None
                            self.ls_upd_in_ignored = None
                            self.ls_upd_in_ls_as = None
                            self.ls_ack_in_packets = None
                            self.ls_ack_in_ls_as = None
                            self.total_out_packets = None
                            self.hello_out_packets = None
                            self.dbdes_out_packets = None
                            self.dbdes_out_ls_as = None
                            self.ls_req_out_packets = None
                            self.ls_req_out_ls_as = None
                            self.ls_upd_out_packets = None
                            self.ls_upd_out_ls_as = None
                            self.ls_ack_out_packets = None
                            self.ls_ack_out_ls_as = None
                            self.dropped_in_gs = None
                            self.checksum_err = None
                            self._segment_path = lambda: "protocol-stat" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.ProtocolStats.ProtocolStat, ['interface_name', u'total_in_packets', u'hello_in_packets', u'dbdes_in_packets', u'dbdes_in_ls_as', u'ls_req_in_packets', u'ls_req_in_ls_as', u'ls_upd_in_packets', u'ls_upd_in_ignored', u'ls_upd_in_ls_as', u'ls_ack_in_packets', u'ls_ack_in_ls_as', u'total_out_packets', u'hello_out_packets', u'dbdes_out_packets', u'dbdes_out_ls_as', u'ls_req_out_packets', u'ls_req_out_ls_as', u'ls_upd_out_packets', u'ls_upd_out_ls_as', u'ls_ack_out_packets', u'ls_ack_out_ls_as', u'dropped_in_gs', u'checksum_err'], name, value)


                class SpfStats(Entity):
                    """
                    OSPFv3 RIB batch statistics
                    
                    .. attribute:: spf_header
                    
                    	SPF statistics header
                    	**type**\:  :py:class:`SpfHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader>`
                    
                    .. attribute:: spf_runtime
                    
                    	List of SPF run\-time statistics
                    	**type**\: list of  		 :py:class:`SpfRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Statistics.SpfStats, self).__init__()

                        self.yang_name = "spf-stats"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("spf-header", ("spf_header", Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader)), ("spf-runtime", ("spf_runtime", Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime))])
                        self._leafs = OrderedDict()

                        self.spf_header = Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader()
                        self.spf_header.parent = self
                        self._children_name_map["spf_header"] = "spf-header"

                        self.spf_runtime = YList(self)
                        self._segment_path = lambda: "spf-stats"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Statistics.SpfStats, [], name, value)


                    class SpfHeader(Entity):
                        """
                        SPF statistics header
                        
                        .. attribute:: header_router_id
                        
                        	Router ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: header_sp_fs
                        
                        	Number of SPF calculations
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_summary
                        
                        	List of Areas with SPF statistics
                        	**type**\: list of  		 :py:class:`AreaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader.AreaSummary>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader, self).__init__()

                            self.yang_name = "spf-header"
                            self.yang_parent_name = "spf-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("area-summary", ("area_summary", Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader.AreaSummary))])
                            self._leafs = OrderedDict([
                                ('header_router_id', (YLeaf(YType.str, 'header-router-id'), ['str'])),
                                ('header_sp_fs', (YLeaf(YType.uint32, 'header-sp-fs'), ['int'])),
                            ])
                            self.header_router_id = None
                            self.header_sp_fs = None

                            self.area_summary = YList(self)
                            self._segment_path = lambda: "spf-header"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader, [u'header_router_id', u'header_sp_fs'], name, value)


                        class AreaSummary(Entity):
                            """
                            List of Areas with SPF statistics
                            
                            .. attribute:: area_id
                            
                            	Area ID of the area SPF statistics
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sp_fs
                            
                            	Number of SPF calculations
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader.AreaSummary, self).__init__()

                                self.yang_name = "area-summary"
                                self.yang_parent_name = "spf-header"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('area_id', (YLeaf(YType.uint32, 'area-id'), ['int'])),
                                    ('sp_fs', (YLeaf(YType.uint32, 'sp-fs'), ['int'])),
                                ])
                                self.area_id = None
                                self.sp_fs = None
                                self._segment_path = lambda: "area-summary"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.SpfStats.SpfHeader.AreaSummary, [u'area_id', u'sp_fs'], name, value)


                    class SpfRuntime(Entity):
                        """
                        List of SPF run\-time statistics
                        
                        .. attribute:: global_time
                        
                        	Global SPF times
                        	**type**\:  :py:class:`GlobalTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.GlobalTime>`
                        
                        .. attribute:: start_time
                        
                        	SPF calculation start time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rib_add_routes
                        
                        	Number of routes added to RIB
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rib_delete_routes
                        
                        	Number of routes deleted from RIB
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: reason_flags
                        
                        	Reasons for triggering an SPF calculation Bit 1 \- Router LSA update Bit 2 \- Network LSA update Bit 3 \- Inter\-Area Prefix LSA update Bit 4 \- Inter\-Area Router LSA update Bit 5 \- AS External LSA update Bit 6 \- MOSPF LSA update Bit 7 \- Type 7 AS External LSA update Bit 8 \- Link LSA update Bit 9 \- Prefix LSA update
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: lsa_changes
                        
                        	Number of LSA changes triggering an SPF calculation
                        	**type**\: int
                        
                        	**range:** \-32768..32767
                        
                        .. attribute:: lsa
                        
                        	List of LSAs triggering the SPF calculation
                        	**type**\: list of  		 :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.Lsa>`
                        
                        .. attribute:: area_stat
                        
                        	List of per\-area SPF statistics
                        	**type**\: list of  		 :py:class:`AreaStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime, self).__init__()

                            self.yang_name = "spf-runtime"
                            self.yang_parent_name = "spf-stats"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("global-time", ("global_time", Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.GlobalTime)), ("lsa", ("lsa", Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.Lsa)), ("area-stat", ("area_stat", Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat))])
                            self._leafs = OrderedDict([
                                ('start_time', (YLeaf(YType.uint32, 'start-time'), ['int'])),
                                ('rib_add_routes', (YLeaf(YType.uint32, 'rib-add-routes'), ['int'])),
                                ('rib_delete_routes', (YLeaf(YType.uint32, 'rib-delete-routes'), ['int'])),
                                ('reason_flags', (YLeaf(YType.str, 'reason-flags'), ['str'])),
                                ('lsa_changes', (YLeaf(YType.int16, 'lsa-changes'), ['int'])),
                            ])
                            self.start_time = None
                            self.rib_add_routes = None
                            self.rib_delete_routes = None
                            self.reason_flags = None
                            self.lsa_changes = None

                            self.global_time = Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.GlobalTime()
                            self.global_time.parent = self
                            self._children_name_map["global_time"] = "global-time"

                            self.lsa = YList(self)
                            self.area_stat = YList(self)
                            self._segment_path = lambda: "spf-runtime"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime, [u'start_time', u'rib_add_routes', u'rib_delete_routes', u'reason_flags', u'lsa_changes'], name, value)


                        class GlobalTime(Entity):
                            """
                            Global SPF times
                            
                            .. attribute:: dijkstra
                            
                            	Dijkstra time in msec
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: intra_prefix
                            
                            	Intra\-prefix processing time in msec
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: intra_prefix_del
                            
                            	Intra\-prefix deletion time in msec
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inter_prefix
                            
                            	Inter\-prefix processing time in msec
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: inter_prefix_del
                            
                            	Intra\-prefix deletion time in msec
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: external_prefix
                            
                            	External prefix processing time in msec
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: external_prefix_del
                            
                            	External prefix deletion time in msec
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_add
                            
                            	RIB add processing time in msec
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_del
                            
                            	RIB deletion time in msec
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.GlobalTime, self).__init__()

                                self.yang_name = "global-time"
                                self.yang_parent_name = "spf-runtime"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('dijkstra', (YLeaf(YType.uint32, 'dijkstra'), ['int'])),
                                    ('intra_prefix', (YLeaf(YType.uint32, 'intra-prefix'), ['int'])),
                                    ('intra_prefix_del', (YLeaf(YType.uint32, 'intra-prefix-del'), ['int'])),
                                    ('inter_prefix', (YLeaf(YType.uint32, 'inter-prefix'), ['int'])),
                                    ('inter_prefix_del', (YLeaf(YType.uint32, 'inter-prefix-del'), ['int'])),
                                    ('external_prefix', (YLeaf(YType.uint32, 'external-prefix'), ['int'])),
                                    ('external_prefix_del', (YLeaf(YType.uint32, 'external-prefix-del'), ['int'])),
                                    ('rib_add', (YLeaf(YType.uint32, 'rib-add'), ['int'])),
                                    ('rib_del', (YLeaf(YType.uint32, 'rib-del'), ['int'])),
                                ])
                                self.dijkstra = None
                                self.intra_prefix = None
                                self.intra_prefix_del = None
                                self.inter_prefix = None
                                self.inter_prefix_del = None
                                self.external_prefix = None
                                self.external_prefix_del = None
                                self.rib_add = None
                                self.rib_del = None
                                self._segment_path = lambda: "global-time"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.GlobalTime, [u'dijkstra', u'intra_prefix', u'intra_prefix_del', u'inter_prefix', u'inter_prefix_del', u'external_prefix', u'external_prefix_del', u'rib_add', u'rib_del'], name, value)


                        class Lsa(Entity):
                            """
                            List of LSAs triggering the SPF calculation
                            
                            .. attribute:: lsa_area_id
                            
                            	Area ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_advertising_router
                            
                            	Advertising router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: lsa_id
                            
                            	LSA ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: lsa_type
                            
                            	LSA type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: lsa_flush
                            
                            	If true, the LSA change is a flush
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.Lsa, self).__init__()

                                self.yang_name = "lsa"
                                self.yang_parent_name = "spf-runtime"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lsa_area_id', (YLeaf(YType.uint32, 'lsa-area-id'), ['int'])),
                                    ('lsa_advertising_router', (YLeaf(YType.str, 'lsa-advertising-router'), ['str'])),
                                    ('lsa_id', (YLeaf(YType.str, 'lsa-id'), ['str'])),
                                    ('lsa_type', (YLeaf(YType.uint8, 'lsa-type'), ['int'])),
                                    ('lsa_flush', (YLeaf(YType.boolean, 'lsa-flush'), ['bool'])),
                                ])
                                self.lsa_area_id = None
                                self.lsa_advertising_router = None
                                self.lsa_id = None
                                self.lsa_type = None
                                self.lsa_flush = None
                                self._segment_path = lambda: "lsa"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.Lsa, [u'lsa_area_id', u'lsa_advertising_router', u'lsa_id', u'lsa_type', u'lsa_flush'], name, value)


                        class AreaStat(Entity):
                            """
                            List of per\-area SPF statistics
                            
                            .. attribute:: spf_stat_time
                            
                            	SPF time calculations
                            	**type**\:  :py:class:`SpfStatTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime>`
                            
                            .. attribute:: spf_stat_area_id
                            
                            	Area ID for area of these SPF statistics
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: spf_stat_lsa_type_count
                            
                            	Counts of LSA types triggering an SPF calculation
                            	**type**\: list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat, self).__init__()

                                self.yang_name = "area-stat"
                                self.yang_parent_name = "spf-runtime"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("spf-stat-time", ("spf_stat_time", Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime))])
                                self._leafs = OrderedDict([
                                    ('spf_stat_area_id', (YLeaf(YType.uint32, 'spf-stat-area-id'), ['int'])),
                                    ('spf_stat_lsa_type_count', (YLeafList(YType.uint32, 'spf-stat-lsa-type-count'), ['int'])),
                                ])
                                self.spf_stat_area_id = None
                                self.spf_stat_lsa_type_count = []

                                self.spf_stat_time = Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime()
                                self.spf_stat_time.parent = self
                                self._children_name_map["spf_stat_time"] = "spf-stat-time"
                                self._segment_path = lambda: "area-stat"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat, [u'spf_stat_area_id', u'spf_stat_lsa_type_count'], name, value)


                            class SpfStatTime(Entity):
                                """
                                SPF time calculations
                                
                                .. attribute:: dijkstra
                                
                                	Dijkstra time in msec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: intra_prefix
                                
                                	Intra\-prefix processing time in msec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: intra_prefix_del
                                
                                	Intra\-prefix deletion time in msec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inter_prefix
                                
                                	Inter\-prefix processing time in msec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inter_prefix_del
                                
                                	Intra\-prefix deletion time in msec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_prefix
                                
                                	External prefix processing time in msec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_prefix_del
                                
                                	External prefix deletion time in msec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_add
                                
                                	RIB add processing time in msec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_del
                                
                                	RIB deletion time in msec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime, self).__init__()

                                    self.yang_name = "spf-stat-time"
                                    self.yang_parent_name = "area-stat"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dijkstra', (YLeaf(YType.uint32, 'dijkstra'), ['int'])),
                                        ('intra_prefix', (YLeaf(YType.uint32, 'intra-prefix'), ['int'])),
                                        ('intra_prefix_del', (YLeaf(YType.uint32, 'intra-prefix-del'), ['int'])),
                                        ('inter_prefix', (YLeaf(YType.uint32, 'inter-prefix'), ['int'])),
                                        ('inter_prefix_del', (YLeaf(YType.uint32, 'inter-prefix-del'), ['int'])),
                                        ('external_prefix', (YLeaf(YType.uint32, 'external-prefix'), ['int'])),
                                        ('external_prefix_del', (YLeaf(YType.uint32, 'external-prefix-del'), ['int'])),
                                        ('rib_add', (YLeaf(YType.uint32, 'rib-add'), ['int'])),
                                        ('rib_del', (YLeaf(YType.uint32, 'rib-del'), ['int'])),
                                    ])
                                    self.dijkstra = None
                                    self.intra_prefix = None
                                    self.intra_prefix_del = None
                                    self.inter_prefix = None
                                    self.inter_prefix_del = None
                                    self.external_prefix = None
                                    self.external_prefix_del = None
                                    self.rib_add = None
                                    self.rib_del = None
                                    self._segment_path = lambda: "spf-stat-time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.Statistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime, [u'dijkstra', u'intra_prefix', u'intra_prefix_del', u'inter_prefix', u'inter_prefix_del', u'external_prefix', u'external_prefix_del', u'rib_add', u'rib_del'], name, value)


                class RawioStats(Entity):
                    """
                    OSPF Prefix SPF Prioritization statistics
                    
                    .. attribute:: raw_conn_open
                    
                    	Raw Connections Open
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: raw_conn_close
                    
                    	Raw Connections Close
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: raw_conn_error
                    
                    	Raw Connections Error
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_packets
                    
                    	Received Packets
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_bytes
                    
                    	Received Bytes
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte
                    
                    .. attribute:: in_long_packets
                    
                    	Received Long Packets
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_malloc_drops
                    
                    	In Malloc Drops
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_handle_drops
                    
                    	In Handle Drops
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_short_drops
                    
                    	In Short Drops
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_error_drops
                    
                    	In Error Drops
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_ipsec_drops
                    
                    	In IPSEC Drops
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: in_queue_drops
                    
                    	In Queue Drops
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: out_packets
                    
                    	Packets Sent
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: out_bytes
                    
                    	Sent Bytes
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte
                    
                    .. attribute:: out_nofd_drops
                    
                    	No FileDescriptor Drops
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: out_error_drops
                    
                    	Error Drops
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: out_ipsec_drops
                    
                    	Out IPSEC Drops
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: out_nopak_drops
                    
                    	No Packet Buffers
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: out_pakapi_errors
                    
                    	PAK API Errors
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: raw_conn_state
                    
                    	Raw Connection State
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Statistics.RawioStats, self).__init__()

                        self.yang_name = "rawio-stats"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('raw_conn_open', (YLeaf(YType.uint64, 'raw-conn-open'), ['int'])),
                            ('raw_conn_close', (YLeaf(YType.uint64, 'raw-conn-close'), ['int'])),
                            ('raw_conn_error', (YLeaf(YType.uint64, 'raw-conn-error'), ['int'])),
                            ('in_packets', (YLeaf(YType.uint64, 'in-packets'), ['int'])),
                            ('in_bytes', (YLeaf(YType.uint64, 'in-bytes'), ['int'])),
                            ('in_long_packets', (YLeaf(YType.uint64, 'in-long-packets'), ['int'])),
                            ('in_malloc_drops', (YLeaf(YType.uint64, 'in-malloc-drops'), ['int'])),
                            ('in_handle_drops', (YLeaf(YType.uint64, 'in-handle-drops'), ['int'])),
                            ('in_short_drops', (YLeaf(YType.uint64, 'in-short-drops'), ['int'])),
                            ('in_error_drops', (YLeaf(YType.uint64, 'in-error-drops'), ['int'])),
                            ('in_ipsec_drops', (YLeaf(YType.uint64, 'in-ipsec-drops'), ['int'])),
                            ('in_queue_drops', (YLeaf(YType.uint64, 'in-queue-drops'), ['int'])),
                            ('out_packets', (YLeaf(YType.uint64, 'out-packets'), ['int'])),
                            ('out_bytes', (YLeaf(YType.uint64, 'out-bytes'), ['int'])),
                            ('out_nofd_drops', (YLeaf(YType.uint64, 'out-nofd-drops'), ['int'])),
                            ('out_error_drops', (YLeaf(YType.uint64, 'out-error-drops'), ['int'])),
                            ('out_ipsec_drops', (YLeaf(YType.uint64, 'out-ipsec-drops'), ['int'])),
                            ('out_nopak_drops', (YLeaf(YType.uint64, 'out-nopak-drops'), ['int'])),
                            ('out_pakapi_errors', (YLeaf(YType.uint64, 'out-pakapi-errors'), ['int'])),
                            ('raw_conn_state', (YLeaf(YType.uint32, 'raw-conn-state'), ['int'])),
                        ])
                        self.raw_conn_open = None
                        self.raw_conn_close = None
                        self.raw_conn_error = None
                        self.in_packets = None
                        self.in_bytes = None
                        self.in_long_packets = None
                        self.in_malloc_drops = None
                        self.in_handle_drops = None
                        self.in_short_drops = None
                        self.in_error_drops = None
                        self.in_ipsec_drops = None
                        self.in_queue_drops = None
                        self.out_packets = None
                        self.out_bytes = None
                        self.out_nofd_drops = None
                        self.out_error_drops = None
                        self.out_ipsec_drops = None
                        self.out_nopak_drops = None
                        self.out_pakapi_errors = None
                        self.raw_conn_state = None
                        self._segment_path = lambda: "rawio-stats"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Statistics.RawioStats, [u'raw_conn_open', u'raw_conn_close', u'raw_conn_error', u'in_packets', u'in_bytes', u'in_long_packets', u'in_malloc_drops', u'in_handle_drops', u'in_short_drops', u'in_error_drops', u'in_ipsec_drops', u'in_queue_drops', u'out_packets', u'out_bytes', u'out_nofd_drops', u'out_error_drops', u'out_ipsec_drops', u'out_nopak_drops', u'out_pakapi_errors', u'raw_conn_state'], name, value)


                class PrefixPriorityStats(Entity):
                    """
                    OSPF Prefix SPF Prioritization statistics
                    
                    .. attribute:: critical
                    
                    	Critical priority classifications
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: high
                    
                    	High priority classifications
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: medium
                    
                    	Medium priority classifications
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: low
                    
                    	Low priority classifications
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Statistics.PrefixPriorityStats, self).__init__()

                        self.yang_name = "prefix-priority-stats"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                            ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                            ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                            ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                        ])
                        self.critical = None
                        self.high = None
                        self.medium = None
                        self.low = None
                        self._segment_path = lambda: "prefix-priority-stats"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Statistics.PrefixPriorityStats, [u'critical', u'high', u'medium', u'low'], name, value)


                class VrfRibBatchStats(Entity):
                    """
                    OSPFv3 RIB batch statistics
                    
                    .. attribute:: batches_sent
                    
                    	No. of RIB batches sent
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: routes_sent
                    
                    	No. of Routes sent to RIB
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: routes_pending
                    
                    	No of Pending Routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_routes
                    
                    	Max No. of Routes in a batch
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: paths_sent
                    
                    	No. of Paths sent to RIB
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: paths_pending
                    
                    	No. of paths waiting to be sent to RIB
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: paths_add
                    
                    	No. of paths added to RIB
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: paths_add_errs
                    
                    	No. of paths add errors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: paths_del
                    
                    	No. of paths del sent to RIB
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: paths_del_errs
                    
                    	No. of Paths del errors
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.Statistics.VrfRibBatchStats, self).__init__()

                        self.yang_name = "vrf-rib-batch-stats"
                        self.yang_parent_name = "statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('batches_sent', (YLeaf(YType.uint32, 'batches-sent'), ['int'])),
                            ('routes_sent', (YLeaf(YType.uint32, 'routes-sent'), ['int'])),
                            ('routes_pending', (YLeaf(YType.uint32, 'routes-pending'), ['int'])),
                            ('max_routes', (YLeaf(YType.uint32, 'max-routes'), ['int'])),
                            ('paths_sent', (YLeaf(YType.uint32, 'paths-sent'), ['int'])),
                            ('paths_pending', (YLeaf(YType.uint32, 'paths-pending'), ['int'])),
                            ('paths_add', (YLeaf(YType.uint32, 'paths-add'), ['int'])),
                            ('paths_add_errs', (YLeaf(YType.uint32, 'paths-add-errs'), ['int'])),
                            ('paths_del', (YLeaf(YType.uint32, 'paths-del'), ['int'])),
                            ('paths_del_errs', (YLeaf(YType.uint32, 'paths-del-errs'), ['int'])),
                        ])
                        self.batches_sent = None
                        self.routes_sent = None
                        self.routes_pending = None
                        self.max_routes = None
                        self.paths_sent = None
                        self.paths_pending = None
                        self.paths_add = None
                        self.paths_add_errs = None
                        self.paths_del = None
                        self.paths_del_errs = None
                        self._segment_path = lambda: "vrf-rib-batch-stats"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.Statistics.VrfRibBatchStats, [u'batches_sent', u'routes_sent', u'routes_pending', u'max_routes', u'paths_sent', u'paths_pending', u'paths_add', u'paths_add_errs', u'paths_del', u'paths_del_errs'], name, value)


            class DefaultVrf(Entity):
                """
                Operational data for the default VRF
                (instance) in the OSPFv3 process
                
                .. attribute:: summary_prefixes
                
                	Summary prefix information table
                	**type**\:  :py:class:`SummaryPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes>`
                
                .. attribute:: border_routers
                
                	OSPFv3 border router information table
                	**type**\:  :py:class:`BorderRouters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.BorderRouters>`
                
                .. attribute:: sham_link_table
                
                	Sham link information
                	**type**\:  :py:class:`ShamLinkTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable>`
                
                .. attribute:: area_informations
                
                	OSPFv3 area information table
                	**type**\:  :py:class:`AreaInformations <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.AreaInformations>`
                
                .. attribute:: database_table
                
                	OSPF Link State Database
                	**type**\:  :py:class:`DatabaseTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable>`
                
                .. attribute:: interface_process_table
                
                	OSPFv3 interface information table for all areas
                	**type**\:  :py:class:`InterfaceProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable>`
                
                .. attribute:: redistributions
                
                	Redistribution information table
                	**type**\:  :py:class:`Redistributions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Redistributions>`
                
                .. attribute:: external_routes
                
                	OSPFv3 external route information table
                	**type**\:  :py:class:`ExternalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes>`
                
                .. attribute:: request_list_process_table
                
                	OSPFv3 request list information for all areas
                	**type**\:  :py:class:`RequestListProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable>`
                
                .. attribute:: virtual_link
                
                	Virtual link information
                	**type**\:  :py:class:`VirtualLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VirtualLink>`
                
                .. attribute:: flood_list_process_table
                
                	OSPFv3 flood list information table for all areas
                	**type**\:  :py:class:`FloodListProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable>`
                
                .. attribute:: route_summary
                
                	Summarize OSPFv3 local RIB tables
                	**type**\:  :py:class:`RouteSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RouteSummary>`
                
                .. attribute:: areas
                
                	OSPFv3 area table
                	**type**\:  :py:class:`Areas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas>`
                
                .. attribute:: internal_routes
                
                	OSPFv3 internal route information table
                	**type**\:  :py:class:`InternalRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes>`
                
                .. attribute:: protocol_areas
                
                	Protocol area table 
                	**type**\:  :py:class:`ProtocolAreas <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas>`
                
                .. attribute:: connected_routes
                
                	OSPFv3 connected route information table
                	**type**\:  :py:class:`ConnectedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes>`
                
                .. attribute:: vrf_statistics
                
                	Container for Statistics
                	**type**\:  :py:class:`VrfStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics>`
                
                .. attribute:: summary
                
                	OSPFv3 summary
                	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary>`
                
                .. attribute:: retransmission_list_process_table
                
                	OSPFv3 retransmission list information table for all areas
                	**type**\:  :py:class:`RetransmissionListProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable>`
                
                .. attribute:: bad_checksums
                
                	Bad Checksum Packets information table
                	**type**\:  :py:class:`BadChecksums <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.BadChecksums>`
                
                .. attribute:: database_summary_table
                
                	Database summary table
                	**type**\:  :py:class:`DatabaseSummaryTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable>`
                
                .. attribute:: neighbor_process_table
                
                	OSPFv3 neighbor information table for all areas
                	**type**\:  :py:class:`NeighborProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable>`
                
                .. attribute:: fast_reroutes
                
                	OSPFv3 fast reroute topology information table
                	**type**\:  :py:class:`FastReroutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FastReroutes>`
                
                .. attribute:: interface_brief_process_table
                
                	OSPFv3 interface brief information table for all areas
                	**type**\:  :py:class:`InterfaceBriefProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable>`
                
                .. attribute:: neighbor_detail_process_table
                
                	OSPFv3 neighbor information table for all areas
                	**type**\:  :py:class:`NeighborDetailProcessTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable>`
                
                

                """

                _prefix = 'ipv6-ospfv3-oper'
                _revision = '2017-10-30'

                def __init__(self):
                    super(Ospfv3.Processes.Process.DefaultVrf, self).__init__()

                    self.yang_name = "default-vrf"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("summary-prefixes", ("summary_prefixes", Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes)), ("border-routers", ("border_routers", Ospfv3.Processes.Process.DefaultVrf.BorderRouters)), ("sham-link-table", ("sham_link_table", Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable)), ("area-informations", ("area_informations", Ospfv3.Processes.Process.DefaultVrf.AreaInformations)), ("database-table", ("database_table", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable)), ("interface-process-table", ("interface_process_table", Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable)), ("redistributions", ("redistributions", Ospfv3.Processes.Process.DefaultVrf.Redistributions)), ("external-routes", ("external_routes", Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes)), ("request-list-process-table", ("request_list_process_table", Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable)), ("virtual-link", ("virtual_link", Ospfv3.Processes.Process.DefaultVrf.VirtualLink)), ("flood-list-process-table", ("flood_list_process_table", Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable)), ("route-summary", ("route_summary", Ospfv3.Processes.Process.DefaultVrf.RouteSummary)), ("areas", ("areas", Ospfv3.Processes.Process.DefaultVrf.Areas)), ("internal-routes", ("internal_routes", Ospfv3.Processes.Process.DefaultVrf.InternalRoutes)), ("protocol-areas", ("protocol_areas", Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas)), ("connected-routes", ("connected_routes", Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes)), ("vrf-statistics", ("vrf_statistics", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics)), ("summary", ("summary", Ospfv3.Processes.Process.DefaultVrf.Summary)), ("retransmission-list-process-table", ("retransmission_list_process_table", Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable)), ("bad-checksums", ("bad_checksums", Ospfv3.Processes.Process.DefaultVrf.BadChecksums)), ("database-summary-table", ("database_summary_table", Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable)), ("neighbor-process-table", ("neighbor_process_table", Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable)), ("fast-reroutes", ("fast_reroutes", Ospfv3.Processes.Process.DefaultVrf.FastReroutes)), ("interface-brief-process-table", ("interface_brief_process_table", Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable)), ("neighbor-detail-process-table", ("neighbor_detail_process_table", Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable))])
                    self._leafs = OrderedDict()

                    self.summary_prefixes = Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes()
                    self.summary_prefixes.parent = self
                    self._children_name_map["summary_prefixes"] = "summary-prefixes"

                    self.border_routers = Ospfv3.Processes.Process.DefaultVrf.BorderRouters()
                    self.border_routers.parent = self
                    self._children_name_map["border_routers"] = "border-routers"

                    self.sham_link_table = Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable()
                    self.sham_link_table.parent = self
                    self._children_name_map["sham_link_table"] = "sham-link-table"

                    self.area_informations = Ospfv3.Processes.Process.DefaultVrf.AreaInformations()
                    self.area_informations.parent = self
                    self._children_name_map["area_informations"] = "area-informations"

                    self.database_table = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable()
                    self.database_table.parent = self
                    self._children_name_map["database_table"] = "database-table"

                    self.interface_process_table = Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable()
                    self.interface_process_table.parent = self
                    self._children_name_map["interface_process_table"] = "interface-process-table"

                    self.redistributions = Ospfv3.Processes.Process.DefaultVrf.Redistributions()
                    self.redistributions.parent = self
                    self._children_name_map["redistributions"] = "redistributions"

                    self.external_routes = Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes()
                    self.external_routes.parent = self
                    self._children_name_map["external_routes"] = "external-routes"

                    self.request_list_process_table = Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable()
                    self.request_list_process_table.parent = self
                    self._children_name_map["request_list_process_table"] = "request-list-process-table"

                    self.virtual_link = Ospfv3.Processes.Process.DefaultVrf.VirtualLink()
                    self.virtual_link.parent = self
                    self._children_name_map["virtual_link"] = "virtual-link"

                    self.flood_list_process_table = Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable()
                    self.flood_list_process_table.parent = self
                    self._children_name_map["flood_list_process_table"] = "flood-list-process-table"

                    self.route_summary = Ospfv3.Processes.Process.DefaultVrf.RouteSummary()
                    self.route_summary.parent = self
                    self._children_name_map["route_summary"] = "route-summary"

                    self.areas = Ospfv3.Processes.Process.DefaultVrf.Areas()
                    self.areas.parent = self
                    self._children_name_map["areas"] = "areas"

                    self.internal_routes = Ospfv3.Processes.Process.DefaultVrf.InternalRoutes()
                    self.internal_routes.parent = self
                    self._children_name_map["internal_routes"] = "internal-routes"

                    self.protocol_areas = Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas()
                    self.protocol_areas.parent = self
                    self._children_name_map["protocol_areas"] = "protocol-areas"

                    self.connected_routes = Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes()
                    self.connected_routes.parent = self
                    self._children_name_map["connected_routes"] = "connected-routes"

                    self.vrf_statistics = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics()
                    self.vrf_statistics.parent = self
                    self._children_name_map["vrf_statistics"] = "vrf-statistics"

                    self.summary = Ospfv3.Processes.Process.DefaultVrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"

                    self.retransmission_list_process_table = Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable()
                    self.retransmission_list_process_table.parent = self
                    self._children_name_map["retransmission_list_process_table"] = "retransmission-list-process-table"

                    self.bad_checksums = Ospfv3.Processes.Process.DefaultVrf.BadChecksums()
                    self.bad_checksums.parent = self
                    self._children_name_map["bad_checksums"] = "bad-checksums"

                    self.database_summary_table = Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable()
                    self.database_summary_table.parent = self
                    self._children_name_map["database_summary_table"] = "database-summary-table"

                    self.neighbor_process_table = Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable()
                    self.neighbor_process_table.parent = self
                    self._children_name_map["neighbor_process_table"] = "neighbor-process-table"

                    self.fast_reroutes = Ospfv3.Processes.Process.DefaultVrf.FastReroutes()
                    self.fast_reroutes.parent = self
                    self._children_name_map["fast_reroutes"] = "fast-reroutes"

                    self.interface_brief_process_table = Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable()
                    self.interface_brief_process_table.parent = self
                    self._children_name_map["interface_brief_process_table"] = "interface-brief-process-table"

                    self.neighbor_detail_process_table = Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable()
                    self.neighbor_detail_process_table.parent = self
                    self._children_name_map["neighbor_detail_process_table"] = "neighbor-detail-process-table"
                    self._segment_path = lambda: "default-vrf"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf, [], name, value)


                class SummaryPrefixes(Entity):
                    """
                    Summary prefix information table
                    
                    .. attribute:: summary_prefix
                    
                    	Summary prefix information
                    	**type**\: list of  		 :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes, self).__init__()

                        self.yang_name = "summary-prefixes"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("summary-prefix", ("summary_prefix", Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix))])
                        self._leafs = OrderedDict()

                        self.summary_prefix = YList(self)
                        self._segment_path = lambda: "summary-prefixes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes, [], name, value)


                    class SummaryPrefix(Entity):
                        """
                        Summary prefix information
                        
                        .. attribute:: prefix
                        
                        	Summary prefix
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\: int
                        
                        	**range:** 0..128
                        
                        .. attribute:: prefix_metric
                        
                        	Prefix metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: prefix_metric_type
                        
                        	Prefix metric type
                        	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                        
                        .. attribute:: tag
                        
                        	Tag
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix, self).__init__()

                            self.yang_name = "summary-prefix"
                            self.yang_parent_name = "summary-prefixes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                ('prefix_metric', (YLeaf(YType.uint32, 'prefix-metric'), ['int'])),
                                ('prefix_metric_type', (YLeaf(YType.enumeration, 'prefix-metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                            ])
                            self.prefix = None
                            self.prefix_length = None
                            self.prefix_metric = None
                            self.prefix_metric_type = None
                            self.tag = None
                            self._segment_path = lambda: "summary-prefix"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.SummaryPrefixes.SummaryPrefix, ['prefix', 'prefix_length', u'prefix_metric', u'prefix_metric_type', u'tag'], name, value)


                class BorderRouters(Entity):
                    """
                    OSPFv3 border router information table
                    
                    .. attribute:: border_router
                    
                    	OSPFv3 border router information
                    	**type**\: list of  		 :py:class:`BorderRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.BorderRouters, self).__init__()

                        self.yang_name = "border-routers"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("border-router", ("border_router", Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter))])
                        self._leafs = OrderedDict()

                        self.border_router = YList(self)
                        self._segment_path = lambda: "border-routers"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.BorderRouters, [], name, value)


                    class BorderRouter(Entity):
                        """
                        OSPFv3 border router information
                        
                        .. attribute:: border_router_id  (key)
                        
                        	Router address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: border_router_path
                        
                        	List of border router paths
                        	**type**\: list of  		 :py:class:`BorderRouterPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter, self).__init__()

                            self.yang_name = "border-router"
                            self.yang_parent_name = "border-routers"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['border_router_id']
                            self._child_classes = OrderedDict([("border-router-path", ("border_router_path", Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath))])
                            self._leafs = OrderedDict([
                                ('border_router_id', (YLeaf(YType.str, 'border-router-id'), ['str'])),
                            ])
                            self.border_router_id = None

                            self.border_router_path = YList(self)
                            self._segment_path = lambda: "border-router" + "[border-router-id='" + str(self.border_router_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter, ['border_router_id'], name, value)


                        class BorderRouterPath(Entity):
                            """
                            List of border router paths
                            
                            .. attribute:: is_intra_area_router
                            
                            	If true, intra\-area router else inter\-area router
                            	**type**\: bool
                            
                            .. attribute:: border_router_route_metric
                            
                            	Metric
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: border_router_next_hop
                            
                            	Next hop address 
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_name
                            
                            	Next hop interface name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: border_router_type
                            
                            	Border router type 
                            	**type**\:  :py:class:`Ospfv3BorderRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3BorderRoute>`
                            
                            .. attribute:: border_router_area_id
                            
                            	Area string in decimal or dotted\-decimal format 
                            	**type**\: str
                            
                            	**length:** 0..16
                            
                            .. attribute:: spf_version
                            
                            	SPF version
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath, self).__init__()

                                self.yang_name = "border-router-path"
                                self.yang_parent_name = "border-router"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('is_intra_area_router', (YLeaf(YType.boolean, 'is-intra-area-router'), ['bool'])),
                                    ('border_router_route_metric', (YLeaf(YType.uint32, 'border-router-route-metric'), ['int'])),
                                    ('border_router_next_hop', (YLeaf(YType.str, 'border-router-next-hop'), ['str'])),
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('border_router_type', (YLeaf(YType.enumeration, 'border-router-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3BorderRoute', '')])),
                                    ('border_router_area_id', (YLeaf(YType.str, 'border-router-area-id'), ['str'])),
                                    ('spf_version', (YLeaf(YType.uint32, 'spf-version'), ['int'])),
                                ])
                                self.is_intra_area_router = None
                                self.border_router_route_metric = None
                                self.border_router_next_hop = None
                                self.interface_name = None
                                self.border_router_type = None
                                self.border_router_area_id = None
                                self.spf_version = None
                                self._segment_path = lambda: "border-router-path"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.BorderRouters.BorderRouter.BorderRouterPath, [u'is_intra_area_router', u'border_router_route_metric', u'border_router_next_hop', u'interface_name', u'border_router_type', u'border_router_area_id', u'spf_version'], name, value)


                class ShamLinkTable(Entity):
                    """
                    Sham link information
                    
                    .. attribute:: sham_link_neighbor
                    
                    	Neighbor information
                    	**type**\:  :py:class:`ShamLinkNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor>`
                    
                    .. attribute:: sham_link_neighbor_id
                    
                    	Neighbor on other end of this sham link
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: sham_link_source_address
                    
                    	Sham\-link source
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: sham_link_dest_address
                    
                    	Sham\-link dest
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: sham_link_state
                    
                    	OSPF interface state for the sham link
                    	**type**\:  :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                    
                    .. attribute:: sham_link_demand_circuit
                    
                    	If true, the link runs as demand circuit
                    	**type**\: bool
                    
                    .. attribute:: sham_link_dc_bitless_lsa
                    
                    	Number of LSA's with demand circuit bit not set
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_ifindex
                    
                    	Sham\-link ifindex
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_area
                    
                    	Area id
                    	**type**\: str
                    
                    .. attribute:: sham_link_cost
                    
                    	Cost of the sham link
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: sham_link_transmission_delay
                    
                    	Transmission delay in seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: sham_link_hello_interval
                    
                    	Hello interval (s)
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_dead_interval
                    
                    	Dead interval (s)
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_wait_interval
                    
                    	Wait interval (s)
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_retransmission_interval
                    
                    	Retransmission interval (s)
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_next_hello
                    
                    	Time until next hello (s)
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_passive
                    
                    	If true, interface is passive
                    	**type**\: bool
                    
                    .. attribute:: is_sham_link_ip_security_required
                    
                    	If true, sham link IP security is required 
                    	**type**\: bool
                    
                    .. attribute:: is_sham_link_ip_security_active
                    
                    	If true, Sham link IP security is active 
                    	**type**\: bool
                    
                    .. attribute:: is_sham_link_authentication_enabled
                    
                    	If true, sham link authentication is enabled 
                    	**type**\: bool
                    
                    .. attribute:: virtual_link_authentication_spi
                    
                    	Sham link authentication spi 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_authentication_transmit
                    
                    	Sham link authentication transmit 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_sham_link_encryption_enabled
                    
                    	If true, sham link encryption is enabled 
                    	**type**\: bool
                    
                    .. attribute:: sham_link_encryption_spi
                    
                    	Sham link encryption spi
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_encryption_transmitted
                    
                    	Sham link encryption transmitted 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_encrypted_authentication_transmitted
                    
                    	Sham link encrypted authentication transmitted 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sham_link_gr_enabled
                    
                    	If true,  enabled
                    	**type**\: bool
                    
                    .. attribute:: sham_link_gr
                    
                    	If true, Gracefule restart in progress
                    	**type**\: bool
                    
                    .. attribute:: sham_link_last_gr
                    
                    	Time in seconds since last GR
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable, self).__init__()

                        self.yang_name = "sham-link-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sham-link-neighbor", ("sham_link_neighbor", Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor))])
                        self._leafs = OrderedDict([
                            ('sham_link_neighbor_id', (YLeaf(YType.str, 'sham-link-neighbor-id'), ['str'])),
                            ('sham_link_source_address', (YLeaf(YType.str, 'sham-link-source-address'), ['str'])),
                            ('sham_link_dest_address', (YLeaf(YType.str, 'sham-link-dest-address'), ['str'])),
                            ('sham_link_state', (YLeaf(YType.enumeration, 'sham-link-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3InterfaceState', '')])),
                            ('sham_link_demand_circuit', (YLeaf(YType.boolean, 'sham-link-demand-circuit'), ['bool'])),
                            ('sham_link_dc_bitless_lsa', (YLeaf(YType.uint32, 'sham-link-dc-bitless-lsa'), ['int'])),
                            ('sham_link_ifindex', (YLeaf(YType.uint32, 'sham-link-ifindex'), ['int'])),
                            ('sham_link_area', (YLeaf(YType.str, 'sham-link-area'), ['str'])),
                            ('sham_link_cost', (YLeaf(YType.uint16, 'sham-link-cost'), ['int'])),
                            ('sham_link_transmission_delay', (YLeaf(YType.uint16, 'sham-link-transmission-delay'), ['int'])),
                            ('sham_link_hello_interval', (YLeaf(YType.uint32, 'sham-link-hello-interval'), ['int'])),
                            ('sham_link_dead_interval', (YLeaf(YType.uint32, 'sham-link-dead-interval'), ['int'])),
                            ('sham_link_wait_interval', (YLeaf(YType.uint32, 'sham-link-wait-interval'), ['int'])),
                            ('sham_link_retransmission_interval', (YLeaf(YType.uint32, 'sham-link-retransmission-interval'), ['int'])),
                            ('sham_link_next_hello', (YLeaf(YType.uint32, 'sham-link-next-hello'), ['int'])),
                            ('sham_link_passive', (YLeaf(YType.boolean, 'sham-link-passive'), ['bool'])),
                            ('is_sham_link_ip_security_required', (YLeaf(YType.boolean, 'is-sham-link-ip-security-required'), ['bool'])),
                            ('is_sham_link_ip_security_active', (YLeaf(YType.boolean, 'is-sham-link-ip-security-active'), ['bool'])),
                            ('is_sham_link_authentication_enabled', (YLeaf(YType.boolean, 'is-sham-link-authentication-enabled'), ['bool'])),
                            ('virtual_link_authentication_spi', (YLeaf(YType.uint32, 'virtual-link-authentication-spi'), ['int'])),
                            ('sham_link_authentication_transmit', (YLeaf(YType.uint32, 'sham-link-authentication-transmit'), ['int'])),
                            ('is_sham_link_encryption_enabled', (YLeaf(YType.boolean, 'is-sham-link-encryption-enabled'), ['bool'])),
                            ('sham_link_encryption_spi', (YLeaf(YType.uint32, 'sham-link-encryption-spi'), ['int'])),
                            ('sham_link_encryption_transmitted', (YLeaf(YType.uint32, 'sham-link-encryption-transmitted'), ['int'])),
                            ('sham_link_encrypted_authentication_transmitted', (YLeaf(YType.uint32, 'sham-link-encrypted-authentication-transmitted'), ['int'])),
                            ('sham_link_gr_enabled', (YLeaf(YType.boolean, 'sham-link-gr-enabled'), ['bool'])),
                            ('sham_link_gr', (YLeaf(YType.boolean, 'sham-link-gr'), ['bool'])),
                            ('sham_link_last_gr', (YLeaf(YType.uint32, 'sham-link-last-gr'), ['int'])),
                        ])
                        self.sham_link_neighbor_id = None
                        self.sham_link_source_address = None
                        self.sham_link_dest_address = None
                        self.sham_link_state = None
                        self.sham_link_demand_circuit = None
                        self.sham_link_dc_bitless_lsa = None
                        self.sham_link_ifindex = None
                        self.sham_link_area = None
                        self.sham_link_cost = None
                        self.sham_link_transmission_delay = None
                        self.sham_link_hello_interval = None
                        self.sham_link_dead_interval = None
                        self.sham_link_wait_interval = None
                        self.sham_link_retransmission_interval = None
                        self.sham_link_next_hello = None
                        self.sham_link_passive = None
                        self.is_sham_link_ip_security_required = None
                        self.is_sham_link_ip_security_active = None
                        self.is_sham_link_authentication_enabled = None
                        self.virtual_link_authentication_spi = None
                        self.sham_link_authentication_transmit = None
                        self.is_sham_link_encryption_enabled = None
                        self.sham_link_encryption_spi = None
                        self.sham_link_encryption_transmitted = None
                        self.sham_link_encrypted_authentication_transmitted = None
                        self.sham_link_gr_enabled = None
                        self.sham_link_gr = None
                        self.sham_link_last_gr = None

                        self.sham_link_neighbor = Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor()
                        self.sham_link_neighbor.parent = self
                        self._children_name_map["sham_link_neighbor"] = "sham-link-neighbor"
                        self._segment_path = lambda: "sham-link-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable, [u'sham_link_neighbor_id', u'sham_link_source_address', u'sham_link_dest_address', u'sham_link_state', u'sham_link_demand_circuit', u'sham_link_dc_bitless_lsa', u'sham_link_ifindex', u'sham_link_area', u'sham_link_cost', u'sham_link_transmission_delay', u'sham_link_hello_interval', u'sham_link_dead_interval', u'sham_link_wait_interval', u'sham_link_retransmission_interval', u'sham_link_next_hello', u'sham_link_passive', u'is_sham_link_ip_security_required', u'is_sham_link_ip_security_active', u'is_sham_link_authentication_enabled', u'virtual_link_authentication_spi', u'sham_link_authentication_transmit', u'is_sham_link_encryption_enabled', u'sham_link_encryption_spi', u'sham_link_encryption_transmitted', u'sham_link_encrypted_authentication_transmitted', u'sham_link_gr_enabled', u'sham_link_gr', u'sham_link_last_gr'], name, value)


                    class ShamLinkNeighbor(Entity):
                        """
                        Neighbor information
                        
                        .. attribute:: sham_link_retransmission
                        
                        	Neighbor retransmission info
                        	**type**\:  :py:class:`ShamLinkRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission>`
                        
                        .. attribute:: sham_link_suppress_hello
                        
                        	If true Hellos suppressed
                        	**type**\: bool
                        
                        .. attribute:: sham_link_state
                        
                        	Adjacency state
                        	**type**\:  :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor, self).__init__()

                            self.yang_name = "sham-link-neighbor"
                            self.yang_parent_name = "sham-link-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("sham-link-retransmission", ("sham_link_retransmission", Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission))])
                            self._leafs = OrderedDict([
                                ('sham_link_suppress_hello', (YLeaf(YType.boolean, 'sham-link-suppress-hello'), ['bool'])),
                                ('sham_link_state', (YLeaf(YType.enumeration, 'sham-link-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3NeighborState', '')])),
                            ])
                            self.sham_link_suppress_hello = None
                            self.sham_link_state = None

                            self.sham_link_retransmission = Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission()
                            self.sham_link_retransmission.parent = self
                            self._children_name_map["sham_link_retransmission"] = "sham-link-retransmission"
                            self._segment_path = lambda: "sham-link-neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor, [u'sham_link_suppress_hello', u'sham_link_state'], name, value)


                        class ShamLinkRetransmission(Entity):
                            """
                            Neighbor retransmission info
                            
                            .. attribute:: database_descriptor_retransmissions
                            
                            	Number of database descriptor retransmissions during last exchange
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_flood_index
                            
                            	Area scope LSA's flood index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_flood_index
                            
                            	AS scope LSA's flood index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_flood_index
                            
                            	Link flood index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_retransmissions
                            
                            	Number of neighbor retransmissions 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: retransmissions
                            
                            	Number of retransmissions for this neighbor
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_first_flood
                            
                            	First flood item for area scope LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_first_flood_index
                            
                            	Index of the first flood item for area scope LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_first_flood
                            
                            	First flood item for AS scope LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_first_flood_index
                            
                            	Index for first flood item for AS scope LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_first_flood
                            
                            	Link first flood information 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_first_flood_index
                            
                            	Link first flood information index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_next_flood
                            
                            	Next flood item for area scope LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_next_flood_index
                            
                            	Index of next flood item for Area scope LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_next_flood
                            
                            	Next flood item for AS scope LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_next_flood_index
                            
                            	Index of next flood item for AS scope LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_next_flood
                            
                            	Link next flood information 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_next_flood_index
                            
                            	Link next flood information index 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_retransmission_length
                            
                            	Number of LSAs sent in last retransmission
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_retransmission_length
                            
                            	Maximum number of LSAs sent in a retransmission
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_retransmission_time
                            
                            	Last retransmission scan time (ms)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_retransmission_time
                            
                            	Maximum retransmission scan time (ms)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_retransmission_timer
                            
                            	Time until next LSA retransmission (ms)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission, self).__init__()

                                self.yang_name = "sham-link-retransmission"
                                self.yang_parent_name = "sham-link-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('database_descriptor_retransmissions', (YLeaf(YType.uint32, 'database-descriptor-retransmissions'), ['int'])),
                                    ('area_flood_index', (YLeaf(YType.uint32, 'area-flood-index'), ['int'])),
                                    ('as_flood_index', (YLeaf(YType.uint32, 'as-flood-index'), ['int'])),
                                    ('link_flood_index', (YLeaf(YType.uint32, 'link-flood-index'), ['int'])),
                                    ('neighbor_retransmissions', (YLeaf(YType.uint32, 'neighbor-retransmissions'), ['int'])),
                                    ('retransmissions', (YLeaf(YType.uint32, 'retransmissions'), ['int'])),
                                    ('area_first_flood', (YLeaf(YType.uint32, 'area-first-flood'), ['int'])),
                                    ('area_first_flood_index', (YLeaf(YType.uint32, 'area-first-flood-index'), ['int'])),
                                    ('as_first_flood', (YLeaf(YType.uint32, 'as-first-flood'), ['int'])),
                                    ('as_first_flood_index', (YLeaf(YType.uint32, 'as-first-flood-index'), ['int'])),
                                    ('link_first_flood', (YLeaf(YType.uint32, 'link-first-flood'), ['int'])),
                                    ('link_first_flood_index', (YLeaf(YType.uint32, 'link-first-flood-index'), ['int'])),
                                    ('area_next_flood', (YLeaf(YType.uint32, 'area-next-flood'), ['int'])),
                                    ('area_next_flood_index', (YLeaf(YType.uint32, 'area-next-flood-index'), ['int'])),
                                    ('as_next_flood', (YLeaf(YType.uint32, 'as-next-flood'), ['int'])),
                                    ('as_next_flood_index', (YLeaf(YType.uint32, 'as-next-flood-index'), ['int'])),
                                    ('link_next_flood', (YLeaf(YType.uint32, 'link-next-flood'), ['int'])),
                                    ('link_next_flood_index', (YLeaf(YType.uint32, 'link-next-flood-index'), ['int'])),
                                    ('last_retransmission_length', (YLeaf(YType.uint32, 'last-retransmission-length'), ['int'])),
                                    ('maximum_retransmission_length', (YLeaf(YType.uint32, 'maximum-retransmission-length'), ['int'])),
                                    ('last_retransmission_time', (YLeaf(YType.uint32, 'last-retransmission-time'), ['int'])),
                                    ('maximum_retransmission_time', (YLeaf(YType.uint32, 'maximum-retransmission-time'), ['int'])),
                                    ('lsa_retransmission_timer', (YLeaf(YType.uint32, 'lsa-retransmission-timer'), ['int'])),
                                ])
                                self.database_descriptor_retransmissions = None
                                self.area_flood_index = None
                                self.as_flood_index = None
                                self.link_flood_index = None
                                self.neighbor_retransmissions = None
                                self.retransmissions = None
                                self.area_first_flood = None
                                self.area_first_flood_index = None
                                self.as_first_flood = None
                                self.as_first_flood_index = None
                                self.link_first_flood = None
                                self.link_first_flood_index = None
                                self.area_next_flood = None
                                self.area_next_flood_index = None
                                self.as_next_flood = None
                                self.as_next_flood_index = None
                                self.link_next_flood = None
                                self.link_next_flood_index = None
                                self.last_retransmission_length = None
                                self.maximum_retransmission_length = None
                                self.last_retransmission_time = None
                                self.maximum_retransmission_time = None
                                self.lsa_retransmission_timer = None
                                self._segment_path = lambda: "sham-link-retransmission"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ShamLinkTable.ShamLinkNeighbor.ShamLinkRetransmission, [u'database_descriptor_retransmissions', u'area_flood_index', u'as_flood_index', u'link_flood_index', u'neighbor_retransmissions', u'retransmissions', u'area_first_flood', u'area_first_flood_index', u'as_first_flood', u'as_first_flood_index', u'link_first_flood', u'link_first_flood_index', u'area_next_flood', u'area_next_flood_index', u'as_next_flood', u'as_next_flood_index', u'link_next_flood', u'link_next_flood_index', u'last_retransmission_length', u'maximum_retransmission_length', u'last_retransmission_time', u'maximum_retransmission_time', u'lsa_retransmission_timer'], name, value)


                class AreaInformations(Entity):
                    """
                    OSPFv3 area information table
                    
                    .. attribute:: area_information
                    
                    	OSPFv3 area information
                    	**type**\: list of  		 :py:class:`AreaInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.AreaInformations, self).__init__()

                        self.yang_name = "area-informations"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("area-information", ("area_information", Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation))])
                        self._leafs = OrderedDict()

                        self.area_information = YList(self)
                        self._segment_path = lambda: "area-informations"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.AreaInformations, [], name, value)


                    class AreaInformation(Entity):
                        """
                        OSPFv3 area information
                        
                        .. attribute:: area_id  (key)
                        
                        	Area ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_backbone_area_active
                        
                        	If true, Backbone area is active
                        	**type**\: bool
                        
                        .. attribute:: area_interfaces
                        
                        	Number of interfaces in the area
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: is_area_stubbed
                        
                        	If true, stub area
                        	**type**\: bool
                        
                        .. attribute:: is_area_total_stubbed
                        
                        	If true, totally stubby area
                        	**type**\: bool
                        
                        .. attribute:: stub_default_cost
                        
                        	Default cost for Stub or NSSA area
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: is_area_nssa
                        
                        	If true, area is a NSSA
                        	**type**\: bool
                        
                        .. attribute:: nssa_no_redistribution
                        
                        	If true, No redistribution into this NSSA area
                        	**type**\: bool
                        
                        .. attribute:: is_nssa_translated
                        
                        	If true, perform 7/5 translation
                        	**type**\: bool
                        
                        .. attribute:: is_nssa_translated_always
                        
                        	If true, perform 7/5 translation always
                        	**type**\: bool
                        
                        .. attribute:: is_nssa_default
                        
                        	If true, generate NSSA default route
                        	**type**\: bool
                        
                        .. attribute:: is_rrr_enabled
                        
                        	If true, RRR is enabled
                        	**type**\: bool
                        
                        .. attribute:: sp_fs
                        
                        	Number of SPF calculations run
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_opaque_lsas
                        
                        	Number of opaque LSAs in the area
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_opaque_lsa_checksum
                        
                        	Sum of opaque LSA checksums
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_dc_bitless_ls_as
                        
                        	Number of LSA with demand circuit bit not set
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: indication_ls_as
                        
                        	Number of indication LSAs
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: do_not_age_ls_as
                        
                        	Number of do not age LSAs
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flood_list_length
                        
                        	Number of LSAs which need to be flooded
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_lfa_interface_count
                        
                        	Number of LFA enabled interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_per_prefix_lfa_interface_count
                        
                        	Number of Per Prefix LFA enabled interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_lfa_revision
                        
                        	Area LFA revision
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: area_range
                        
                        	List of ranges to summarize
                        	**type**\: list of  		 :py:class:`AreaRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation.AreaRange>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation, self).__init__()

                            self.yang_name = "area-information"
                            self.yang_parent_name = "area-informations"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['area_id']
                            self._child_classes = OrderedDict([("area-range", ("area_range", Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation.AreaRange))])
                            self._leafs = OrderedDict([
                                ('area_id', (YLeaf(YType.uint32, 'area-id'), ['int'])),
                                ('is_backbone_area_active', (YLeaf(YType.boolean, 'is-backbone-area-active'), ['bool'])),
                                ('area_interfaces', (YLeaf(YType.uint16, 'area-interfaces'), ['int'])),
                                ('is_area_stubbed', (YLeaf(YType.boolean, 'is-area-stubbed'), ['bool'])),
                                ('is_area_total_stubbed', (YLeaf(YType.boolean, 'is-area-total-stubbed'), ['bool'])),
                                ('stub_default_cost', (YLeaf(YType.uint16, 'stub-default-cost'), ['int'])),
                                ('is_area_nssa', (YLeaf(YType.boolean, 'is-area-nssa'), ['bool'])),
                                ('nssa_no_redistribution', (YLeaf(YType.boolean, 'nssa-no-redistribution'), ['bool'])),
                                ('is_nssa_translated', (YLeaf(YType.boolean, 'is-nssa-translated'), ['bool'])),
                                ('is_nssa_translated_always', (YLeaf(YType.boolean, 'is-nssa-translated-always'), ['bool'])),
                                ('is_nssa_default', (YLeaf(YType.boolean, 'is-nssa-default'), ['bool'])),
                                ('is_rrr_enabled', (YLeaf(YType.boolean, 'is-rrr-enabled'), ['bool'])),
                                ('sp_fs', (YLeaf(YType.uint32, 'sp-fs'), ['int'])),
                                ('area_opaque_lsas', (YLeaf(YType.uint32, 'area-opaque-lsas'), ['int'])),
                                ('area_opaque_lsa_checksum', (YLeaf(YType.uint32, 'area-opaque-lsa-checksum'), ['int'])),
                                ('area_dc_bitless_ls_as', (YLeaf(YType.uint32, 'area-dc-bitless-ls-as'), ['int'])),
                                ('indication_ls_as', (YLeaf(YType.uint32, 'indication-ls-as'), ['int'])),
                                ('do_not_age_ls_as', (YLeaf(YType.uint32, 'do-not-age-ls-as'), ['int'])),
                                ('flood_list_length', (YLeaf(YType.uint32, 'flood-list-length'), ['int'])),
                                ('area_lfa_interface_count', (YLeaf(YType.uint32, 'area-lfa-interface-count'), ['int'])),
                                ('area_per_prefix_lfa_interface_count', (YLeaf(YType.uint32, 'area-per-prefix-lfa-interface-count'), ['int'])),
                                ('area_lfa_revision', (YLeaf(YType.uint32, 'area-lfa-revision'), ['int'])),
                            ])
                            self.area_id = None
                            self.is_backbone_area_active = None
                            self.area_interfaces = None
                            self.is_area_stubbed = None
                            self.is_area_total_stubbed = None
                            self.stub_default_cost = None
                            self.is_area_nssa = None
                            self.nssa_no_redistribution = None
                            self.is_nssa_translated = None
                            self.is_nssa_translated_always = None
                            self.is_nssa_default = None
                            self.is_rrr_enabled = None
                            self.sp_fs = None
                            self.area_opaque_lsas = None
                            self.area_opaque_lsa_checksum = None
                            self.area_dc_bitless_ls_as = None
                            self.indication_ls_as = None
                            self.do_not_age_ls_as = None
                            self.flood_list_length = None
                            self.area_lfa_interface_count = None
                            self.area_per_prefix_lfa_interface_count = None
                            self.area_lfa_revision = None

                            self.area_range = YList(self)
                            self._segment_path = lambda: "area-information" + "[area-id='" + str(self.area_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation, ['area_id', u'is_backbone_area_active', u'area_interfaces', u'is_area_stubbed', u'is_area_total_stubbed', u'stub_default_cost', u'is_area_nssa', u'nssa_no_redistribution', u'is_nssa_translated', u'is_nssa_translated_always', u'is_nssa_default', u'is_rrr_enabled', u'sp_fs', u'area_opaque_lsas', u'area_opaque_lsa_checksum', u'area_dc_bitless_ls_as', u'indication_ls_as', u'do_not_age_ls_as', u'flood_list_length', u'area_lfa_interface_count', u'area_per_prefix_lfa_interface_count', u'area_lfa_revision'], name, value)


                        class AreaRange(Entity):
                            """
                            List of ranges to summarize
                            
                            .. attribute:: range_prefix
                            
                            	IP prefix for summarization
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: range_prefix_length
                            
                            	IP prefix length for summarization
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: net_cost
                            
                            	Net cost 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status
                            
                            	Area range status 
                            	**type**\:  :py:class:`Ospfv3AreaRangeStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3AreaRangeStatus>`
                            
                            .. attribute:: is_cost_configured
                            
                            	If true, cost is configured 
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation.AreaRange, self).__init__()

                                self.yang_name = "area-range"
                                self.yang_parent_name = "area-information"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('range_prefix', (YLeaf(YType.str, 'range-prefix'), ['str'])),
                                    ('range_prefix_length', (YLeaf(YType.uint32, 'range-prefix-length'), ['int'])),
                                    ('net_cost', (YLeaf(YType.uint32, 'net-cost'), ['int'])),
                                    ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3AreaRangeStatus', '')])),
                                    ('is_cost_configured', (YLeaf(YType.boolean, 'is-cost-configured'), ['bool'])),
                                ])
                                self.range_prefix = None
                                self.range_prefix_length = None
                                self.net_cost = None
                                self.status = None
                                self.is_cost_configured = None
                                self._segment_path = lambda: "area-range"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.AreaInformations.AreaInformation.AreaRange, [u'range_prefix', u'range_prefix_length', u'net_cost', u'status', u'is_cost_configured'], name, value)


                class DatabaseTable(Entity):
                    """
                    OSPF Link State Database
                    
                    .. attribute:: lsa_table
                    
                    	Database LSA information
                    	**type**\:  :py:class:`LsaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable>`
                    
                    .. attribute:: lsa_internal_table
                    
                    	Database LSA information
                    	**type**\:  :py:class:`LsaInternalTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable, self).__init__()

                        self.yang_name = "database-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("lsa-table", ("lsa_table", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable)), ("lsa-internal-table", ("lsa_internal_table", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable))])
                        self._leafs = OrderedDict()

                        self.lsa_table = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable()
                        self.lsa_table.parent = self
                        self._children_name_map["lsa_table"] = "lsa-table"

                        self.lsa_internal_table = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable()
                        self.lsa_internal_table.parent = self
                        self._children_name_map["lsa_internal_table"] = "lsa-internal-table"
                        self._segment_path = lambda: "database-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable, [], name, value)


                    class LsaTable(Entity):
                        """
                        Database LSA information
                        
                        .. attribute:: lsa
                        
                        	Database LSA information
                        	**type**\: list of  		 :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable, self).__init__()

                            self.yang_name = "lsa-table"
                            self.yang_parent_name = "database-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lsa", ("lsa", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa))])
                            self._leafs = OrderedDict()

                            self.lsa = YList(self)
                            self._segment_path = lambda: "lsa-table"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable, [], name, value)


                        class Lsa(Entity):
                            """
                            Database LSA information
                            
                            .. attribute:: area_id
                            
                            	Area ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ls_type
                            
                            	LSA type
                            	**type**\:  :py:class:`Ospfv3Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa>`
                            
                            .. attribute:: advertising_router
                            
                            	Advertising Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ls_id
                            
                            	Link state ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_name
                            
                            	InterfaceName
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: lsa_info
                            
                            	Summary of all LSAs or LSA specific information 
                            	**type**\:  :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa, self).__init__()

                                self.yang_name = "lsa"
                                self.yang_parent_name = "lsa-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lsa-info", ("lsa_info", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo))])
                                self._leafs = OrderedDict([
                                    ('area_id', (YLeaf(YType.uint32, 'area-id'), ['int'])),
                                    ('ls_type', (YLeaf(YType.enumeration, 'ls-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa', '')])),
                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ])
                                self.area_id = None
                                self.ls_type = None
                                self.advertising_router = None
                                self.ls_id = None
                                self.interface_name = None

                                self.lsa_info = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo()
                                self.lsa_info.parent = self
                                self._children_name_map["lsa_info"] = "lsa-info"
                                self._segment_path = lambda: "lsa"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa, ['area_id', 'ls_type', 'advertising_router', 'ls_id', 'interface_name'], name, value)


                            class LsaInfo(Entity):
                                """
                                Summary of all LSAs or LSA specific information 
                                
                                .. attribute:: lsa_summary_info
                                
                                	Summary information of LSAs
                                	**type**\:  :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                
                                .. attribute:: router_lsa_type
                                
                                	Router LSA
                                	**type**\:  :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType>`
                                
                                .. attribute:: network_lsa_type
                                
                                	Network LSA
                                	**type**\:  :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType>`
                                
                                .. attribute:: inter_area_prefix_lsa_type
                                
                                	Inter Area Prefix LSA
                                	**type**\:  :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                
                                .. attribute:: inter_area_router_lsa_type
                                
                                	Inter Area Router LSA
                                	**type**\:  :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                
                                .. attribute:: external_lsa_type
                                
                                	External LSA
                                	**type**\:  :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType>`
                                
                                .. attribute:: nssalsa_type
                                
                                	NSSA External LSA
                                	**type**\:  :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType>`
                                
                                .. attribute:: link_lsa_type
                                
                                	Link LSA
                                	**type**\:  :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType>`
                                
                                .. attribute:: intra_area_prefix_lsa_type
                                
                                	Intra Area Prefix LSA
                                	**type**\:  :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                
                                .. attribute:: grace_lsa
                                
                                	Grace LSA
                                	**type**\:  :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa>`
                                
                                .. attribute:: unknown_link_lsa_type
                                
                                	Unknown Link Scope LSA
                                	**type**\:  :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                
                                .. attribute:: unknown_area_lsa_type
                                
                                	Unknown\-Area scope LSA
                                	**type**\:  :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                
                                .. attribute:: unknown_aslsa_type
                                
                                	Unknown\-AS scope LSA
                                	**type**\:  :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType>`
                                
                                .. attribute:: unknown_lsa_type
                                
                                	Unknown LSA
                                	**type**\:  :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType>`
                                
                                .. attribute:: lsa_info_type
                                
                                	LSAInfoType
                                	**type**\:  :py:class:`Ospfv3LsaInfoTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypes>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo, self).__init__()

                                    self.yang_name = "lsa-info"
                                    self.yang_parent_name = "lsa"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lsa-summary-info", ("lsa_summary_info", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo)), ("router-lsa-type", ("router_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType)), ("network-lsa-type", ("network_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType)), ("inter-area-prefix-lsa-type", ("inter_area_prefix_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType)), ("inter-area-router-lsa-type", ("inter_area_router_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType)), ("external-lsa-type", ("external_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType)), ("nssalsa-type", ("nssalsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType)), ("link-lsa-type", ("link_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType)), ("intra-area-prefix-lsa-type", ("intra_area_prefix_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType)), ("grace-lsa", ("grace_lsa", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa)), ("unknown-link-lsa-type", ("unknown_link_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType)), ("unknown-area-lsa-type", ("unknown_area_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType)), ("unknown-aslsa-type", ("unknown_aslsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType)), ("unknown-lsa-type", ("unknown_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType))])
                                    self._leafs = OrderedDict([
                                        ('lsa_info_type', (YLeaf(YType.enumeration, 'lsa-info-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3LsaInfoTypes', '')])),
                                    ])
                                    self.lsa_info_type = None

                                    self.lsa_summary_info = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo()
                                    self.lsa_summary_info.parent = self
                                    self._children_name_map["lsa_summary_info"] = "lsa-summary-info"

                                    self.router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType()
                                    self.router_lsa_type.parent = self
                                    self._children_name_map["router_lsa_type"] = "router-lsa-type"

                                    self.network_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType()
                                    self.network_lsa_type.parent = self
                                    self._children_name_map["network_lsa_type"] = "network-lsa-type"

                                    self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                    self.inter_area_prefix_lsa_type.parent = self
                                    self._children_name_map["inter_area_prefix_lsa_type"] = "inter-area-prefix-lsa-type"

                                    self.inter_area_router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                    self.inter_area_router_lsa_type.parent = self
                                    self._children_name_map["inter_area_router_lsa_type"] = "inter-area-router-lsa-type"

                                    self.external_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType()
                                    self.external_lsa_type.parent = self
                                    self._children_name_map["external_lsa_type"] = "external-lsa-type"

                                    self.nssalsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType()
                                    self.nssalsa_type.parent = self
                                    self._children_name_map["nssalsa_type"] = "nssalsa-type"

                                    self.link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType()
                                    self.link_lsa_type.parent = self
                                    self._children_name_map["link_lsa_type"] = "link-lsa-type"

                                    self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                    self.intra_area_prefix_lsa_type.parent = self
                                    self._children_name_map["intra_area_prefix_lsa_type"] = "intra-area-prefix-lsa-type"

                                    self.grace_lsa = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa()
                                    self.grace_lsa.parent = self
                                    self._children_name_map["grace_lsa"] = "grace-lsa"

                                    self.unknown_link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                    self.unknown_link_lsa_type.parent = self
                                    self._children_name_map["unknown_link_lsa_type"] = "unknown-link-lsa-type"

                                    self.unknown_area_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                    self.unknown_area_lsa_type.parent = self
                                    self._children_name_map["unknown_area_lsa_type"] = "unknown-area-lsa-type"

                                    self.unknown_aslsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType()
                                    self.unknown_aslsa_type.parent = self
                                    self._children_name_map["unknown_aslsa_type"] = "unknown-aslsa-type"

                                    self.unknown_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType()
                                    self.unknown_lsa_type.parent = self
                                    self._children_name_map["unknown_lsa_type"] = "unknown-lsa-type"
                                    self._segment_path = lambda: "lsa-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo, [u'lsa_info_type'], name, value)


                                class LsaSummaryInfo(Entity):
                                    """
                                    Summary information of LSAs
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                    
                                    .. attribute:: links
                                    
                                    	Number of links
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: router_la_bits
                                    
                                    	Router LA bits 
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: reference_type
                                    
                                    	Reference type 
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: reference_lsa_id
                                    
                                    	Reference LSA ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_router_id
                                    
                                    	LSA router ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	OSPFv3 address Prefix 
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\: bool
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\: bool
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Sham link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo, self).__init__()

                                        self.yang_name = "lsa-summary-info"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('links', (YLeaf(YType.uint16, 'links'), ['int'])),
                                            ('router_la_bits', (YLeaf(YType.uint8, 'router-la-bits'), ['int'])),
                                            ('reference_type', (YLeaf(YType.uint16, 'reference-type'), ['int'])),
                                            ('reference_lsa_id', (YLeaf(YType.uint32, 'reference-lsa-id'), ['int'])),
                                            ('lsa_router_id', (YLeaf(YType.uint32, 'lsa-router-id'), ['int'])),
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                            ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                            ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                            ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                        ])
                                        self.links = None
                                        self.router_la_bits = None
                                        self.reference_type = None
                                        self.reference_lsa_id = None
                                        self.lsa_router_id = None
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.interface_name = None
                                        self.is_virtual_link = None
                                        self.virtual_link_id = None
                                        self.is_sham_link = None
                                        self.sham_link_id = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "lsa-summary-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo, [u'links', u'router_la_bits', u'reference_type', u'reference_lsa_id', u'lsa_router_id', u'prefix', u'prefix_length', u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "lsa-summary-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "lsa-summary-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class RouterLsaType(Entity):
                                    """
                                    Router LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                    
                                    .. attribute:: rpf_path
                                    
                                    	Router LSA Reverse\-Path Forwarding information 
                                    	**type**\:  :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                    
                                    .. attribute:: router_la_bits
                                    
                                    	Router LA bits 
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: link
                                    
                                    	List of links in this LSA
                                    	**type**\: list of  		 :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType, self).__init__()

                                        self.yang_name = "router-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail)), ("rpf-path", ("rpf_path", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath)), ("link", ("link", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link))])
                                        self._leafs = OrderedDict([
                                            ('router_la_bits', (YLeaf(YType.uint8, 'router-la-bits'), ['int'])),
                                        ])
                                        self.router_la_bits = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"

                                        self.rpf_path = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                        self.rpf_path.parent = self
                                        self._children_name_map["rpf_path"] = "rpf-path"

                                        self.link = YList(self)
                                        self._segment_path = lambda: "router-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType, [u'router_la_bits'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class RpfPath(Entity):
                                        """
                                        Router LSA Reverse\-Path Forwarding information 
                                        
                                        .. attribute:: rpf_multicast_next_hop
                                        
                                        	RPF multicast next hop 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_name
                                        
                                        	RPF multicast IDB 
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath, self).__init__()

                                            self.yang_name = "rpf-path"
                                            self.yang_parent_name = "router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('rpf_multicast_next_hop', (YLeaf(YType.uint32, 'rpf-multicast-next-hop'), ['int'])),
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ])
                                            self.rpf_multicast_next_hop = None
                                            self.interface_name = None
                                            self._segment_path = lambda: "rpf-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath, [u'rpf_multicast_next_hop', u'interface_name'], name, value)


                                    class Link(Entity):
                                        """
                                        List of links in this LSA
                                        
                                        .. attribute:: link_type
                                        
                                        	Type of link
                                        	**type**\:  :py:class:`Ospfv3Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Link>`
                                        
                                        .. attribute:: link_metric
                                        
                                        	LSA link metric 
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: link_interface_id
                                        
                                        	LSA link interface ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_neighbor_interface_id
                                        
                                        	LSA link neighbor interface ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_neighbor_router_id
                                        
                                        	LSA link neigbhor router id 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link, self).__init__()

                                            self.yang_name = "link"
                                            self.yang_parent_name = "router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Link', '')])),
                                                ('link_metric', (YLeaf(YType.uint16, 'link-metric'), ['int'])),
                                                ('link_interface_id', (YLeaf(YType.uint32, 'link-interface-id'), ['int'])),
                                                ('link_neighbor_interface_id', (YLeaf(YType.uint32, 'link-neighbor-interface-id'), ['int'])),
                                                ('link_neighbor_router_id', (YLeaf(YType.uint32, 'link-neighbor-router-id'), ['int'])),
                                            ])
                                            self.link_type = None
                                            self.link_metric = None
                                            self.link_interface_id = None
                                            self.link_neighbor_interface_id = None
                                            self.link_neighbor_router_id = None
                                            self._segment_path = lambda: "link"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link, [u'link_type', u'link_metric', u'link_interface_id', u'link_neighbor_interface_id', u'link_neighbor_router_id'], name, value)


                                class NetworkLsaType(Entity):
                                    """
                                    Network LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                    
                                    .. attribute:: neighbor_router
                                    
                                    	Neighbor router list
                                    	**type**\: list of str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType, self).__init__()

                                        self.yang_name = "network-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('neighbor_router', (YLeafList(YType.str, 'neighbor-router'), ['str'])),
                                        ])
                                        self.neighbor_router = []

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "network-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType, [u'neighbor_router'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "network-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "network-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class InterAreaPrefixLsaType(Entity):
                                    """
                                    Inter Area Prefix LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA Information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                    
                                    .. attribute:: prefix
                                    
                                    	LSA address prefix 
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: priority
                                    
                                    	Prefix priority
                                    	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType, self).__init__()

                                        self.yang_name = "inter-area-prefix-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.priority = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "inter-area-prefix-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType, [u'prefix', u'prefix_length', u'priority'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "inter-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "inter-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class InterAreaRouterLsaType(Entity):
                                    """
                                    Inter Area Router LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_router_id
                                    
                                    	LSA router ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType, self).__init__()

                                        self.yang_name = "inter-area-router-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('lsa_router_id', (YLeaf(YType.uint32, 'lsa-router-id'), ['int'])),
                                        ])
                                        self.lsa_router_id = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "inter-area-router-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType, [u'lsa_router_id'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "inter-area-router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "inter-area-router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class ExternalLsaType(Entity):
                                    """
                                    External LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA Information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                    
                                    .. attribute:: prefix
                                    
                                    	IPV6 address prefix 
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: metric_type
                                    
                                    	Metric type 
                                    	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                    
                                    .. attribute:: tos_cost
                                    
                                    	Type of service cost metric 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_forwarding_address_set
                                    
                                    	If true, forwarding address is set 
                                    	**type**\: bool
                                    
                                    .. attribute:: forwarding_address
                                    
                                    	Forwarding Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: external_tag
                                    
                                    	Route Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: priority
                                    
                                    	Prefix priority
                                    	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType, self).__init__()

                                        self.yang_name = "external-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                            ('tos_cost', (YLeaf(YType.uint32, 'tos-cost'), ['int'])),
                                            ('is_forwarding_address_set', (YLeaf(YType.boolean, 'is-forwarding-address-set'), ['bool'])),
                                            ('forwarding_address', (YLeaf(YType.str, 'forwarding-address'), ['str'])),
                                            ('external_tag', (YLeaf(YType.uint32, 'external-tag'), ['int'])),
                                            ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.metric_type = None
                                        self.tos_cost = None
                                        self.is_forwarding_address_set = None
                                        self.forwarding_address = None
                                        self.external_tag = None
                                        self.priority = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "external-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType, [u'prefix', u'prefix_length', u'metric_type', u'tos_cost', u'is_forwarding_address_set', u'forwarding_address', u'external_tag', u'priority'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "external-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "external-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class NssalsaType(Entity):
                                    """
                                    NSSA External LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA Information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                    
                                    .. attribute:: prefix
                                    
                                    	IPV6 address prefix 
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: metric_type
                                    
                                    	Metric type 
                                    	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                    
                                    .. attribute:: tos_cost
                                    
                                    	Type of service cost metric 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_forwarding_address_set
                                    
                                    	If true, forwarding address is set 
                                    	**type**\: bool
                                    
                                    .. attribute:: forwarding_address
                                    
                                    	Forwarding Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: external_tag
                                    
                                    	Route Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: priority
                                    
                                    	Prefix priority
                                    	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType, self).__init__()

                                        self.yang_name = "nssalsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                            ('tos_cost', (YLeaf(YType.uint32, 'tos-cost'), ['int'])),
                                            ('is_forwarding_address_set', (YLeaf(YType.boolean, 'is-forwarding-address-set'), ['bool'])),
                                            ('forwarding_address', (YLeaf(YType.str, 'forwarding-address'), ['str'])),
                                            ('external_tag', (YLeaf(YType.uint32, 'external-tag'), ['int'])),
                                            ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.metric_type = None
                                        self.tos_cost = None
                                        self.is_forwarding_address_set = None
                                        self.forwarding_address = None
                                        self.external_tag = None
                                        self.priority = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "nssalsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType, [u'prefix', u'prefix_length', u'metric_type', u'tos_cost', u'is_forwarding_address_set', u'forwarding_address', u'external_tag', u'priority'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "nssalsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "nssalsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class LinkLsaType(Entity):
                                    """
                                    Link LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface handle
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link
                                    	**type**\: bool
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link
                                    	**type**\: bool
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Sham link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_link_local
                                    
                                    	LSA link local 
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: router_priority
                                    
                                    	Router priority 
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: prefix
                                    
                                    	OSPFv3 prefix 
                                    	**type**\: list of  		 :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType, self).__init__()

                                        self.yang_name = "link-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail)), ("prefix", ("prefix", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                            ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                            ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                            ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                            ('lsa_link_local', (YLeaf(YType.str, 'lsa-link-local'), ['str'])),
                                            ('router_priority', (YLeaf(YType.uint8, 'router-priority'), ['int'])),
                                        ])
                                        self.interface_name = None
                                        self.is_virtual_link = None
                                        self.virtual_link_id = None
                                        self.is_sham_link = None
                                        self.sham_link_id = None
                                        self.lsa_link_local = None
                                        self.router_priority = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"

                                        self.prefix = YList(self)
                                        self._segment_path = lambda: "link-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id', u'lsa_link_local', u'router_priority'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class Prefix(Entity):
                                        """
                                        OSPFv3 prefix 
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ospfv3_prefix_length
                                        
                                        	OSPFv3 prefix length 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ospfv3_prefix_options
                                        
                                        	OSPFv3 prefix options 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ospfv3_prefix_metric
                                        
                                        	OSPFv3 prefix metric 
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix, self).__init__()

                                            self.yang_name = "prefix"
                                            self.yang_parent_name = "link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                ('ospfv3_prefix_length', (YLeaf(YType.uint8, 'ospfv3-prefix-length'), ['int'])),
                                                ('ospfv3_prefix_options', (YLeaf(YType.uint8, 'ospfv3-prefix-options'), ['int'])),
                                                ('ospfv3_prefix_metric', (YLeaf(YType.uint16, 'ospfv3-prefix-metric'), ['int'])),
                                                ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                            ])
                                            self.prefix = None
                                            self.ospfv3_prefix_length = None
                                            self.ospfv3_prefix_options = None
                                            self.ospfv3_prefix_metric = None
                                            self.priority = None
                                            self._segment_path = lambda: "prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix, [u'prefix', u'ospfv3_prefix_length', u'ospfv3_prefix_options', u'ospfv3_prefix_metric', u'priority'], name, value)


                                class IntraAreaPrefixLsaType(Entity):
                                    """
                                    Intra Area Prefix LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                    
                                    .. attribute:: reference_type
                                    
                                    	Reference type 
                                    	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                    
                                    .. attribute:: reference_lsa_id
                                    
                                    	Reference LSA ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reference_advertised_router
                                    
                                    	Reference advertised router 
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix
                                    
                                    	OSPFv3 prefix 
                                    	**type**\: list of  		 :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, self).__init__()

                                        self.yang_name = "intra-area-prefix-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail)), ("prefix", ("prefix", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix))])
                                        self._leafs = OrderedDict([
                                            ('reference_type', (YLeaf(YType.enumeration, 'reference-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                            ('reference_lsa_id', (YLeaf(YType.uint32, 'reference-lsa-id'), ['int'])),
                                            ('reference_advertised_router', (YLeaf(YType.str, 'reference-advertised-router'), ['str'])),
                                        ])
                                        self.reference_type = None
                                        self.reference_lsa_id = None
                                        self.reference_advertised_router = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"

                                        self.prefix = YList(self)
                                        self._segment_path = lambda: "intra-area-prefix-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, [u'reference_type', u'reference_lsa_id', u'reference_advertised_router'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "intra-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "intra-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class Prefix(Entity):
                                        """
                                        OSPFv3 prefix 
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ospfv3_prefix_length
                                        
                                        	OSPFv3 prefix length 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ospfv3_prefix_options
                                        
                                        	OSPFv3 prefix options 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ospfv3_prefix_metric
                                        
                                        	OSPFv3 prefix metric 
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, self).__init__()

                                            self.yang_name = "prefix"
                                            self.yang_parent_name = "intra-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                ('ospfv3_prefix_length', (YLeaf(YType.uint8, 'ospfv3-prefix-length'), ['int'])),
                                                ('ospfv3_prefix_options', (YLeaf(YType.uint8, 'ospfv3-prefix-options'), ['int'])),
                                                ('ospfv3_prefix_metric', (YLeaf(YType.uint16, 'ospfv3-prefix-metric'), ['int'])),
                                                ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                            ])
                                            self.prefix = None
                                            self.ospfv3_prefix_length = None
                                            self.ospfv3_prefix_options = None
                                            self.ospfv3_prefix_metric = None
                                            self.priority = None
                                            self._segment_path = lambda: "prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, [u'prefix', u'ospfv3_prefix_length', u'ospfv3_prefix_options', u'ospfv3_prefix_metric', u'priority'], name, value)


                                class GraceLsa(Entity):
                                    """
                                    Grace LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface handle
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link
                                    	**type**\: bool
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link
                                    	**type**\: bool
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Sham link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: grace_period
                                    
                                    	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: grace_reason
                                    
                                    	Reason for router restart
                                    	**type**\:  :py:class:`Ospfv3GracefulRestartReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReason>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa, self).__init__()

                                        self.yang_name = "grace-lsa"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                            ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                            ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                            ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                            ('grace_period', (YLeaf(YType.uint32, 'grace-period'), ['int'])),
                                            ('grace_reason', (YLeaf(YType.enumeration, 'grace-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3GracefulRestartReason', '')])),
                                        ])
                                        self.interface_name = None
                                        self.is_virtual_link = None
                                        self.virtual_link_id = None
                                        self.is_sham_link = None
                                        self.sham_link_id = None
                                        self.grace_period = None
                                        self.grace_reason = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "grace-lsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id', u'grace_period', u'grace_reason'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "grace-lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "grace-lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class UnknownLinkLsaType(Entity):
                                    """
                                    Unknown Link Scope LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\: bool
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\: bool
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType, self).__init__()

                                        self.yang_name = "unknown-link-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                            ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                            ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                            ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                        ])
                                        self.interface_name = None
                                        self.is_virtual_link = None
                                        self.virtual_link_id = None
                                        self.is_sham_link = None
                                        self.sham_link_id = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "unknown-link-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "unknown-link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "unknown-link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class UnknownAreaLsaType(Entity):
                                    """
                                    Unknown\-Area scope LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\: bool
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\: bool
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType, self).__init__()

                                        self.yang_name = "unknown-area-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                            ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                            ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                            ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                        ])
                                        self.interface_name = None
                                        self.is_virtual_link = None
                                        self.virtual_link_id = None
                                        self.is_sham_link = None
                                        self.sham_link_id = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "unknown-area-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "unknown-area-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "unknown-area-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class UnknownAslsaType(Entity):
                                    """
                                    Unknown\-AS scope LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\: bool
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\: bool
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType, self).__init__()

                                        self.yang_name = "unknown-aslsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                            ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                            ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                            ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                        ])
                                        self.interface_name = None
                                        self.is_virtual_link = None
                                        self.virtual_link_id = None
                                        self.is_sham_link = None
                                        self.sham_link_id = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "unknown-aslsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "unknown-aslsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "unknown-aslsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class UnknownLsaType(Entity):
                                    """
                                    Unknown LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\: bool
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\: bool
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType, self).__init__()

                                        self.yang_name = "unknown-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                            ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                            ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                            ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                        ])
                                        self.interface_name = None
                                        self.is_virtual_link = None
                                        self.virtual_link_id = None
                                        self.is_sham_link = None
                                        self.sham_link_id = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "unknown-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "unknown-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "unknown-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                    class LsaInternalTable(Entity):
                        """
                        Database LSA information
                        
                        .. attribute:: lsa
                        
                        	Database LSA information
                        	**type**\: list of  		 :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable, self).__init__()

                            self.yang_name = "lsa-internal-table"
                            self.yang_parent_name = "database-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lsa", ("lsa", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa))])
                            self._leafs = OrderedDict()

                            self.lsa = YList(self)
                            self._segment_path = lambda: "lsa-internal-table"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable, [], name, value)


                        class Lsa(Entity):
                            """
                            Database LSA information
                            
                            .. attribute:: area_id
                            
                            	Area ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ls_type
                            
                            	LSA type
                            	**type**\:  :py:class:`Ospfv3Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa>`
                            
                            .. attribute:: advertising_router
                            
                            	Advertising Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ls_id
                            
                            	Link state ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_name
                            
                            	InterfaceName
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: lsa_info
                            
                            	Summary of all LSAs or LSA specific information 
                            	**type**\:  :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa, self).__init__()

                                self.yang_name = "lsa"
                                self.yang_parent_name = "lsa-internal-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lsa-info", ("lsa_info", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo))])
                                self._leafs = OrderedDict([
                                    ('area_id', (YLeaf(YType.uint32, 'area-id'), ['int'])),
                                    ('ls_type', (YLeaf(YType.enumeration, 'ls-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa', '')])),
                                    ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                    ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ])
                                self.area_id = None
                                self.ls_type = None
                                self.advertising_router = None
                                self.ls_id = None
                                self.interface_name = None

                                self.lsa_info = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo()
                                self.lsa_info.parent = self
                                self._children_name_map["lsa_info"] = "lsa-info"
                                self._segment_path = lambda: "lsa"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa, ['area_id', 'ls_type', 'advertising_router', 'ls_id', 'interface_name'], name, value)


                            class LsaInfo(Entity):
                                """
                                Summary of all LSAs or LSA specific information 
                                
                                .. attribute:: lsa_summary_info
                                
                                	Summary information of LSAs
                                	**type**\:  :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                
                                .. attribute:: router_lsa_type
                                
                                	Router LSA
                                	**type**\:  :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType>`
                                
                                .. attribute:: network_lsa_type
                                
                                	Network LSA
                                	**type**\:  :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType>`
                                
                                .. attribute:: inter_area_prefix_lsa_type
                                
                                	Inter Area Prefix LSA
                                	**type**\:  :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                
                                .. attribute:: inter_area_router_lsa_type
                                
                                	Inter Area Router LSA
                                	**type**\:  :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                
                                .. attribute:: external_lsa_type
                                
                                	External LSA
                                	**type**\:  :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType>`
                                
                                .. attribute:: nssalsa_type
                                
                                	NSSA External LSA
                                	**type**\:  :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType>`
                                
                                .. attribute:: link_lsa_type
                                
                                	Link LSA
                                	**type**\:  :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType>`
                                
                                .. attribute:: intra_area_prefix_lsa_type
                                
                                	Intra Area Prefix LSA
                                	**type**\:  :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                
                                .. attribute:: grace_lsa
                                
                                	Grace LSA
                                	**type**\:  :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa>`
                                
                                .. attribute:: unknown_link_lsa_type
                                
                                	Unknown Link Scope LSA
                                	**type**\:  :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                
                                .. attribute:: unknown_area_lsa_type
                                
                                	Unknown\-Area scope LSA
                                	**type**\:  :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                
                                .. attribute:: unknown_aslsa_type
                                
                                	Unknown\-AS scope LSA
                                	**type**\:  :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType>`
                                
                                .. attribute:: unknown_lsa_type
                                
                                	Unknown LSA
                                	**type**\:  :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType>`
                                
                                .. attribute:: lsa_info_type
                                
                                	LSAInfoType
                                	**type**\:  :py:class:`Ospfv3LsaInfoTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypes>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo, self).__init__()

                                    self.yang_name = "lsa-info"
                                    self.yang_parent_name = "lsa"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lsa-summary-info", ("lsa_summary_info", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo)), ("router-lsa-type", ("router_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType)), ("network-lsa-type", ("network_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType)), ("inter-area-prefix-lsa-type", ("inter_area_prefix_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType)), ("inter-area-router-lsa-type", ("inter_area_router_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType)), ("external-lsa-type", ("external_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType)), ("nssalsa-type", ("nssalsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType)), ("link-lsa-type", ("link_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType)), ("intra-area-prefix-lsa-type", ("intra_area_prefix_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType)), ("grace-lsa", ("grace_lsa", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa)), ("unknown-link-lsa-type", ("unknown_link_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType)), ("unknown-area-lsa-type", ("unknown_area_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType)), ("unknown-aslsa-type", ("unknown_aslsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType)), ("unknown-lsa-type", ("unknown_lsa_type", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType))])
                                    self._leafs = OrderedDict([
                                        ('lsa_info_type', (YLeaf(YType.enumeration, 'lsa-info-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3LsaInfoTypes', '')])),
                                    ])
                                    self.lsa_info_type = None

                                    self.lsa_summary_info = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo()
                                    self.lsa_summary_info.parent = self
                                    self._children_name_map["lsa_summary_info"] = "lsa-summary-info"

                                    self.router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType()
                                    self.router_lsa_type.parent = self
                                    self._children_name_map["router_lsa_type"] = "router-lsa-type"

                                    self.network_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType()
                                    self.network_lsa_type.parent = self
                                    self._children_name_map["network_lsa_type"] = "network-lsa-type"

                                    self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                    self.inter_area_prefix_lsa_type.parent = self
                                    self._children_name_map["inter_area_prefix_lsa_type"] = "inter-area-prefix-lsa-type"

                                    self.inter_area_router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                    self.inter_area_router_lsa_type.parent = self
                                    self._children_name_map["inter_area_router_lsa_type"] = "inter-area-router-lsa-type"

                                    self.external_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType()
                                    self.external_lsa_type.parent = self
                                    self._children_name_map["external_lsa_type"] = "external-lsa-type"

                                    self.nssalsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType()
                                    self.nssalsa_type.parent = self
                                    self._children_name_map["nssalsa_type"] = "nssalsa-type"

                                    self.link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType()
                                    self.link_lsa_type.parent = self
                                    self._children_name_map["link_lsa_type"] = "link-lsa-type"

                                    self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                    self.intra_area_prefix_lsa_type.parent = self
                                    self._children_name_map["intra_area_prefix_lsa_type"] = "intra-area-prefix-lsa-type"

                                    self.grace_lsa = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa()
                                    self.grace_lsa.parent = self
                                    self._children_name_map["grace_lsa"] = "grace-lsa"

                                    self.unknown_link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                    self.unknown_link_lsa_type.parent = self
                                    self._children_name_map["unknown_link_lsa_type"] = "unknown-link-lsa-type"

                                    self.unknown_area_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                    self.unknown_area_lsa_type.parent = self
                                    self._children_name_map["unknown_area_lsa_type"] = "unknown-area-lsa-type"

                                    self.unknown_aslsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType()
                                    self.unknown_aslsa_type.parent = self
                                    self._children_name_map["unknown_aslsa_type"] = "unknown-aslsa-type"

                                    self.unknown_lsa_type = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType()
                                    self.unknown_lsa_type.parent = self
                                    self._children_name_map["unknown_lsa_type"] = "unknown-lsa-type"
                                    self._segment_path = lambda: "lsa-info"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo, [u'lsa_info_type'], name, value)


                                class LsaSummaryInfo(Entity):
                                    """
                                    Summary information of LSAs
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                    
                                    .. attribute:: links
                                    
                                    	Number of links
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: router_la_bits
                                    
                                    	Router LA bits 
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: reference_type
                                    
                                    	Reference type 
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: reference_lsa_id
                                    
                                    	Reference LSA ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_router_id
                                    
                                    	LSA router ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: prefix
                                    
                                    	OSPFv3 address Prefix 
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\: bool
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\: bool
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Sham link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo, self).__init__()

                                        self.yang_name = "lsa-summary-info"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('links', (YLeaf(YType.uint16, 'links'), ['int'])),
                                            ('router_la_bits', (YLeaf(YType.uint8, 'router-la-bits'), ['int'])),
                                            ('reference_type', (YLeaf(YType.uint16, 'reference-type'), ['int'])),
                                            ('reference_lsa_id', (YLeaf(YType.uint32, 'reference-lsa-id'), ['int'])),
                                            ('lsa_router_id', (YLeaf(YType.uint32, 'lsa-router-id'), ['int'])),
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                            ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                            ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                            ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                        ])
                                        self.links = None
                                        self.router_la_bits = None
                                        self.reference_type = None
                                        self.reference_lsa_id = None
                                        self.lsa_router_id = None
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.interface_name = None
                                        self.is_virtual_link = None
                                        self.virtual_link_id = None
                                        self.is_sham_link = None
                                        self.sham_link_id = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "lsa-summary-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo, [u'links', u'router_la_bits', u'reference_type', u'reference_lsa_id', u'lsa_router_id', u'prefix', u'prefix_length', u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "lsa-summary-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "lsa-summary-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class RouterLsaType(Entity):
                                    """
                                    Router LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                    
                                    .. attribute:: rpf_path
                                    
                                    	Router LSA Reverse\-Path Forwarding information 
                                    	**type**\:  :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                    
                                    .. attribute:: router_la_bits
                                    
                                    	Router LA bits 
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: link
                                    
                                    	List of links in this LSA
                                    	**type**\: list of  		 :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType, self).__init__()

                                        self.yang_name = "router-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail)), ("rpf-path", ("rpf_path", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath)), ("link", ("link", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link))])
                                        self._leafs = OrderedDict([
                                            ('router_la_bits', (YLeaf(YType.uint8, 'router-la-bits'), ['int'])),
                                        ])
                                        self.router_la_bits = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"

                                        self.rpf_path = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                        self.rpf_path.parent = self
                                        self._children_name_map["rpf_path"] = "rpf-path"

                                        self.link = YList(self)
                                        self._segment_path = lambda: "router-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType, [u'router_la_bits'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class RpfPath(Entity):
                                        """
                                        Router LSA Reverse\-Path Forwarding information 
                                        
                                        .. attribute:: rpf_multicast_next_hop
                                        
                                        	RPF multicast next hop 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_name
                                        
                                        	RPF multicast IDB 
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath, self).__init__()

                                            self.yang_name = "rpf-path"
                                            self.yang_parent_name = "router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('rpf_multicast_next_hop', (YLeaf(YType.uint32, 'rpf-multicast-next-hop'), ['int'])),
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ])
                                            self.rpf_multicast_next_hop = None
                                            self.interface_name = None
                                            self._segment_path = lambda: "rpf-path"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath, [u'rpf_multicast_next_hop', u'interface_name'], name, value)


                                    class Link(Entity):
                                        """
                                        List of links in this LSA
                                        
                                        .. attribute:: link_type
                                        
                                        	Type of link
                                        	**type**\:  :py:class:`Ospfv3Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Link>`
                                        
                                        .. attribute:: link_metric
                                        
                                        	LSA link metric 
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: link_interface_id
                                        
                                        	LSA link interface ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_neighbor_interface_id
                                        
                                        	LSA link neighbor interface ID 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_neighbor_router_id
                                        
                                        	LSA link neigbhor router id 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link, self).__init__()

                                            self.yang_name = "link"
                                            self.yang_parent_name = "router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Link', '')])),
                                                ('link_metric', (YLeaf(YType.uint16, 'link-metric'), ['int'])),
                                                ('link_interface_id', (YLeaf(YType.uint32, 'link-interface-id'), ['int'])),
                                                ('link_neighbor_interface_id', (YLeaf(YType.uint32, 'link-neighbor-interface-id'), ['int'])),
                                                ('link_neighbor_router_id', (YLeaf(YType.uint32, 'link-neighbor-router-id'), ['int'])),
                                            ])
                                            self.link_type = None
                                            self.link_metric = None
                                            self.link_interface_id = None
                                            self.link_neighbor_interface_id = None
                                            self.link_neighbor_router_id = None
                                            self._segment_path = lambda: "link"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link, [u'link_type', u'link_metric', u'link_interface_id', u'link_neighbor_interface_id', u'link_neighbor_router_id'], name, value)


                                class NetworkLsaType(Entity):
                                    """
                                    Network LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                    
                                    .. attribute:: neighbor_router
                                    
                                    	Neighbor router list
                                    	**type**\: list of str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType, self).__init__()

                                        self.yang_name = "network-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('neighbor_router', (YLeafList(YType.str, 'neighbor-router'), ['str'])),
                                        ])
                                        self.neighbor_router = []

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "network-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType, [u'neighbor_router'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "network-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "network-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class InterAreaPrefixLsaType(Entity):
                                    """
                                    Inter Area Prefix LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA Information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                    
                                    .. attribute:: prefix
                                    
                                    	LSA address prefix 
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: priority
                                    
                                    	Prefix priority
                                    	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType, self).__init__()

                                        self.yang_name = "inter-area-prefix-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.priority = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "inter-area-prefix-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType, [u'prefix', u'prefix_length', u'priority'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "inter-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "inter-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class InterAreaRouterLsaType(Entity):
                                    """
                                    Inter Area Router LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                    
                                    .. attribute:: lsa_router_id
                                    
                                    	LSA router ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType, self).__init__()

                                        self.yang_name = "inter-area-router-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('lsa_router_id', (YLeaf(YType.uint32, 'lsa-router-id'), ['int'])),
                                        ])
                                        self.lsa_router_id = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "inter-area-router-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType, [u'lsa_router_id'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "inter-area-router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "inter-area-router-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class ExternalLsaType(Entity):
                                    """
                                    External LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA Information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                    
                                    .. attribute:: prefix
                                    
                                    	IPV6 address prefix 
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: metric_type
                                    
                                    	Metric type 
                                    	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                    
                                    .. attribute:: tos_cost
                                    
                                    	Type of service cost metric 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_forwarding_address_set
                                    
                                    	If true, forwarding address is set 
                                    	**type**\: bool
                                    
                                    .. attribute:: forwarding_address
                                    
                                    	Forwarding Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: external_tag
                                    
                                    	Route Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: priority
                                    
                                    	Prefix priority
                                    	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType, self).__init__()

                                        self.yang_name = "external-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                            ('tos_cost', (YLeaf(YType.uint32, 'tos-cost'), ['int'])),
                                            ('is_forwarding_address_set', (YLeaf(YType.boolean, 'is-forwarding-address-set'), ['bool'])),
                                            ('forwarding_address', (YLeaf(YType.str, 'forwarding-address'), ['str'])),
                                            ('external_tag', (YLeaf(YType.uint32, 'external-tag'), ['int'])),
                                            ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.metric_type = None
                                        self.tos_cost = None
                                        self.is_forwarding_address_set = None
                                        self.forwarding_address = None
                                        self.external_tag = None
                                        self.priority = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "external-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType, [u'prefix', u'prefix_length', u'metric_type', u'tos_cost', u'is_forwarding_address_set', u'forwarding_address', u'external_tag', u'priority'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "external-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "external-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class NssalsaType(Entity):
                                    """
                                    NSSA External LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA Information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                    
                                    .. attribute:: prefix
                                    
                                    	IPV6 address prefix 
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	Prefix length 
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: metric_type
                                    
                                    	Metric type 
                                    	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                    
                                    .. attribute:: tos_cost
                                    
                                    	Type of service cost metric 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_forwarding_address_set
                                    
                                    	If true, forwarding address is set 
                                    	**type**\: bool
                                    
                                    .. attribute:: forwarding_address
                                    
                                    	Forwarding Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: external_tag
                                    
                                    	Route Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: priority
                                    
                                    	Prefix priority
                                    	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType, self).__init__()

                                        self.yang_name = "nssalsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                            ('tos_cost', (YLeaf(YType.uint32, 'tos-cost'), ['int'])),
                                            ('is_forwarding_address_set', (YLeaf(YType.boolean, 'is-forwarding-address-set'), ['bool'])),
                                            ('forwarding_address', (YLeaf(YType.str, 'forwarding-address'), ['str'])),
                                            ('external_tag', (YLeaf(YType.uint32, 'external-tag'), ['int'])),
                                            ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None
                                        self.metric_type = None
                                        self.tos_cost = None
                                        self.is_forwarding_address_set = None
                                        self.forwarding_address = None
                                        self.external_tag = None
                                        self.priority = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "nssalsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType, [u'prefix', u'prefix_length', u'metric_type', u'tos_cost', u'is_forwarding_address_set', u'forwarding_address', u'external_tag', u'priority'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "nssalsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA Information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "nssalsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class LinkLsaType(Entity):
                                    """
                                    Link LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface handle
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link
                                    	**type**\: bool
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link
                                    	**type**\: bool
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Sham link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_link_local
                                    
                                    	LSA link local 
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: router_priority
                                    
                                    	Router priority 
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: prefix
                                    
                                    	OSPFv3 prefix 
                                    	**type**\: list of  		 :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType, self).__init__()

                                        self.yang_name = "link-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail)), ("prefix", ("prefix", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                            ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                            ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                            ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                            ('lsa_link_local', (YLeaf(YType.str, 'lsa-link-local'), ['str'])),
                                            ('router_priority', (YLeaf(YType.uint8, 'router-priority'), ['int'])),
                                        ])
                                        self.interface_name = None
                                        self.is_virtual_link = None
                                        self.virtual_link_id = None
                                        self.is_sham_link = None
                                        self.sham_link_id = None
                                        self.lsa_link_local = None
                                        self.router_priority = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"

                                        self.prefix = YList(self)
                                        self._segment_path = lambda: "link-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id', u'lsa_link_local', u'router_priority'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class Prefix(Entity):
                                        """
                                        OSPFv3 prefix 
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ospfv3_prefix_length
                                        
                                        	OSPFv3 prefix length 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ospfv3_prefix_options
                                        
                                        	OSPFv3 prefix options 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ospfv3_prefix_metric
                                        
                                        	OSPFv3 prefix metric 
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix, self).__init__()

                                            self.yang_name = "prefix"
                                            self.yang_parent_name = "link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                ('ospfv3_prefix_length', (YLeaf(YType.uint8, 'ospfv3-prefix-length'), ['int'])),
                                                ('ospfv3_prefix_options', (YLeaf(YType.uint8, 'ospfv3-prefix-options'), ['int'])),
                                                ('ospfv3_prefix_metric', (YLeaf(YType.uint16, 'ospfv3-prefix-metric'), ['int'])),
                                                ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                            ])
                                            self.prefix = None
                                            self.ospfv3_prefix_length = None
                                            self.ospfv3_prefix_options = None
                                            self.ospfv3_prefix_metric = None
                                            self.priority = None
                                            self._segment_path = lambda: "prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix, [u'prefix', u'ospfv3_prefix_length', u'ospfv3_prefix_options', u'ospfv3_prefix_metric', u'priority'], name, value)


                                class IntraAreaPrefixLsaType(Entity):
                                    """
                                    Intra Area Prefix LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                    
                                    .. attribute:: reference_type
                                    
                                    	Reference type 
                                    	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                    
                                    .. attribute:: reference_lsa_id
                                    
                                    	Reference LSA ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reference_advertised_router
                                    
                                    	Reference advertised router 
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix
                                    
                                    	OSPFv3 prefix 
                                    	**type**\: list of  		 :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, self).__init__()

                                        self.yang_name = "intra-area-prefix-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail)), ("prefix", ("prefix", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix))])
                                        self._leafs = OrderedDict([
                                            ('reference_type', (YLeaf(YType.enumeration, 'reference-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                            ('reference_lsa_id', (YLeaf(YType.uint32, 'reference-lsa-id'), ['int'])),
                                            ('reference_advertised_router', (YLeaf(YType.str, 'reference-advertised-router'), ['str'])),
                                        ])
                                        self.reference_type = None
                                        self.reference_lsa_id = None
                                        self.reference_advertised_router = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"

                                        self.prefix = YList(self)
                                        self._segment_path = lambda: "intra-area-prefix-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, [u'reference_type', u'reference_lsa_id', u'reference_advertised_router'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "intra-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "intra-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                    class Prefix(Entity):
                                        """
                                        OSPFv3 prefix 
                                        
                                        .. attribute:: prefix
                                        
                                        	OSPFv3 prefix 
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ospfv3_prefix_length
                                        
                                        	OSPFv3 prefix length 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ospfv3_prefix_options
                                        
                                        	OSPFv3 prefix options 
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ospfv3_prefix_metric
                                        
                                        	OSPFv3 prefix metric 
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: priority
                                        
                                        	Prefix priority
                                        	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, self).__init__()

                                            self.yang_name = "prefix"
                                            self.yang_parent_name = "intra-area-prefix-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                ('ospfv3_prefix_length', (YLeaf(YType.uint8, 'ospfv3-prefix-length'), ['int'])),
                                                ('ospfv3_prefix_options', (YLeaf(YType.uint8, 'ospfv3-prefix-options'), ['int'])),
                                                ('ospfv3_prefix_metric', (YLeaf(YType.uint16, 'ospfv3-prefix-metric'), ['int'])),
                                                ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                            ])
                                            self.prefix = None
                                            self.ospfv3_prefix_length = None
                                            self.ospfv3_prefix_options = None
                                            self.ospfv3_prefix_metric = None
                                            self.priority = None
                                            self._segment_path = lambda: "prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, [u'prefix', u'ospfv3_prefix_length', u'ospfv3_prefix_options', u'ospfv3_prefix_metric', u'priority'], name, value)


                                class GraceLsa(Entity):
                                    """
                                    Grace LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface handle
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link
                                    	**type**\: bool
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link
                                    	**type**\: bool
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Sham link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: grace_period
                                    
                                    	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: grace_reason
                                    
                                    	Reason for router restart
                                    	**type**\:  :py:class:`Ospfv3GracefulRestartReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReason>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa, self).__init__()

                                        self.yang_name = "grace-lsa"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                            ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                            ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                            ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                            ('grace_period', (YLeaf(YType.uint32, 'grace-period'), ['int'])),
                                            ('grace_reason', (YLeaf(YType.enumeration, 'grace-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3GracefulRestartReason', '')])),
                                        ])
                                        self.interface_name = None
                                        self.is_virtual_link = None
                                        self.virtual_link_id = None
                                        self.is_sham_link = None
                                        self.sham_link_id = None
                                        self.grace_period = None
                                        self.grace_reason = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "grace-lsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id', u'grace_period', u'grace_reason'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "grace-lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "grace-lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class UnknownLinkLsaType(Entity):
                                    """
                                    Unknown Link Scope LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\: bool
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\: bool
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType, self).__init__()

                                        self.yang_name = "unknown-link-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                            ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                            ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                            ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                        ])
                                        self.interface_name = None
                                        self.is_virtual_link = None
                                        self.virtual_link_id = None
                                        self.is_sham_link = None
                                        self.sham_link_id = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "unknown-link-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "unknown-link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "unknown-link-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class UnknownAreaLsaType(Entity):
                                    """
                                    Unknown\-Area scope LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\: bool
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\: bool
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType, self).__init__()

                                        self.yang_name = "unknown-area-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                            ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                            ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                            ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                        ])
                                        self.interface_name = None
                                        self.is_virtual_link = None
                                        self.virtual_link_id = None
                                        self.is_sham_link = None
                                        self.sham_link_id = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "unknown-area-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "unknown-area-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "unknown-area-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class UnknownAslsaType(Entity):
                                    """
                                    Unknown\-AS scope LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\: bool
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\: bool
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType, self).__init__()

                                        self.yang_name = "unknown-aslsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                            ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                            ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                            ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                        ])
                                        self.interface_name = None
                                        self.is_virtual_link = None
                                        self.virtual_link_id = None
                                        self.is_sham_link = None
                                        self.sham_link_id = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "unknown-aslsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "unknown-aslsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "unknown-aslsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                class UnknownLsaType(Entity):
                                    """
                                    Unknown LSA
                                    
                                    .. attribute:: lsa_header
                                    
                                    	Header information 
                                    	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                    
                                    .. attribute:: lsa_detail
                                    
                                    	Detailed LSA information
                                    	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                    
                                    .. attribute:: interface_name
                                    
                                    	LSA interface name 
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: is_virtual_link
                                    
                                    	If true, it is a virtual link 
                                    	**type**\: bool
                                    
                                    .. attribute:: virtual_link_id
                                    
                                    	Virtual link ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_sham_link
                                    
                                    	If true, it is a sham link 
                                    	**type**\: bool
                                    
                                    .. attribute:: sham_link_id
                                    
                                    	Shamlink ID 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType, self).__init__()

                                        self.yang_name = "unknown-lsa-type"
                                        self.yang_parent_name = "lsa-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail))])
                                        self._leafs = OrderedDict([
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                            ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                            ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                            ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                        ])
                                        self.interface_name = None
                                        self.is_virtual_link = None
                                        self.virtual_link_id = None
                                        self.is_sham_link = None
                                        self.sham_link_id = None

                                        self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                        self.lsa_header.parent = self
                                        self._children_name_map["lsa_header"] = "lsa-header"

                                        self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                        self.lsa_detail.parent = self
                                        self._children_name_map["lsa_detail"] = "lsa-detail"
                                        self._segment_path = lambda: "unknown-lsa-type"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                    class LsaHeader(Entity):
                                        """
                                        Header information 
                                        
                                        .. attribute:: lsa_type
                                        
                                        	LSA type
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_area_id
                                        
                                        	Area ID in decimal or dotted\-decimal format
                                        	**type**\: str
                                        
                                        	**length:** 0..16
                                        
                                        .. attribute:: lsa_age
                                        
                                        	LSA's Age (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_do_not_age_lsa
                                        
                                        	If true, Do Not Age this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: ls_id
                                        
                                        	LS ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: advertising_router
                                        
                                        	Router ID of Advertising Router
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: sequence_number
                                        
                                        	Current Sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: checksum
                                        
                                        	Checksum value
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: is_graceful_restart_active
                                        
                                        	If true, if grace restart is active 
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, self).__init__()

                                            self.yang_name = "lsa-header"
                                            self.yang_parent_name = "unknown-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                            ])
                                            self.lsa_type = None
                                            self.lsa_area_id = None
                                            self.lsa_age = None
                                            self.is_do_not_age_lsa = None
                                            self.ls_id = None
                                            self.advertising_router = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.is_graceful_restart_active = None
                                            self._segment_path = lambda: "lsa-header"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                    class LsaDetail(Entity):
                                        """
                                        Detailed LSA information
                                        
                                        .. attribute:: second_table_index
                                        
                                        	Second table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: minute_table_index
                                        
                                        	Minute table index
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: free_time
                                        
                                        	The amount of time since the last check was made to free this LSA (s)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_deleted
                                        
                                        	If true, flag is set to delete this LSA 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_bit
                                        
                                        	If true, Routing Bit set on the LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_advertising_router_reachable
                                        
                                        	If true, Advertising Router is reachable
                                        	**type**\: bool
                                        
                                        .. attribute:: is_no_delete
                                        
                                        	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                        	**type**\: bool
                                        
                                        .. attribute:: is_neighbor_exchange
                                        
                                        	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                        	**type**\: bool
                                        
                                        .. attribute:: is_routing_table
                                        
                                        	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_acknowledged
                                        
                                        	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                        	**type**\: bool
                                        
                                        .. attribute:: is_maximum_aged
                                        
                                        	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_partial_spf
                                        
                                        	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                        	**type**\: bool
                                        
                                        .. attribute:: is_flood_pending
                                        
                                        	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                        	**type**\: bool
                                        
                                        .. attribute:: rate_limit
                                        
                                        	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                        	**type**\: bool
                                        
                                        .. attribute:: is_nsr_ack_pending
                                        
                                        	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                        	**type**\: bool
                                        
                                        .. attribute:: nsr_flood_required
                                        
                                        	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_flood_required_post_fail_over
                                        
                                        	LSA flood required after FO
                                        	**type**\: bool
                                        
                                        .. attribute:: lsa_length
                                        
                                        	Length of the LSA
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: lsa_sync_state
                                        
                                        	State of LSA sync with active
                                        	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, self).__init__()

                                            self.yang_name = "lsa-detail"
                                            self.yang_parent_name = "unknown-lsa-type"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                            ])
                                            self.second_table_index = None
                                            self.minute_table_index = None
                                            self.free_time = None
                                            self.is_deleted = None
                                            self.is_routing_bit = None
                                            self.is_advertising_router_reachable = None
                                            self.is_no_delete = None
                                            self.is_neighbor_exchange = None
                                            self.is_routing_table = None
                                            self.is_acknowledged = None
                                            self.is_maximum_aged = None
                                            self.is_partial_spf = None
                                            self.is_flood_pending = None
                                            self.rate_limit = None
                                            self.is_nsr_ack_pending = None
                                            self.nsr_flood_required = None
                                            self.lsa_flood_required_post_fail_over = None
                                            self.lsa_length = None
                                            self.lsa_sync_state = None
                                            self._segment_path = lambda: "lsa-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                class InterfaceProcessTable(Entity):
                    """
                    OSPFv3 interface information table for all areas
                    
                    .. attribute:: interface
                    
                    	OSPFv3 interface information
                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable, self).__init__()

                        self.yang_name = "interface-process-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface", ("interface", Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface))])
                        self._leafs = OrderedDict()

                        self.interface = YList(self)
                        self._segment_path = lambda: "interface-process-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable, [], name, value)


                    class Interface(Entity):
                        """
                        OSPFv3 interface information
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: active_interface
                        
                        	Active interface details 
                        	**type**\:  :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.ActiveInterface>`
                        
                        .. attribute:: interface_bfd
                        
                        	BFD information 
                        	**type**\:  :py:class:`InterfaceBfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceBfd>`
                        
                        .. attribute:: interface_state
                        
                        	Interface state
                        	**type**\:  :py:class:`ImStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.ImStateEnum>`
                        
                        .. attribute:: is_interface_line_up
                        
                        	If true, line protocol is up 
                        	**type**\: bool
                        
                        .. attribute:: is_interface_ip_security_required
                        
                        	If true, interface IP security is required 
                        	**type**\: bool
                        
                        .. attribute:: is_interface_ip_security_active
                        
                        	If true, interface IP security is active 
                        	**type**\: bool
                        
                        .. attribute:: interface_address
                        
                        	Interface IPv6 address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_number
                        
                        	Interface number 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_router_id
                        
                        	Interface router ID 
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: network_type
                        
                        	Network type
                        	**type**\:  :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                        
                        .. attribute:: interface_link_cost
                        
                        	Interface link cost
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: is_interface_flood_reduction
                        
                        	If true, interface flood reduction is active 
                        	**type**\: bool
                        
                        .. attribute:: is_demand_circuit_configured
                        
                        	If true, configured as demand circuit 
                        	**type**\: bool
                        
                        .. attribute:: is_interface_demand_circuit
                        
                        	If true, interface running as demand circuit
                        	**type**\: bool
                        
                        .. attribute:: interface_dc_bitless_ls_as
                        
                        	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transmission_delay
                        
                        	Interface transmission delay (sec)
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ospf_interface_state
                        
                        	Interface state
                        	**type**\:  :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                        
                        .. attribute:: interface_priority
                        
                        	Interface priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: is_designated_router
                        
                        	If true, designated router
                        	**type**\: bool
                        
                        .. attribute:: designated_router_id
                        
                        	Designated router ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: designated_router_address
                        
                        	Designated router interface address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: backup_designated_router_id
                        
                        	Backup designated router ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: backup_designated_router_address
                        
                        	Backup designated router interface address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: network_lsa_flush_timer
                        
                        	The amount of time in seconds before flush timer for old network LSA expires 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: is_interface_lsa_filtered
                        
                        	Filter is configured for out going LSAs 
                        	**type**\: bool
                        
                        .. attribute:: hello_interval
                        
                        	Configured hello interval (s)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: dead_interval
                        
                        	Configured dead interval (s) 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: wait_interval
                        
                        	Configured wait interval (s) 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_retransmission_interval
                        
                        	Configured retransmit interval (s) 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hello_time
                        
                        	Time until next Hello (s) 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_authentication_spi
                        
                        	Interface authentication spi 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_authentication_transmit
                        
                        	Interface authentication transmit 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_interface_encryption_enabled
                        
                        	If true, interface encryption is enabled 
                        	**type**\: bool
                        
                        .. attribute:: is_prefix_suppress
                        
                        	If true prefix suppression is enabled
                        	**type**\: bool
                        
                        .. attribute:: interface_encryption_spi
                        
                        	Interface encryption spi
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_encryption_transmitted
                        
                        	Interface encryption transmitted 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_encrypted_authentication_transmitted
                        
                        	Interface encrypted authentication transmitted 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: adjacent_neighbor
                        
                        	Number of adjacent neighbors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_references
                        
                        	Interface reference count 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured_ldp_sync
                        
                        	If true, configured as LDP sync
                        	**type**\: bool
                        
                        .. attribute:: interface_ldp_sync
                        
                        	If true, interface LDP sync is achieved
                        	**type**\: bool
                        
                        .. attribute:: interface_neighbor
                        
                        	Information for neighbors on the interface
                        	**type**\: list of  		 :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceNeighbor>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interface-process-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("active-interface", ("active_interface", Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.ActiveInterface)), ("interface-bfd", ("interface_bfd", Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceBfd)), ("interface-neighbor", ("interface_neighbor", Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceNeighbor))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('interface_state', (YLeaf(YType.enumeration, 'interface-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'ImStateEnum', '')])),
                                ('is_interface_line_up', (YLeaf(YType.boolean, 'is-interface-line-up'), ['bool'])),
                                ('is_interface_ip_security_required', (YLeaf(YType.boolean, 'is-interface-ip-security-required'), ['bool'])),
                                ('is_interface_ip_security_active', (YLeaf(YType.boolean, 'is-interface-ip-security-active'), ['bool'])),
                                ('interface_address', (YLeaf(YType.str, 'interface-address'), ['str'])),
                                ('interface_number', (YLeaf(YType.uint32, 'interface-number'), ['int'])),
                                ('interface_router_id', (YLeaf(YType.str, 'interface-router-id'), ['str'])),
                                ('network_type', (YLeaf(YType.enumeration, 'network-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Interface', '')])),
                                ('interface_link_cost', (YLeaf(YType.uint16, 'interface-link-cost'), ['int'])),
                                ('is_interface_flood_reduction', (YLeaf(YType.boolean, 'is-interface-flood-reduction'), ['bool'])),
                                ('is_demand_circuit_configured', (YLeaf(YType.boolean, 'is-demand-circuit-configured'), ['bool'])),
                                ('is_interface_demand_circuit', (YLeaf(YType.boolean, 'is-interface-demand-circuit'), ['bool'])),
                                ('interface_dc_bitless_ls_as', (YLeaf(YType.uint32, 'interface-dc-bitless-ls-as'), ['int'])),
                                ('transmission_delay', (YLeaf(YType.uint16, 'transmission-delay'), ['int'])),
                                ('ospf_interface_state', (YLeaf(YType.enumeration, 'ospf-interface-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3InterfaceState', '')])),
                                ('interface_priority', (YLeaf(YType.uint8, 'interface-priority'), ['int'])),
                                ('is_designated_router', (YLeaf(YType.boolean, 'is-designated-router'), ['bool'])),
                                ('designated_router_id', (YLeaf(YType.str, 'designated-router-id'), ['str'])),
                                ('designated_router_address', (YLeaf(YType.str, 'designated-router-address'), ['str'])),
                                ('backup_designated_router_id', (YLeaf(YType.str, 'backup-designated-router-id'), ['str'])),
                                ('backup_designated_router_address', (YLeaf(YType.str, 'backup-designated-router-address'), ['str'])),
                                ('network_lsa_flush_timer', (YLeaf(YType.uint32, 'network-lsa-flush-timer'), ['int'])),
                                ('is_interface_lsa_filtered', (YLeaf(YType.boolean, 'is-interface-lsa-filtered'), ['bool'])),
                                ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                ('dead_interval', (YLeaf(YType.uint32, 'dead-interval'), ['int'])),
                                ('wait_interval', (YLeaf(YType.uint32, 'wait-interval'), ['int'])),
                                ('interface_retransmission_interval', (YLeaf(YType.uint32, 'interface-retransmission-interval'), ['int'])),
                                ('next_hello_time', (YLeaf(YType.uint32, 'next-hello-time'), ['int'])),
                                ('interface_authentication_spi', (YLeaf(YType.uint32, 'interface-authentication-spi'), ['int'])),
                                ('interface_authentication_transmit', (YLeaf(YType.uint32, 'interface-authentication-transmit'), ['int'])),
                                ('is_interface_encryption_enabled', (YLeaf(YType.boolean, 'is-interface-encryption-enabled'), ['bool'])),
                                ('is_prefix_suppress', (YLeaf(YType.boolean, 'is-prefix-suppress'), ['bool'])),
                                ('interface_encryption_spi', (YLeaf(YType.uint32, 'interface-encryption-spi'), ['int'])),
                                ('interface_encryption_transmitted', (YLeaf(YType.uint32, 'interface-encryption-transmitted'), ['int'])),
                                ('interface_encrypted_authentication_transmitted', (YLeaf(YType.uint32, 'interface-encrypted-authentication-transmitted'), ['int'])),
                                ('adjacent_neighbor', (YLeaf(YType.uint32, 'adjacent-neighbor'), ['int'])),
                                ('interface_references', (YLeaf(YType.uint32, 'interface-references'), ['int'])),
                                ('configured_ldp_sync', (YLeaf(YType.boolean, 'configured-ldp-sync'), ['bool'])),
                                ('interface_ldp_sync', (YLeaf(YType.boolean, 'interface-ldp-sync'), ['bool'])),
                            ])
                            self.interface_name = None
                            self.interface_state = None
                            self.is_interface_line_up = None
                            self.is_interface_ip_security_required = None
                            self.is_interface_ip_security_active = None
                            self.interface_address = None
                            self.interface_number = None
                            self.interface_router_id = None
                            self.network_type = None
                            self.interface_link_cost = None
                            self.is_interface_flood_reduction = None
                            self.is_demand_circuit_configured = None
                            self.is_interface_demand_circuit = None
                            self.interface_dc_bitless_ls_as = None
                            self.transmission_delay = None
                            self.ospf_interface_state = None
                            self.interface_priority = None
                            self.is_designated_router = None
                            self.designated_router_id = None
                            self.designated_router_address = None
                            self.backup_designated_router_id = None
                            self.backup_designated_router_address = None
                            self.network_lsa_flush_timer = None
                            self.is_interface_lsa_filtered = None
                            self.hello_interval = None
                            self.dead_interval = None
                            self.wait_interval = None
                            self.interface_retransmission_interval = None
                            self.next_hello_time = None
                            self.interface_authentication_spi = None
                            self.interface_authentication_transmit = None
                            self.is_interface_encryption_enabled = None
                            self.is_prefix_suppress = None
                            self.interface_encryption_spi = None
                            self.interface_encryption_transmitted = None
                            self.interface_encrypted_authentication_transmitted = None
                            self.adjacent_neighbor = None
                            self.interface_references = None
                            self.configured_ldp_sync = None
                            self.interface_ldp_sync = None

                            self.active_interface = Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.ActiveInterface()
                            self.active_interface.parent = self
                            self._children_name_map["active_interface"] = "active-interface"

                            self.interface_bfd = Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceBfd()
                            self.interface_bfd.parent = self
                            self._children_name_map["interface_bfd"] = "interface-bfd"

                            self.interface_neighbor = YList(self)
                            self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface, ['interface_name', u'interface_state', u'is_interface_line_up', u'is_interface_ip_security_required', u'is_interface_ip_security_active', u'interface_address', u'interface_number', u'interface_router_id', u'network_type', u'interface_link_cost', u'is_interface_flood_reduction', u'is_demand_circuit_configured', u'is_interface_demand_circuit', u'interface_dc_bitless_ls_as', u'transmission_delay', u'ospf_interface_state', u'interface_priority', u'is_designated_router', u'designated_router_id', u'designated_router_address', u'backup_designated_router_id', u'backup_designated_router_address', u'network_lsa_flush_timer', u'is_interface_lsa_filtered', u'hello_interval', u'dead_interval', u'wait_interval', u'interface_retransmission_interval', u'next_hello_time', u'interface_authentication_spi', u'interface_authentication_transmit', u'is_interface_encryption_enabled', u'is_prefix_suppress', u'interface_encryption_spi', u'interface_encryption_transmitted', u'interface_encrypted_authentication_transmitted', u'adjacent_neighbor', u'interface_references', u'configured_ldp_sync', u'interface_ldp_sync'], name, value)


                        class ActiveInterface(Entity):
                            """
                            Active interface details 
                            
                            .. attribute:: wait_time
                            
                            	Wait time for DR/BDR selection (s)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_area_flood_index
                            
                            	Area scope LSAs flood index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_as_flood_index
                            
                            	AS scope LSAs flood index 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_link_flood_index
                            
                            	Interface flood link index 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: flood_queue_length
                            
                            	Flood queue length
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_area_next_flood
                            
                            	Next LSA to flood (Area scope)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_area_next_flood_index
                            
                            	Index of next LSA to flood (Area scope) 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_as_next_flood
                            
                            	Next LSA to flood (AS scope)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_as_next_flood_index
                            
                            	Index of next LSA to flood (AS scope)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_link_next_flood
                            
                            	Interface link next flood information 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_link_next_index
                            
                            	Interface link next information index 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: flood_scan_length
                            
                            	Last flood scan length 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_flood_length
                            
                            	Maximum flood length 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_flood_time
                            
                            	Last flood scan time (ms)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_flood_time
                            
                            	Maximum flood time (ms) 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_flood_pacing_timer
                            
                            	Time until next flood pacing timer (ms) 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_neighbors
                            
                            	Total number of neighbors 
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: suppressed_hellos
                            
                            	Number of neighbors for which hellos are suppressed 
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.ActiveInterface, self).__init__()

                                self.yang_name = "active-interface"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('wait_time', (YLeaf(YType.uint32, 'wait-time'), ['int'])),
                                    ('interface_area_flood_index', (YLeaf(YType.uint32, 'interface-area-flood-index'), ['int'])),
                                    ('interface_as_flood_index', (YLeaf(YType.uint32, 'interface-as-flood-index'), ['int'])),
                                    ('interface_link_flood_index', (YLeaf(YType.uint32, 'interface-link-flood-index'), ['int'])),
                                    ('flood_queue_length', (YLeaf(YType.uint32, 'flood-queue-length'), ['int'])),
                                    ('interface_area_next_flood', (YLeaf(YType.uint32, 'interface-area-next-flood'), ['int'])),
                                    ('interface_area_next_flood_index', (YLeaf(YType.uint32, 'interface-area-next-flood-index'), ['int'])),
                                    ('interface_as_next_flood', (YLeaf(YType.uint32, 'interface-as-next-flood'), ['int'])),
                                    ('interface_as_next_flood_index', (YLeaf(YType.uint32, 'interface-as-next-flood-index'), ['int'])),
                                    ('interface_link_next_flood', (YLeaf(YType.uint32, 'interface-link-next-flood'), ['int'])),
                                    ('interface_link_next_index', (YLeaf(YType.uint32, 'interface-link-next-index'), ['int'])),
                                    ('flood_scan_length', (YLeaf(YType.uint32, 'flood-scan-length'), ['int'])),
                                    ('maximum_flood_length', (YLeaf(YType.uint32, 'maximum-flood-length'), ['int'])),
                                    ('last_flood_time', (YLeaf(YType.uint32, 'last-flood-time'), ['int'])),
                                    ('maximum_flood_time', (YLeaf(YType.uint32, 'maximum-flood-time'), ['int'])),
                                    ('interface_flood_pacing_timer', (YLeaf(YType.uint32, 'interface-flood-pacing-timer'), ['int'])),
                                    ('interface_neighbors', (YLeaf(YType.uint16, 'interface-neighbors'), ['int'])),
                                    ('suppressed_hellos', (YLeaf(YType.uint16, 'suppressed-hellos'), ['int'])),
                                ])
                                self.wait_time = None
                                self.interface_area_flood_index = None
                                self.interface_as_flood_index = None
                                self.interface_link_flood_index = None
                                self.flood_queue_length = None
                                self.interface_area_next_flood = None
                                self.interface_area_next_flood_index = None
                                self.interface_as_next_flood = None
                                self.interface_as_next_flood_index = None
                                self.interface_link_next_flood = None
                                self.interface_link_next_index = None
                                self.flood_scan_length = None
                                self.maximum_flood_length = None
                                self.last_flood_time = None
                                self.maximum_flood_time = None
                                self.interface_flood_pacing_timer = None
                                self.interface_neighbors = None
                                self.suppressed_hellos = None
                                self._segment_path = lambda: "active-interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.ActiveInterface, [u'wait_time', u'interface_area_flood_index', u'interface_as_flood_index', u'interface_link_flood_index', u'flood_queue_length', u'interface_area_next_flood', u'interface_area_next_flood_index', u'interface_as_next_flood', u'interface_as_next_flood_index', u'interface_link_next_flood', u'interface_link_next_index', u'flood_scan_length', u'maximum_flood_length', u'last_flood_time', u'maximum_flood_time', u'interface_flood_pacing_timer', u'interface_neighbors', u'suppressed_hellos'], name, value)


                        class InterfaceBfd(Entity):
                            """
                            BFD information 
                            
                            .. attribute:: bfd_intf_enable_mode
                            
                            	BFD Enable Mode on the interface \- Default/Strict
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_interval
                            
                            	BFD interval (ms) 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_detection_multiplier
                            
                            	BFD detection multiplier 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceBfd, self).__init__()

                                self.yang_name = "interface-bfd"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('bfd_intf_enable_mode', (YLeaf(YType.uint32, 'bfd-intf-enable-mode'), ['int'])),
                                    ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                                    ('bfd_detection_multiplier', (YLeaf(YType.uint32, 'bfd-detection-multiplier'), ['int'])),
                                ])
                                self.bfd_intf_enable_mode = None
                                self.bfd_interval = None
                                self.bfd_detection_multiplier = None
                                self._segment_path = lambda: "interface-bfd"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceBfd, [u'bfd_intf_enable_mode', u'bfd_interval', u'bfd_detection_multiplier'], name, value)


                        class InterfaceNeighbor(Entity):
                            """
                            Information for neighbors on the interface
                            
                            .. attribute:: interface_neighbor_id
                            
                            	Neighbor router ID 
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_neighbor_cost
                            
                            	Cost of link to neighbor
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_neighbor_dr
                            
                            	If true, designated router is found 
                            	**type**\: bool
                            
                            .. attribute:: is_neighbor_bdr
                            
                            	If true, backup designated router is found 
                            	**type**\: bool
                            
                            .. attribute:: is_hello_suppressed
                            
                            	If true, hello is suppressed 
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceNeighbor, self).__init__()

                                self.yang_name = "interface-neighbor"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface_neighbor_id', (YLeaf(YType.str, 'interface-neighbor-id'), ['str'])),
                                    ('interface_neighbor_cost', (YLeaf(YType.uint32, 'interface-neighbor-cost'), ['int'])),
                                    ('is_neighbor_dr', (YLeaf(YType.boolean, 'is-neighbor-dr'), ['bool'])),
                                    ('is_neighbor_bdr', (YLeaf(YType.boolean, 'is-neighbor-bdr'), ['bool'])),
                                    ('is_hello_suppressed', (YLeaf(YType.boolean, 'is-hello-suppressed'), ['bool'])),
                                ])
                                self.interface_neighbor_id = None
                                self.interface_neighbor_cost = None
                                self.is_neighbor_dr = None
                                self.is_neighbor_bdr = None
                                self.is_hello_suppressed = None
                                self._segment_path = lambda: "interface-neighbor"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InterfaceProcessTable.Interface.InterfaceNeighbor, [u'interface_neighbor_id', u'interface_neighbor_cost', u'is_neighbor_dr', u'is_neighbor_bdr', u'is_hello_suppressed'], name, value)


                class Redistributions(Entity):
                    """
                    Redistribution information table
                    
                    .. attribute:: redistribution
                    
                    	Redistribution information
                    	**type**\: list of  		 :py:class:`Redistribution <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Redistributions.Redistribution>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.Redistributions, self).__init__()

                        self.yang_name = "redistributions"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("redistribution", ("redistribution", Ospfv3.Processes.Process.DefaultVrf.Redistributions.Redistribution))])
                        self._leafs = OrderedDict()

                        self.redistribution = YList(self)
                        self._segment_path = lambda: "redistributions"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Redistributions, [], name, value)


                    class Redistribution(Entity):
                        """
                        Redistribution information
                        
                        .. attribute:: protocol_name
                        
                        	Protocol name that is redistributed
                        	**type**\: str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: process_name
                        
                        	Process name of a protocolbeing redistributed 
                        	**type**\: str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: protocol_name_xr
                        
                        	Protocol name 
                        	**type**\: str
                        
                        	**length:** 0..40
                        
                        .. attribute:: process_id
                        
                        	Process ID 
                        	**type**\: str
                        
                        	**length:** 0..40
                        
                        .. attribute:: red_metric_flag
                        
                        	red metric flag
                        	**type**\: bool
                        
                        .. attribute:: red_metric
                        
                        	red metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: red_mtype_flag
                        
                        	red mtype flag
                        	**type**\: bool
                        
                        .. attribute:: red_metric_type
                        
                        	red metric type
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: red_tag
                        
                        	red tag
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: policy_name
                        
                        	Route policy name 
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.Redistributions.Redistribution, self).__init__()

                            self.yang_name = "redistribution"
                            self.yang_parent_name = "redistributions"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('protocol_name', (YLeaf(YType.str, 'protocol-name'), ['str'])),
                                ('process_name', (YLeaf(YType.str, 'process-name'), ['str'])),
                                ('protocol_name_xr', (YLeaf(YType.str, 'protocol-name-xr'), ['str'])),
                                ('process_id', (YLeaf(YType.str, 'process-id'), ['str'])),
                                ('red_metric_flag', (YLeaf(YType.boolean, 'red-metric-flag'), ['bool'])),
                                ('red_metric', (YLeaf(YType.uint32, 'red-metric'), ['int'])),
                                ('red_mtype_flag', (YLeaf(YType.boolean, 'red-mtype-flag'), ['bool'])),
                                ('red_metric_type', (YLeaf(YType.uint8, 'red-metric-type'), ['int'])),
                                ('red_tag', (YLeaf(YType.uint32, 'red-tag'), ['int'])),
                                ('policy_name', (YLeaf(YType.str, 'policy-name'), ['str'])),
                            ])
                            self.protocol_name = None
                            self.process_name = None
                            self.protocol_name_xr = None
                            self.process_id = None
                            self.red_metric_flag = None
                            self.red_metric = None
                            self.red_mtype_flag = None
                            self.red_metric_type = None
                            self.red_tag = None
                            self.policy_name = None
                            self._segment_path = lambda: "redistribution"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Redistributions.Redistribution, ['protocol_name', 'process_name', u'protocol_name_xr', u'process_id', u'red_metric_flag', u'red_metric', u'red_mtype_flag', u'red_metric_type', u'red_tag', u'policy_name'], name, value)


                class ExternalRoutes(Entity):
                    """
                    OSPFv3 external route information table
                    
                    .. attribute:: external_route
                    
                    	OSPFv3 external route information
                    	**type**\: list of  		 :py:class:`ExternalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes, self).__init__()

                        self.yang_name = "external-routes"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("external-route", ("external_route", Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute))])
                        self._leafs = OrderedDict()

                        self.external_route = YList(self)
                        self._segment_path = lambda: "external-routes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes, [], name, value)


                    class ExternalRoute(Entity):
                        """
                        OSPFv3 external route information
                        
                        .. attribute:: prefix
                        
                        	Route prefix
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\: int
                        
                        	**range:** 0..128
                        
                        .. attribute:: route_topology
                        
                        	Common Route topology information
                        	**type**\:  :py:class:`RouteTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteTopology>`
                        
                        .. attribute:: route_extended_community
                        
                        	Extended communities in the route
                        	**type**\:  :py:class:`RouteExtendedCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity>`
                        
                        .. attribute:: route_path
                        
                        	List of paths to this route
                        	**type**\: list of  		 :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute, self).__init__()

                            self.yang_name = "external-route"
                            self.yang_parent_name = "external-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("route-topology", ("route_topology", Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteTopology)), ("route-extended-community", ("route_extended_community", Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity)), ("route-path", ("route_path", Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath))])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                            ])
                            self.prefix = None
                            self.prefix_length = None

                            self.route_topology = Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteTopology()
                            self.route_topology.parent = self
                            self._children_name_map["route_topology"] = "route-topology"

                            self.route_extended_community = Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity()
                            self.route_extended_community.parent = self
                            self._children_name_map["route_extended_community"] = "route-extended-community"

                            self.route_path = YList(self)
                            self._segment_path = lambda: "external-route"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute, ['prefix', 'prefix_length'], name, value)


                        class RouteTopology(Entity):
                            """
                            Common Route topology information
                            
                            .. attribute:: route_id
                            
                            	Route ID 
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_distance
                            
                            	Route distance 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_cost
                            
                            	Route cost 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteTopology, self).__init__()

                                self.yang_name = "route-topology"
                                self.yang_parent_name = "external-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('route_id', (YLeaf(YType.str, 'route-id'), ['str'])),
                                    ('route_distance', (YLeaf(YType.uint32, 'route-distance'), ['int'])),
                                    ('route_cost', (YLeaf(YType.uint32, 'route-cost'), ['int'])),
                                    ('route_type', (YLeaf(YType.uint32, 'route-type'), ['int'])),
                                ])
                                self.route_id = None
                                self.route_distance = None
                                self.route_cost = None
                                self.route_type = None
                                self._segment_path = lambda: "route-topology"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteTopology, [u'route_id', u'route_distance', u'route_cost', u'route_type'], name, value)


                        class RouteExtendedCommunity(Entity):
                            """
                            Extended communities in the route
                            
                            .. attribute:: extended_community_domain_id_value
                            
                            	Domain ID value
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: extended_communityl_domain_id_type
                            
                            	Domain ID type
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: extended_community_area_id
                            
                            	Area id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: extended_community_router_id
                            
                            	Router id
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: extended_community_route_type
                            
                            	Route type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: extended_community_options
                            
                            	Route Options
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity, self).__init__()

                                self.yang_name = "route-extended-community"
                                self.yang_parent_name = "external-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('extended_community_domain_id_value', (YLeaf(YType.str, 'extended-community-domain-id-value'), ['str'])),
                                    ('extended_communityl_domain_id_type', (YLeaf(YType.uint16, 'extended-communityl-domain-id-type'), ['int'])),
                                    ('extended_community_area_id', (YLeaf(YType.uint32, 'extended-community-area-id'), ['int'])),
                                    ('extended_community_router_id', (YLeaf(YType.str, 'extended-community-router-id'), ['str'])),
                                    ('extended_community_route_type', (YLeaf(YType.uint8, 'extended-community-route-type'), ['int'])),
                                    ('extended_community_options', (YLeaf(YType.uint8, 'extended-community-options'), ['int'])),
                                ])
                                self.extended_community_domain_id_value = None
                                self.extended_communityl_domain_id_type = None
                                self.extended_community_area_id = None
                                self.extended_community_router_id = None
                                self.extended_community_route_type = None
                                self.extended_community_options = None
                                self._segment_path = lambda: "route-extended-community"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RouteExtendedCommunity, [u'extended_community_domain_id_value', u'extended_communityl_domain_id_type', u'extended_community_area_id', u'extended_community_router_id', u'extended_community_route_type', u'extended_community_options'], name, value)


                        class RoutePath(Entity):
                            """
                            List of paths to this route
                            
                            .. attribute:: route_backup_path
                            
                            	Backup Path Info
                            	**type**\:  :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath>`
                            
                            .. attribute:: interface_name
                            
                            	Route path interface name 
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: interface_index
                            
                            	Route path interface Index 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_path_next_hop
                            
                            	Route path next hop 
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_path_id
                            
                            	Path ID of path
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: neighbor_next_hop
                            
                            	NeighborNextHop
                            	**type**\: list of  		 :py:class:`NeighborNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath.NeighborNextHop>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath, self).__init__()

                                self.yang_name = "route-path"
                                self.yang_parent_name = "external-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("route-backup-path", ("route_backup_path", Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath)), ("neighbor-next-hop", ("neighbor_next_hop", Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath.NeighborNextHop))])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                    ('route_path_next_hop', (YLeaf(YType.str, 'route-path-next-hop'), ['str'])),
                                    ('route_path_id', (YLeaf(YType.uint16, 'route-path-id'), ['int'])),
                                ])
                                self.interface_name = None
                                self.interface_index = None
                                self.route_path_next_hop = None
                                self.route_path_id = None

                                self.route_backup_path = Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath()
                                self.route_backup_path.parent = self
                                self._children_name_map["route_backup_path"] = "route-backup-path"

                                self.neighbor_next_hop = YList(self)
                                self._segment_path = lambda: "route-path"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath, [u'interface_name', u'interface_index', u'route_path_next_hop', u'route_path_id'], name, value)


                            class RouteBackupPath(Entity):
                                """
                                Backup Path Info
                                
                                .. attribute:: backup_route_interface_name
                                
                                	Next hop Interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: backup_route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_route_source
                                
                                	IP address of source of route
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_metric
                                
                                	Metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: primary_path
                                
                                	Primary Path
                                	**type**\: bool
                                
                                .. attribute:: line_card_disjoint
                                
                                	Line Card Disjoint
                                	**type**\: bool
                                
                                .. attribute:: downstream
                                
                                	Downstream
                                	**type**\: bool
                                
                                .. attribute:: node_protect
                                
                                	Node Protect
                                	**type**\: bool
                                
                                .. attribute:: srlg_disjoint
                                
                                	SRLG Disjoint
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath, self).__init__()

                                    self.yang_name = "route-backup-path"
                                    self.yang_parent_name = "route-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('backup_route_interface_name', (YLeaf(YType.str, 'backup-route-interface-name'), ['str'])),
                                        ('backup_route_next_hop_address', (YLeaf(YType.str, 'backup-route-next-hop-address'), ['str'])),
                                        ('backup_route_source', (YLeaf(YType.str, 'backup-route-source'), ['str'])),
                                        ('backup_metric', (YLeaf(YType.uint32, 'backup-metric'), ['int'])),
                                        ('primary_path', (YLeaf(YType.boolean, 'primary-path'), ['bool'])),
                                        ('line_card_disjoint', (YLeaf(YType.boolean, 'line-card-disjoint'), ['bool'])),
                                        ('downstream', (YLeaf(YType.boolean, 'downstream'), ['bool'])),
                                        ('node_protect', (YLeaf(YType.boolean, 'node-protect'), ['bool'])),
                                        ('srlg_disjoint', (YLeaf(YType.boolean, 'srlg-disjoint'), ['bool'])),
                                    ])
                                    self.backup_route_interface_name = None
                                    self.backup_route_next_hop_address = None
                                    self.backup_route_source = None
                                    self.backup_metric = None
                                    self.primary_path = None
                                    self.line_card_disjoint = None
                                    self.downstream = None
                                    self.node_protect = None
                                    self.srlg_disjoint = None
                                    self._segment_path = lambda: "route-backup-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath.RouteBackupPath, [u'backup_route_interface_name', u'backup_route_next_hop_address', u'backup_route_source', u'backup_metric', u'primary_path', u'line_card_disjoint', u'downstream', u'node_protect', u'srlg_disjoint'], name, value)


                            class NeighborNextHop(Entity):
                                """
                                NeighborNextHop
                                
                                .. attribute:: neighbor_next_hop_intf_index
                                
                                	Neighbor NextHop Interface Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath.NeighborNextHop, self).__init__()

                                    self.yang_name = "neighbor-next-hop"
                                    self.yang_parent_name = "route-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('neighbor_next_hop_intf_index', (YLeaf(YType.uint32, 'neighbor-next-hop-intf-index'), ['int'])),
                                    ])
                                    self.neighbor_next_hop_intf_index = None
                                    self._segment_path = lambda: "neighbor-next-hop"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ExternalRoutes.ExternalRoute.RoutePath.NeighborNextHop, [u'neighbor_next_hop_intf_index'], name, value)


                class RequestListProcessTable(Entity):
                    """
                    OSPFv3 request list information for all areas
                    
                    .. attribute:: request
                    
                    	OSPFv3 request list information
                    	**type**\: list of  		 :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable, self).__init__()

                        self.yang_name = "request-list-process-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("request", ("request", Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request))])
                        self._leafs = OrderedDict()

                        self.request = YList(self)
                        self._segment_path = lambda: "request-list-process-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable, [], name, value)


                    class Request(Entity):
                        """
                        OSPFv3 request list information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: request_neighbor_address
                        
                        	Neighbor IP address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_request_virtual_link
                        
                        	If true, virtual link is requested 
                        	**type**\: bool
                        
                        .. attribute:: request_virtual_link_id
                        
                        	Request virtual link ID 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_request_sham_link
                        
                        	If true, sham link is requested 
                        	**type**\: bool
                        
                        .. attribute:: request_sham_link_id
                        
                        	Request sham link ID 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: request
                        
                        	List of request list entries
                        	**type**\: list of  		 :py:class:`Request_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request.Request_>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request, self).__init__()

                            self.yang_name = "request"
                            self.yang_parent_name = "request-list-process-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("request", ("request", Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request.Request_))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                ('request_neighbor_address', (YLeaf(YType.str, 'request-neighbor-address'), ['str'])),
                                ('is_request_virtual_link', (YLeaf(YType.boolean, 'is-request-virtual-link'), ['bool'])),
                                ('request_virtual_link_id', (YLeaf(YType.uint32, 'request-virtual-link-id'), ['int'])),
                                ('is_request_sham_link', (YLeaf(YType.boolean, 'is-request-sham-link'), ['bool'])),
                                ('request_sham_link_id', (YLeaf(YType.uint32, 'request-sham-link-id'), ['int'])),
                            ])
                            self.interface_name = None
                            self.neighbor_address = None
                            self.request_neighbor_address = None
                            self.is_request_virtual_link = None
                            self.request_virtual_link_id = None
                            self.is_request_sham_link = None
                            self.request_sham_link_id = None

                            self.request = YList(self)
                            self._segment_path = lambda: "request"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request, ['interface_name', 'neighbor_address', u'request_neighbor_address', u'is_request_virtual_link', u'request_virtual_link_id', u'is_request_sham_link', u'request_sham_link_id'], name, value)


                        class Request_(Entity):
                            """
                            List of request list entries
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request.Request_, self).__init__()

                                self.yang_name = "request"
                                self.yang_parent_name = "request"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                    ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                    ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                    ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                    ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                ])
                                self.header_lsa_type = None
                                self.header_lsa_age = None
                                self.header_lsa_id = None
                                self.header_advertising_router = None
                                self.header_sequence_number = None
                                self._segment_path = lambda: "request"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.RequestListProcessTable.Request.Request_, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                class VirtualLink(Entity):
                    """
                    Virtual link information
                    
                    .. attribute:: virtual_link_neighbor
                    
                    	Neighbor information 
                    	**type**\:  :py:class:`VirtualLinkNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor>`
                    
                    .. attribute:: virtual_link_neighbor_id
                    
                    	Neighbor on other end of this virtual link
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: virtual_link_interface_number
                    
                    	Virtual link interface number 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_state
                    
                    	OSPF interface state for the virtual link
                    	**type**\:  :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                    
                    .. attribute:: is_virtual_link_ip_security_required
                    
                    	If true, virtual link IP security is required 
                    	**type**\: bool
                    
                    .. attribute:: is_virtual_link_ip_security_active
                    
                    	If true, Virtual link IP security is active 
                    	**type**\: bool
                    
                    .. attribute:: virtual_link_neighbor_address
                    
                    	Virtual link neighbor addresss 
                    	**type**\: str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_virtual_link_demand_circuit
                    
                    	If true, the link runs as demand circuit
                    	**type**\: bool
                    
                    .. attribute:: virtual_link_dc_bitless_lsa
                    
                    	Number of LSA's with demand circuit bit not set 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: transit_area_id
                    
                    	Transit area id 
                    	**type**\: str
                    
                    .. attribute:: interface_name
                    
                    	Interface on which this virtual link is formed
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: virtual_link_cost
                    
                    	Cost of the virtual link
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: virual_link_transmission_delay
                    
                    	Transmission delay in seconds
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: virtual_link_hello_interval
                    
                    	Hello interval (s)
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_dead_interval
                    
                    	Dead interval (s)
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_wait_interval
                    
                    	Wait interval (s)
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_retransmission_interval
                    
                    	Retransmission interval (s)
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_next_hello
                    
                    	Time until next hello (s)
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_virtual_link_passive
                    
                    	If true, interface is passive
                    	**type**\: bool
                    
                    .. attribute:: is_virtual_link_authentication_enabled
                    
                    	If true, virtual link authentication is enabled 
                    	**type**\: bool
                    
                    .. attribute:: virtual_link_authentication_spi
                    
                    	Virtual link authentication spi 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_authentication_transmit
                    
                    	Virtual link authentication transmit 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_virtual_link_encryption_enabled
                    
                    	If true, virtual link encryption is enabled 
                    	**type**\: bool
                    
                    .. attribute:: virtual_link_encryption_spi
                    
                    	Virtual link encryption spi
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_encryption_transmitted
                    
                    	Virtual link encryption transmitted 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_link_encrypted_authentication_transmitted
                    
                    	Virtual link encrypted authentication transmitted 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.VirtualLink, self).__init__()

                        self.yang_name = "virtual-link"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("virtual-link-neighbor", ("virtual_link_neighbor", Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor))])
                        self._leafs = OrderedDict([
                            ('virtual_link_neighbor_id', (YLeaf(YType.str, 'virtual-link-neighbor-id'), ['str'])),
                            ('virtual_link_interface_number', (YLeaf(YType.uint32, 'virtual-link-interface-number'), ['int'])),
                            ('virtual_link_state', (YLeaf(YType.enumeration, 'virtual-link-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3InterfaceState', '')])),
                            ('is_virtual_link_ip_security_required', (YLeaf(YType.boolean, 'is-virtual-link-ip-security-required'), ['bool'])),
                            ('is_virtual_link_ip_security_active', (YLeaf(YType.boolean, 'is-virtual-link-ip-security-active'), ['bool'])),
                            ('virtual_link_neighbor_address', (YLeaf(YType.str, 'virtual-link-neighbor-address'), ['str'])),
                            ('is_virtual_link_demand_circuit', (YLeaf(YType.boolean, 'is-virtual-link-demand-circuit'), ['bool'])),
                            ('virtual_link_dc_bitless_lsa', (YLeaf(YType.uint32, 'virtual-link-dc-bitless-lsa'), ['int'])),
                            ('transit_area_id', (YLeaf(YType.str, 'transit-area-id'), ['str'])),
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('virtual_link_cost', (YLeaf(YType.uint16, 'virtual-link-cost'), ['int'])),
                            ('virual_link_transmission_delay', (YLeaf(YType.uint16, 'virual-link-transmission-delay'), ['int'])),
                            ('virtual_link_hello_interval', (YLeaf(YType.uint32, 'virtual-link-hello-interval'), ['int'])),
                            ('virtual_link_dead_interval', (YLeaf(YType.uint32, 'virtual-link-dead-interval'), ['int'])),
                            ('virtual_link_wait_interval', (YLeaf(YType.uint32, 'virtual-link-wait-interval'), ['int'])),
                            ('virtual_link_retransmission_interval', (YLeaf(YType.uint32, 'virtual-link-retransmission-interval'), ['int'])),
                            ('virtual_link_next_hello', (YLeaf(YType.uint32, 'virtual-link-next-hello'), ['int'])),
                            ('is_virtual_link_passive', (YLeaf(YType.boolean, 'is-virtual-link-passive'), ['bool'])),
                            ('is_virtual_link_authentication_enabled', (YLeaf(YType.boolean, 'is-virtual-link-authentication-enabled'), ['bool'])),
                            ('virtual_link_authentication_spi', (YLeaf(YType.uint32, 'virtual-link-authentication-spi'), ['int'])),
                            ('virtual_link_authentication_transmit', (YLeaf(YType.uint32, 'virtual-link-authentication-transmit'), ['int'])),
                            ('is_virtual_link_encryption_enabled', (YLeaf(YType.boolean, 'is-virtual-link-encryption-enabled'), ['bool'])),
                            ('virtual_link_encryption_spi', (YLeaf(YType.uint32, 'virtual-link-encryption-spi'), ['int'])),
                            ('virtual_link_encryption_transmitted', (YLeaf(YType.uint32, 'virtual-link-encryption-transmitted'), ['int'])),
                            ('virtual_link_encrypted_authentication_transmitted', (YLeaf(YType.uint32, 'virtual-link-encrypted-authentication-transmitted'), ['int'])),
                        ])
                        self.virtual_link_neighbor_id = None
                        self.virtual_link_interface_number = None
                        self.virtual_link_state = None
                        self.is_virtual_link_ip_security_required = None
                        self.is_virtual_link_ip_security_active = None
                        self.virtual_link_neighbor_address = None
                        self.is_virtual_link_demand_circuit = None
                        self.virtual_link_dc_bitless_lsa = None
                        self.transit_area_id = None
                        self.interface_name = None
                        self.virtual_link_cost = None
                        self.virual_link_transmission_delay = None
                        self.virtual_link_hello_interval = None
                        self.virtual_link_dead_interval = None
                        self.virtual_link_wait_interval = None
                        self.virtual_link_retransmission_interval = None
                        self.virtual_link_next_hello = None
                        self.is_virtual_link_passive = None
                        self.is_virtual_link_authentication_enabled = None
                        self.virtual_link_authentication_spi = None
                        self.virtual_link_authentication_transmit = None
                        self.is_virtual_link_encryption_enabled = None
                        self.virtual_link_encryption_spi = None
                        self.virtual_link_encryption_transmitted = None
                        self.virtual_link_encrypted_authentication_transmitted = None

                        self.virtual_link_neighbor = Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor()
                        self.virtual_link_neighbor.parent = self
                        self._children_name_map["virtual_link_neighbor"] = "virtual-link-neighbor"
                        self._segment_path = lambda: "virtual-link"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VirtualLink, [u'virtual_link_neighbor_id', u'virtual_link_interface_number', u'virtual_link_state', u'is_virtual_link_ip_security_required', u'is_virtual_link_ip_security_active', u'virtual_link_neighbor_address', u'is_virtual_link_demand_circuit', u'virtual_link_dc_bitless_lsa', u'transit_area_id', u'interface_name', u'virtual_link_cost', u'virual_link_transmission_delay', u'virtual_link_hello_interval', u'virtual_link_dead_interval', u'virtual_link_wait_interval', u'virtual_link_retransmission_interval', u'virtual_link_next_hello', u'is_virtual_link_passive', u'is_virtual_link_authentication_enabled', u'virtual_link_authentication_spi', u'virtual_link_authentication_transmit', u'is_virtual_link_encryption_enabled', u'virtual_link_encryption_spi', u'virtual_link_encryption_transmitted', u'virtual_link_encrypted_authentication_transmitted'], name, value)


                    class VirtualLinkNeighbor(Entity):
                        """
                        Neighbor information 
                        
                        .. attribute:: virtual_link_retransmission
                        
                        	Virtual link retransmission information 
                        	**type**\:  :py:class:`VirtualLinkRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission>`
                        
                        .. attribute:: is_virtual_link_hello_suppressed
                        
                        	If true, hello suppressed 
                        	**type**\: bool
                        
                        .. attribute:: virtual_link_state
                        
                        	OSPF interface state for the virtual link
                        	**type**\:  :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor, self).__init__()

                            self.yang_name = "virtual-link-neighbor"
                            self.yang_parent_name = "virtual-link"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("virtual-link-retransmission", ("virtual_link_retransmission", Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission))])
                            self._leafs = OrderedDict([
                                ('is_virtual_link_hello_suppressed', (YLeaf(YType.boolean, 'is-virtual-link-hello-suppressed'), ['bool'])),
                                ('virtual_link_state', (YLeaf(YType.enumeration, 'virtual-link-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3InterfaceState', '')])),
                            ])
                            self.is_virtual_link_hello_suppressed = None
                            self.virtual_link_state = None

                            self.virtual_link_retransmission = Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission()
                            self.virtual_link_retransmission.parent = self
                            self._children_name_map["virtual_link_retransmission"] = "virtual-link-retransmission"
                            self._segment_path = lambda: "virtual-link-neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor, [u'is_virtual_link_hello_suppressed', u'virtual_link_state'], name, value)


                        class VirtualLinkRetransmission(Entity):
                            """
                            Virtual link retransmission information 
                            
                            .. attribute:: database_descriptor_retransmissions
                            
                            	Number of database descriptor retransmissions during last exchange
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_flood_index
                            
                            	Area scope LSA's flood index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_flood_index
                            
                            	AS scope LSA's flood index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_flood_index
                            
                            	Link flood index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_retransmissions
                            
                            	Number of neighbor retransmissions 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: retransmissions
                            
                            	Number of retransmissions for this neighbor
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_first_flood
                            
                            	First flood item for area scope LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_first_flood_index
                            
                            	Index of the first flood item for area scope LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_first_flood
                            
                            	First flood item for AS scope LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_first_flood_index
                            
                            	Index for first flood item for AS scope LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_first_flood
                            
                            	Link first flood information 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_first_flood_index
                            
                            	Link first flood information index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_next_flood
                            
                            	Next flood item for area scope LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_next_flood_index
                            
                            	Index of next flood item for Area scope LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_next_flood
                            
                            	Next flood item for AS scope LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_next_flood_index
                            
                            	Index of next flood item for AS scope LSAs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_next_flood
                            
                            	Link next flood information 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: link_next_flood_index
                            
                            	Link next flood information index 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_retransmission_length
                            
                            	Number of LSAs sent in last retransmission
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_retransmission_length
                            
                            	Maximum number of LSAs sent in a retransmission
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_retransmission_time
                            
                            	Last retransmission scan time (ms)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: maximum_retransmission_time
                            
                            	Maximum retransmission scan time (ms)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_retransmission_timer
                            
                            	Time until next LSA retransmission (ms)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission, self).__init__()

                                self.yang_name = "virtual-link-retransmission"
                                self.yang_parent_name = "virtual-link-neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('database_descriptor_retransmissions', (YLeaf(YType.uint32, 'database-descriptor-retransmissions'), ['int'])),
                                    ('area_flood_index', (YLeaf(YType.uint32, 'area-flood-index'), ['int'])),
                                    ('as_flood_index', (YLeaf(YType.uint32, 'as-flood-index'), ['int'])),
                                    ('link_flood_index', (YLeaf(YType.uint32, 'link-flood-index'), ['int'])),
                                    ('neighbor_retransmissions', (YLeaf(YType.uint32, 'neighbor-retransmissions'), ['int'])),
                                    ('retransmissions', (YLeaf(YType.uint32, 'retransmissions'), ['int'])),
                                    ('area_first_flood', (YLeaf(YType.uint32, 'area-first-flood'), ['int'])),
                                    ('area_first_flood_index', (YLeaf(YType.uint32, 'area-first-flood-index'), ['int'])),
                                    ('as_first_flood', (YLeaf(YType.uint32, 'as-first-flood'), ['int'])),
                                    ('as_first_flood_index', (YLeaf(YType.uint32, 'as-first-flood-index'), ['int'])),
                                    ('link_first_flood', (YLeaf(YType.uint32, 'link-first-flood'), ['int'])),
                                    ('link_first_flood_index', (YLeaf(YType.uint32, 'link-first-flood-index'), ['int'])),
                                    ('area_next_flood', (YLeaf(YType.uint32, 'area-next-flood'), ['int'])),
                                    ('area_next_flood_index', (YLeaf(YType.uint32, 'area-next-flood-index'), ['int'])),
                                    ('as_next_flood', (YLeaf(YType.uint32, 'as-next-flood'), ['int'])),
                                    ('as_next_flood_index', (YLeaf(YType.uint32, 'as-next-flood-index'), ['int'])),
                                    ('link_next_flood', (YLeaf(YType.uint32, 'link-next-flood'), ['int'])),
                                    ('link_next_flood_index', (YLeaf(YType.uint32, 'link-next-flood-index'), ['int'])),
                                    ('last_retransmission_length', (YLeaf(YType.uint32, 'last-retransmission-length'), ['int'])),
                                    ('maximum_retransmission_length', (YLeaf(YType.uint32, 'maximum-retransmission-length'), ['int'])),
                                    ('last_retransmission_time', (YLeaf(YType.uint32, 'last-retransmission-time'), ['int'])),
                                    ('maximum_retransmission_time', (YLeaf(YType.uint32, 'maximum-retransmission-time'), ['int'])),
                                    ('lsa_retransmission_timer', (YLeaf(YType.uint32, 'lsa-retransmission-timer'), ['int'])),
                                ])
                                self.database_descriptor_retransmissions = None
                                self.area_flood_index = None
                                self.as_flood_index = None
                                self.link_flood_index = None
                                self.neighbor_retransmissions = None
                                self.retransmissions = None
                                self.area_first_flood = None
                                self.area_first_flood_index = None
                                self.as_first_flood = None
                                self.as_first_flood_index = None
                                self.link_first_flood = None
                                self.link_first_flood_index = None
                                self.area_next_flood = None
                                self.area_next_flood_index = None
                                self.as_next_flood = None
                                self.as_next_flood_index = None
                                self.link_next_flood = None
                                self.link_next_flood_index = None
                                self.last_retransmission_length = None
                                self.maximum_retransmission_length = None
                                self.last_retransmission_time = None
                                self.maximum_retransmission_time = None
                                self.lsa_retransmission_timer = None
                                self._segment_path = lambda: "virtual-link-retransmission"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VirtualLink.VirtualLinkNeighbor.VirtualLinkRetransmission, [u'database_descriptor_retransmissions', u'area_flood_index', u'as_flood_index', u'link_flood_index', u'neighbor_retransmissions', u'retransmissions', u'area_first_flood', u'area_first_flood_index', u'as_first_flood', u'as_first_flood_index', u'link_first_flood', u'link_first_flood_index', u'area_next_flood', u'area_next_flood_index', u'as_next_flood', u'as_next_flood_index', u'link_next_flood', u'link_next_flood_index', u'last_retransmission_length', u'maximum_retransmission_length', u'last_retransmission_time', u'maximum_retransmission_time', u'lsa_retransmission_timer'], name, value)


                class FloodListProcessTable(Entity):
                    """
                    OSPFv3 flood list information table for all
                    areas
                    
                    .. attribute:: flood
                    
                    	OSPFv3 flood list information
                    	**type**\: list of  		 :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable, self).__init__()

                        self.yang_name = "flood-list-process-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("flood", ("flood", Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood))])
                        self._leafs = OrderedDict()

                        self.flood = YList(self)
                        self._segment_path = lambda: "flood-list-process-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable, [], name, value)


                    class Flood(Entity):
                        """
                        OSPFv3 flood list information
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: ls_transmission_timer
                        
                        	Time until next LS transmission (ms) 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: queue_length
                        
                        	Number of LSAs currently being flooded 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: link_flood
                        
                        	Link floodlist
                        	**type**\: list of  		 :py:class:`LinkFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.LinkFlood>`
                        
                        .. attribute:: area_flood
                        
                        	Area scope floodlist
                        	**type**\: list of  		 :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AreaFlood>`
                        
                        .. attribute:: as_flood
                        
                        	AS scope floodlist
                        	**type**\: list of  		 :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AsFlood>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood, self).__init__()

                            self.yang_name = "flood"
                            self.yang_parent_name = "flood-list-process-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("link-flood", ("link_flood", Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.LinkFlood)), ("area-flood", ("area_flood", Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AreaFlood)), ("as-flood", ("as_flood", Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AsFlood))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('ls_transmission_timer', (YLeaf(YType.uint32, 'ls-transmission-timer'), ['int'])),
                                ('queue_length', (YLeaf(YType.uint32, 'queue-length'), ['int'])),
                            ])
                            self.interface_name = None
                            self.ls_transmission_timer = None
                            self.queue_length = None

                            self.link_flood = YList(self)
                            self.area_flood = YList(self)
                            self.as_flood = YList(self)
                            self._segment_path = lambda: "flood" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood, ['interface_name', u'ls_transmission_timer', u'queue_length'], name, value)


                        class LinkFlood(Entity):
                            """
                            Link floodlist
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.LinkFlood, self).__init__()

                                self.yang_name = "link-flood"
                                self.yang_parent_name = "flood"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                    ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                    ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                    ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                    ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                ])
                                self.header_lsa_type = None
                                self.header_lsa_age = None
                                self.header_lsa_id = None
                                self.header_advertising_router = None
                                self.header_sequence_number = None
                                self._segment_path = lambda: "link-flood"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.LinkFlood, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                        class AreaFlood(Entity):
                            """
                            Area scope floodlist
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AreaFlood, self).__init__()

                                self.yang_name = "area-flood"
                                self.yang_parent_name = "flood"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                    ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                    ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                    ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                    ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                ])
                                self.header_lsa_type = None
                                self.header_lsa_age = None
                                self.header_lsa_id = None
                                self.header_advertising_router = None
                                self.header_sequence_number = None
                                self._segment_path = lambda: "area-flood"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AreaFlood, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                        class AsFlood(Entity):
                            """
                            AS scope floodlist
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AsFlood, self).__init__()

                                self.yang_name = "as-flood"
                                self.yang_parent_name = "flood"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                    ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                    ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                    ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                    ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                ])
                                self.header_lsa_type = None
                                self.header_lsa_age = None
                                self.header_lsa_id = None
                                self.header_advertising_router = None
                                self.header_sequence_number = None
                                self._segment_path = lambda: "as-flood"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.FloodListProcessTable.Flood.AsFlood, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                class RouteSummary(Entity):
                    """
                    Summarize OSPFv3 local RIB tables
                    
                    .. attribute:: route_id
                    
                    	Route summary of a route ID 
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: intra_area_route
                    
                    	Intra route summary 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inter_area_route
                    
                    	Inter route summary 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: extern_one_route
                    
                    	Extern 1 route summary 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: extern_two_route
                    
                    	Extern 2 route summary 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nssa_one_route
                    
                    	NSSA 1 route summary 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nssa_two_route
                    
                    	NSSA 2 route summary 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_sent_route
                    
                    	Total route summary 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: route_connected
                    
                    	Route connected 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redistribution_route
                    
                    	Redistribution route summary 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_received_route
                    
                    	Total route received summary
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.RouteSummary, self).__init__()

                        self.yang_name = "route-summary"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('route_id', (YLeaf(YType.str, 'route-id'), ['str'])),
                            ('intra_area_route', (YLeaf(YType.uint32, 'intra-area-route'), ['int'])),
                            ('inter_area_route', (YLeaf(YType.uint32, 'inter-area-route'), ['int'])),
                            ('extern_one_route', (YLeaf(YType.uint32, 'extern-one-route'), ['int'])),
                            ('extern_two_route', (YLeaf(YType.uint32, 'extern-two-route'), ['int'])),
                            ('nssa_one_route', (YLeaf(YType.uint32, 'nssa-one-route'), ['int'])),
                            ('nssa_two_route', (YLeaf(YType.uint32, 'nssa-two-route'), ['int'])),
                            ('total_sent_route', (YLeaf(YType.uint32, 'total-sent-route'), ['int'])),
                            ('route_connected', (YLeaf(YType.uint32, 'route-connected'), ['int'])),
                            ('redistribution_route', (YLeaf(YType.uint32, 'redistribution-route'), ['int'])),
                            ('total_received_route', (YLeaf(YType.uint32, 'total-received-route'), ['int'])),
                        ])
                        self.route_id = None
                        self.intra_area_route = None
                        self.inter_area_route = None
                        self.extern_one_route = None
                        self.extern_two_route = None
                        self.nssa_one_route = None
                        self.nssa_two_route = None
                        self.total_sent_route = None
                        self.route_connected = None
                        self.redistribution_route = None
                        self.total_received_route = None
                        self._segment_path = lambda: "route-summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.RouteSummary, [u'route_id', u'intra_area_route', u'inter_area_route', u'extern_one_route', u'extern_two_route', u'nssa_one_route', u'nssa_two_route', u'total_sent_route', u'route_connected', u'redistribution_route', u'total_received_route'], name, value)


                class Areas(Entity):
                    """
                    OSPFv3 area table
                    
                    .. attribute:: area
                    
                    	Per\-area information
                    	**type**\: list of  		 :py:class:`Area <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.Areas, self).__init__()

                        self.yang_name = "areas"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("area", ("area", Ospfv3.Processes.Process.DefaultVrf.Areas.Area))])
                        self._leafs = OrderedDict()

                        self.area = YList(self)
                        self._segment_path = lambda: "areas"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas, [], name, value)


                    class Area(Entity):
                        """
                        Per\-area information
                        
                        .. attribute:: area_id  (key)
                        
                        	Area ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_detail_table
                        
                        	OSPFv3 area neighbor information table
                        	**type**\:  :py:class:`NeighborDetailTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable>`
                        
                        .. attribute:: interface_brief_table
                        
                        	OSPFv3 interface brief information table for an area
                        	**type**\:  :py:class:`InterfaceBriefTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable>`
                        
                        .. attribute:: request_list_table
                        
                        	OSPFv3 request list information in an area
                        	**type**\:  :py:class:`RequestListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable>`
                        
                        .. attribute:: neighbor_table
                        
                        	OSPFv3 neighbor information table
                        	**type**\:  :py:class:`NeighborTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable>`
                        
                        .. attribute:: interface_table
                        
                        	OSPFv3 interface information table for an area
                        	**type**\:  :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable>`
                        
                        .. attribute:: flood_list_table
                        
                        	OSPFv3 flood list information table for an area
                        	**type**\:  :py:class:`FloodListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable>`
                        
                        .. attribute:: retransmission_list_table
                        
                        	OSPFv3 retransmission list information table in an area
                        	**type**\:  :py:class:`RetransmissionListTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable>`
                        
                        .. attribute:: database_table
                        
                        	OSPF Link State Database
                        	**type**\:  :py:class:`DatabaseTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable>`
                        
                        .. attribute:: database_summary_table
                        
                        	Database summary table
                        	**type**\:  :py:class:`DatabaseSummaryTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area, self).__init__()

                            self.yang_name = "area"
                            self.yang_parent_name = "areas"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['area_id']
                            self._child_classes = OrderedDict([("neighbor-detail-table", ("neighbor_detail_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable)), ("interface-brief-table", ("interface_brief_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable)), ("request-list-table", ("request_list_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable)), ("neighbor-table", ("neighbor_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable)), ("interface-table", ("interface_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable)), ("flood-list-table", ("flood_list_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable)), ("retransmission-list-table", ("retransmission_list_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable)), ("database-table", ("database_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable)), ("database-summary-table", ("database_summary_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable))])
                            self._leafs = OrderedDict([
                                ('area_id', (YLeaf(YType.uint32, 'area-id'), ['int'])),
                            ])
                            self.area_id = None

                            self.neighbor_detail_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable()
                            self.neighbor_detail_table.parent = self
                            self._children_name_map["neighbor_detail_table"] = "neighbor-detail-table"

                            self.interface_brief_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable()
                            self.interface_brief_table.parent = self
                            self._children_name_map["interface_brief_table"] = "interface-brief-table"

                            self.request_list_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable()
                            self.request_list_table.parent = self
                            self._children_name_map["request_list_table"] = "request-list-table"

                            self.neighbor_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable()
                            self.neighbor_table.parent = self
                            self._children_name_map["neighbor_table"] = "neighbor-table"

                            self.interface_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable()
                            self.interface_table.parent = self
                            self._children_name_map["interface_table"] = "interface-table"

                            self.flood_list_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable()
                            self.flood_list_table.parent = self
                            self._children_name_map["flood_list_table"] = "flood-list-table"

                            self.retransmission_list_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable()
                            self.retransmission_list_table.parent = self
                            self._children_name_map["retransmission_list_table"] = "retransmission-list-table"

                            self.database_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable()
                            self.database_table.parent = self
                            self._children_name_map["database_table"] = "database-table"

                            self.database_summary_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable()
                            self.database_summary_table.parent = self
                            self._children_name_map["database_summary_table"] = "database-summary-table"
                            self._segment_path = lambda: "area" + "[area-id='" + str(self.area_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area, ['area_id'], name, value)


                        class NeighborDetailTable(Entity):
                            """
                            OSPFv3 area neighbor information table
                            
                            .. attribute:: neighbor_detail
                            
                            	OSPFv3 neighbor detail information
                            	**type**\: list of  		 :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable, self).__init__()

                                self.yang_name = "neighbor-detail-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("neighbor-detail", ("neighbor_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail))])
                                self._leafs = OrderedDict()

                                self.neighbor_detail = YList(self)
                                self._segment_path = lambda: "neighbor-detail-table"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable, [], name, value)


                            class NeighborDetail(Entity):
                                """
                                OSPFv3 neighbor detail information
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_detail
                                
                                	Detailed OSPFv3 neighbor information 
                                	**type**\:  :py:class:`NeighborDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_>`
                                
                                .. attribute:: neighbor_bfd_info
                                
                                	Neighbor BFD information
                                	**type**\:  :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo>`
                                
                                .. attribute:: neighbor_address_xr
                                
                                	Neighbor IP Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_interface_id
                                
                                	Neighbor interface ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_dr_priority
                                
                                	Neighbor's DR priority
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: neighbor_state
                                
                                	Neighbor's state
                                	**type**\:  :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                                
                                .. attribute:: neighbor_designated_router
                                
                                	Designated router 
                                	**type**\: str
                                
                                	**length:** 0..9
                                
                                .. attribute:: neighbor_dead_timer
                                
                                	Time until neighbor's dead timer expires (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_up_time
                                
                                	Amount of time since the adjacency is up (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_virtual_link_id
                                
                                	Neighbor virtual link id 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_neighbor_virtual_link
                                
                                	If true, neighbor is on a virtual link 
                                	**type**\: bool
                                
                                .. attribute:: neighbor_sham_link_id
                                
                                	Neighbor sham link id 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_neighbor_sham_link
                                
                                	If true, neighbor is on a sham link 
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail, self).__init__()

                                    self.yang_name = "neighbor-detail"
                                    self.yang_parent_name = "neighbor-detail-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor-detail", ("neighbor_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_)), ("neighbor-bfd-info", ("neighbor_bfd_info", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                        ('neighbor_address_xr', (YLeaf(YType.str, 'neighbor-address-xr'), ['str'])),
                                        ('neighbor_interface_id', (YLeaf(YType.uint32, 'neighbor-interface-id'), ['int'])),
                                        ('neighbor_dr_priority', (YLeaf(YType.uint8, 'neighbor-dr-priority'), ['int'])),
                                        ('neighbor_state', (YLeaf(YType.enumeration, 'neighbor-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3NeighborState', '')])),
                                        ('neighbor_designated_router', (YLeaf(YType.str, 'neighbor-designated-router'), ['str'])),
                                        ('neighbor_dead_timer', (YLeaf(YType.uint32, 'neighbor-dead-timer'), ['int'])),
                                        ('neighbor_up_time', (YLeaf(YType.uint32, 'neighbor-up-time'), ['int'])),
                                        ('neighbor_virtual_link_id', (YLeaf(YType.uint32, 'neighbor-virtual-link-id'), ['int'])),
                                        ('is_neighbor_virtual_link', (YLeaf(YType.boolean, 'is-neighbor-virtual-link'), ['bool'])),
                                        ('neighbor_sham_link_id', (YLeaf(YType.uint32, 'neighbor-sham-link-id'), ['int'])),
                                        ('is_neighbor_sham_link', (YLeaf(YType.boolean, 'is-neighbor-sham-link'), ['bool'])),
                                    ])
                                    self.interface_name = None
                                    self.neighbor_address = None
                                    self.neighbor_address_xr = None
                                    self.neighbor_interface_id = None
                                    self.neighbor_dr_priority = None
                                    self.neighbor_state = None
                                    self.neighbor_designated_router = None
                                    self.neighbor_dead_timer = None
                                    self.neighbor_up_time = None
                                    self.neighbor_virtual_link_id = None
                                    self.is_neighbor_virtual_link = None
                                    self.neighbor_sham_link_id = None
                                    self.is_neighbor_sham_link = None

                                    self.neighbor_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_()
                                    self.neighbor_detail.parent = self
                                    self._children_name_map["neighbor_detail"] = "neighbor-detail"

                                    self.neighbor_bfd_info = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo()
                                    self.neighbor_bfd_info.parent = self
                                    self._children_name_map["neighbor_bfd_info"] = "neighbor-bfd-info"
                                    self._segment_path = lambda: "neighbor-detail"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail, ['interface_name', 'neighbor_address', u'neighbor_address_xr', u'neighbor_interface_id', u'neighbor_dr_priority', u'neighbor_state', u'neighbor_designated_router', u'neighbor_dead_timer', u'neighbor_up_time', u'neighbor_virtual_link_id', u'is_neighbor_virtual_link', u'neighbor_sham_link_id', u'is_neighbor_sham_link'], name, value)


                                class NeighborDetail_(Entity):
                                    """
                                    Detailed OSPFv3 neighbor information 
                                    
                                    .. attribute:: neighbor_retransmission
                                    
                                    	Retransmission information with this neighbor
                                    	**type**\:  :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_.NeighborRetransmission>`
                                    
                                    .. attribute:: state_changes
                                    
                                    	Number of state changes 
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: neighbor_cost
                                    
                                    	Cost of path to this neighbor 
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: is_neighbor_filtered
                                    
                                    	If true, filter outgoing LSAs 
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor_designated_router_address
                                    
                                    	Address of designated router
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_backup_designated_router_address
                                    
                                    	Address of backup designated router
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_type
                                    
                                    	Interface type
                                    	**type**\:  :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                    
                                    .. attribute:: poll_interval
                                    
                                    	Poll interval (s)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_poll_interval
                                    
                                    	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_ignore_timer
                                    
                                    	Remaining time when ignore timer is running 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_option
                                    
                                    	 This is bitmask of neighbor's option field received 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pending_events
                                    
                                    	Number of pending events 
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_, self).__init__()

                                        self.yang_name = "neighbor-detail"
                                        self.yang_parent_name = "neighbor-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor-retransmission", ("neighbor_retransmission", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_.NeighborRetransmission))])
                                        self._leafs = OrderedDict([
                                            ('state_changes', (YLeaf(YType.uint16, 'state-changes'), ['int'])),
                                            ('neighbor_cost', (YLeaf(YType.uint16, 'neighbor-cost'), ['int'])),
                                            ('is_neighbor_filtered', (YLeaf(YType.boolean, 'is-neighbor-filtered'), ['bool'])),
                                            ('neighbor_designated_router_address', (YLeaf(YType.str, 'neighbor-designated-router-address'), ['str'])),
                                            ('neighbor_backup_designated_router_address', (YLeaf(YType.str, 'neighbor-backup-designated-router-address'), ['str'])),
                                            ('interface_type', (YLeaf(YType.enumeration, 'interface-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Interface', '')])),
                                            ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                            ('next_poll_interval', (YLeaf(YType.uint32, 'next-poll-interval'), ['int'])),
                                            ('neighbor_ignore_timer', (YLeaf(YType.uint32, 'neighbor-ignore-timer'), ['int'])),
                                            ('neighbor_option', (YLeaf(YType.uint32, 'neighbor-option'), ['int'])),
                                            ('pending_events', (YLeaf(YType.uint16, 'pending-events'), ['int'])),
                                        ])
                                        self.state_changes = None
                                        self.neighbor_cost = None
                                        self.is_neighbor_filtered = None
                                        self.neighbor_designated_router_address = None
                                        self.neighbor_backup_designated_router_address = None
                                        self.interface_type = None
                                        self.poll_interval = None
                                        self.next_poll_interval = None
                                        self.neighbor_ignore_timer = None
                                        self.neighbor_option = None
                                        self.pending_events = None

                                        self.neighbor_retransmission = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_.NeighborRetransmission()
                                        self.neighbor_retransmission.parent = self
                                        self._children_name_map["neighbor_retransmission"] = "neighbor-retransmission"
                                        self._segment_path = lambda: "neighbor-detail"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_, [u'state_changes', u'neighbor_cost', u'is_neighbor_filtered', u'neighbor_designated_router_address', u'neighbor_backup_designated_router_address', u'interface_type', u'poll_interval', u'next_poll_interval', u'neighbor_ignore_timer', u'neighbor_option', u'pending_events'], name, value)


                                    class NeighborRetransmission(Entity):
                                        """
                                        Retransmission information with this neighbor
                                        
                                        .. attribute:: database_descriptor_retransmissions
                                        
                                        	Number of database descriptor retransmissions during last exchange
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_flood_index
                                        
                                        	Area scope LSA's flood index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_flood_index
                                        
                                        	AS scope LSA's flood index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_flood_index
                                        
                                        	Link flood index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_retransmissions
                                        
                                        	Number of neighbor retransmissions 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: retransmissions
                                        
                                        	Number of retransmissions for this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_first_flood
                                        
                                        	First flood item for area scope LSAs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_first_flood_index
                                        
                                        	Index of the first flood item for area scope LSAs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood
                                        
                                        	First flood item for AS scope LSAs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood_index
                                        
                                        	Index for first flood item for AS scope LSAs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_first_flood
                                        
                                        	Link first flood information 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_first_flood_index
                                        
                                        	Link first flood information index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood
                                        
                                        	Next flood item for area scope LSAs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood_index
                                        
                                        	Index of next flood item for Area scope LSAs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood
                                        
                                        	Next flood item for AS scope LSAs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood_index
                                        
                                        	Index of next flood item for AS scope LSAs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_next_flood
                                        
                                        	Link next flood information 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_next_flood_index
                                        
                                        	Link next flood information index 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_length
                                        
                                        	Number of LSAs sent in last retransmission
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_length
                                        
                                        	Maximum number of LSAs sent in a retransmission
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_time
                                        
                                        	Last retransmission scan time (ms)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_time
                                        
                                        	Maximum retransmission scan time (ms)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_retransmission_timer
                                        
                                        	Time until next LSA retransmission (ms)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_.NeighborRetransmission, self).__init__()

                                            self.yang_name = "neighbor-retransmission"
                                            self.yang_parent_name = "neighbor-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('database_descriptor_retransmissions', (YLeaf(YType.uint32, 'database-descriptor-retransmissions'), ['int'])),
                                                ('area_flood_index', (YLeaf(YType.uint32, 'area-flood-index'), ['int'])),
                                                ('as_flood_index', (YLeaf(YType.uint32, 'as-flood-index'), ['int'])),
                                                ('link_flood_index', (YLeaf(YType.uint32, 'link-flood-index'), ['int'])),
                                                ('neighbor_retransmissions', (YLeaf(YType.uint32, 'neighbor-retransmissions'), ['int'])),
                                                ('retransmissions', (YLeaf(YType.uint32, 'retransmissions'), ['int'])),
                                                ('area_first_flood', (YLeaf(YType.uint32, 'area-first-flood'), ['int'])),
                                                ('area_first_flood_index', (YLeaf(YType.uint32, 'area-first-flood-index'), ['int'])),
                                                ('as_first_flood', (YLeaf(YType.uint32, 'as-first-flood'), ['int'])),
                                                ('as_first_flood_index', (YLeaf(YType.uint32, 'as-first-flood-index'), ['int'])),
                                                ('link_first_flood', (YLeaf(YType.uint32, 'link-first-flood'), ['int'])),
                                                ('link_first_flood_index', (YLeaf(YType.uint32, 'link-first-flood-index'), ['int'])),
                                                ('area_next_flood', (YLeaf(YType.uint32, 'area-next-flood'), ['int'])),
                                                ('area_next_flood_index', (YLeaf(YType.uint32, 'area-next-flood-index'), ['int'])),
                                                ('as_next_flood', (YLeaf(YType.uint32, 'as-next-flood'), ['int'])),
                                                ('as_next_flood_index', (YLeaf(YType.uint32, 'as-next-flood-index'), ['int'])),
                                                ('link_next_flood', (YLeaf(YType.uint32, 'link-next-flood'), ['int'])),
                                                ('link_next_flood_index', (YLeaf(YType.uint32, 'link-next-flood-index'), ['int'])),
                                                ('last_retransmission_length', (YLeaf(YType.uint32, 'last-retransmission-length'), ['int'])),
                                                ('maximum_retransmission_length', (YLeaf(YType.uint32, 'maximum-retransmission-length'), ['int'])),
                                                ('last_retransmission_time', (YLeaf(YType.uint32, 'last-retransmission-time'), ['int'])),
                                                ('maximum_retransmission_time', (YLeaf(YType.uint32, 'maximum-retransmission-time'), ['int'])),
                                                ('lsa_retransmission_timer', (YLeaf(YType.uint32, 'lsa-retransmission-timer'), ['int'])),
                                            ])
                                            self.database_descriptor_retransmissions = None
                                            self.area_flood_index = None
                                            self.as_flood_index = None
                                            self.link_flood_index = None
                                            self.neighbor_retransmissions = None
                                            self.retransmissions = None
                                            self.area_first_flood = None
                                            self.area_first_flood_index = None
                                            self.as_first_flood = None
                                            self.as_first_flood_index = None
                                            self.link_first_flood = None
                                            self.link_first_flood_index = None
                                            self.area_next_flood = None
                                            self.area_next_flood_index = None
                                            self.as_next_flood = None
                                            self.as_next_flood_index = None
                                            self.link_next_flood = None
                                            self.link_next_flood_index = None
                                            self.last_retransmission_length = None
                                            self.maximum_retransmission_length = None
                                            self.last_retransmission_time = None
                                            self.maximum_retransmission_time = None
                                            self.lsa_retransmission_timer = None
                                            self._segment_path = lambda: "neighbor-retransmission"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborDetail_.NeighborRetransmission, [u'database_descriptor_retransmissions', u'area_flood_index', u'as_flood_index', u'link_flood_index', u'neighbor_retransmissions', u'retransmissions', u'area_first_flood', u'area_first_flood_index', u'as_first_flood', u'as_first_flood_index', u'link_first_flood', u'link_first_flood_index', u'area_next_flood', u'area_next_flood_index', u'as_next_flood', u'as_next_flood_index', u'link_next_flood', u'link_next_flood_index', u'last_retransmission_length', u'maximum_retransmission_length', u'last_retransmission_time', u'maximum_retransmission_time', u'lsa_retransmission_timer'], name, value)


                                class NeighborBfdInfo(Entity):
                                    """
                                    Neighbor BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_status_flag
                                    
                                    	Status of the BFD Session
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo, self).__init__()

                                        self.yang_name = "neighbor-bfd-info"
                                        self.yang_parent_name = "neighbor-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bfd_intf_enable_mode', (YLeaf(YType.uint32, 'bfd-intf-enable-mode'), ['int'])),
                                            ('bfd_status_flag', (YLeaf(YType.uint8, 'bfd-status-flag'), ['int'])),
                                        ])
                                        self.bfd_intf_enable_mode = None
                                        self.bfd_status_flag = None
                                        self._segment_path = lambda: "neighbor-bfd-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborDetailTable.NeighborDetail.NeighborBfdInfo, [u'bfd_intf_enable_mode', u'bfd_status_flag'], name, value)


                        class InterfaceBriefTable(Entity):
                            """
                            OSPFv3 interface brief information table for
                            an area
                            
                            .. attribute:: interface_brief
                            
                            	Interface brief information
                            	**type**\: list of  		 :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable.InterfaceBrief>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable, self).__init__()

                                self.yang_name = "interface-brief-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface-brief", ("interface_brief", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable.InterfaceBrief))])
                                self._leafs = OrderedDict()

                                self.interface_brief = YList(self)
                                self._segment_path = lambda: "interface-brief-table"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable, [], name, value)


                            class InterfaceBrief(Entity):
                                """
                                Interface brief information
                                
                                .. attribute:: interface_name  (key)
                                
                                	Interface name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: interface_address
                                
                                	Interface IP address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_link_cost
                                
                                	Interface link cost
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ospf_interface_state
                                
                                	Interface OSPF state
                                	**type**\:  :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                                
                                .. attribute:: interface_neighbors
                                
                                	Total number of neighbors 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interface_adjacent_neighbors
                                
                                	Total number of adjacent neighbors
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: network_type
                                
                                	Network type
                                	**type**\:  :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable.InterfaceBrief, self).__init__()

                                    self.yang_name = "interface-brief"
                                    self.yang_parent_name = "interface-brief-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['interface_name']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('interface_address', (YLeaf(YType.str, 'interface-address'), ['str'])),
                                        ('interface_link_cost', (YLeaf(YType.uint16, 'interface-link-cost'), ['int'])),
                                        ('ospf_interface_state', (YLeaf(YType.enumeration, 'ospf-interface-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3InterfaceState', '')])),
                                        ('interface_neighbors', (YLeaf(YType.uint16, 'interface-neighbors'), ['int'])),
                                        ('interface_adjacent_neighbors', (YLeaf(YType.uint16, 'interface-adjacent-neighbors'), ['int'])),
                                        ('network_type', (YLeaf(YType.enumeration, 'network-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Interface', '')])),
                                    ])
                                    self.interface_name = None
                                    self.interface_address = None
                                    self.interface_link_cost = None
                                    self.ospf_interface_state = None
                                    self.interface_neighbors = None
                                    self.interface_adjacent_neighbors = None
                                    self.network_type = None
                                    self._segment_path = lambda: "interface-brief" + "[interface-name='" + str(self.interface_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceBriefTable.InterfaceBrief, ['interface_name', u'interface_address', u'interface_link_cost', u'ospf_interface_state', u'interface_neighbors', u'interface_adjacent_neighbors', u'network_type'], name, value)


                        class RequestListTable(Entity):
                            """
                            OSPFv3 request list information in an area
                            
                            .. attribute:: request
                            
                            	OSPFv3 request list information
                            	**type**\: list of  		 :py:class:`Request <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable, self).__init__()

                                self.yang_name = "request-list-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("request", ("request", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request))])
                                self._leafs = OrderedDict()

                                self.request = YList(self)
                                self._segment_path = lambda: "request-list-table"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable, [], name, value)


                            class Request(Entity):
                                """
                                OSPFv3 request list information
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: request_neighbor_address
                                
                                	Neighbor IP address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_request_virtual_link
                                
                                	If true, virtual link is requested 
                                	**type**\: bool
                                
                                .. attribute:: request_virtual_link_id
                                
                                	Request virtual link ID 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_request_sham_link
                                
                                	If true, sham link is requested 
                                	**type**\: bool
                                
                                .. attribute:: request_sham_link_id
                                
                                	Request sham link ID 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: request
                                
                                	List of request list entries
                                	**type**\: list of  		 :py:class:`Request_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request.Request_>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request, self).__init__()

                                    self.yang_name = "request"
                                    self.yang_parent_name = "request-list-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("request", ("request", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request.Request_))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                        ('request_neighbor_address', (YLeaf(YType.str, 'request-neighbor-address'), ['str'])),
                                        ('is_request_virtual_link', (YLeaf(YType.boolean, 'is-request-virtual-link'), ['bool'])),
                                        ('request_virtual_link_id', (YLeaf(YType.uint32, 'request-virtual-link-id'), ['int'])),
                                        ('is_request_sham_link', (YLeaf(YType.boolean, 'is-request-sham-link'), ['bool'])),
                                        ('request_sham_link_id', (YLeaf(YType.uint32, 'request-sham-link-id'), ['int'])),
                                    ])
                                    self.interface_name = None
                                    self.neighbor_address = None
                                    self.request_neighbor_address = None
                                    self.is_request_virtual_link = None
                                    self.request_virtual_link_id = None
                                    self.is_request_sham_link = None
                                    self.request_sham_link_id = None

                                    self.request = YList(self)
                                    self._segment_path = lambda: "request"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request, ['interface_name', 'neighbor_address', u'request_neighbor_address', u'is_request_virtual_link', u'request_virtual_link_id', u'is_request_sham_link', u'request_sham_link_id'], name, value)


                                class Request_(Entity):
                                    """
                                    List of request list entries
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request.Request_, self).__init__()

                                        self.yang_name = "request"
                                        self.yang_parent_name = "request"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                            ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                            ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                            ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                            ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                        ])
                                        self.header_lsa_type = None
                                        self.header_lsa_age = None
                                        self.header_lsa_id = None
                                        self.header_advertising_router = None
                                        self.header_sequence_number = None
                                        self._segment_path = lambda: "request"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RequestListTable.Request.Request_, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                        class NeighborTable(Entity):
                            """
                            OSPFv3 neighbor information table
                            
                            .. attribute:: neighbor
                            
                            	OSPFv3 neighbor detail information
                            	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable, self).__init__()

                                self.yang_name = "neighbor-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("neighbor", ("neighbor", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor))])
                                self._leafs = OrderedDict()

                                self.neighbor = YList(self)
                                self._segment_path = lambda: "neighbor-table"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable, [], name, value)


                            class Neighbor(Entity):
                                """
                                OSPFv3 neighbor detail information
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_detail
                                
                                	Detailed OSPFv3 neighbor information 
                                	**type**\:  :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail>`
                                
                                .. attribute:: neighbor_bfd_info
                                
                                	Neighbor BFD information
                                	**type**\:  :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo>`
                                
                                .. attribute:: neighbor_address_xr
                                
                                	Neighbor IP Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: neighbor_interface_id
                                
                                	Neighbor interface ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_dr_priority
                                
                                	Neighbor's DR priority
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: neighbor_state
                                
                                	Neighbor's state
                                	**type**\:  :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                                
                                .. attribute:: neighbor_designated_router
                                
                                	Designated router 
                                	**type**\: str
                                
                                	**length:** 0..9
                                
                                .. attribute:: neighbor_dead_timer
                                
                                	Time until neighbor's dead timer expires (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_up_time
                                
                                	Amount of time since the adjacency is up (seconds)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: neighbor_virtual_link_id
                                
                                	Neighbor virtual link id 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_neighbor_virtual_link
                                
                                	If true, neighbor is on a virtual link 
                                	**type**\: bool
                                
                                .. attribute:: neighbor_sham_link_id
                                
                                	Neighbor sham link id 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_neighbor_sham_link
                                
                                	If true, neighbor is on a sham link 
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "neighbor-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("neighbor-detail", ("neighbor_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail)), ("neighbor-bfd-info", ("neighbor_bfd_info", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                        ('neighbor_address_xr', (YLeaf(YType.str, 'neighbor-address-xr'), ['str'])),
                                        ('neighbor_interface_id', (YLeaf(YType.uint32, 'neighbor-interface-id'), ['int'])),
                                        ('neighbor_dr_priority', (YLeaf(YType.uint8, 'neighbor-dr-priority'), ['int'])),
                                        ('neighbor_state', (YLeaf(YType.enumeration, 'neighbor-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3NeighborState', '')])),
                                        ('neighbor_designated_router', (YLeaf(YType.str, 'neighbor-designated-router'), ['str'])),
                                        ('neighbor_dead_timer', (YLeaf(YType.uint32, 'neighbor-dead-timer'), ['int'])),
                                        ('neighbor_up_time', (YLeaf(YType.uint32, 'neighbor-up-time'), ['int'])),
                                        ('neighbor_virtual_link_id', (YLeaf(YType.uint32, 'neighbor-virtual-link-id'), ['int'])),
                                        ('is_neighbor_virtual_link', (YLeaf(YType.boolean, 'is-neighbor-virtual-link'), ['bool'])),
                                        ('neighbor_sham_link_id', (YLeaf(YType.uint32, 'neighbor-sham-link-id'), ['int'])),
                                        ('is_neighbor_sham_link', (YLeaf(YType.boolean, 'is-neighbor-sham-link'), ['bool'])),
                                    ])
                                    self.interface_name = None
                                    self.neighbor_address = None
                                    self.neighbor_address_xr = None
                                    self.neighbor_interface_id = None
                                    self.neighbor_dr_priority = None
                                    self.neighbor_state = None
                                    self.neighbor_designated_router = None
                                    self.neighbor_dead_timer = None
                                    self.neighbor_up_time = None
                                    self.neighbor_virtual_link_id = None
                                    self.is_neighbor_virtual_link = None
                                    self.neighbor_sham_link_id = None
                                    self.is_neighbor_sham_link = None

                                    self.neighbor_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail()
                                    self.neighbor_detail.parent = self
                                    self._children_name_map["neighbor_detail"] = "neighbor-detail"

                                    self.neighbor_bfd_info = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo()
                                    self.neighbor_bfd_info.parent = self
                                    self._children_name_map["neighbor_bfd_info"] = "neighbor-bfd-info"
                                    self._segment_path = lambda: "neighbor"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor, ['interface_name', 'neighbor_address', u'neighbor_address_xr', u'neighbor_interface_id', u'neighbor_dr_priority', u'neighbor_state', u'neighbor_designated_router', u'neighbor_dead_timer', u'neighbor_up_time', u'neighbor_virtual_link_id', u'is_neighbor_virtual_link', u'neighbor_sham_link_id', u'is_neighbor_sham_link'], name, value)


                                class NeighborDetail(Entity):
                                    """
                                    Detailed OSPFv3 neighbor information 
                                    
                                    .. attribute:: neighbor_retransmission
                                    
                                    	Retransmission information with this neighbor
                                    	**type**\:  :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission>`
                                    
                                    .. attribute:: state_changes
                                    
                                    	Number of state changes 
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: neighbor_cost
                                    
                                    	Cost of path to this neighbor 
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: is_neighbor_filtered
                                    
                                    	If true, filter outgoing LSAs 
                                    	**type**\: bool
                                    
                                    .. attribute:: neighbor_designated_router_address
                                    
                                    	Address of designated router
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: neighbor_backup_designated_router_address
                                    
                                    	Address of backup designated router
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_type
                                    
                                    	Interface type
                                    	**type**\:  :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                    
                                    .. attribute:: poll_interval
                                    
                                    	Poll interval (s)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_poll_interval
                                    
                                    	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: neighbor_ignore_timer
                                    
                                    	Remaining time when ignore timer is running 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: neighbor_option
                                    
                                    	 This is bitmask of neighbor's option field received 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pending_events
                                    
                                    	Number of pending events 
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail, self).__init__()

                                        self.yang_name = "neighbor-detail"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("neighbor-retransmission", ("neighbor_retransmission", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission))])
                                        self._leafs = OrderedDict([
                                            ('state_changes', (YLeaf(YType.uint16, 'state-changes'), ['int'])),
                                            ('neighbor_cost', (YLeaf(YType.uint16, 'neighbor-cost'), ['int'])),
                                            ('is_neighbor_filtered', (YLeaf(YType.boolean, 'is-neighbor-filtered'), ['bool'])),
                                            ('neighbor_designated_router_address', (YLeaf(YType.str, 'neighbor-designated-router-address'), ['str'])),
                                            ('neighbor_backup_designated_router_address', (YLeaf(YType.str, 'neighbor-backup-designated-router-address'), ['str'])),
                                            ('interface_type', (YLeaf(YType.enumeration, 'interface-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Interface', '')])),
                                            ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                            ('next_poll_interval', (YLeaf(YType.uint32, 'next-poll-interval'), ['int'])),
                                            ('neighbor_ignore_timer', (YLeaf(YType.uint32, 'neighbor-ignore-timer'), ['int'])),
                                            ('neighbor_option', (YLeaf(YType.uint32, 'neighbor-option'), ['int'])),
                                            ('pending_events', (YLeaf(YType.uint16, 'pending-events'), ['int'])),
                                        ])
                                        self.state_changes = None
                                        self.neighbor_cost = None
                                        self.is_neighbor_filtered = None
                                        self.neighbor_designated_router_address = None
                                        self.neighbor_backup_designated_router_address = None
                                        self.interface_type = None
                                        self.poll_interval = None
                                        self.next_poll_interval = None
                                        self.neighbor_ignore_timer = None
                                        self.neighbor_option = None
                                        self.pending_events = None

                                        self.neighbor_retransmission = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission()
                                        self.neighbor_retransmission.parent = self
                                        self._children_name_map["neighbor_retransmission"] = "neighbor-retransmission"
                                        self._segment_path = lambda: "neighbor-detail"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail, [u'state_changes', u'neighbor_cost', u'is_neighbor_filtered', u'neighbor_designated_router_address', u'neighbor_backup_designated_router_address', u'interface_type', u'poll_interval', u'next_poll_interval', u'neighbor_ignore_timer', u'neighbor_option', u'pending_events'], name, value)


                                    class NeighborRetransmission(Entity):
                                        """
                                        Retransmission information with this neighbor
                                        
                                        .. attribute:: database_descriptor_retransmissions
                                        
                                        	Number of database descriptor retransmissions during last exchange
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_flood_index
                                        
                                        	Area scope LSA's flood index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_flood_index
                                        
                                        	AS scope LSA's flood index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_flood_index
                                        
                                        	Link flood index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: neighbor_retransmissions
                                        
                                        	Number of neighbor retransmissions 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: retransmissions
                                        
                                        	Number of retransmissions for this neighbor
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_first_flood
                                        
                                        	First flood item for area scope LSAs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_first_flood_index
                                        
                                        	Index of the first flood item for area scope LSAs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood
                                        
                                        	First flood item for AS scope LSAs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_first_flood_index
                                        
                                        	Index for first flood item for AS scope LSAs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_first_flood
                                        
                                        	Link first flood information 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_first_flood_index
                                        
                                        	Link first flood information index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood
                                        
                                        	Next flood item for area scope LSAs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: area_next_flood_index
                                        
                                        	Index of next flood item for Area scope LSAs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood
                                        
                                        	Next flood item for AS scope LSAs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_next_flood_index
                                        
                                        	Index of next flood item for AS scope LSAs
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_next_flood
                                        
                                        	Link next flood information 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: link_next_flood_index
                                        
                                        	Link next flood information index 
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_length
                                        
                                        	Number of LSAs sent in last retransmission
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_length
                                        
                                        	Maximum number of LSAs sent in a retransmission
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: last_retransmission_time
                                        
                                        	Last retransmission scan time (ms)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: maximum_retransmission_time
                                        
                                        	Maximum retransmission scan time (ms)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_retransmission_timer
                                        
                                        	Time until next LSA retransmission (ms)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission, self).__init__()

                                            self.yang_name = "neighbor-retransmission"
                                            self.yang_parent_name = "neighbor-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('database_descriptor_retransmissions', (YLeaf(YType.uint32, 'database-descriptor-retransmissions'), ['int'])),
                                                ('area_flood_index', (YLeaf(YType.uint32, 'area-flood-index'), ['int'])),
                                                ('as_flood_index', (YLeaf(YType.uint32, 'as-flood-index'), ['int'])),
                                                ('link_flood_index', (YLeaf(YType.uint32, 'link-flood-index'), ['int'])),
                                                ('neighbor_retransmissions', (YLeaf(YType.uint32, 'neighbor-retransmissions'), ['int'])),
                                                ('retransmissions', (YLeaf(YType.uint32, 'retransmissions'), ['int'])),
                                                ('area_first_flood', (YLeaf(YType.uint32, 'area-first-flood'), ['int'])),
                                                ('area_first_flood_index', (YLeaf(YType.uint32, 'area-first-flood-index'), ['int'])),
                                                ('as_first_flood', (YLeaf(YType.uint32, 'as-first-flood'), ['int'])),
                                                ('as_first_flood_index', (YLeaf(YType.uint32, 'as-first-flood-index'), ['int'])),
                                                ('link_first_flood', (YLeaf(YType.uint32, 'link-first-flood'), ['int'])),
                                                ('link_first_flood_index', (YLeaf(YType.uint32, 'link-first-flood-index'), ['int'])),
                                                ('area_next_flood', (YLeaf(YType.uint32, 'area-next-flood'), ['int'])),
                                                ('area_next_flood_index', (YLeaf(YType.uint32, 'area-next-flood-index'), ['int'])),
                                                ('as_next_flood', (YLeaf(YType.uint32, 'as-next-flood'), ['int'])),
                                                ('as_next_flood_index', (YLeaf(YType.uint32, 'as-next-flood-index'), ['int'])),
                                                ('link_next_flood', (YLeaf(YType.uint32, 'link-next-flood'), ['int'])),
                                                ('link_next_flood_index', (YLeaf(YType.uint32, 'link-next-flood-index'), ['int'])),
                                                ('last_retransmission_length', (YLeaf(YType.uint32, 'last-retransmission-length'), ['int'])),
                                                ('maximum_retransmission_length', (YLeaf(YType.uint32, 'maximum-retransmission-length'), ['int'])),
                                                ('last_retransmission_time', (YLeaf(YType.uint32, 'last-retransmission-time'), ['int'])),
                                                ('maximum_retransmission_time', (YLeaf(YType.uint32, 'maximum-retransmission-time'), ['int'])),
                                                ('lsa_retransmission_timer', (YLeaf(YType.uint32, 'lsa-retransmission-timer'), ['int'])),
                                            ])
                                            self.database_descriptor_retransmissions = None
                                            self.area_flood_index = None
                                            self.as_flood_index = None
                                            self.link_flood_index = None
                                            self.neighbor_retransmissions = None
                                            self.retransmissions = None
                                            self.area_first_flood = None
                                            self.area_first_flood_index = None
                                            self.as_first_flood = None
                                            self.as_first_flood_index = None
                                            self.link_first_flood = None
                                            self.link_first_flood_index = None
                                            self.area_next_flood = None
                                            self.area_next_flood_index = None
                                            self.as_next_flood = None
                                            self.as_next_flood_index = None
                                            self.link_next_flood = None
                                            self.link_next_flood_index = None
                                            self.last_retransmission_length = None
                                            self.maximum_retransmission_length = None
                                            self.last_retransmission_time = None
                                            self.maximum_retransmission_time = None
                                            self.lsa_retransmission_timer = None
                                            self._segment_path = lambda: "neighbor-retransmission"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborDetail.NeighborRetransmission, [u'database_descriptor_retransmissions', u'area_flood_index', u'as_flood_index', u'link_flood_index', u'neighbor_retransmissions', u'retransmissions', u'area_first_flood', u'area_first_flood_index', u'as_first_flood', u'as_first_flood_index', u'link_first_flood', u'link_first_flood_index', u'area_next_flood', u'area_next_flood_index', u'as_next_flood', u'as_next_flood_index', u'link_next_flood', u'link_next_flood_index', u'last_retransmission_length', u'maximum_retransmission_length', u'last_retransmission_time', u'maximum_retransmission_time', u'lsa_retransmission_timer'], name, value)


                                class NeighborBfdInfo(Entity):
                                    """
                                    Neighbor BFD information
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD enable mode \- Default/Strict
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_status_flag
                                    
                                    	Status of the BFD Session
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo, self).__init__()

                                        self.yang_name = "neighbor-bfd-info"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bfd_intf_enable_mode', (YLeaf(YType.uint32, 'bfd-intf-enable-mode'), ['int'])),
                                            ('bfd_status_flag', (YLeaf(YType.uint8, 'bfd-status-flag'), ['int'])),
                                        ])
                                        self.bfd_intf_enable_mode = None
                                        self.bfd_status_flag = None
                                        self._segment_path = lambda: "neighbor-bfd-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.NeighborTable.Neighbor.NeighborBfdInfo, [u'bfd_intf_enable_mode', u'bfd_status_flag'], name, value)


                        class InterfaceTable(Entity):
                            """
                            OSPFv3 interface information table for an area
                            
                            .. attribute:: interface
                            
                            	OSPFv3 interface information
                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable, self).__init__()

                                self.yang_name = "interface-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface", ("interface", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface))])
                                self._leafs = OrderedDict()

                                self.interface = YList(self)
                                self._segment_path = lambda: "interface-table"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable, [], name, value)


                            class Interface(Entity):
                                """
                                OSPFv3 interface information
                                
                                .. attribute:: interface_name  (key)
                                
                                	Interface name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: active_interface
                                
                                	Active interface details 
                                	**type**\:  :py:class:`ActiveInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.ActiveInterface>`
                                
                                .. attribute:: interface_bfd
                                
                                	BFD information 
                                	**type**\:  :py:class:`InterfaceBfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd>`
                                
                                .. attribute:: interface_state
                                
                                	Interface state
                                	**type**\:  :py:class:`ImStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.ImStateEnum>`
                                
                                .. attribute:: is_interface_line_up
                                
                                	If true, line protocol is up 
                                	**type**\: bool
                                
                                .. attribute:: is_interface_ip_security_required
                                
                                	If true, interface IP security is required 
                                	**type**\: bool
                                
                                .. attribute:: is_interface_ip_security_active
                                
                                	If true, interface IP security is active 
                                	**type**\: bool
                                
                                .. attribute:: interface_address
                                
                                	Interface IPv6 address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_number
                                
                                	Interface number 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_router_id
                                
                                	Interface router ID 
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: network_type
                                
                                	Network type
                                	**type**\:  :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                                
                                .. attribute:: interface_link_cost
                                
                                	Interface link cost
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: is_interface_flood_reduction
                                
                                	If true, interface flood reduction is active 
                                	**type**\: bool
                                
                                .. attribute:: is_demand_circuit_configured
                                
                                	If true, configured as demand circuit 
                                	**type**\: bool
                                
                                .. attribute:: is_interface_demand_circuit
                                
                                	If true, interface running as demand circuit
                                	**type**\: bool
                                
                                .. attribute:: interface_dc_bitless_ls_as
                                
                                	Number of LSAs with demand circuit bit not set for the area in which the interface is running
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: transmission_delay
                                
                                	Interface transmission delay (sec)
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ospf_interface_state
                                
                                	Interface state
                                	**type**\:  :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                                
                                .. attribute:: interface_priority
                                
                                	Interface priority
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: is_designated_router
                                
                                	If true, designated router
                                	**type**\: bool
                                
                                .. attribute:: designated_router_id
                                
                                	Designated router ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: designated_router_address
                                
                                	Designated router interface address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_designated_router_id
                                
                                	Backup designated router ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_designated_router_address
                                
                                	Backup designated router interface address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: network_lsa_flush_timer
                                
                                	The amount of time in seconds before flush timer for old network LSA expires 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: is_interface_lsa_filtered
                                
                                	Filter is configured for out going LSAs 
                                	**type**\: bool
                                
                                .. attribute:: hello_interval
                                
                                	Configured hello interval (s)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: dead_interval
                                
                                	Configured dead interval (s) 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: wait_interval
                                
                                	Configured wait interval (s) 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_retransmission_interval
                                
                                	Configured retransmit interval (s) 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hello_time
                                
                                	Time until next Hello (s) 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_authentication_spi
                                
                                	Interface authentication spi 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_authentication_transmit
                                
                                	Interface authentication transmit 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_interface_encryption_enabled
                                
                                	If true, interface encryption is enabled 
                                	**type**\: bool
                                
                                .. attribute:: is_prefix_suppress
                                
                                	If true prefix suppression is enabled
                                	**type**\: bool
                                
                                .. attribute:: interface_encryption_spi
                                
                                	Interface encryption spi
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_encryption_transmitted
                                
                                	Interface encryption transmitted 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_encrypted_authentication_transmitted
                                
                                	Interface encrypted authentication transmitted 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: adjacent_neighbor
                                
                                	Number of adjacent neighbors
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_references
                                
                                	Interface reference count 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: configured_ldp_sync
                                
                                	If true, configured as LDP sync
                                	**type**\: bool
                                
                                .. attribute:: interface_ldp_sync
                                
                                	If true, interface LDP sync is achieved
                                	**type**\: bool
                                
                                .. attribute:: interface_neighbor
                                
                                	Information for neighbors on the interface
                                	**type**\: list of  		 :py:class:`InterfaceNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "interface-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['interface_name']
                                    self._child_classes = OrderedDict([("active-interface", ("active_interface", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.ActiveInterface)), ("interface-bfd", ("interface_bfd", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd)), ("interface-neighbor", ("interface_neighbor", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('interface_state', (YLeaf(YType.enumeration, 'interface-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'ImStateEnum', '')])),
                                        ('is_interface_line_up', (YLeaf(YType.boolean, 'is-interface-line-up'), ['bool'])),
                                        ('is_interface_ip_security_required', (YLeaf(YType.boolean, 'is-interface-ip-security-required'), ['bool'])),
                                        ('is_interface_ip_security_active', (YLeaf(YType.boolean, 'is-interface-ip-security-active'), ['bool'])),
                                        ('interface_address', (YLeaf(YType.str, 'interface-address'), ['str'])),
                                        ('interface_number', (YLeaf(YType.uint32, 'interface-number'), ['int'])),
                                        ('interface_router_id', (YLeaf(YType.str, 'interface-router-id'), ['str'])),
                                        ('network_type', (YLeaf(YType.enumeration, 'network-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Interface', '')])),
                                        ('interface_link_cost', (YLeaf(YType.uint16, 'interface-link-cost'), ['int'])),
                                        ('is_interface_flood_reduction', (YLeaf(YType.boolean, 'is-interface-flood-reduction'), ['bool'])),
                                        ('is_demand_circuit_configured', (YLeaf(YType.boolean, 'is-demand-circuit-configured'), ['bool'])),
                                        ('is_interface_demand_circuit', (YLeaf(YType.boolean, 'is-interface-demand-circuit'), ['bool'])),
                                        ('interface_dc_bitless_ls_as', (YLeaf(YType.uint32, 'interface-dc-bitless-ls-as'), ['int'])),
                                        ('transmission_delay', (YLeaf(YType.uint16, 'transmission-delay'), ['int'])),
                                        ('ospf_interface_state', (YLeaf(YType.enumeration, 'ospf-interface-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3InterfaceState', '')])),
                                        ('interface_priority', (YLeaf(YType.uint8, 'interface-priority'), ['int'])),
                                        ('is_designated_router', (YLeaf(YType.boolean, 'is-designated-router'), ['bool'])),
                                        ('designated_router_id', (YLeaf(YType.str, 'designated-router-id'), ['str'])),
                                        ('designated_router_address', (YLeaf(YType.str, 'designated-router-address'), ['str'])),
                                        ('backup_designated_router_id', (YLeaf(YType.str, 'backup-designated-router-id'), ['str'])),
                                        ('backup_designated_router_address', (YLeaf(YType.str, 'backup-designated-router-address'), ['str'])),
                                        ('network_lsa_flush_timer', (YLeaf(YType.uint32, 'network-lsa-flush-timer'), ['int'])),
                                        ('is_interface_lsa_filtered', (YLeaf(YType.boolean, 'is-interface-lsa-filtered'), ['bool'])),
                                        ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                        ('dead_interval', (YLeaf(YType.uint32, 'dead-interval'), ['int'])),
                                        ('wait_interval', (YLeaf(YType.uint32, 'wait-interval'), ['int'])),
                                        ('interface_retransmission_interval', (YLeaf(YType.uint32, 'interface-retransmission-interval'), ['int'])),
                                        ('next_hello_time', (YLeaf(YType.uint32, 'next-hello-time'), ['int'])),
                                        ('interface_authentication_spi', (YLeaf(YType.uint32, 'interface-authentication-spi'), ['int'])),
                                        ('interface_authentication_transmit', (YLeaf(YType.uint32, 'interface-authentication-transmit'), ['int'])),
                                        ('is_interface_encryption_enabled', (YLeaf(YType.boolean, 'is-interface-encryption-enabled'), ['bool'])),
                                        ('is_prefix_suppress', (YLeaf(YType.boolean, 'is-prefix-suppress'), ['bool'])),
                                        ('interface_encryption_spi', (YLeaf(YType.uint32, 'interface-encryption-spi'), ['int'])),
                                        ('interface_encryption_transmitted', (YLeaf(YType.uint32, 'interface-encryption-transmitted'), ['int'])),
                                        ('interface_encrypted_authentication_transmitted', (YLeaf(YType.uint32, 'interface-encrypted-authentication-transmitted'), ['int'])),
                                        ('adjacent_neighbor', (YLeaf(YType.uint32, 'adjacent-neighbor'), ['int'])),
                                        ('interface_references', (YLeaf(YType.uint32, 'interface-references'), ['int'])),
                                        ('configured_ldp_sync', (YLeaf(YType.boolean, 'configured-ldp-sync'), ['bool'])),
                                        ('interface_ldp_sync', (YLeaf(YType.boolean, 'interface-ldp-sync'), ['bool'])),
                                    ])
                                    self.interface_name = None
                                    self.interface_state = None
                                    self.is_interface_line_up = None
                                    self.is_interface_ip_security_required = None
                                    self.is_interface_ip_security_active = None
                                    self.interface_address = None
                                    self.interface_number = None
                                    self.interface_router_id = None
                                    self.network_type = None
                                    self.interface_link_cost = None
                                    self.is_interface_flood_reduction = None
                                    self.is_demand_circuit_configured = None
                                    self.is_interface_demand_circuit = None
                                    self.interface_dc_bitless_ls_as = None
                                    self.transmission_delay = None
                                    self.ospf_interface_state = None
                                    self.interface_priority = None
                                    self.is_designated_router = None
                                    self.designated_router_id = None
                                    self.designated_router_address = None
                                    self.backup_designated_router_id = None
                                    self.backup_designated_router_address = None
                                    self.network_lsa_flush_timer = None
                                    self.is_interface_lsa_filtered = None
                                    self.hello_interval = None
                                    self.dead_interval = None
                                    self.wait_interval = None
                                    self.interface_retransmission_interval = None
                                    self.next_hello_time = None
                                    self.interface_authentication_spi = None
                                    self.interface_authentication_transmit = None
                                    self.is_interface_encryption_enabled = None
                                    self.is_prefix_suppress = None
                                    self.interface_encryption_spi = None
                                    self.interface_encryption_transmitted = None
                                    self.interface_encrypted_authentication_transmitted = None
                                    self.adjacent_neighbor = None
                                    self.interface_references = None
                                    self.configured_ldp_sync = None
                                    self.interface_ldp_sync = None

                                    self.active_interface = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.ActiveInterface()
                                    self.active_interface.parent = self
                                    self._children_name_map["active_interface"] = "active-interface"

                                    self.interface_bfd = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd()
                                    self.interface_bfd.parent = self
                                    self._children_name_map["interface_bfd"] = "interface-bfd"

                                    self.interface_neighbor = YList(self)
                                    self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface, ['interface_name', u'interface_state', u'is_interface_line_up', u'is_interface_ip_security_required', u'is_interface_ip_security_active', u'interface_address', u'interface_number', u'interface_router_id', u'network_type', u'interface_link_cost', u'is_interface_flood_reduction', u'is_demand_circuit_configured', u'is_interface_demand_circuit', u'interface_dc_bitless_ls_as', u'transmission_delay', u'ospf_interface_state', u'interface_priority', u'is_designated_router', u'designated_router_id', u'designated_router_address', u'backup_designated_router_id', u'backup_designated_router_address', u'network_lsa_flush_timer', u'is_interface_lsa_filtered', u'hello_interval', u'dead_interval', u'wait_interval', u'interface_retransmission_interval', u'next_hello_time', u'interface_authentication_spi', u'interface_authentication_transmit', u'is_interface_encryption_enabled', u'is_prefix_suppress', u'interface_encryption_spi', u'interface_encryption_transmitted', u'interface_encrypted_authentication_transmitted', u'adjacent_neighbor', u'interface_references', u'configured_ldp_sync', u'interface_ldp_sync'], name, value)


                                class ActiveInterface(Entity):
                                    """
                                    Active interface details 
                                    
                                    .. attribute:: wait_time
                                    
                                    	Wait time for DR/BDR selection (s)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_flood_index
                                    
                                    	Area scope LSAs flood index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_flood_index
                                    
                                    	AS scope LSAs flood index 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_link_flood_index
                                    
                                    	Interface flood link index 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: flood_queue_length
                                    
                                    	Flood queue length
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_next_flood
                                    
                                    	Next LSA to flood (Area scope)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_area_next_flood_index
                                    
                                    	Index of next LSA to flood (Area scope) 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_next_flood
                                    
                                    	Next LSA to flood (AS scope)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_as_next_flood_index
                                    
                                    	Index of next LSA to flood (AS scope)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_link_next_flood
                                    
                                    	Interface link next flood information 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_link_next_index
                                    
                                    	Interface link next information index 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: flood_scan_length
                                    
                                    	Last flood scan length 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_flood_length
                                    
                                    	Maximum flood length 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: last_flood_time
                                    
                                    	Last flood scan time (ms)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: maximum_flood_time
                                    
                                    	Maximum flood time (ms) 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_flood_pacing_timer
                                    
                                    	Time until next flood pacing timer (ms) 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_neighbors
                                    
                                    	Total number of neighbors 
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: suppressed_hellos
                                    
                                    	Number of neighbors for which hellos are suppressed 
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.ActiveInterface, self).__init__()

                                        self.yang_name = "active-interface"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('wait_time', (YLeaf(YType.uint32, 'wait-time'), ['int'])),
                                            ('interface_area_flood_index', (YLeaf(YType.uint32, 'interface-area-flood-index'), ['int'])),
                                            ('interface_as_flood_index', (YLeaf(YType.uint32, 'interface-as-flood-index'), ['int'])),
                                            ('interface_link_flood_index', (YLeaf(YType.uint32, 'interface-link-flood-index'), ['int'])),
                                            ('flood_queue_length', (YLeaf(YType.uint32, 'flood-queue-length'), ['int'])),
                                            ('interface_area_next_flood', (YLeaf(YType.uint32, 'interface-area-next-flood'), ['int'])),
                                            ('interface_area_next_flood_index', (YLeaf(YType.uint32, 'interface-area-next-flood-index'), ['int'])),
                                            ('interface_as_next_flood', (YLeaf(YType.uint32, 'interface-as-next-flood'), ['int'])),
                                            ('interface_as_next_flood_index', (YLeaf(YType.uint32, 'interface-as-next-flood-index'), ['int'])),
                                            ('interface_link_next_flood', (YLeaf(YType.uint32, 'interface-link-next-flood'), ['int'])),
                                            ('interface_link_next_index', (YLeaf(YType.uint32, 'interface-link-next-index'), ['int'])),
                                            ('flood_scan_length', (YLeaf(YType.uint32, 'flood-scan-length'), ['int'])),
                                            ('maximum_flood_length', (YLeaf(YType.uint32, 'maximum-flood-length'), ['int'])),
                                            ('last_flood_time', (YLeaf(YType.uint32, 'last-flood-time'), ['int'])),
                                            ('maximum_flood_time', (YLeaf(YType.uint32, 'maximum-flood-time'), ['int'])),
                                            ('interface_flood_pacing_timer', (YLeaf(YType.uint32, 'interface-flood-pacing-timer'), ['int'])),
                                            ('interface_neighbors', (YLeaf(YType.uint16, 'interface-neighbors'), ['int'])),
                                            ('suppressed_hellos', (YLeaf(YType.uint16, 'suppressed-hellos'), ['int'])),
                                        ])
                                        self.wait_time = None
                                        self.interface_area_flood_index = None
                                        self.interface_as_flood_index = None
                                        self.interface_link_flood_index = None
                                        self.flood_queue_length = None
                                        self.interface_area_next_flood = None
                                        self.interface_area_next_flood_index = None
                                        self.interface_as_next_flood = None
                                        self.interface_as_next_flood_index = None
                                        self.interface_link_next_flood = None
                                        self.interface_link_next_index = None
                                        self.flood_scan_length = None
                                        self.maximum_flood_length = None
                                        self.last_flood_time = None
                                        self.maximum_flood_time = None
                                        self.interface_flood_pacing_timer = None
                                        self.interface_neighbors = None
                                        self.suppressed_hellos = None
                                        self._segment_path = lambda: "active-interface"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.ActiveInterface, [u'wait_time', u'interface_area_flood_index', u'interface_as_flood_index', u'interface_link_flood_index', u'flood_queue_length', u'interface_area_next_flood', u'interface_area_next_flood_index', u'interface_as_next_flood', u'interface_as_next_flood_index', u'interface_link_next_flood', u'interface_link_next_index', u'flood_scan_length', u'maximum_flood_length', u'last_flood_time', u'maximum_flood_time', u'interface_flood_pacing_timer', u'interface_neighbors', u'suppressed_hellos'], name, value)


                                class InterfaceBfd(Entity):
                                    """
                                    BFD information 
                                    
                                    .. attribute:: bfd_intf_enable_mode
                                    
                                    	BFD Enable Mode on the interface \- Default/Strict
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_interval
                                    
                                    	BFD interval (ms) 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bfd_detection_multiplier
                                    
                                    	BFD detection multiplier 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd, self).__init__()

                                        self.yang_name = "interface-bfd"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bfd_intf_enable_mode', (YLeaf(YType.uint32, 'bfd-intf-enable-mode'), ['int'])),
                                            ('bfd_interval', (YLeaf(YType.uint32, 'bfd-interval'), ['int'])),
                                            ('bfd_detection_multiplier', (YLeaf(YType.uint32, 'bfd-detection-multiplier'), ['int'])),
                                        ])
                                        self.bfd_intf_enable_mode = None
                                        self.bfd_interval = None
                                        self.bfd_detection_multiplier = None
                                        self._segment_path = lambda: "interface-bfd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceBfd, [u'bfd_intf_enable_mode', u'bfd_interval', u'bfd_detection_multiplier'], name, value)


                                class InterfaceNeighbor(Entity):
                                    """
                                    Information for neighbors on the interface
                                    
                                    .. attribute:: interface_neighbor_id
                                    
                                    	Neighbor router ID 
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_neighbor_cost
                                    
                                    	Cost of link to neighbor
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_neighbor_dr
                                    
                                    	If true, designated router is found 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_neighbor_bdr
                                    
                                    	If true, backup designated router is found 
                                    	**type**\: bool
                                    
                                    .. attribute:: is_hello_suppressed
                                    
                                    	If true, hello is suppressed 
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor, self).__init__()

                                        self.yang_name = "interface-neighbor"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface_neighbor_id', (YLeaf(YType.str, 'interface-neighbor-id'), ['str'])),
                                            ('interface_neighbor_cost', (YLeaf(YType.uint32, 'interface-neighbor-cost'), ['int'])),
                                            ('is_neighbor_dr', (YLeaf(YType.boolean, 'is-neighbor-dr'), ['bool'])),
                                            ('is_neighbor_bdr', (YLeaf(YType.boolean, 'is-neighbor-bdr'), ['bool'])),
                                            ('is_hello_suppressed', (YLeaf(YType.boolean, 'is-hello-suppressed'), ['bool'])),
                                        ])
                                        self.interface_neighbor_id = None
                                        self.interface_neighbor_cost = None
                                        self.is_neighbor_dr = None
                                        self.is_neighbor_bdr = None
                                        self.is_hello_suppressed = None
                                        self._segment_path = lambda: "interface-neighbor"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.InterfaceTable.Interface.InterfaceNeighbor, [u'interface_neighbor_id', u'interface_neighbor_cost', u'is_neighbor_dr', u'is_neighbor_bdr', u'is_hello_suppressed'], name, value)


                        class FloodListTable(Entity):
                            """
                            OSPFv3 flood list information table for an
                            area
                            
                            .. attribute:: flood
                            
                            	OSPFv3 flood list information
                            	**type**\: list of  		 :py:class:`Flood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable, self).__init__()

                                self.yang_name = "flood-list-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("flood", ("flood", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood))])
                                self._leafs = OrderedDict()

                                self.flood = YList(self)
                                self._segment_path = lambda: "flood-list-table"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable, [], name, value)


                            class Flood(Entity):
                                """
                                OSPFv3 flood list information
                                
                                .. attribute:: interface_name  (key)
                                
                                	Interface name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: ls_transmission_timer
                                
                                	Time until next LS transmission (ms) 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: queue_length
                                
                                	Number of LSAs currently being flooded 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_flood
                                
                                	Link floodlist
                                	**type**\: list of  		 :py:class:`LinkFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.LinkFlood>`
                                
                                .. attribute:: area_flood
                                
                                	Area scope floodlist
                                	**type**\: list of  		 :py:class:`AreaFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AreaFlood>`
                                
                                .. attribute:: as_flood
                                
                                	AS scope floodlist
                                	**type**\: list of  		 :py:class:`AsFlood <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AsFlood>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood, self).__init__()

                                    self.yang_name = "flood"
                                    self.yang_parent_name = "flood-list-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['interface_name']
                                    self._child_classes = OrderedDict([("link-flood", ("link_flood", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.LinkFlood)), ("area-flood", ("area_flood", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AreaFlood)), ("as-flood", ("as_flood", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AsFlood))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('ls_transmission_timer', (YLeaf(YType.uint32, 'ls-transmission-timer'), ['int'])),
                                        ('queue_length', (YLeaf(YType.uint32, 'queue-length'), ['int'])),
                                    ])
                                    self.interface_name = None
                                    self.ls_transmission_timer = None
                                    self.queue_length = None

                                    self.link_flood = YList(self)
                                    self.area_flood = YList(self)
                                    self.as_flood = YList(self)
                                    self._segment_path = lambda: "flood" + "[interface-name='" + str(self.interface_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood, ['interface_name', u'ls_transmission_timer', u'queue_length'], name, value)


                                class LinkFlood(Entity):
                                    """
                                    Link floodlist
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.LinkFlood, self).__init__()

                                        self.yang_name = "link-flood"
                                        self.yang_parent_name = "flood"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                            ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                            ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                            ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                            ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                        ])
                                        self.header_lsa_type = None
                                        self.header_lsa_age = None
                                        self.header_lsa_id = None
                                        self.header_advertising_router = None
                                        self.header_sequence_number = None
                                        self._segment_path = lambda: "link-flood"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.LinkFlood, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                                class AreaFlood(Entity):
                                    """
                                    Area scope floodlist
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AreaFlood, self).__init__()

                                        self.yang_name = "area-flood"
                                        self.yang_parent_name = "flood"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                            ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                            ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                            ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                            ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                        ])
                                        self.header_lsa_type = None
                                        self.header_lsa_age = None
                                        self.header_lsa_id = None
                                        self.header_advertising_router = None
                                        self.header_sequence_number = None
                                        self._segment_path = lambda: "area-flood"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AreaFlood, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                                class AsFlood(Entity):
                                    """
                                    AS scope floodlist
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AsFlood, self).__init__()

                                        self.yang_name = "as-flood"
                                        self.yang_parent_name = "flood"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                            ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                            ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                            ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                            ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                        ])
                                        self.header_lsa_type = None
                                        self.header_lsa_age = None
                                        self.header_lsa_id = None
                                        self.header_advertising_router = None
                                        self.header_sequence_number = None
                                        self._segment_path = lambda: "as-flood"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.FloodListTable.Flood.AsFlood, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                        class RetransmissionListTable(Entity):
                            """
                            OSPFv3 retransmission list information table
                            in an area
                            
                            .. attribute:: retransmission
                            
                            	OSPFv3 retransmission list information
                            	**type**\: list of  		 :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable, self).__init__()

                                self.yang_name = "retransmission-list-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("retransmission", ("retransmission", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission))])
                                self._leafs = OrderedDict()

                                self.retransmission = YList(self)
                                self._segment_path = lambda: "retransmission-list-table"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable, [], name, value)


                            class Retransmission(Entity):
                                """
                                OSPFv3 retransmission list information
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: neighbor_address
                                
                                	Neighbor address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: retransmission_neighbor_address
                                
                                	Neighbor IP address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_retransmissionvirtual_link
                                
                                	If true, virtual link is retransmitted 
                                	**type**\: bool
                                
                                .. attribute:: retransmissionvirtual_link_id
                                
                                	Retransmission virtual link ID 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_retransmission_sham_link
                                
                                	If true, sham link is retransmitted 
                                	**type**\: bool
                                
                                .. attribute:: retransmission_sham_link_id
                                
                                	Retransmission sham link ID 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmission_timer
                                
                                	Amount of time remaining on retransmission timer (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmission_length
                                
                                	Retransmission queue length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmissionvirtual_link_db
                                
                                	List of virtual link scope entries 
                                	**type**\: list of  		 :py:class:`RetransmissionvirtualLinkDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb>`
                                
                                .. attribute:: retransmission_area_db
                                
                                	List of area scope entries
                                	**type**\: list of  		 :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb>`
                                
                                .. attribute:: retransmission_asdb
                                
                                	List of AS scope entries
                                	**type**\: list of  		 :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission, self).__init__()

                                    self.yang_name = "retransmission"
                                    self.yang_parent_name = "retransmission-list-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("retransmissionvirtual-link-db", ("retransmissionvirtual_link_db", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb)), ("retransmission-area-db", ("retransmission_area_db", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb)), ("retransmission-asdb", ("retransmission_asdb", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                        ('retransmission_neighbor_address', (YLeaf(YType.str, 'retransmission-neighbor-address'), ['str'])),
                                        ('is_retransmissionvirtual_link', (YLeaf(YType.boolean, 'is-retransmissionvirtual-link'), ['bool'])),
                                        ('retransmissionvirtual_link_id', (YLeaf(YType.uint32, 'retransmissionvirtual-link-id'), ['int'])),
                                        ('is_retransmission_sham_link', (YLeaf(YType.boolean, 'is-retransmission-sham-link'), ['bool'])),
                                        ('retransmission_sham_link_id', (YLeaf(YType.uint32, 'retransmission-sham-link-id'), ['int'])),
                                        ('retransmission_timer', (YLeaf(YType.uint32, 'retransmission-timer'), ['int'])),
                                        ('retransmission_length', (YLeaf(YType.uint32, 'retransmission-length'), ['int'])),
                                    ])
                                    self.interface_name = None
                                    self.neighbor_address = None
                                    self.retransmission_neighbor_address = None
                                    self.is_retransmissionvirtual_link = None
                                    self.retransmissionvirtual_link_id = None
                                    self.is_retransmission_sham_link = None
                                    self.retransmission_sham_link_id = None
                                    self.retransmission_timer = None
                                    self.retransmission_length = None

                                    self.retransmissionvirtual_link_db = YList(self)
                                    self.retransmission_area_db = YList(self)
                                    self.retransmission_asdb = YList(self)
                                    self._segment_path = lambda: "retransmission"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission, ['interface_name', 'neighbor_address', u'retransmission_neighbor_address', u'is_retransmissionvirtual_link', u'retransmissionvirtual_link_id', u'is_retransmission_sham_link', u'retransmission_sham_link_id', u'retransmission_timer', u'retransmission_length'], name, value)


                                class RetransmissionvirtualLinkDb(Entity):
                                    """
                                    List of virtual link scope entries 
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb, self).__init__()

                                        self.yang_name = "retransmissionvirtual-link-db"
                                        self.yang_parent_name = "retransmission"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                            ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                            ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                            ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                            ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                        ])
                                        self.header_lsa_type = None
                                        self.header_lsa_age = None
                                        self.header_lsa_id = None
                                        self.header_advertising_router = None
                                        self.header_sequence_number = None
                                        self._segment_path = lambda: "retransmissionvirtual-link-db"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionvirtualLinkDb, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                                class RetransmissionAreaDb(Entity):
                                    """
                                    List of area scope entries
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb, self).__init__()

                                        self.yang_name = "retransmission-area-db"
                                        self.yang_parent_name = "retransmission"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                            ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                            ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                            ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                            ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                        ])
                                        self.header_lsa_type = None
                                        self.header_lsa_age = None
                                        self.header_lsa_id = None
                                        self.header_advertising_router = None
                                        self.header_sequence_number = None
                                        self._segment_path = lambda: "retransmission-area-db"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAreaDb, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                                class RetransmissionAsdb(Entity):
                                    """
                                    List of AS scope entries
                                    
                                    .. attribute:: header_lsa_type
                                    
                                    	LSA type
                                    	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                    
                                    .. attribute:: header_lsa_age
                                    
                                    	Age of the LSA (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: header_lsa_id
                                    
                                    	LSA ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_advertising_router
                                    
                                    	Router ID of the advertising router
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: header_sequence_number
                                    
                                    	Current LSA sequence number
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb, self).__init__()

                                        self.yang_name = "retransmission-asdb"
                                        self.yang_parent_name = "retransmission"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                            ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                            ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                            ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                            ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                        ])
                                        self.header_lsa_type = None
                                        self.header_lsa_age = None
                                        self.header_lsa_id = None
                                        self.header_advertising_router = None
                                        self.header_sequence_number = None
                                        self._segment_path = lambda: "retransmission-asdb"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.RetransmissionListTable.Retransmission.RetransmissionAsdb, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                        class DatabaseTable(Entity):
                            """
                            OSPF Link State Database
                            
                            .. attribute:: lsa_table
                            
                            	Database LSA information
                            	**type**\:  :py:class:`LsaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable>`
                            
                            .. attribute:: lsa_internal_table
                            
                            	Database LSA information
                            	**type**\:  :py:class:`LsaInternalTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable, self).__init__()

                                self.yang_name = "database-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lsa-table", ("lsa_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable)), ("lsa-internal-table", ("lsa_internal_table", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable))])
                                self._leafs = OrderedDict()

                                self.lsa_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable()
                                self.lsa_table.parent = self
                                self._children_name_map["lsa_table"] = "lsa-table"

                                self.lsa_internal_table = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable()
                                self.lsa_internal_table.parent = self
                                self._children_name_map["lsa_internal_table"] = "lsa-internal-table"
                                self._segment_path = lambda: "database-table"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable, [], name, value)


                            class LsaTable(Entity):
                                """
                                Database LSA information
                                
                                .. attribute:: lsa
                                
                                	Database LSA information
                                	**type**\: list of  		 :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable, self).__init__()

                                    self.yang_name = "lsa-table"
                                    self.yang_parent_name = "database-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lsa", ("lsa", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa))])
                                    self._leafs = OrderedDict()

                                    self.lsa = YList(self)
                                    self._segment_path = lambda: "lsa-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable, [], name, value)


                                class Lsa(Entity):
                                    """
                                    Database LSA information
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ls_type
                                    
                                    	LSA type
                                    	**type**\:  :py:class:`Ospfv3Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa>`
                                    
                                    .. attribute:: advertising_router
                                    
                                    	Advertising Router ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ls_id
                                    
                                    	Link state ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_name
                                    
                                    	InterfaceName
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: lsa_info
                                    
                                    	Summary of all LSAs or LSA specific information 
                                    	**type**\:  :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa, self).__init__()

                                        self.yang_name = "lsa"
                                        self.yang_parent_name = "lsa-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-info", ("lsa_info", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo))])
                                        self._leafs = OrderedDict([
                                            ('area_id', (YLeaf(YType.uint32, 'area-id'), ['int'])),
                                            ('ls_type', (YLeaf(YType.enumeration, 'ls-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa', '')])),
                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ])
                                        self.area_id = None
                                        self.ls_type = None
                                        self.advertising_router = None
                                        self.ls_id = None
                                        self.interface_name = None

                                        self.lsa_info = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo()
                                        self.lsa_info.parent = self
                                        self._children_name_map["lsa_info"] = "lsa-info"
                                        self._segment_path = lambda: "lsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa, ['area_id', 'ls_type', 'advertising_router', 'ls_id', 'interface_name'], name, value)


                                    class LsaInfo(Entity):
                                        """
                                        Summary of all LSAs or LSA specific information 
                                        
                                        .. attribute:: lsa_summary_info
                                        
                                        	Summary information of LSAs
                                        	**type**\:  :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                        
                                        .. attribute:: router_lsa_type
                                        
                                        	Router LSA
                                        	**type**\:  :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType>`
                                        
                                        .. attribute:: network_lsa_type
                                        
                                        	Network LSA
                                        	**type**\:  :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType>`
                                        
                                        .. attribute:: inter_area_prefix_lsa_type
                                        
                                        	Inter Area Prefix LSA
                                        	**type**\:  :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                        
                                        .. attribute:: inter_area_router_lsa_type
                                        
                                        	Inter Area Router LSA
                                        	**type**\:  :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                        
                                        .. attribute:: external_lsa_type
                                        
                                        	External LSA
                                        	**type**\:  :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType>`
                                        
                                        .. attribute:: nssalsa_type
                                        
                                        	NSSA External LSA
                                        	**type**\:  :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType>`
                                        
                                        .. attribute:: link_lsa_type
                                        
                                        	Link LSA
                                        	**type**\:  :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType>`
                                        
                                        .. attribute:: intra_area_prefix_lsa_type
                                        
                                        	Intra Area Prefix LSA
                                        	**type**\:  :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                        
                                        .. attribute:: grace_lsa
                                        
                                        	Grace LSA
                                        	**type**\:  :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa>`
                                        
                                        .. attribute:: unknown_link_lsa_type
                                        
                                        	Unknown Link Scope LSA
                                        	**type**\:  :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                        
                                        .. attribute:: unknown_area_lsa_type
                                        
                                        	Unknown\-Area scope LSA
                                        	**type**\:  :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                        
                                        .. attribute:: unknown_aslsa_type
                                        
                                        	Unknown\-AS scope LSA
                                        	**type**\:  :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType>`
                                        
                                        .. attribute:: unknown_lsa_type
                                        
                                        	Unknown LSA
                                        	**type**\:  :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType>`
                                        
                                        .. attribute:: lsa_info_type
                                        
                                        	LSAInfoType
                                        	**type**\:  :py:class:`Ospfv3LsaInfoTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypes>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo, self).__init__()

                                            self.yang_name = "lsa-info"
                                            self.yang_parent_name = "lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-summary-info", ("lsa_summary_info", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo)), ("router-lsa-type", ("router_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType)), ("network-lsa-type", ("network_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType)), ("inter-area-prefix-lsa-type", ("inter_area_prefix_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType)), ("inter-area-router-lsa-type", ("inter_area_router_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType)), ("external-lsa-type", ("external_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType)), ("nssalsa-type", ("nssalsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType)), ("link-lsa-type", ("link_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType)), ("intra-area-prefix-lsa-type", ("intra_area_prefix_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType)), ("grace-lsa", ("grace_lsa", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa)), ("unknown-link-lsa-type", ("unknown_link_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType)), ("unknown-area-lsa-type", ("unknown_area_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType)), ("unknown-aslsa-type", ("unknown_aslsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType)), ("unknown-lsa-type", ("unknown_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType))])
                                            self._leafs = OrderedDict([
                                                ('lsa_info_type', (YLeaf(YType.enumeration, 'lsa-info-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3LsaInfoTypes', '')])),
                                            ])
                                            self.lsa_info_type = None

                                            self.lsa_summary_info = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo()
                                            self.lsa_summary_info.parent = self
                                            self._children_name_map["lsa_summary_info"] = "lsa-summary-info"

                                            self.router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType()
                                            self.router_lsa_type.parent = self
                                            self._children_name_map["router_lsa_type"] = "router-lsa-type"

                                            self.network_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType()
                                            self.network_lsa_type.parent = self
                                            self._children_name_map["network_lsa_type"] = "network-lsa-type"

                                            self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                            self.inter_area_prefix_lsa_type.parent = self
                                            self._children_name_map["inter_area_prefix_lsa_type"] = "inter-area-prefix-lsa-type"

                                            self.inter_area_router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                            self.inter_area_router_lsa_type.parent = self
                                            self._children_name_map["inter_area_router_lsa_type"] = "inter-area-router-lsa-type"

                                            self.external_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType()
                                            self.external_lsa_type.parent = self
                                            self._children_name_map["external_lsa_type"] = "external-lsa-type"

                                            self.nssalsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType()
                                            self.nssalsa_type.parent = self
                                            self._children_name_map["nssalsa_type"] = "nssalsa-type"

                                            self.link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType()
                                            self.link_lsa_type.parent = self
                                            self._children_name_map["link_lsa_type"] = "link-lsa-type"

                                            self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                            self.intra_area_prefix_lsa_type.parent = self
                                            self._children_name_map["intra_area_prefix_lsa_type"] = "intra-area-prefix-lsa-type"

                                            self.grace_lsa = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa()
                                            self.grace_lsa.parent = self
                                            self._children_name_map["grace_lsa"] = "grace-lsa"

                                            self.unknown_link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                            self.unknown_link_lsa_type.parent = self
                                            self._children_name_map["unknown_link_lsa_type"] = "unknown-link-lsa-type"

                                            self.unknown_area_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                            self.unknown_area_lsa_type.parent = self
                                            self._children_name_map["unknown_area_lsa_type"] = "unknown-area-lsa-type"

                                            self.unknown_aslsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType()
                                            self.unknown_aslsa_type.parent = self
                                            self._children_name_map["unknown_aslsa_type"] = "unknown-aslsa-type"

                                            self.unknown_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType()
                                            self.unknown_lsa_type.parent = self
                                            self._children_name_map["unknown_lsa_type"] = "unknown-lsa-type"
                                            self._segment_path = lambda: "lsa-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo, [u'lsa_info_type'], name, value)


                                        class LsaSummaryInfo(Entity):
                                            """
                                            Summary information of LSAs
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                            
                                            .. attribute:: links
                                            
                                            	Number of links
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: router_la_bits
                                            
                                            	Router LA bits 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: reference_type
                                            
                                            	Reference type 
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: reference_lsa_id
                                            
                                            	Reference LSA ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_router_id
                                            
                                            	LSA router ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 address Prefix 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\: bool
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\: bool
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Sham link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo, self).__init__()

                                                self.yang_name = "lsa-summary-info"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('links', (YLeaf(YType.uint16, 'links'), ['int'])),
                                                    ('router_la_bits', (YLeaf(YType.uint8, 'router-la-bits'), ['int'])),
                                                    ('reference_type', (YLeaf(YType.uint16, 'reference-type'), ['int'])),
                                                    ('reference_lsa_id', (YLeaf(YType.uint32, 'reference-lsa-id'), ['int'])),
                                                    ('lsa_router_id', (YLeaf(YType.uint32, 'lsa-router-id'), ['int'])),
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                    ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                    ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                    ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                ])
                                                self.links = None
                                                self.router_la_bits = None
                                                self.reference_type = None
                                                self.reference_lsa_id = None
                                                self.lsa_router_id = None
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.interface_name = None
                                                self.is_virtual_link = None
                                                self.virtual_link_id = None
                                                self.is_sham_link = None
                                                self.sham_link_id = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "lsa-summary-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo, [u'links', u'router_la_bits', u'reference_type', u'reference_lsa_id', u'lsa_router_id', u'prefix', u'prefix_length', u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "lsa-summary-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "lsa-summary-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class RouterLsaType(Entity):
                                            """
                                            Router LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                            
                                            .. attribute:: rpf_path
                                            
                                            	Router LSA Reverse\-Path Forwarding information 
                                            	**type**\:  :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                            
                                            .. attribute:: router_la_bits
                                            
                                            	Router LA bits 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: link
                                            
                                            	List of links in this LSA
                                            	**type**\: list of  		 :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType, self).__init__()

                                                self.yang_name = "router-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail)), ("rpf-path", ("rpf_path", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath)), ("link", ("link", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link))])
                                                self._leafs = OrderedDict([
                                                    ('router_la_bits', (YLeaf(YType.uint8, 'router-la-bits'), ['int'])),
                                                ])
                                                self.router_la_bits = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"

                                                self.rpf_path = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                                self.rpf_path.parent = self
                                                self._children_name_map["rpf_path"] = "rpf-path"

                                                self.link = YList(self)
                                                self._segment_path = lambda: "router-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType, [u'router_la_bits'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class RpfPath(Entity):
                                                """
                                                Router LSA Reverse\-Path Forwarding information 
                                                
                                                .. attribute:: rpf_multicast_next_hop
                                                
                                                	RPF multicast next hop 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_name
                                                
                                                	RPF multicast IDB 
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath, self).__init__()

                                                    self.yang_name = "rpf-path"
                                                    self.yang_parent_name = "router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('rpf_multicast_next_hop', (YLeaf(YType.uint32, 'rpf-multicast-next-hop'), ['int'])),
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ])
                                                    self.rpf_multicast_next_hop = None
                                                    self.interface_name = None
                                                    self._segment_path = lambda: "rpf-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.RpfPath, [u'rpf_multicast_next_hop', u'interface_name'], name, value)


                                            class Link(Entity):
                                                """
                                                List of links in this LSA
                                                
                                                .. attribute:: link_type
                                                
                                                	Type of link
                                                	**type**\:  :py:class:`Ospfv3Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Link>`
                                                
                                                .. attribute:: link_metric
                                                
                                                	LSA link metric 
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: link_interface_id
                                                
                                                	LSA link interface ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: link_neighbor_interface_id
                                                
                                                	LSA link neighbor interface ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: link_neighbor_router_id
                                                
                                                	LSA link neigbhor router id 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link, self).__init__()

                                                    self.yang_name = "link"
                                                    self.yang_parent_name = "router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Link', '')])),
                                                        ('link_metric', (YLeaf(YType.uint16, 'link-metric'), ['int'])),
                                                        ('link_interface_id', (YLeaf(YType.uint32, 'link-interface-id'), ['int'])),
                                                        ('link_neighbor_interface_id', (YLeaf(YType.uint32, 'link-neighbor-interface-id'), ['int'])),
                                                        ('link_neighbor_router_id', (YLeaf(YType.uint32, 'link-neighbor-router-id'), ['int'])),
                                                    ])
                                                    self.link_type = None
                                                    self.link_metric = None
                                                    self.link_interface_id = None
                                                    self.link_neighbor_interface_id = None
                                                    self.link_neighbor_router_id = None
                                                    self._segment_path = lambda: "link"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.RouterLsaType.Link, [u'link_type', u'link_metric', u'link_interface_id', u'link_neighbor_interface_id', u'link_neighbor_router_id'], name, value)


                                        class NetworkLsaType(Entity):
                                            """
                                            Network LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                            
                                            .. attribute:: neighbor_router
                                            
                                            	Neighbor router list
                                            	**type**\: list of str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType, self).__init__()

                                                self.yang_name = "network-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_router', (YLeafList(YType.str, 'neighbor-router'), ['str'])),
                                                ])
                                                self.neighbor_router = []

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "network-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType, [u'neighbor_router'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "network-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "network-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class InterAreaPrefixLsaType(Entity):
                                            """
                                            Inter Area Prefix LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA Information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                            
                                            .. attribute:: prefix
                                            
                                            	LSA address prefix 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType, self).__init__()

                                                self.yang_name = "inter-area-prefix-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                ])
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.priority = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "inter-area-prefix-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType, [u'prefix', u'prefix_length', u'priority'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA Information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class InterAreaRouterLsaType(Entity):
                                            """
                                            Inter Area Router LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_router_id
                                            
                                            	LSA router ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType, self).__init__()

                                                self.yang_name = "inter-area-router-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('lsa_router_id', (YLeaf(YType.uint32, 'lsa-router-id'), ['int'])),
                                                ])
                                                self.lsa_router_id = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "inter-area-router-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType, [u'lsa_router_id'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "inter-area-router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "inter-area-router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class ExternalLsaType(Entity):
                                            """
                                            External LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA Information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                            
                                            .. attribute:: prefix
                                            
                                            	IPV6 address prefix 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: metric_type
                                            
                                            	Metric type 
                                            	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                            
                                            .. attribute:: tos_cost
                                            
                                            	Type of service cost metric 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_forwarding_address_set
                                            
                                            	If true, forwarding address is set 
                                            	**type**\: bool
                                            
                                            .. attribute:: forwarding_address
                                            
                                            	Forwarding Address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: external_tag
                                            
                                            	Route Tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType, self).__init__()

                                                self.yang_name = "external-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                                    ('tos_cost', (YLeaf(YType.uint32, 'tos-cost'), ['int'])),
                                                    ('is_forwarding_address_set', (YLeaf(YType.boolean, 'is-forwarding-address-set'), ['bool'])),
                                                    ('forwarding_address', (YLeaf(YType.str, 'forwarding-address'), ['str'])),
                                                    ('external_tag', (YLeaf(YType.uint32, 'external-tag'), ['int'])),
                                                    ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                ])
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.metric_type = None
                                                self.tos_cost = None
                                                self.is_forwarding_address_set = None
                                                self.forwarding_address = None
                                                self.external_tag = None
                                                self.priority = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "external-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType, [u'prefix', u'prefix_length', u'metric_type', u'tos_cost', u'is_forwarding_address_set', u'forwarding_address', u'external_tag', u'priority'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "external-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA Information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "external-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class NssalsaType(Entity):
                                            """
                                            NSSA External LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA Information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                            
                                            .. attribute:: prefix
                                            
                                            	IPV6 address prefix 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: metric_type
                                            
                                            	Metric type 
                                            	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                            
                                            .. attribute:: tos_cost
                                            
                                            	Type of service cost metric 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_forwarding_address_set
                                            
                                            	If true, forwarding address is set 
                                            	**type**\: bool
                                            
                                            .. attribute:: forwarding_address
                                            
                                            	Forwarding Address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: external_tag
                                            
                                            	Route Tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType, self).__init__()

                                                self.yang_name = "nssalsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                                    ('tos_cost', (YLeaf(YType.uint32, 'tos-cost'), ['int'])),
                                                    ('is_forwarding_address_set', (YLeaf(YType.boolean, 'is-forwarding-address-set'), ['bool'])),
                                                    ('forwarding_address', (YLeaf(YType.str, 'forwarding-address'), ['str'])),
                                                    ('external_tag', (YLeaf(YType.uint32, 'external-tag'), ['int'])),
                                                    ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                ])
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.metric_type = None
                                                self.tos_cost = None
                                                self.is_forwarding_address_set = None
                                                self.forwarding_address = None
                                                self.external_tag = None
                                                self.priority = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "nssalsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType, [u'prefix', u'prefix_length', u'metric_type', u'tos_cost', u'is_forwarding_address_set', u'forwarding_address', u'external_tag', u'priority'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "nssalsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA Information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "nssalsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.NssalsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class LinkLsaType(Entity):
                                            """
                                            Link LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface handle
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link
                                            	**type**\: bool
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link
                                            	**type**\: bool
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Sham link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_link_local
                                            
                                            	LSA link local 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: router_priority
                                            
                                            	Router priority 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\: list of  		 :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType, self).__init__()

                                                self.yang_name = "link-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail)), ("prefix", ("prefix", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                    ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                    ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                    ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                    ('lsa_link_local', (YLeaf(YType.str, 'lsa-link-local'), ['str'])),
                                                    ('router_priority', (YLeaf(YType.uint8, 'router-priority'), ['int'])),
                                                ])
                                                self.interface_name = None
                                                self.is_virtual_link = None
                                                self.virtual_link_id = None
                                                self.is_sham_link = None
                                                self.sham_link_id = None
                                                self.lsa_link_local = None
                                                self.router_priority = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"

                                                self.prefix = YList(self)
                                                self._segment_path = lambda: "link-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id', u'lsa_link_local', u'router_priority'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class Prefix(Entity):
                                                """
                                                OSPFv3 prefix 
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ospfv3_prefix_length
                                                
                                                	OSPFv3 prefix length 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ospfv3_prefix_options
                                                
                                                	OSPFv3 prefix options 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ospfv3_prefix_metric
                                                
                                                	OSPFv3 prefix metric 
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('ospfv3_prefix_length', (YLeaf(YType.uint8, 'ospfv3-prefix-length'), ['int'])),
                                                        ('ospfv3_prefix_options', (YLeaf(YType.uint8, 'ospfv3-prefix-options'), ['int'])),
                                                        ('ospfv3_prefix_metric', (YLeaf(YType.uint16, 'ospfv3-prefix-metric'), ['int'])),
                                                        ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                    ])
                                                    self.prefix = None
                                                    self.ospfv3_prefix_length = None
                                                    self.ospfv3_prefix_options = None
                                                    self.ospfv3_prefix_metric = None
                                                    self.priority = None
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.LinkLsaType.Prefix, [u'prefix', u'ospfv3_prefix_length', u'ospfv3_prefix_options', u'ospfv3_prefix_metric', u'priority'], name, value)


                                        class IntraAreaPrefixLsaType(Entity):
                                            """
                                            Intra Area Prefix LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                            
                                            .. attribute:: reference_type
                                            
                                            	Reference type 
                                            	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                            
                                            .. attribute:: reference_lsa_id
                                            
                                            	Reference LSA ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reference_advertised_router
                                            
                                            	Reference advertised router 
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\: list of  		 :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, self).__init__()

                                                self.yang_name = "intra-area-prefix-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail)), ("prefix", ("prefix", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('reference_type', (YLeaf(YType.enumeration, 'reference-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                                    ('reference_lsa_id', (YLeaf(YType.uint32, 'reference-lsa-id'), ['int'])),
                                                    ('reference_advertised_router', (YLeaf(YType.str, 'reference-advertised-router'), ['str'])),
                                                ])
                                                self.reference_type = None
                                                self.reference_lsa_id = None
                                                self.reference_advertised_router = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"

                                                self.prefix = YList(self)
                                                self._segment_path = lambda: "intra-area-prefix-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, [u'reference_type', u'reference_lsa_id', u'reference_advertised_router'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class Prefix(Entity):
                                                """
                                                OSPFv3 prefix 
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ospfv3_prefix_length
                                                
                                                	OSPFv3 prefix length 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ospfv3_prefix_options
                                                
                                                	OSPFv3 prefix options 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ospfv3_prefix_metric
                                                
                                                	OSPFv3 prefix metric 
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('ospfv3_prefix_length', (YLeaf(YType.uint8, 'ospfv3-prefix-length'), ['int'])),
                                                        ('ospfv3_prefix_options', (YLeaf(YType.uint8, 'ospfv3-prefix-options'), ['int'])),
                                                        ('ospfv3_prefix_metric', (YLeaf(YType.uint16, 'ospfv3-prefix-metric'), ['int'])),
                                                        ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                    ])
                                                    self.prefix = None
                                                    self.ospfv3_prefix_length = None
                                                    self.ospfv3_prefix_options = None
                                                    self.ospfv3_prefix_metric = None
                                                    self.priority = None
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, [u'prefix', u'ospfv3_prefix_length', u'ospfv3_prefix_options', u'ospfv3_prefix_metric', u'priority'], name, value)


                                        class GraceLsa(Entity):
                                            """
                                            Grace LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface handle
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link
                                            	**type**\: bool
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link
                                            	**type**\: bool
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Sham link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: grace_period
                                            
                                            	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: grace_reason
                                            
                                            	Reason for router restart
                                            	**type**\:  :py:class:`Ospfv3GracefulRestartReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReason>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa, self).__init__()

                                                self.yang_name = "grace-lsa"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                    ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                    ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                    ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                    ('grace_period', (YLeaf(YType.uint32, 'grace-period'), ['int'])),
                                                    ('grace_reason', (YLeaf(YType.enumeration, 'grace-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3GracefulRestartReason', '')])),
                                                ])
                                                self.interface_name = None
                                                self.is_virtual_link = None
                                                self.virtual_link_id = None
                                                self.is_sham_link = None
                                                self.sham_link_id = None
                                                self.grace_period = None
                                                self.grace_reason = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "grace-lsa"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id', u'grace_period', u'grace_reason'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "grace-lsa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "grace-lsa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.GraceLsa.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class UnknownLinkLsaType(Entity):
                                            """
                                            Unknown Link Scope LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\: bool
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\: bool
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType, self).__init__()

                                                self.yang_name = "unknown-link-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                    ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                    ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                    ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                ])
                                                self.interface_name = None
                                                self.is_virtual_link = None
                                                self.virtual_link_id = None
                                                self.is_sham_link = None
                                                self.sham_link_id = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "unknown-link-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "unknown-link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "unknown-link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class UnknownAreaLsaType(Entity):
                                            """
                                            Unknown\-Area scope LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\: bool
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\: bool
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType, self).__init__()

                                                self.yang_name = "unknown-area-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                    ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                    ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                    ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                ])
                                                self.interface_name = None
                                                self.is_virtual_link = None
                                                self.virtual_link_id = None
                                                self.is_sham_link = None
                                                self.sham_link_id = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "unknown-area-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "unknown-area-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "unknown-area-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class UnknownAslsaType(Entity):
                                            """
                                            Unknown\-AS scope LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\: bool
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\: bool
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType, self).__init__()

                                                self.yang_name = "unknown-aslsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                    ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                    ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                    ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                ])
                                                self.interface_name = None
                                                self.is_virtual_link = None
                                                self.virtual_link_id = None
                                                self.is_sham_link = None
                                                self.sham_link_id = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "unknown-aslsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "unknown-aslsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "unknown-aslsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class UnknownLsaType(Entity):
                                            """
                                            Unknown LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\: bool
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\: bool
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType, self).__init__()

                                                self.yang_name = "unknown-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                    ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                    ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                    ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                ])
                                                self.interface_name = None
                                                self.is_virtual_link = None
                                                self.virtual_link_id = None
                                                self.is_sham_link = None
                                                self.sham_link_id = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "unknown-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "unknown-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "unknown-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                            class LsaInternalTable(Entity):
                                """
                                Database LSA information
                                
                                .. attribute:: lsa
                                
                                	Database LSA information
                                	**type**\: list of  		 :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable, self).__init__()

                                    self.yang_name = "lsa-internal-table"
                                    self.yang_parent_name = "database-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lsa", ("lsa", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa))])
                                    self._leafs = OrderedDict()

                                    self.lsa = YList(self)
                                    self._segment_path = lambda: "lsa-internal-table"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable, [], name, value)


                                class Lsa(Entity):
                                    """
                                    Database LSA information
                                    
                                    .. attribute:: area_id
                                    
                                    	Area ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ls_type
                                    
                                    	LSA type
                                    	**type**\:  :py:class:`Ospfv3Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa>`
                                    
                                    .. attribute:: advertising_router
                                    
                                    	Advertising Router ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ls_id
                                    
                                    	Link state ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_name
                                    
                                    	InterfaceName
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: lsa_info
                                    
                                    	Summary of all LSAs or LSA specific information 
                                    	**type**\:  :py:class:`LsaInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo>`
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa, self).__init__()

                                        self.yang_name = "lsa"
                                        self.yang_parent_name = "lsa-internal-table"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("lsa-info", ("lsa_info", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo))])
                                        self._leafs = OrderedDict([
                                            ('area_id', (YLeaf(YType.uint32, 'area-id'), ['int'])),
                                            ('ls_type', (YLeaf(YType.enumeration, 'ls-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa', '')])),
                                            ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                            ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                        ])
                                        self.area_id = None
                                        self.ls_type = None
                                        self.advertising_router = None
                                        self.ls_id = None
                                        self.interface_name = None

                                        self.lsa_info = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo()
                                        self.lsa_info.parent = self
                                        self._children_name_map["lsa_info"] = "lsa-info"
                                        self._segment_path = lambda: "lsa"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa, ['area_id', 'ls_type', 'advertising_router', 'ls_id', 'interface_name'], name, value)


                                    class LsaInfo(Entity):
                                        """
                                        Summary of all LSAs or LSA specific information 
                                        
                                        .. attribute:: lsa_summary_info
                                        
                                        	Summary information of LSAs
                                        	**type**\:  :py:class:`LsaSummaryInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo>`
                                        
                                        .. attribute:: router_lsa_type
                                        
                                        	Router LSA
                                        	**type**\:  :py:class:`RouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType>`
                                        
                                        .. attribute:: network_lsa_type
                                        
                                        	Network LSA
                                        	**type**\:  :py:class:`NetworkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType>`
                                        
                                        .. attribute:: inter_area_prefix_lsa_type
                                        
                                        	Inter Area Prefix LSA
                                        	**type**\:  :py:class:`InterAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType>`
                                        
                                        .. attribute:: inter_area_router_lsa_type
                                        
                                        	Inter Area Router LSA
                                        	**type**\:  :py:class:`InterAreaRouterLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType>`
                                        
                                        .. attribute:: external_lsa_type
                                        
                                        	External LSA
                                        	**type**\:  :py:class:`ExternalLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType>`
                                        
                                        .. attribute:: nssalsa_type
                                        
                                        	NSSA External LSA
                                        	**type**\:  :py:class:`NssalsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType>`
                                        
                                        .. attribute:: link_lsa_type
                                        
                                        	Link LSA
                                        	**type**\:  :py:class:`LinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType>`
                                        
                                        .. attribute:: intra_area_prefix_lsa_type
                                        
                                        	Intra Area Prefix LSA
                                        	**type**\:  :py:class:`IntraAreaPrefixLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType>`
                                        
                                        .. attribute:: grace_lsa
                                        
                                        	Grace LSA
                                        	**type**\:  :py:class:`GraceLsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa>`
                                        
                                        .. attribute:: unknown_link_lsa_type
                                        
                                        	Unknown Link Scope LSA
                                        	**type**\:  :py:class:`UnknownLinkLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType>`
                                        
                                        .. attribute:: unknown_area_lsa_type
                                        
                                        	Unknown\-Area scope LSA
                                        	**type**\:  :py:class:`UnknownAreaLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType>`
                                        
                                        .. attribute:: unknown_aslsa_type
                                        
                                        	Unknown\-AS scope LSA
                                        	**type**\:  :py:class:`UnknownAslsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType>`
                                        
                                        .. attribute:: unknown_lsa_type
                                        
                                        	Unknown LSA
                                        	**type**\:  :py:class:`UnknownLsaType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType>`
                                        
                                        .. attribute:: lsa_info_type
                                        
                                        	LSAInfoType
                                        	**type**\:  :py:class:`Ospfv3LsaInfoTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3LsaInfoTypes>`
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo, self).__init__()

                                            self.yang_name = "lsa-info"
                                            self.yang_parent_name = "lsa"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsa-summary-info", ("lsa_summary_info", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo)), ("router-lsa-type", ("router_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType)), ("network-lsa-type", ("network_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType)), ("inter-area-prefix-lsa-type", ("inter_area_prefix_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType)), ("inter-area-router-lsa-type", ("inter_area_router_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType)), ("external-lsa-type", ("external_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType)), ("nssalsa-type", ("nssalsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType)), ("link-lsa-type", ("link_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType)), ("intra-area-prefix-lsa-type", ("intra_area_prefix_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType)), ("grace-lsa", ("grace_lsa", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa)), ("unknown-link-lsa-type", ("unknown_link_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType)), ("unknown-area-lsa-type", ("unknown_area_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType)), ("unknown-aslsa-type", ("unknown_aslsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType)), ("unknown-lsa-type", ("unknown_lsa_type", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType))])
                                            self._leafs = OrderedDict([
                                                ('lsa_info_type', (YLeaf(YType.enumeration, 'lsa-info-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3LsaInfoTypes', '')])),
                                            ])
                                            self.lsa_info_type = None

                                            self.lsa_summary_info = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo()
                                            self.lsa_summary_info.parent = self
                                            self._children_name_map["lsa_summary_info"] = "lsa-summary-info"

                                            self.router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType()
                                            self.router_lsa_type.parent = self
                                            self._children_name_map["router_lsa_type"] = "router-lsa-type"

                                            self.network_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType()
                                            self.network_lsa_type.parent = self
                                            self._children_name_map["network_lsa_type"] = "network-lsa-type"

                                            self.inter_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType()
                                            self.inter_area_prefix_lsa_type.parent = self
                                            self._children_name_map["inter_area_prefix_lsa_type"] = "inter-area-prefix-lsa-type"

                                            self.inter_area_router_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType()
                                            self.inter_area_router_lsa_type.parent = self
                                            self._children_name_map["inter_area_router_lsa_type"] = "inter-area-router-lsa-type"

                                            self.external_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType()
                                            self.external_lsa_type.parent = self
                                            self._children_name_map["external_lsa_type"] = "external-lsa-type"

                                            self.nssalsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType()
                                            self.nssalsa_type.parent = self
                                            self._children_name_map["nssalsa_type"] = "nssalsa-type"

                                            self.link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType()
                                            self.link_lsa_type.parent = self
                                            self._children_name_map["link_lsa_type"] = "link-lsa-type"

                                            self.intra_area_prefix_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType()
                                            self.intra_area_prefix_lsa_type.parent = self
                                            self._children_name_map["intra_area_prefix_lsa_type"] = "intra-area-prefix-lsa-type"

                                            self.grace_lsa = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa()
                                            self.grace_lsa.parent = self
                                            self._children_name_map["grace_lsa"] = "grace-lsa"

                                            self.unknown_link_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType()
                                            self.unknown_link_lsa_type.parent = self
                                            self._children_name_map["unknown_link_lsa_type"] = "unknown-link-lsa-type"

                                            self.unknown_area_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType()
                                            self.unknown_area_lsa_type.parent = self
                                            self._children_name_map["unknown_area_lsa_type"] = "unknown-area-lsa-type"

                                            self.unknown_aslsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType()
                                            self.unknown_aslsa_type.parent = self
                                            self._children_name_map["unknown_aslsa_type"] = "unknown-aslsa-type"

                                            self.unknown_lsa_type = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType()
                                            self.unknown_lsa_type.parent = self
                                            self._children_name_map["unknown_lsa_type"] = "unknown-lsa-type"
                                            self._segment_path = lambda: "lsa-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo, [u'lsa_info_type'], name, value)


                                        class LsaSummaryInfo(Entity):
                                            """
                                            Summary information of LSAs
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail>`
                                            
                                            .. attribute:: links
                                            
                                            	Number of links
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: router_la_bits
                                            
                                            	Router LA bits 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: reference_type
                                            
                                            	Reference type 
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: reference_lsa_id
                                            
                                            	Reference LSA ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_router_id
                                            
                                            	LSA router ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 address Prefix 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\: bool
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\: bool
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Sham link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo, self).__init__()

                                                self.yang_name = "lsa-summary-info"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('links', (YLeaf(YType.uint16, 'links'), ['int'])),
                                                    ('router_la_bits', (YLeaf(YType.uint8, 'router-la-bits'), ['int'])),
                                                    ('reference_type', (YLeaf(YType.uint16, 'reference-type'), ['int'])),
                                                    ('reference_lsa_id', (YLeaf(YType.uint32, 'reference-lsa-id'), ['int'])),
                                                    ('lsa_router_id', (YLeaf(YType.uint32, 'lsa-router-id'), ['int'])),
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                    ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                    ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                    ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                ])
                                                self.links = None
                                                self.router_la_bits = None
                                                self.reference_type = None
                                                self.reference_lsa_id = None
                                                self.lsa_router_id = None
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.interface_name = None
                                                self.is_virtual_link = None
                                                self.virtual_link_id = None
                                                self.is_sham_link = None
                                                self.sham_link_id = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "lsa-summary-info"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo, [u'links', u'router_la_bits', u'reference_type', u'reference_lsa_id', u'lsa_router_id', u'prefix', u'prefix_length', u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "lsa-summary-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "lsa-summary-info"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LsaSummaryInfo.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class RouterLsaType(Entity):
                                            """
                                            Router LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail>`
                                            
                                            .. attribute:: rpf_path
                                            
                                            	Router LSA Reverse\-Path Forwarding information 
                                            	**type**\:  :py:class:`RpfPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath>`
                                            
                                            .. attribute:: router_la_bits
                                            
                                            	Router LA bits 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: link
                                            
                                            	List of links in this LSA
                                            	**type**\: list of  		 :py:class:`Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType, self).__init__()

                                                self.yang_name = "router-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail)), ("rpf-path", ("rpf_path", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath)), ("link", ("link", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link))])
                                                self._leafs = OrderedDict([
                                                    ('router_la_bits', (YLeaf(YType.uint8, 'router-la-bits'), ['int'])),
                                                ])
                                                self.router_la_bits = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"

                                                self.rpf_path = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath()
                                                self.rpf_path.parent = self
                                                self._children_name_map["rpf_path"] = "rpf-path"

                                                self.link = YList(self)
                                                self._segment_path = lambda: "router-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType, [u'router_la_bits'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class RpfPath(Entity):
                                                """
                                                Router LSA Reverse\-Path Forwarding information 
                                                
                                                .. attribute:: rpf_multicast_next_hop
                                                
                                                	RPF multicast next hop 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_name
                                                
                                                	RPF multicast IDB 
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath, self).__init__()

                                                    self.yang_name = "rpf-path"
                                                    self.yang_parent_name = "router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('rpf_multicast_next_hop', (YLeaf(YType.uint32, 'rpf-multicast-next-hop'), ['int'])),
                                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ])
                                                    self.rpf_multicast_next_hop = None
                                                    self.interface_name = None
                                                    self._segment_path = lambda: "rpf-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.RpfPath, [u'rpf_multicast_next_hop', u'interface_name'], name, value)


                                            class Link(Entity):
                                                """
                                                List of links in this LSA
                                                
                                                .. attribute:: link_type
                                                
                                                	Type of link
                                                	**type**\:  :py:class:`Ospfv3Link <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Link>`
                                                
                                                .. attribute:: link_metric
                                                
                                                	LSA link metric 
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: link_interface_id
                                                
                                                	LSA link interface ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: link_neighbor_interface_id
                                                
                                                	LSA link neighbor interface ID 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: link_neighbor_router_id
                                                
                                                	LSA link neigbhor router id 
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link, self).__init__()

                                                    self.yang_name = "link"
                                                    self.yang_parent_name = "router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Link', '')])),
                                                        ('link_metric', (YLeaf(YType.uint16, 'link-metric'), ['int'])),
                                                        ('link_interface_id', (YLeaf(YType.uint32, 'link-interface-id'), ['int'])),
                                                        ('link_neighbor_interface_id', (YLeaf(YType.uint32, 'link-neighbor-interface-id'), ['int'])),
                                                        ('link_neighbor_router_id', (YLeaf(YType.uint32, 'link-neighbor-router-id'), ['int'])),
                                                    ])
                                                    self.link_type = None
                                                    self.link_metric = None
                                                    self.link_interface_id = None
                                                    self.link_neighbor_interface_id = None
                                                    self.link_neighbor_router_id = None
                                                    self._segment_path = lambda: "link"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.RouterLsaType.Link, [u'link_type', u'link_metric', u'link_interface_id', u'link_neighbor_interface_id', u'link_neighbor_router_id'], name, value)


                                        class NetworkLsaType(Entity):
                                            """
                                            Network LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail>`
                                            
                                            .. attribute:: neighbor_router
                                            
                                            	Neighbor router list
                                            	**type**\: list of str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType, self).__init__()

                                                self.yang_name = "network-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_router', (YLeafList(YType.str, 'neighbor-router'), ['str'])),
                                                ])
                                                self.neighbor_router = []

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "network-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType, [u'neighbor_router'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "network-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "network-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NetworkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class InterAreaPrefixLsaType(Entity):
                                            """
                                            Inter Area Prefix LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA Information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail>`
                                            
                                            .. attribute:: prefix
                                            
                                            	LSA address prefix 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType, self).__init__()

                                                self.yang_name = "inter-area-prefix-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                ])
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.priority = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "inter-area-prefix-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType, [u'prefix', u'prefix_length', u'priority'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA Information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "inter-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaPrefixLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class InterAreaRouterLsaType(Entity):
                                            """
                                            Inter Area Router LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail>`
                                            
                                            .. attribute:: lsa_router_id
                                            
                                            	LSA router ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType, self).__init__()

                                                self.yang_name = "inter-area-router-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('lsa_router_id', (YLeaf(YType.uint32, 'lsa-router-id'), ['int'])),
                                                ])
                                                self.lsa_router_id = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "inter-area-router-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType, [u'lsa_router_id'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "inter-area-router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "inter-area-router-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.InterAreaRouterLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class ExternalLsaType(Entity):
                                            """
                                            External LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA Information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail>`
                                            
                                            .. attribute:: prefix
                                            
                                            	IPV6 address prefix 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: metric_type
                                            
                                            	Metric type 
                                            	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                            
                                            .. attribute:: tos_cost
                                            
                                            	Type of service cost metric 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_forwarding_address_set
                                            
                                            	If true, forwarding address is set 
                                            	**type**\: bool
                                            
                                            .. attribute:: forwarding_address
                                            
                                            	Forwarding Address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: external_tag
                                            
                                            	Route Tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType, self).__init__()

                                                self.yang_name = "external-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                                    ('tos_cost', (YLeaf(YType.uint32, 'tos-cost'), ['int'])),
                                                    ('is_forwarding_address_set', (YLeaf(YType.boolean, 'is-forwarding-address-set'), ['bool'])),
                                                    ('forwarding_address', (YLeaf(YType.str, 'forwarding-address'), ['str'])),
                                                    ('external_tag', (YLeaf(YType.uint32, 'external-tag'), ['int'])),
                                                    ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                ])
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.metric_type = None
                                                self.tos_cost = None
                                                self.is_forwarding_address_set = None
                                                self.forwarding_address = None
                                                self.external_tag = None
                                                self.priority = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "external-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType, [u'prefix', u'prefix_length', u'metric_type', u'tos_cost', u'is_forwarding_address_set', u'forwarding_address', u'external_tag', u'priority'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "external-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA Information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "external-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.ExternalLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class NssalsaType(Entity):
                                            """
                                            NSSA External LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA Information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail>`
                                            
                                            .. attribute:: prefix
                                            
                                            	IPV6 address prefix 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix length 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: metric_type
                                            
                                            	Metric type 
                                            	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                                            
                                            .. attribute:: tos_cost
                                            
                                            	Type of service cost metric 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_forwarding_address_set
                                            
                                            	If true, forwarding address is set 
                                            	**type**\: bool
                                            
                                            .. attribute:: forwarding_address
                                            
                                            	Forwarding Address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: external_tag
                                            
                                            	Route Tag
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: priority
                                            
                                            	Prefix priority
                                            	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType, self).__init__()

                                                self.yang_name = "nssalsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ('metric_type', (YLeaf(YType.enumeration, 'metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                                    ('tos_cost', (YLeaf(YType.uint32, 'tos-cost'), ['int'])),
                                                    ('is_forwarding_address_set', (YLeaf(YType.boolean, 'is-forwarding-address-set'), ['bool'])),
                                                    ('forwarding_address', (YLeaf(YType.str, 'forwarding-address'), ['str'])),
                                                    ('external_tag', (YLeaf(YType.uint32, 'external-tag'), ['int'])),
                                                    ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                ])
                                                self.prefix = None
                                                self.prefix_length = None
                                                self.metric_type = None
                                                self.tos_cost = None
                                                self.is_forwarding_address_set = None
                                                self.forwarding_address = None
                                                self.external_tag = None
                                                self.priority = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "nssalsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType, [u'prefix', u'prefix_length', u'metric_type', u'tos_cost', u'is_forwarding_address_set', u'forwarding_address', u'external_tag', u'priority'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "nssalsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA Information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "nssalsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.NssalsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class LinkLsaType(Entity):
                                            """
                                            Link LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail>`
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface handle
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link
                                            	**type**\: bool
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link
                                            	**type**\: bool
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Sham link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsa_link_local
                                            
                                            	LSA link local 
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: router_priority
                                            
                                            	Router priority 
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\: list of  		 :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType, self).__init__()

                                                self.yang_name = "link-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail)), ("prefix", ("prefix", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                    ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                    ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                    ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                    ('lsa_link_local', (YLeaf(YType.str, 'lsa-link-local'), ['str'])),
                                                    ('router_priority', (YLeaf(YType.uint8, 'router-priority'), ['int'])),
                                                ])
                                                self.interface_name = None
                                                self.is_virtual_link = None
                                                self.virtual_link_id = None
                                                self.is_sham_link = None
                                                self.sham_link_id = None
                                                self.lsa_link_local = None
                                                self.router_priority = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"

                                                self.prefix = YList(self)
                                                self._segment_path = lambda: "link-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id', u'lsa_link_local', u'router_priority'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class Prefix(Entity):
                                                """
                                                OSPFv3 prefix 
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ospfv3_prefix_length
                                                
                                                	OSPFv3 prefix length 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ospfv3_prefix_options
                                                
                                                	OSPFv3 prefix options 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ospfv3_prefix_metric
                                                
                                                	OSPFv3 prefix metric 
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('ospfv3_prefix_length', (YLeaf(YType.uint8, 'ospfv3-prefix-length'), ['int'])),
                                                        ('ospfv3_prefix_options', (YLeaf(YType.uint8, 'ospfv3-prefix-options'), ['int'])),
                                                        ('ospfv3_prefix_metric', (YLeaf(YType.uint16, 'ospfv3-prefix-metric'), ['int'])),
                                                        ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                    ])
                                                    self.prefix = None
                                                    self.ospfv3_prefix_length = None
                                                    self.ospfv3_prefix_options = None
                                                    self.ospfv3_prefix_metric = None
                                                    self.priority = None
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.LinkLsaType.Prefix, [u'prefix', u'ospfv3_prefix_length', u'ospfv3_prefix_options', u'ospfv3_prefix_metric', u'priority'], name, value)


                                        class IntraAreaPrefixLsaType(Entity):
                                            """
                                            Intra Area Prefix LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail>`
                                            
                                            .. attribute:: reference_type
                                            
                                            	Reference type 
                                            	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                                            
                                            .. attribute:: reference_lsa_id
                                            
                                            	Reference LSA ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reference_advertised_router
                                            
                                            	Reference advertised router 
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix
                                            
                                            	OSPFv3 prefix 
                                            	**type**\: list of  		 :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, self).__init__()

                                                self.yang_name = "intra-area-prefix-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail)), ("prefix", ("prefix", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix))])
                                                self._leafs = OrderedDict([
                                                    ('reference_type', (YLeaf(YType.enumeration, 'reference-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                                    ('reference_lsa_id', (YLeaf(YType.uint32, 'reference-lsa-id'), ['int'])),
                                                    ('reference_advertised_router', (YLeaf(YType.str, 'reference-advertised-router'), ['str'])),
                                                ])
                                                self.reference_type = None
                                                self.reference_lsa_id = None
                                                self.reference_advertised_router = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"

                                                self.prefix = YList(self)
                                                self._segment_path = lambda: "intra-area-prefix-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType, [u'reference_type', u'reference_lsa_id', u'reference_advertised_router'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                            class Prefix(Entity):
                                                """
                                                OSPFv3 prefix 
                                                
                                                .. attribute:: prefix
                                                
                                                	OSPFv3 prefix 
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: ospfv3_prefix_length
                                                
                                                	OSPFv3 prefix length 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ospfv3_prefix_options
                                                
                                                	OSPFv3 prefix options 
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ospfv3_prefix_metric
                                                
                                                	OSPFv3 prefix metric 
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: priority
                                                
                                                	Prefix priority
                                                	**type**\:  :py:class:`PrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.PrefixPriority>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, self).__init__()

                                                    self.yang_name = "prefix"
                                                    self.yang_parent_name = "intra-area-prefix-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('ospfv3_prefix_length', (YLeaf(YType.uint8, 'ospfv3-prefix-length'), ['int'])),
                                                        ('ospfv3_prefix_options', (YLeaf(YType.uint8, 'ospfv3-prefix-options'), ['int'])),
                                                        ('ospfv3_prefix_metric', (YLeaf(YType.uint16, 'ospfv3-prefix-metric'), ['int'])),
                                                        ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'PrefixPriority', '')])),
                                                    ])
                                                    self.prefix = None
                                                    self.ospfv3_prefix_length = None
                                                    self.ospfv3_prefix_options = None
                                                    self.ospfv3_prefix_metric = None
                                                    self.priority = None
                                                    self._segment_path = lambda: "prefix"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.IntraAreaPrefixLsaType.Prefix, [u'prefix', u'ospfv3_prefix_length', u'ospfv3_prefix_options', u'ospfv3_prefix_metric', u'priority'], name, value)


                                        class GraceLsa(Entity):
                                            """
                                            Grace LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail>`
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface handle
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link
                                            	**type**\: bool
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link
                                            	**type**\: bool
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Sham link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: grace_period
                                            
                                            	The grace periord where helper routers should wait before advertising it fully adjacent(s) 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: grace_reason
                                            
                                            	Reason for router restart
                                            	**type**\:  :py:class:`Ospfv3GracefulRestartReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulRestartReason>`
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa, self).__init__()

                                                self.yang_name = "grace-lsa"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                    ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                    ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                    ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                    ('grace_period', (YLeaf(YType.uint32, 'grace-period'), ['int'])),
                                                    ('grace_reason', (YLeaf(YType.enumeration, 'grace-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3GracefulRestartReason', '')])),
                                                ])
                                                self.interface_name = None
                                                self.is_virtual_link = None
                                                self.virtual_link_id = None
                                                self.is_sham_link = None
                                                self.sham_link_id = None
                                                self.grace_period = None
                                                self.grace_reason = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "grace-lsa"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id', u'grace_period', u'grace_reason'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "grace-lsa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "grace-lsa"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.GraceLsa.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class UnknownLinkLsaType(Entity):
                                            """
                                            Unknown Link Scope LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail>`
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\: bool
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\: bool
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType, self).__init__()

                                                self.yang_name = "unknown-link-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                    ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                    ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                    ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                ])
                                                self.interface_name = None
                                                self.is_virtual_link = None
                                                self.virtual_link_id = None
                                                self.is_sham_link = None
                                                self.sham_link_id = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "unknown-link-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "unknown-link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "unknown-link-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLinkLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class UnknownAreaLsaType(Entity):
                                            """
                                            Unknown\-Area scope LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail>`
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\: bool
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\: bool
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType, self).__init__()

                                                self.yang_name = "unknown-area-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                    ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                    ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                    ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                ])
                                                self.interface_name = None
                                                self.is_virtual_link = None
                                                self.virtual_link_id = None
                                                self.is_sham_link = None
                                                self.sham_link_id = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "unknown-area-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "unknown-area-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "unknown-area-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAreaLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class UnknownAslsaType(Entity):
                                            """
                                            Unknown\-AS scope LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail>`
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\: bool
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\: bool
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType, self).__init__()

                                                self.yang_name = "unknown-aslsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                    ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                    ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                    ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                ])
                                                self.interface_name = None
                                                self.is_virtual_link = None
                                                self.virtual_link_id = None
                                                self.is_sham_link = None
                                                self.sham_link_id = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "unknown-aslsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "unknown-aslsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "unknown-aslsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownAslsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                                        class UnknownLsaType(Entity):
                                            """
                                            Unknown LSA
                                            
                                            .. attribute:: lsa_header
                                            
                                            	Header information 
                                            	**type**\:  :py:class:`LsaHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader>`
                                            
                                            .. attribute:: lsa_detail
                                            
                                            	Detailed LSA information
                                            	**type**\:  :py:class:`LsaDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail>`
                                            
                                            .. attribute:: interface_name
                                            
                                            	LSA interface name 
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: is_virtual_link
                                            
                                            	If true, it is a virtual link 
                                            	**type**\: bool
                                            
                                            .. attribute:: virtual_link_id
                                            
                                            	Virtual link ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_sham_link
                                            
                                            	If true, it is a sham link 
                                            	**type**\: bool
                                            
                                            .. attribute:: sham_link_id
                                            
                                            	Shamlink ID 
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv6-ospfv3-oper'
                                            _revision = '2017-10-30'

                                            def __init__(self):
                                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType, self).__init__()

                                                self.yang_name = "unknown-lsa-type"
                                                self.yang_parent_name = "lsa-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsa-header", ("lsa_header", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader)), ("lsa-detail", ("lsa_detail", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail))])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                                    ('is_virtual_link', (YLeaf(YType.boolean, 'is-virtual-link'), ['bool'])),
                                                    ('virtual_link_id', (YLeaf(YType.uint32, 'virtual-link-id'), ['int'])),
                                                    ('is_sham_link', (YLeaf(YType.boolean, 'is-sham-link'), ['bool'])),
                                                    ('sham_link_id', (YLeaf(YType.uint32, 'sham-link-id'), ['int'])),
                                                ])
                                                self.interface_name = None
                                                self.is_virtual_link = None
                                                self.virtual_link_id = None
                                                self.is_sham_link = None
                                                self.sham_link_id = None

                                                self.lsa_header = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader()
                                                self.lsa_header.parent = self
                                                self._children_name_map["lsa_header"] = "lsa-header"

                                                self.lsa_detail = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail()
                                                self.lsa_detail.parent = self
                                                self._children_name_map["lsa_detail"] = "lsa-detail"
                                                self._segment_path = lambda: "unknown-lsa-type"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType, [u'interface_name', u'is_virtual_link', u'virtual_link_id', u'is_sham_link', u'sham_link_id'], name, value)


                                            class LsaHeader(Entity):
                                                """
                                                Header information 
                                                
                                                .. attribute:: lsa_type
                                                
                                                	LSA type
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_area_id
                                                
                                                	Area ID in decimal or dotted\-decimal format
                                                	**type**\: str
                                                
                                                	**length:** 0..16
                                                
                                                .. attribute:: lsa_age
                                                
                                                	LSA's Age (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_do_not_age_lsa
                                                
                                                	If true, Do Not Age this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: ls_id
                                                
                                                	LS ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: advertising_router
                                                
                                                	Router ID of Advertising Router
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: sequence_number
                                                
                                                	Current Sequence number
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: checksum
                                                
                                                	Checksum value
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: is_graceful_restart_active
                                                
                                                	If true, if grace restart is active 
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, self).__init__()

                                                    self.yang_name = "lsa-header"
                                                    self.yang_parent_name = "unknown-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lsa_type', (YLeaf(YType.uint16, 'lsa-type'), ['int'])),
                                                        ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                                        ('lsa_age', (YLeaf(YType.uint16, 'lsa-age'), ['int'])),
                                                        ('is_do_not_age_lsa', (YLeaf(YType.boolean, 'is-do-not-age-lsa'), ['bool'])),
                                                        ('ls_id', (YLeaf(YType.uint32, 'ls-id'), ['int'])),
                                                        ('advertising_router', (YLeaf(YType.str, 'advertising-router'), ['str'])),
                                                        ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                        ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                        ('is_graceful_restart_active', (YLeaf(YType.boolean, 'is-graceful-restart-active'), ['bool'])),
                                                    ])
                                                    self.lsa_type = None
                                                    self.lsa_area_id = None
                                                    self.lsa_age = None
                                                    self.is_do_not_age_lsa = None
                                                    self.ls_id = None
                                                    self.advertising_router = None
                                                    self.sequence_number = None
                                                    self.checksum = None
                                                    self.is_graceful_restart_active = None
                                                    self._segment_path = lambda: "lsa-header"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaHeader, [u'lsa_type', u'lsa_area_id', u'lsa_age', u'is_do_not_age_lsa', u'ls_id', u'advertising_router', u'sequence_number', u'checksum', u'is_graceful_restart_active'], name, value)


                                            class LsaDetail(Entity):
                                                """
                                                Detailed LSA information
                                                
                                                .. attribute:: second_table_index
                                                
                                                	Second table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: minute_table_index
                                                
                                                	Minute table index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: free_time
                                                
                                                	The amount of time since the last check was made to free this LSA (s)
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_deleted
                                                
                                                	If true, flag is set to delete this LSA 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_bit
                                                
                                                	If true, Routing Bit set on the LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_advertising_router_reachable
                                                
                                                	If true, Advertising Router is reachable
                                                	**type**\: bool
                                                
                                                .. attribute:: is_no_delete
                                                
                                                	If true, the reason not to delete this LSA is because delete flag not set on this LSA
                                                	**type**\: bool
                                                
                                                .. attribute:: is_neighbor_exchange
                                                
                                                	If true, the reason  not to delete this LSA is because neighbor is in exchange state
                                                	**type**\: bool
                                                
                                                .. attribute:: is_routing_table
                                                
                                                	If true, the reason  not to delete this LSA is because it has a contributing entry in the routing table 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_acknowledged
                                                
                                                	If true, the reason not to delete this LSA is because it's Acknowledgement list is not empty 
                                                	**type**\: bool
                                                
                                                .. attribute:: is_maximum_aged
                                                
                                                	If true, the reason not to delete this LSA is because it is in Maxage Queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_partial_spf
                                                
                                                	If true, the reason not to delete this LSA is because it is in partial SPF queue
                                                	**type**\: bool
                                                
                                                .. attribute:: is_flood_pending
                                                
                                                	If true, the reason not to delete this LSA is because waiting for flooding or retransmission
                                                	**type**\: bool
                                                
                                                .. attribute:: rate_limit
                                                
                                                	If true, the reason not to delete this LSA is because waiting for next wait\-interval to expire
                                                	**type**\: bool
                                                
                                                .. attribute:: is_nsr_ack_pending
                                                
                                                	If true, the reason not to delete this LSA is because NSR ACK from standby is pending
                                                	**type**\: bool
                                                
                                                .. attribute:: nsr_flood_required
                                                
                                                	If true, the reason not to delete this LSA is because it is pending flooding on switchover
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_flood_required_post_fail_over
                                                
                                                	LSA flood required after FO
                                                	**type**\: bool
                                                
                                                .. attribute:: lsa_length
                                                
                                                	Length of the LSA
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: lsa_sync_state
                                                
                                                	State of LSA sync with active
                                                	**type**\:  :py:class:`OspfLsaSyncState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.OspfLsaSyncState>`
                                                
                                                

                                                """

                                                _prefix = 'ipv6-ospfv3-oper'
                                                _revision = '2017-10-30'

                                                def __init__(self):
                                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, self).__init__()

                                                    self.yang_name = "lsa-detail"
                                                    self.yang_parent_name = "unknown-lsa-type"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('second_table_index', (YLeaf(YType.uint8, 'second-table-index'), ['int'])),
                                                        ('minute_table_index', (YLeaf(YType.uint8, 'minute-table-index'), ['int'])),
                                                        ('free_time', (YLeaf(YType.uint32, 'free-time'), ['int'])),
                                                        ('is_deleted', (YLeaf(YType.boolean, 'is-deleted'), ['bool'])),
                                                        ('is_routing_bit', (YLeaf(YType.boolean, 'is-routing-bit'), ['bool'])),
                                                        ('is_advertising_router_reachable', (YLeaf(YType.boolean, 'is-advertising-router-reachable'), ['bool'])),
                                                        ('is_no_delete', (YLeaf(YType.boolean, 'is-no-delete'), ['bool'])),
                                                        ('is_neighbor_exchange', (YLeaf(YType.boolean, 'is-neighbor-exchange'), ['bool'])),
                                                        ('is_routing_table', (YLeaf(YType.boolean, 'is-routing-table'), ['bool'])),
                                                        ('is_acknowledged', (YLeaf(YType.boolean, 'is-acknowledged'), ['bool'])),
                                                        ('is_maximum_aged', (YLeaf(YType.boolean, 'is-maximum-aged'), ['bool'])),
                                                        ('is_partial_spf', (YLeaf(YType.boolean, 'is-partial-spf'), ['bool'])),
                                                        ('is_flood_pending', (YLeaf(YType.boolean, 'is-flood-pending'), ['bool'])),
                                                        ('rate_limit', (YLeaf(YType.boolean, 'rate-limit'), ['bool'])),
                                                        ('is_nsr_ack_pending', (YLeaf(YType.boolean, 'is-nsr-ack-pending'), ['bool'])),
                                                        ('nsr_flood_required', (YLeaf(YType.boolean, 'nsr-flood-required'), ['bool'])),
                                                        ('lsa_flood_required_post_fail_over', (YLeaf(YType.boolean, 'lsa-flood-required-post-fail-over'), ['bool'])),
                                                        ('lsa_length', (YLeaf(YType.uint16, 'lsa-length'), ['int'])),
                                                        ('lsa_sync_state', (YLeaf(YType.enumeration, 'lsa-sync-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'OspfLsaSyncState', '')])),
                                                    ])
                                                    self.second_table_index = None
                                                    self.minute_table_index = None
                                                    self.free_time = None
                                                    self.is_deleted = None
                                                    self.is_routing_bit = None
                                                    self.is_advertising_router_reachable = None
                                                    self.is_no_delete = None
                                                    self.is_neighbor_exchange = None
                                                    self.is_routing_table = None
                                                    self.is_acknowledged = None
                                                    self.is_maximum_aged = None
                                                    self.is_partial_spf = None
                                                    self.is_flood_pending = None
                                                    self.rate_limit = None
                                                    self.is_nsr_ack_pending = None
                                                    self.nsr_flood_required = None
                                                    self.lsa_flood_required_post_fail_over = None
                                                    self.lsa_length = None
                                                    self.lsa_sync_state = None
                                                    self._segment_path = lambda: "lsa-detail"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseTable.LsaInternalTable.Lsa.LsaInfo.UnknownLsaType.LsaDetail, [u'second_table_index', u'minute_table_index', u'free_time', u'is_deleted', u'is_routing_bit', u'is_advertising_router_reachable', u'is_no_delete', u'is_neighbor_exchange', u'is_routing_table', u'is_acknowledged', u'is_maximum_aged', u'is_partial_spf', u'is_flood_pending', u'rate_limit', u'is_nsr_ack_pending', u'nsr_flood_required', u'lsa_flood_required_post_fail_over', u'lsa_length', u'lsa_sync_state'], name, value)


                        class DatabaseSummaryTable(Entity):
                            """
                            Database summary table
                            
                            .. attribute:: database_summary
                            
                            	Database Summary information
                            	**type**\:  :py:class:`DatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable, self).__init__()

                                self.yang_name = "database-summary-table"
                                self.yang_parent_name = "area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("database-summary", ("database_summary", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary))])
                                self._leafs = OrderedDict()

                                self.database_summary = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary()
                                self.database_summary.parent = self
                                self._children_name_map["database_summary"] = "database-summary"
                                self._segment_path = lambda: "database-summary-table"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable, [], name, value)


                            class DatabaseSummary(Entity):
                                """
                                Database Summary information
                                
                                .. attribute:: database_counters
                                
                                	OSPFv3 database counters 
                                	**type**\:  :py:class:`DatabaseCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters>`
                                
                                .. attribute:: database_router_id
                                
                                	Database router ID 
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_opaque_database_capable
                                
                                	If true, opaque database is capable 
                                	**type**\: bool
                                
                                .. attribute:: area_database
                                
                                	OSPFv3 Area Database list 
                                	**type**\: list of  		 :py:class:`AreaDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase>`
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary, self).__init__()

                                    self.yang_name = "database-summary"
                                    self.yang_parent_name = "database-summary-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("database-counters", ("database_counters", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters)), ("area-database", ("area_database", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase))])
                                    self._leafs = OrderedDict([
                                        ('database_router_id', (YLeaf(YType.str, 'database-router-id'), ['str'])),
                                        ('is_opaque_database_capable', (YLeaf(YType.boolean, 'is-opaque-database-capable'), ['bool'])),
                                    ])
                                    self.database_router_id = None
                                    self.is_opaque_database_capable = None

                                    self.database_counters = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters()
                                    self.database_counters.parent = self
                                    self._children_name_map["database_counters"] = "database-counters"

                                    self.area_database = YList(self)
                                    self._segment_path = lambda: "database-summary"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary, [u'database_router_id', u'is_opaque_database_capable'], name, value)


                                class DatabaseCounters(Entity):
                                    """
                                    OSPFv3 database counters 
                                    
                                    .. attribute:: lsa
                                    
                                    	lsa
                                    	**type**\: list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: deleted_lsa
                                    
                                    	deleted lsa
                                    	**type**\: list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: max_age_lsa
                                    
                                    	max age lsa
                                    	**type**\: list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsa_checksum
                                    
                                    	lsa checksum
                                    	**type**\: list of int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters, self).__init__()

                                        self.yang_name = "database-counters"
                                        self.yang_parent_name = "database-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsa', (YLeafList(YType.uint32, 'lsa'), ['int'])),
                                            ('deleted_lsa', (YLeafList(YType.uint32, 'deleted-lsa'), ['int'])),
                                            ('max_age_lsa', (YLeafList(YType.uint32, 'max-age-lsa'), ['int'])),
                                            ('lsa_checksum', (YLeafList(YType.uint32, 'lsa-checksum'), ['int'])),
                                        ])
                                        self.lsa = []
                                        self.deleted_lsa = []
                                        self.max_age_lsa = []
                                        self.lsa_checksum = []
                                        self._segment_path = lambda: "database-counters"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters, [u'lsa', u'deleted_lsa', u'max_age_lsa', u'lsa_checksum'], name, value)


                                class AreaDatabase(Entity):
                                    """
                                    OSPFv3 Area Database list 
                                    
                                    .. attribute:: area_database_summary
                                    
                                    	Area database summary 
                                    	**type**\:  :py:class:`AreaDatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary>`
                                    
                                    .. attribute:: lsa_area_id
                                    
                                    	Area ID in decimal or dotted\-decimal format
                                    	**type**\: str
                                    
                                    	**length:** 0..16
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase, self).__init__()

                                        self.yang_name = "area-database"
                                        self.yang_parent_name = "database-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("area-database-summary", ("area_database_summary", Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary))])
                                        self._leafs = OrderedDict([
                                            ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                        ])
                                        self.lsa_area_id = None

                                        self.area_database_summary = Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary()
                                        self.area_database_summary.parent = self
                                        self._children_name_map["area_database_summary"] = "area-database-summary"
                                        self._segment_path = lambda: "area-database"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase, [u'lsa_area_id'], name, value)


                                    class AreaDatabaseSummary(Entity):
                                        """
                                        Area database summary 
                                        
                                        .. attribute:: lsa
                                        
                                        	lsa
                                        	**type**\: list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: deleted_lsa
                                        
                                        	deleted lsa
                                        	**type**\: list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_age_lsa
                                        
                                        	max age lsa
                                        	**type**\: list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsa_checksum
                                        
                                        	lsa checksum
                                        	**type**\: list of int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv6-ospfv3-oper'
                                        _revision = '2017-10-30'

                                        def __init__(self):
                                            super(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary, self).__init__()

                                            self.yang_name = "area-database-summary"
                                            self.yang_parent_name = "area-database"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsa', (YLeafList(YType.uint32, 'lsa'), ['int'])),
                                                ('deleted_lsa', (YLeafList(YType.uint32, 'deleted-lsa'), ['int'])),
                                                ('max_age_lsa', (YLeafList(YType.uint32, 'max-age-lsa'), ['int'])),
                                                ('lsa_checksum', (YLeafList(YType.uint32, 'lsa-checksum'), ['int'])),
                                            ])
                                            self.lsa = []
                                            self.deleted_lsa = []
                                            self.max_age_lsa = []
                                            self.lsa_checksum = []
                                            self._segment_path = lambda: "area-database-summary"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Areas.Area.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary, [u'lsa', u'deleted_lsa', u'max_age_lsa', u'lsa_checksum'], name, value)


                class InternalRoutes(Entity):
                    """
                    OSPFv3 internal route information table
                    
                    .. attribute:: internal_route
                    
                    	OSPFv3 internal route information
                    	**type**\: list of  		 :py:class:`InternalRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes, self).__init__()

                        self.yang_name = "internal-routes"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("internal-route", ("internal_route", Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute))])
                        self._leafs = OrderedDict()

                        self.internal_route = YList(self)
                        self._segment_path = lambda: "internal-routes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes, [], name, value)


                    class InternalRoute(Entity):
                        """
                        OSPFv3 internal route information
                        
                        .. attribute:: prefix
                        
                        	Route prefix
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\: int
                        
                        	**range:** 0..128
                        
                        .. attribute:: route_topology
                        
                        	Common Route topology information
                        	**type**\:  :py:class:`RouteTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteTopology>`
                        
                        .. attribute:: route_area_id
                        
                        	Route area ID 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_source
                        
                        	List of topology source information
                        	**type**\: list of  		 :py:class:`RouteSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteSource>`
                        
                        .. attribute:: route_path
                        
                        	List of paths to this route
                        	**type**\: list of  		 :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute, self).__init__()

                            self.yang_name = "internal-route"
                            self.yang_parent_name = "internal-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("route-topology", ("route_topology", Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteTopology)), ("route-source", ("route_source", Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteSource)), ("route-path", ("route_path", Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath))])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                ('route_area_id', (YLeaf(YType.uint32, 'route-area-id'), ['int'])),
                            ])
                            self.prefix = None
                            self.prefix_length = None
                            self.route_area_id = None

                            self.route_topology = Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteTopology()
                            self.route_topology.parent = self
                            self._children_name_map["route_topology"] = "route-topology"

                            self.route_source = YList(self)
                            self.route_path = YList(self)
                            self._segment_path = lambda: "internal-route"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute, ['prefix', 'prefix_length', u'route_area_id'], name, value)


                        class RouteTopology(Entity):
                            """
                            Common Route topology information
                            
                            .. attribute:: route_id
                            
                            	Route ID 
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_distance
                            
                            	Route distance 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_cost
                            
                            	Route cost 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteTopology, self).__init__()

                                self.yang_name = "route-topology"
                                self.yang_parent_name = "internal-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('route_id', (YLeaf(YType.str, 'route-id'), ['str'])),
                                    ('route_distance', (YLeaf(YType.uint32, 'route-distance'), ['int'])),
                                    ('route_cost', (YLeaf(YType.uint32, 'route-cost'), ['int'])),
                                    ('route_type', (YLeaf(YType.uint32, 'route-type'), ['int'])),
                                ])
                                self.route_id = None
                                self.route_distance = None
                                self.route_cost = None
                                self.route_type = None
                                self._segment_path = lambda: "route-topology"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteTopology, [u'route_id', u'route_distance', u'route_cost', u'route_type'], name, value)


                        class RouteSource(Entity):
                            """
                            List of topology source information
                            
                            .. attribute:: route_source_adversting_router
                            
                            	Route source of the advertising router 
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_source_id
                            
                            	Route source ID 
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_source_lsa_type
                            
                            	Type of LSA advertising the prefix, see RFC5340
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteSource, self).__init__()

                                self.yang_name = "route-source"
                                self.yang_parent_name = "internal-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('route_source_adversting_router', (YLeaf(YType.str, 'route-source-adversting-router'), ['str'])),
                                    ('route_source_id', (YLeaf(YType.str, 'route-source-id'), ['str'])),
                                    ('route_source_lsa_type', (YLeaf(YType.uint32, 'route-source-lsa-type'), ['int'])),
                                ])
                                self.route_source_adversting_router = None
                                self.route_source_id = None
                                self.route_source_lsa_type = None
                                self._segment_path = lambda: "route-source"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RouteSource, [u'route_source_adversting_router', u'route_source_id', u'route_source_lsa_type'], name, value)


                        class RoutePath(Entity):
                            """
                            List of paths to this route
                            
                            .. attribute:: route_backup_path
                            
                            	Backup Path Info
                            	**type**\:  :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath>`
                            
                            .. attribute:: interface_name
                            
                            	Route path interface name 
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: interface_index
                            
                            	Route path interface Index 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_path_next_hop
                            
                            	Route path next hop 
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_path_id
                            
                            	Path ID of path
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: neighbor_next_hop
                            
                            	NeighborNextHop
                            	**type**\: list of  		 :py:class:`NeighborNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath.NeighborNextHop>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath, self).__init__()

                                self.yang_name = "route-path"
                                self.yang_parent_name = "internal-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("route-backup-path", ("route_backup_path", Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath)), ("neighbor-next-hop", ("neighbor_next_hop", Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath.NeighborNextHop))])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                    ('route_path_next_hop', (YLeaf(YType.str, 'route-path-next-hop'), ['str'])),
                                    ('route_path_id', (YLeaf(YType.uint16, 'route-path-id'), ['int'])),
                                ])
                                self.interface_name = None
                                self.interface_index = None
                                self.route_path_next_hop = None
                                self.route_path_id = None

                                self.route_backup_path = Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath()
                                self.route_backup_path.parent = self
                                self._children_name_map["route_backup_path"] = "route-backup-path"

                                self.neighbor_next_hop = YList(self)
                                self._segment_path = lambda: "route-path"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath, [u'interface_name', u'interface_index', u'route_path_next_hop', u'route_path_id'], name, value)


                            class RouteBackupPath(Entity):
                                """
                                Backup Path Info
                                
                                .. attribute:: backup_route_interface_name
                                
                                	Next hop Interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: backup_route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_route_source
                                
                                	IP address of source of route
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_metric
                                
                                	Metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: primary_path
                                
                                	Primary Path
                                	**type**\: bool
                                
                                .. attribute:: line_card_disjoint
                                
                                	Line Card Disjoint
                                	**type**\: bool
                                
                                .. attribute:: downstream
                                
                                	Downstream
                                	**type**\: bool
                                
                                .. attribute:: node_protect
                                
                                	Node Protect
                                	**type**\: bool
                                
                                .. attribute:: srlg_disjoint
                                
                                	SRLG Disjoint
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath, self).__init__()

                                    self.yang_name = "route-backup-path"
                                    self.yang_parent_name = "route-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('backup_route_interface_name', (YLeaf(YType.str, 'backup-route-interface-name'), ['str'])),
                                        ('backup_route_next_hop_address', (YLeaf(YType.str, 'backup-route-next-hop-address'), ['str'])),
                                        ('backup_route_source', (YLeaf(YType.str, 'backup-route-source'), ['str'])),
                                        ('backup_metric', (YLeaf(YType.uint32, 'backup-metric'), ['int'])),
                                        ('primary_path', (YLeaf(YType.boolean, 'primary-path'), ['bool'])),
                                        ('line_card_disjoint', (YLeaf(YType.boolean, 'line-card-disjoint'), ['bool'])),
                                        ('downstream', (YLeaf(YType.boolean, 'downstream'), ['bool'])),
                                        ('node_protect', (YLeaf(YType.boolean, 'node-protect'), ['bool'])),
                                        ('srlg_disjoint', (YLeaf(YType.boolean, 'srlg-disjoint'), ['bool'])),
                                    ])
                                    self.backup_route_interface_name = None
                                    self.backup_route_next_hop_address = None
                                    self.backup_route_source = None
                                    self.backup_metric = None
                                    self.primary_path = None
                                    self.line_card_disjoint = None
                                    self.downstream = None
                                    self.node_protect = None
                                    self.srlg_disjoint = None
                                    self._segment_path = lambda: "route-backup-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath.RouteBackupPath, [u'backup_route_interface_name', u'backup_route_next_hop_address', u'backup_route_source', u'backup_metric', u'primary_path', u'line_card_disjoint', u'downstream', u'node_protect', u'srlg_disjoint'], name, value)


                            class NeighborNextHop(Entity):
                                """
                                NeighborNextHop
                                
                                .. attribute:: neighbor_next_hop_intf_index
                                
                                	Neighbor NextHop Interface Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath.NeighborNextHop, self).__init__()

                                    self.yang_name = "neighbor-next-hop"
                                    self.yang_parent_name = "route-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('neighbor_next_hop_intf_index', (YLeaf(YType.uint32, 'neighbor-next-hop-intf-index'), ['int'])),
                                    ])
                                    self.neighbor_next_hop_intf_index = None
                                    self._segment_path = lambda: "neighbor-next-hop"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InternalRoutes.InternalRoute.RoutePath.NeighborNextHop, [u'neighbor_next_hop_intf_index'], name, value)


                class ProtocolAreas(Entity):
                    """
                    Protocol area table 
                    
                    .. attribute:: protocol_area
                    
                    	Area information 
                    	**type**\: list of  		 :py:class:`ProtocolArea <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas, self).__init__()

                        self.yang_name = "protocol-areas"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol-area", ("protocol_area", Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea))])
                        self._leafs = OrderedDict()

                        self.protocol_area = YList(self)
                        self._segment_path = lambda: "protocol-areas"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas, [], name, value)


                    class ProtocolArea(Entity):
                        """
                        Area information 
                        
                        .. attribute:: area_id  (key)
                        
                        	Area ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: protocol_area_id
                        
                        	Area ID string in decimal and dotted\-decimal format
                        	**type**\: str
                        
                        	**length:** 0..16
                        
                        .. attribute:: distribute_list_in
                        
                        	Distribute List In
                        	**type**\: str
                        
                        .. attribute:: protocol_interface
                        
                        	Interface list
                        	**type**\: list of  		 :py:class:`ProtocolInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea.ProtocolInterface>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea, self).__init__()

                            self.yang_name = "protocol-area"
                            self.yang_parent_name = "protocol-areas"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['area_id']
                            self._child_classes = OrderedDict([("protocol-interface", ("protocol_interface", Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea.ProtocolInterface))])
                            self._leafs = OrderedDict([
                                ('area_id', (YLeaf(YType.str, 'area-id'), ['str'])),
                                ('protocol_area_id', (YLeaf(YType.str, 'protocol-area-id'), ['str'])),
                                ('distribute_list_in', (YLeaf(YType.str, 'distribute-list-in'), ['str'])),
                            ])
                            self.area_id = None
                            self.protocol_area_id = None
                            self.distribute_list_in = None

                            self.protocol_interface = YList(self)
                            self._segment_path = lambda: "protocol-area" + "[area-id='" + str(self.area_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea, ['area_id', u'protocol_area_id', u'distribute_list_in'], name, value)


                        class ProtocolInterface(Entity):
                            """
                            Interface list
                            
                            .. attribute:: interface_name
                            
                            	Protocol interface name 
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: distribute_list_in
                            
                            	Distribute List In
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea.ProtocolInterface, self).__init__()

                                self.yang_name = "protocol-interface"
                                self.yang_parent_name = "protocol-area"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('distribute_list_in', (YLeaf(YType.str, 'distribute-list-in'), ['str'])),
                                ])
                                self.interface_name = None
                                self.distribute_list_in = None
                                self._segment_path = lambda: "protocol-interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ProtocolAreas.ProtocolArea.ProtocolInterface, [u'interface_name', u'distribute_list_in'], name, value)


                class ConnectedRoutes(Entity):
                    """
                    OSPFv3 connected route information table
                    
                    .. attribute:: connected_route
                    
                    	OSPFv3 connected route information
                    	**type**\: list of  		 :py:class:`ConnectedRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes, self).__init__()

                        self.yang_name = "connected-routes"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("connected-route", ("connected_route", Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute))])
                        self._leafs = OrderedDict()

                        self.connected_route = YList(self)
                        self._segment_path = lambda: "connected-routes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes, [], name, value)


                    class ConnectedRoute(Entity):
                        """
                        OSPFv3 connected route information
                        
                        .. attribute:: prefix
                        
                        	Route prefix
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\: int
                        
                        	**range:** 0..128
                        
                        .. attribute:: route_topology
                        
                        	Common Route topology information
                        	**type**\:  :py:class:`RouteTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RouteTopology>`
                        
                        .. attribute:: route_path
                        
                        	List of paths to this route
                        	**type**\: list of  		 :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute, self).__init__()

                            self.yang_name = "connected-route"
                            self.yang_parent_name = "connected-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("route-topology", ("route_topology", Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RouteTopology)), ("route-path", ("route_path", Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath))])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                            ])
                            self.prefix = None
                            self.prefix_length = None

                            self.route_topology = Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RouteTopology()
                            self.route_topology.parent = self
                            self._children_name_map["route_topology"] = "route-topology"

                            self.route_path = YList(self)
                            self._segment_path = lambda: "connected-route"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute, ['prefix', 'prefix_length'], name, value)


                        class RouteTopology(Entity):
                            """
                            Common Route topology information
                            
                            .. attribute:: route_id
                            
                            	Route ID 
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_distance
                            
                            	Route distance 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_cost
                            
                            	Route cost 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_type
                            
                            	Route type
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RouteTopology, self).__init__()

                                self.yang_name = "route-topology"
                                self.yang_parent_name = "connected-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('route_id', (YLeaf(YType.str, 'route-id'), ['str'])),
                                    ('route_distance', (YLeaf(YType.uint32, 'route-distance'), ['int'])),
                                    ('route_cost', (YLeaf(YType.uint32, 'route-cost'), ['int'])),
                                    ('route_type', (YLeaf(YType.uint32, 'route-type'), ['int'])),
                                ])
                                self.route_id = None
                                self.route_distance = None
                                self.route_cost = None
                                self.route_type = None
                                self._segment_path = lambda: "route-topology"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RouteTopology, [u'route_id', u'route_distance', u'route_cost', u'route_type'], name, value)


                        class RoutePath(Entity):
                            """
                            List of paths to this route
                            
                            .. attribute:: route_backup_path
                            
                            	Backup Path Info
                            	**type**\:  :py:class:`RouteBackupPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath>`
                            
                            .. attribute:: interface_name
                            
                            	Route path interface name 
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: interface_index
                            
                            	Route path interface Index 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: route_path_next_hop
                            
                            	Route path next hop 
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: route_path_id
                            
                            	Path ID of path
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: neighbor_next_hop
                            
                            	NeighborNextHop
                            	**type**\: list of  		 :py:class:`NeighborNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath.NeighborNextHop>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath, self).__init__()

                                self.yang_name = "route-path"
                                self.yang_parent_name = "connected-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("route-backup-path", ("route_backup_path", Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath)), ("neighbor-next-hop", ("neighbor_next_hop", Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath.NeighborNextHop))])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                    ('route_path_next_hop', (YLeaf(YType.str, 'route-path-next-hop'), ['str'])),
                                    ('route_path_id', (YLeaf(YType.uint16, 'route-path-id'), ['int'])),
                                ])
                                self.interface_name = None
                                self.interface_index = None
                                self.route_path_next_hop = None
                                self.route_path_id = None

                                self.route_backup_path = Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath()
                                self.route_backup_path.parent = self
                                self._children_name_map["route_backup_path"] = "route-backup-path"

                                self.neighbor_next_hop = YList(self)
                                self._segment_path = lambda: "route-path"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath, [u'interface_name', u'interface_index', u'route_path_next_hop', u'route_path_id'], name, value)


                            class RouteBackupPath(Entity):
                                """
                                Backup Path Info
                                
                                .. attribute:: backup_route_interface_name
                                
                                	Next hop Interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                
                                .. attribute:: backup_route_next_hop_address
                                
                                	Nexthop IP address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_route_source
                                
                                	IP address of source of route
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_metric
                                
                                	Metric
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: primary_path
                                
                                	Primary Path
                                	**type**\: bool
                                
                                .. attribute:: line_card_disjoint
                                
                                	Line Card Disjoint
                                	**type**\: bool
                                
                                .. attribute:: downstream
                                
                                	Downstream
                                	**type**\: bool
                                
                                .. attribute:: node_protect
                                
                                	Node Protect
                                	**type**\: bool
                                
                                .. attribute:: srlg_disjoint
                                
                                	SRLG Disjoint
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath, self).__init__()

                                    self.yang_name = "route-backup-path"
                                    self.yang_parent_name = "route-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('backup_route_interface_name', (YLeaf(YType.str, 'backup-route-interface-name'), ['str'])),
                                        ('backup_route_next_hop_address', (YLeaf(YType.str, 'backup-route-next-hop-address'), ['str'])),
                                        ('backup_route_source', (YLeaf(YType.str, 'backup-route-source'), ['str'])),
                                        ('backup_metric', (YLeaf(YType.uint32, 'backup-metric'), ['int'])),
                                        ('primary_path', (YLeaf(YType.boolean, 'primary-path'), ['bool'])),
                                        ('line_card_disjoint', (YLeaf(YType.boolean, 'line-card-disjoint'), ['bool'])),
                                        ('downstream', (YLeaf(YType.boolean, 'downstream'), ['bool'])),
                                        ('node_protect', (YLeaf(YType.boolean, 'node-protect'), ['bool'])),
                                        ('srlg_disjoint', (YLeaf(YType.boolean, 'srlg-disjoint'), ['bool'])),
                                    ])
                                    self.backup_route_interface_name = None
                                    self.backup_route_next_hop_address = None
                                    self.backup_route_source = None
                                    self.backup_metric = None
                                    self.primary_path = None
                                    self.line_card_disjoint = None
                                    self.downstream = None
                                    self.node_protect = None
                                    self.srlg_disjoint = None
                                    self._segment_path = lambda: "route-backup-path"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath.RouteBackupPath, [u'backup_route_interface_name', u'backup_route_next_hop_address', u'backup_route_source', u'backup_metric', u'primary_path', u'line_card_disjoint', u'downstream', u'node_protect', u'srlg_disjoint'], name, value)


                            class NeighborNextHop(Entity):
                                """
                                NeighborNextHop
                                
                                .. attribute:: neighbor_next_hop_intf_index
                                
                                	Neighbor NextHop Interface Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath.NeighborNextHop, self).__init__()

                                    self.yang_name = "neighbor-next-hop"
                                    self.yang_parent_name = "route-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('neighbor_next_hop_intf_index', (YLeaf(YType.uint32, 'neighbor-next-hop-intf-index'), ['int'])),
                                    ])
                                    self.neighbor_next_hop_intf_index = None
                                    self._segment_path = lambda: "neighbor-next-hop"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.ConnectedRoutes.ConnectedRoute.RoutePath.NeighborNextHop, [u'neighbor_next_hop_intf_index'], name, value)


                class VrfStatistics(Entity):
                    """
                    Container for Statistics
                    
                    .. attribute:: protocol_stats
                    
                    	Protocol table
                    	**type**\:  :py:class:`ProtocolStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats>`
                    
                    .. attribute:: spf_stats
                    
                    	OSPFv3 RIB batch statistics
                    	**type**\:  :py:class:`SpfStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats>`
                    
                    .. attribute:: rawio_stats
                    
                    	OSPF Prefix SPF Prioritization statistics
                    	**type**\:  :py:class:`RawioStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.RawioStats>`
                    
                    .. attribute:: prefix_priority_stats
                    
                    	OSPF Prefix SPF Prioritization statistics
                    	**type**\:  :py:class:`PrefixPriorityStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.PrefixPriorityStats>`
                    
                    .. attribute:: vrf_rib_batch_stats
                    
                    	OSPFv3 RIB batch statistics
                    	**type**\:  :py:class:`VrfRibBatchStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.VrfRibBatchStats>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics, self).__init__()

                        self.yang_name = "vrf-statistics"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol-stats", ("protocol_stats", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats)), ("spf-stats", ("spf_stats", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats)), ("rawio-stats", ("rawio_stats", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.RawioStats)), ("prefix-priority-stats", ("prefix_priority_stats", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.PrefixPriorityStats)), ("vrf-rib-batch-stats", ("vrf_rib_batch_stats", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.VrfRibBatchStats))])
                        self._leafs = OrderedDict()

                        self.protocol_stats = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats()
                        self.protocol_stats.parent = self
                        self._children_name_map["protocol_stats"] = "protocol-stats"

                        self.spf_stats = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats()
                        self.spf_stats.parent = self
                        self._children_name_map["spf_stats"] = "spf-stats"

                        self.rawio_stats = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.RawioStats()
                        self.rawio_stats.parent = self
                        self._children_name_map["rawio_stats"] = "rawio-stats"

                        self.prefix_priority_stats = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.PrefixPriorityStats()
                        self.prefix_priority_stats.parent = self
                        self._children_name_map["prefix_priority_stats"] = "prefix-priority-stats"

                        self.vrf_rib_batch_stats = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.VrfRibBatchStats()
                        self.vrf_rib_batch_stats.parent = self
                        self._children_name_map["vrf_rib_batch_stats"] = "vrf-rib-batch-stats"
                        self._segment_path = lambda: "vrf-statistics"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics, [], name, value)


                    class ProtocolStats(Entity):
                        """
                        Protocol table
                        
                        .. attribute:: protocol_stat
                        
                        	Protocol statistics for an interface
                        	**type**\: list of  		 :py:class:`ProtocolStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats.ProtocolStat>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats, self).__init__()

                            self.yang_name = "protocol-stats"
                            self.yang_parent_name = "vrf-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("protocol-stat", ("protocol_stat", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats.ProtocolStat))])
                            self._leafs = OrderedDict()

                            self.protocol_stat = YList(self)
                            self._segment_path = lambda: "protocol-stats"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats, [], name, value)


                        class ProtocolStat(Entity):
                            """
                            Protocol statistics for an interface
                            
                            .. attribute:: interface_name  (key)
                            
                            	Interface name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: total_in_packets
                            
                            	Total inputs packets
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: hello_in_packets
                            
                            	Hello packets in
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: dbdes_in_packets
                            
                            	Database Description Packets in
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: dbdes_in_ls_as
                            
                            	Database Description LSAs in
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_req_in_packets
                            
                            	LSA Requests in
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_req_in_ls_as
                            
                            	LS Requests in
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_upd_in_packets
                            
                            	LS Updates Packets in
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_upd_in_ignored
                            
                            	LS Updates ignored
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_upd_in_ls_as
                            
                            	LS Updates LSAs in
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_ack_in_packets
                            
                            	LS Acks Packets in
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_ack_in_ls_as
                            
                            	LS Ack LSAs in
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: total_out_packets
                            
                            	Total Out Packets
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: hello_out_packets
                            
                            	Hello Out Packets
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: dbdes_out_packets
                            
                            	Database Description Packets out
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: dbdes_out_ls_as
                            
                            	Database Description LSAs out
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_req_out_packets
                            
                            	LS Request Packets out
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_req_out_ls_as
                            
                            	LS Reuqests LSAs out
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_upd_out_packets
                            
                            	LS Update Packets out
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_upd_out_ls_as
                            
                            	LS Update LSAs out
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_ack_out_packets
                            
                            	LS Ack Packets out
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: ls_ack_out_ls_as
                            
                            	LS Ack LSAs out
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: dropped_in_gs
                            
                            	Dropped in GS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: checksum_err
                            
                            	Checksum Errors
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats.ProtocolStat, self).__init__()

                                self.yang_name = "protocol-stat"
                                self.yang_parent_name = "protocol-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['interface_name']
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('total_in_packets', (YLeaf(YType.uint64, 'total-in-packets'), ['int'])),
                                    ('hello_in_packets', (YLeaf(YType.uint64, 'hello-in-packets'), ['int'])),
                                    ('dbdes_in_packets', (YLeaf(YType.uint64, 'dbdes-in-packets'), ['int'])),
                                    ('dbdes_in_ls_as', (YLeaf(YType.uint64, 'dbdes-in-ls-as'), ['int'])),
                                    ('ls_req_in_packets', (YLeaf(YType.uint64, 'ls-req-in-packets'), ['int'])),
                                    ('ls_req_in_ls_as', (YLeaf(YType.uint64, 'ls-req-in-ls-as'), ['int'])),
                                    ('ls_upd_in_packets', (YLeaf(YType.uint64, 'ls-upd-in-packets'), ['int'])),
                                    ('ls_upd_in_ignored', (YLeaf(YType.uint64, 'ls-upd-in-ignored'), ['int'])),
                                    ('ls_upd_in_ls_as', (YLeaf(YType.uint64, 'ls-upd-in-ls-as'), ['int'])),
                                    ('ls_ack_in_packets', (YLeaf(YType.uint64, 'ls-ack-in-packets'), ['int'])),
                                    ('ls_ack_in_ls_as', (YLeaf(YType.uint64, 'ls-ack-in-ls-as'), ['int'])),
                                    ('total_out_packets', (YLeaf(YType.uint64, 'total-out-packets'), ['int'])),
                                    ('hello_out_packets', (YLeaf(YType.uint64, 'hello-out-packets'), ['int'])),
                                    ('dbdes_out_packets', (YLeaf(YType.uint64, 'dbdes-out-packets'), ['int'])),
                                    ('dbdes_out_ls_as', (YLeaf(YType.uint64, 'dbdes-out-ls-as'), ['int'])),
                                    ('ls_req_out_packets', (YLeaf(YType.uint64, 'ls-req-out-packets'), ['int'])),
                                    ('ls_req_out_ls_as', (YLeaf(YType.uint64, 'ls-req-out-ls-as'), ['int'])),
                                    ('ls_upd_out_packets', (YLeaf(YType.uint64, 'ls-upd-out-packets'), ['int'])),
                                    ('ls_upd_out_ls_as', (YLeaf(YType.uint64, 'ls-upd-out-ls-as'), ['int'])),
                                    ('ls_ack_out_packets', (YLeaf(YType.uint64, 'ls-ack-out-packets'), ['int'])),
                                    ('ls_ack_out_ls_as', (YLeaf(YType.uint64, 'ls-ack-out-ls-as'), ['int'])),
                                    ('dropped_in_gs', (YLeaf(YType.uint64, 'dropped-in-gs'), ['int'])),
                                    ('checksum_err', (YLeaf(YType.uint64, 'checksum-err'), ['int'])),
                                ])
                                self.interface_name = None
                                self.total_in_packets = None
                                self.hello_in_packets = None
                                self.dbdes_in_packets = None
                                self.dbdes_in_ls_as = None
                                self.ls_req_in_packets = None
                                self.ls_req_in_ls_as = None
                                self.ls_upd_in_packets = None
                                self.ls_upd_in_ignored = None
                                self.ls_upd_in_ls_as = None
                                self.ls_ack_in_packets = None
                                self.ls_ack_in_ls_as = None
                                self.total_out_packets = None
                                self.hello_out_packets = None
                                self.dbdes_out_packets = None
                                self.dbdes_out_ls_as = None
                                self.ls_req_out_packets = None
                                self.ls_req_out_ls_as = None
                                self.ls_upd_out_packets = None
                                self.ls_upd_out_ls_as = None
                                self.ls_ack_out_packets = None
                                self.ls_ack_out_ls_as = None
                                self.dropped_in_gs = None
                                self.checksum_err = None
                                self._segment_path = lambda: "protocol-stat" + "[interface-name='" + str(self.interface_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.ProtocolStats.ProtocolStat, ['interface_name', u'total_in_packets', u'hello_in_packets', u'dbdes_in_packets', u'dbdes_in_ls_as', u'ls_req_in_packets', u'ls_req_in_ls_as', u'ls_upd_in_packets', u'ls_upd_in_ignored', u'ls_upd_in_ls_as', u'ls_ack_in_packets', u'ls_ack_in_ls_as', u'total_out_packets', u'hello_out_packets', u'dbdes_out_packets', u'dbdes_out_ls_as', u'ls_req_out_packets', u'ls_req_out_ls_as', u'ls_upd_out_packets', u'ls_upd_out_ls_as', u'ls_ack_out_packets', u'ls_ack_out_ls_as', u'dropped_in_gs', u'checksum_err'], name, value)


                    class SpfStats(Entity):
                        """
                        OSPFv3 RIB batch statistics
                        
                        .. attribute:: spf_header
                        
                        	SPF statistics header
                        	**type**\:  :py:class:`SpfHeader <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader>`
                        
                        .. attribute:: spf_runtime
                        
                        	List of SPF run\-time statistics
                        	**type**\: list of  		 :py:class:`SpfRuntime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats, self).__init__()

                            self.yang_name = "spf-stats"
                            self.yang_parent_name = "vrf-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("spf-header", ("spf_header", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader)), ("spf-runtime", ("spf_runtime", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime))])
                            self._leafs = OrderedDict()

                            self.spf_header = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader()
                            self.spf_header.parent = self
                            self._children_name_map["spf_header"] = "spf-header"

                            self.spf_runtime = YList(self)
                            self._segment_path = lambda: "spf-stats"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats, [], name, value)


                        class SpfHeader(Entity):
                            """
                            SPF statistics header
                            
                            .. attribute:: header_router_id
                            
                            	Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_sp_fs
                            
                            	Number of SPF calculations
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: area_summary
                            
                            	List of Areas with SPF statistics
                            	**type**\: list of  		 :py:class:`AreaSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader, self).__init__()

                                self.yang_name = "spf-header"
                                self.yang_parent_name = "spf-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("area-summary", ("area_summary", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary))])
                                self._leafs = OrderedDict([
                                    ('header_router_id', (YLeaf(YType.str, 'header-router-id'), ['str'])),
                                    ('header_sp_fs', (YLeaf(YType.uint32, 'header-sp-fs'), ['int'])),
                                ])
                                self.header_router_id = None
                                self.header_sp_fs = None

                                self.area_summary = YList(self)
                                self._segment_path = lambda: "spf-header"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader, [u'header_router_id', u'header_sp_fs'], name, value)


                            class AreaSummary(Entity):
                                """
                                List of Areas with SPF statistics
                                
                                .. attribute:: area_id
                                
                                	Area ID of the area SPF statistics
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sp_fs
                                
                                	Number of SPF calculations
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary, self).__init__()

                                    self.yang_name = "area-summary"
                                    self.yang_parent_name = "spf-header"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('area_id', (YLeaf(YType.uint32, 'area-id'), ['int'])),
                                        ('sp_fs', (YLeaf(YType.uint32, 'sp-fs'), ['int'])),
                                    ])
                                    self.area_id = None
                                    self.sp_fs = None
                                    self._segment_path = lambda: "area-summary"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfHeader.AreaSummary, [u'area_id', u'sp_fs'], name, value)


                        class SpfRuntime(Entity):
                            """
                            List of SPF run\-time statistics
                            
                            .. attribute:: global_time
                            
                            	Global SPF times
                            	**type**\:  :py:class:`GlobalTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime>`
                            
                            .. attribute:: start_time
                            
                            	SPF calculation start time
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_add_routes
                            
                            	Number of routes added to RIB
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rib_delete_routes
                            
                            	Number of routes deleted from RIB
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reason_flags
                            
                            	Reasons for triggering an SPF calculation Bit 1 \- Router LSA update Bit 2 \- Network LSA update Bit 3 \- Inter\-Area Prefix LSA update Bit 4 \- Inter\-Area Router LSA update Bit 5 \- AS External LSA update Bit 6 \- MOSPF LSA update Bit 7 \- Type 7 AS External LSA update Bit 8 \- Link LSA update Bit 9 \- Prefix LSA update
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: lsa_changes
                            
                            	Number of LSA changes triggering an SPF calculation
                            	**type**\: int
                            
                            	**range:** \-32768..32767
                            
                            .. attribute:: lsa
                            
                            	List of LSAs triggering the SPF calculation
                            	**type**\: list of  		 :py:class:`Lsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.Lsa>`
                            
                            .. attribute:: area_stat
                            
                            	List of per\-area SPF statistics
                            	**type**\: list of  		 :py:class:`AreaStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime, self).__init__()

                                self.yang_name = "spf-runtime"
                                self.yang_parent_name = "spf-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("global-time", ("global_time", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime)), ("lsa", ("lsa", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.Lsa)), ("area-stat", ("area_stat", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat))])
                                self._leafs = OrderedDict([
                                    ('start_time', (YLeaf(YType.uint32, 'start-time'), ['int'])),
                                    ('rib_add_routes', (YLeaf(YType.uint32, 'rib-add-routes'), ['int'])),
                                    ('rib_delete_routes', (YLeaf(YType.uint32, 'rib-delete-routes'), ['int'])),
                                    ('reason_flags', (YLeaf(YType.str, 'reason-flags'), ['str'])),
                                    ('lsa_changes', (YLeaf(YType.int16, 'lsa-changes'), ['int'])),
                                ])
                                self.start_time = None
                                self.rib_add_routes = None
                                self.rib_delete_routes = None
                                self.reason_flags = None
                                self.lsa_changes = None

                                self.global_time = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime()
                                self.global_time.parent = self
                                self._children_name_map["global_time"] = "global-time"

                                self.lsa = YList(self)
                                self.area_stat = YList(self)
                                self._segment_path = lambda: "spf-runtime"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime, [u'start_time', u'rib_add_routes', u'rib_delete_routes', u'reason_flags', u'lsa_changes'], name, value)


                            class GlobalTime(Entity):
                                """
                                Global SPF times
                                
                                .. attribute:: dijkstra
                                
                                	Dijkstra time in msec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: intra_prefix
                                
                                	Intra\-prefix processing time in msec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: intra_prefix_del
                                
                                	Intra\-prefix deletion time in msec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inter_prefix
                                
                                	Inter\-prefix processing time in msec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: inter_prefix_del
                                
                                	Intra\-prefix deletion time in msec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_prefix
                                
                                	External prefix processing time in msec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: external_prefix_del
                                
                                	External prefix deletion time in msec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_add
                                
                                	RIB add processing time in msec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rib_del
                                
                                	RIB deletion time in msec
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime, self).__init__()

                                    self.yang_name = "global-time"
                                    self.yang_parent_name = "spf-runtime"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('dijkstra', (YLeaf(YType.uint32, 'dijkstra'), ['int'])),
                                        ('intra_prefix', (YLeaf(YType.uint32, 'intra-prefix'), ['int'])),
                                        ('intra_prefix_del', (YLeaf(YType.uint32, 'intra-prefix-del'), ['int'])),
                                        ('inter_prefix', (YLeaf(YType.uint32, 'inter-prefix'), ['int'])),
                                        ('inter_prefix_del', (YLeaf(YType.uint32, 'inter-prefix-del'), ['int'])),
                                        ('external_prefix', (YLeaf(YType.uint32, 'external-prefix'), ['int'])),
                                        ('external_prefix_del', (YLeaf(YType.uint32, 'external-prefix-del'), ['int'])),
                                        ('rib_add', (YLeaf(YType.uint32, 'rib-add'), ['int'])),
                                        ('rib_del', (YLeaf(YType.uint32, 'rib-del'), ['int'])),
                                    ])
                                    self.dijkstra = None
                                    self.intra_prefix = None
                                    self.intra_prefix_del = None
                                    self.inter_prefix = None
                                    self.inter_prefix_del = None
                                    self.external_prefix = None
                                    self.external_prefix_del = None
                                    self.rib_add = None
                                    self.rib_del = None
                                    self._segment_path = lambda: "global-time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.GlobalTime, [u'dijkstra', u'intra_prefix', u'intra_prefix_del', u'inter_prefix', u'inter_prefix_del', u'external_prefix', u'external_prefix_del', u'rib_add', u'rib_del'], name, value)


                            class Lsa(Entity):
                                """
                                List of LSAs triggering the SPF calculation
                                
                                .. attribute:: lsa_area_id
                                
                                	Area ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_advertising_router
                                
                                	Advertising router ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsa_id
                                
                                	LSA ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsa_type
                                
                                	LSA type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: lsa_flush
                                
                                	If true, the LSA change is a flush
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.Lsa, self).__init__()

                                    self.yang_name = "lsa"
                                    self.yang_parent_name = "spf-runtime"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lsa_area_id', (YLeaf(YType.uint32, 'lsa-area-id'), ['int'])),
                                        ('lsa_advertising_router', (YLeaf(YType.str, 'lsa-advertising-router'), ['str'])),
                                        ('lsa_id', (YLeaf(YType.str, 'lsa-id'), ['str'])),
                                        ('lsa_type', (YLeaf(YType.uint8, 'lsa-type'), ['int'])),
                                        ('lsa_flush', (YLeaf(YType.boolean, 'lsa-flush'), ['bool'])),
                                    ])
                                    self.lsa_area_id = None
                                    self.lsa_advertising_router = None
                                    self.lsa_id = None
                                    self.lsa_type = None
                                    self.lsa_flush = None
                                    self._segment_path = lambda: "lsa"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.Lsa, [u'lsa_area_id', u'lsa_advertising_router', u'lsa_id', u'lsa_type', u'lsa_flush'], name, value)


                            class AreaStat(Entity):
                                """
                                List of per\-area SPF statistics
                                
                                .. attribute:: spf_stat_time
                                
                                	SPF time calculations
                                	**type**\:  :py:class:`SpfStatTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime>`
                                
                                .. attribute:: spf_stat_area_id
                                
                                	Area ID for area of these SPF statistics
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: spf_stat_lsa_type_count
                                
                                	Counts of LSA types triggering an SPF calculation
                                	**type**\: list of int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat, self).__init__()

                                    self.yang_name = "area-stat"
                                    self.yang_parent_name = "spf-runtime"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("spf-stat-time", ("spf_stat_time", Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime))])
                                    self._leafs = OrderedDict([
                                        ('spf_stat_area_id', (YLeaf(YType.uint32, 'spf-stat-area-id'), ['int'])),
                                        ('spf_stat_lsa_type_count', (YLeafList(YType.uint32, 'spf-stat-lsa-type-count'), ['int'])),
                                    ])
                                    self.spf_stat_area_id = None
                                    self.spf_stat_lsa_type_count = []

                                    self.spf_stat_time = Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime()
                                    self.spf_stat_time.parent = self
                                    self._children_name_map["spf_stat_time"] = "spf-stat-time"
                                    self._segment_path = lambda: "area-stat"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat, [u'spf_stat_area_id', u'spf_stat_lsa_type_count'], name, value)


                                class SpfStatTime(Entity):
                                    """
                                    SPF time calculations
                                    
                                    .. attribute:: dijkstra
                                    
                                    	Dijkstra time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: intra_prefix
                                    
                                    	Intra\-prefix processing time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: intra_prefix_del
                                    
                                    	Intra\-prefix deletion time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inter_prefix
                                    
                                    	Inter\-prefix processing time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: inter_prefix_del
                                    
                                    	Intra\-prefix deletion time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_prefix
                                    
                                    	External prefix processing time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: external_prefix_del
                                    
                                    	External prefix deletion time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_add
                                    
                                    	RIB add processing time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rib_del
                                    
                                    	RIB deletion time in msec
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime, self).__init__()

                                        self.yang_name = "spf-stat-time"
                                        self.yang_parent_name = "area-stat"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('dijkstra', (YLeaf(YType.uint32, 'dijkstra'), ['int'])),
                                            ('intra_prefix', (YLeaf(YType.uint32, 'intra-prefix'), ['int'])),
                                            ('intra_prefix_del', (YLeaf(YType.uint32, 'intra-prefix-del'), ['int'])),
                                            ('inter_prefix', (YLeaf(YType.uint32, 'inter-prefix'), ['int'])),
                                            ('inter_prefix_del', (YLeaf(YType.uint32, 'inter-prefix-del'), ['int'])),
                                            ('external_prefix', (YLeaf(YType.uint32, 'external-prefix'), ['int'])),
                                            ('external_prefix_del', (YLeaf(YType.uint32, 'external-prefix-del'), ['int'])),
                                            ('rib_add', (YLeaf(YType.uint32, 'rib-add'), ['int'])),
                                            ('rib_del', (YLeaf(YType.uint32, 'rib-del'), ['int'])),
                                        ])
                                        self.dijkstra = None
                                        self.intra_prefix = None
                                        self.intra_prefix_del = None
                                        self.inter_prefix = None
                                        self.inter_prefix_del = None
                                        self.external_prefix = None
                                        self.external_prefix_del = None
                                        self.rib_add = None
                                        self.rib_del = None
                                        self._segment_path = lambda: "spf-stat-time"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.SpfStats.SpfRuntime.AreaStat.SpfStatTime, [u'dijkstra', u'intra_prefix', u'intra_prefix_del', u'inter_prefix', u'inter_prefix_del', u'external_prefix', u'external_prefix_del', u'rib_add', u'rib_del'], name, value)


                    class RawioStats(Entity):
                        """
                        OSPF Prefix SPF Prioritization statistics
                        
                        .. attribute:: raw_conn_open
                        
                        	Raw Connections Open
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: raw_conn_close
                        
                        	Raw Connections Close
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: raw_conn_error
                        
                        	Raw Connections Error
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_packets
                        
                        	Received Packets
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_bytes
                        
                        	Received Bytes
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: byte
                        
                        .. attribute:: in_long_packets
                        
                        	Received Long Packets
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_malloc_drops
                        
                        	In Malloc Drops
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_handle_drops
                        
                        	In Handle Drops
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_short_drops
                        
                        	In Short Drops
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_error_drops
                        
                        	In Error Drops
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_ipsec_drops
                        
                        	In IPSEC Drops
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: in_queue_drops
                        
                        	In Queue Drops
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: out_packets
                        
                        	Packets Sent
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: out_bytes
                        
                        	Sent Bytes
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: byte
                        
                        .. attribute:: out_nofd_drops
                        
                        	No FileDescriptor Drops
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: out_error_drops
                        
                        	Error Drops
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: out_ipsec_drops
                        
                        	Out IPSEC Drops
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: out_nopak_drops
                        
                        	No Packet Buffers
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: out_pakapi_errors
                        
                        	PAK API Errors
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: raw_conn_state
                        
                        	Raw Connection State
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.RawioStats, self).__init__()

                            self.yang_name = "rawio-stats"
                            self.yang_parent_name = "vrf-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('raw_conn_open', (YLeaf(YType.uint64, 'raw-conn-open'), ['int'])),
                                ('raw_conn_close', (YLeaf(YType.uint64, 'raw-conn-close'), ['int'])),
                                ('raw_conn_error', (YLeaf(YType.uint64, 'raw-conn-error'), ['int'])),
                                ('in_packets', (YLeaf(YType.uint64, 'in-packets'), ['int'])),
                                ('in_bytes', (YLeaf(YType.uint64, 'in-bytes'), ['int'])),
                                ('in_long_packets', (YLeaf(YType.uint64, 'in-long-packets'), ['int'])),
                                ('in_malloc_drops', (YLeaf(YType.uint64, 'in-malloc-drops'), ['int'])),
                                ('in_handle_drops', (YLeaf(YType.uint64, 'in-handle-drops'), ['int'])),
                                ('in_short_drops', (YLeaf(YType.uint64, 'in-short-drops'), ['int'])),
                                ('in_error_drops', (YLeaf(YType.uint64, 'in-error-drops'), ['int'])),
                                ('in_ipsec_drops', (YLeaf(YType.uint64, 'in-ipsec-drops'), ['int'])),
                                ('in_queue_drops', (YLeaf(YType.uint64, 'in-queue-drops'), ['int'])),
                                ('out_packets', (YLeaf(YType.uint64, 'out-packets'), ['int'])),
                                ('out_bytes', (YLeaf(YType.uint64, 'out-bytes'), ['int'])),
                                ('out_nofd_drops', (YLeaf(YType.uint64, 'out-nofd-drops'), ['int'])),
                                ('out_error_drops', (YLeaf(YType.uint64, 'out-error-drops'), ['int'])),
                                ('out_ipsec_drops', (YLeaf(YType.uint64, 'out-ipsec-drops'), ['int'])),
                                ('out_nopak_drops', (YLeaf(YType.uint64, 'out-nopak-drops'), ['int'])),
                                ('out_pakapi_errors', (YLeaf(YType.uint64, 'out-pakapi-errors'), ['int'])),
                                ('raw_conn_state', (YLeaf(YType.uint32, 'raw-conn-state'), ['int'])),
                            ])
                            self.raw_conn_open = None
                            self.raw_conn_close = None
                            self.raw_conn_error = None
                            self.in_packets = None
                            self.in_bytes = None
                            self.in_long_packets = None
                            self.in_malloc_drops = None
                            self.in_handle_drops = None
                            self.in_short_drops = None
                            self.in_error_drops = None
                            self.in_ipsec_drops = None
                            self.in_queue_drops = None
                            self.out_packets = None
                            self.out_bytes = None
                            self.out_nofd_drops = None
                            self.out_error_drops = None
                            self.out_ipsec_drops = None
                            self.out_nopak_drops = None
                            self.out_pakapi_errors = None
                            self.raw_conn_state = None
                            self._segment_path = lambda: "rawio-stats"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.RawioStats, [u'raw_conn_open', u'raw_conn_close', u'raw_conn_error', u'in_packets', u'in_bytes', u'in_long_packets', u'in_malloc_drops', u'in_handle_drops', u'in_short_drops', u'in_error_drops', u'in_ipsec_drops', u'in_queue_drops', u'out_packets', u'out_bytes', u'out_nofd_drops', u'out_error_drops', u'out_ipsec_drops', u'out_nopak_drops', u'out_pakapi_errors', u'raw_conn_state'], name, value)


                    class PrefixPriorityStats(Entity):
                        """
                        OSPF Prefix SPF Prioritization statistics
                        
                        .. attribute:: critical
                        
                        	Critical priority classifications
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: high
                        
                        	High priority classifications
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: medium
                        
                        	Medium priority classifications
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: low
                        
                        	Low priority classifications
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.PrefixPriorityStats, self).__init__()

                            self.yang_name = "prefix-priority-stats"
                            self.yang_parent_name = "vrf-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                            ])
                            self.critical = None
                            self.high = None
                            self.medium = None
                            self.low = None
                            self._segment_path = lambda: "prefix-priority-stats"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.PrefixPriorityStats, [u'critical', u'high', u'medium', u'low'], name, value)


                    class VrfRibBatchStats(Entity):
                        """
                        OSPFv3 RIB batch statistics
                        
                        .. attribute:: batches_sent
                        
                        	No. of RIB batches sent
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: routes_sent
                        
                        	No. of Routes sent to RIB
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: routes_pending
                        
                        	No of Pending Routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: max_routes
                        
                        	Max No. of Routes in a batch
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_sent
                        
                        	No. of Paths sent to RIB
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_pending
                        
                        	No. of paths waiting to be sent to RIB
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_add
                        
                        	No. of paths added to RIB
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_add_errs
                        
                        	No. of paths add errors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_del
                        
                        	No. of paths del sent to RIB
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_del_errs
                        
                        	No. of Paths del errors
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.VrfRibBatchStats, self).__init__()

                            self.yang_name = "vrf-rib-batch-stats"
                            self.yang_parent_name = "vrf-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('batches_sent', (YLeaf(YType.uint32, 'batches-sent'), ['int'])),
                                ('routes_sent', (YLeaf(YType.uint32, 'routes-sent'), ['int'])),
                                ('routes_pending', (YLeaf(YType.uint32, 'routes-pending'), ['int'])),
                                ('max_routes', (YLeaf(YType.uint32, 'max-routes'), ['int'])),
                                ('paths_sent', (YLeaf(YType.uint32, 'paths-sent'), ['int'])),
                                ('paths_pending', (YLeaf(YType.uint32, 'paths-pending'), ['int'])),
                                ('paths_add', (YLeaf(YType.uint32, 'paths-add'), ['int'])),
                                ('paths_add_errs', (YLeaf(YType.uint32, 'paths-add-errs'), ['int'])),
                                ('paths_del', (YLeaf(YType.uint32, 'paths-del'), ['int'])),
                                ('paths_del_errs', (YLeaf(YType.uint32, 'paths-del-errs'), ['int'])),
                            ])
                            self.batches_sent = None
                            self.routes_sent = None
                            self.routes_pending = None
                            self.max_routes = None
                            self.paths_sent = None
                            self.paths_pending = None
                            self.paths_add = None
                            self.paths_add_errs = None
                            self.paths_del = None
                            self.paths_del_errs = None
                            self._segment_path = lambda: "vrf-rib-batch-stats"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.VrfStatistics.VrfRibBatchStats, [u'batches_sent', u'routes_sent', u'routes_pending', u'max_routes', u'paths_sent', u'paths_pending', u'paths_add', u'paths_add_errs', u'paths_del', u'paths_del_errs'], name, value)


                class Summary(Entity):
                    """
                    OSPFv3 summary
                    
                    .. attribute:: protocol
                    
                    	OSPFv3 protocol summary
                    	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Protocol>`
                    
                    .. attribute:: ospfv3
                    
                    	OSPFv3 summary
                    	**type**\:  :py:class:`Ospfv3_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_>`
                    
                    .. attribute:: route
                    
                    	OSPFv3 route summary
                    	**type**\:  :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Route>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocol", ("protocol", Ospfv3.Processes.Process.DefaultVrf.Summary.Protocol)), ("ospfv3", ("ospfv3", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_)), ("route", ("route", Ospfv3.Processes.Process.DefaultVrf.Summary.Route))])
                        self._leafs = OrderedDict()

                        self.protocol = Ospfv3.Processes.Process.DefaultVrf.Summary.Protocol()
                        self.protocol.parent = self
                        self._children_name_map["protocol"] = "protocol"

                        self.ospfv3 = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_()
                        self.ospfv3.parent = self
                        self._children_name_map["ospfv3"] = "ospfv3"

                        self.route = Ospfv3.Processes.Process.DefaultVrf.Summary.Route()
                        self.route.parent = self
                        self._children_name_map["route"] = "route"
                        self._segment_path = lambda: "summary"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary, [], name, value)


                    class Protocol(Entity):
                        """
                        OSPFv3 protocol summary
                        
                        .. attribute:: protocol_router_id
                        
                        	Protocol router ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: administrative_distance
                        
                        	Administrative distance
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: administrative_distance_inter_area
                        
                        	Administrative Distance for Inter Area routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: administrative_distance_external
                        
                        	Administrative Distance for External routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_graceful_restart
                        
                        	If true, Graceful restart is enabled 
                        	**type**\: bool
                        
                        .. attribute:: distribute_list_in
                        
                        	Distribute List In
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.Summary.Protocol, self).__init__()

                            self.yang_name = "protocol"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('protocol_router_id', (YLeaf(YType.str, 'protocol-router-id'), ['str'])),
                                ('administrative_distance', (YLeaf(YType.uint32, 'administrative-distance'), ['int'])),
                                ('administrative_distance_inter_area', (YLeaf(YType.uint32, 'administrative-distance-inter-area'), ['int'])),
                                ('administrative_distance_external', (YLeaf(YType.uint32, 'administrative-distance-external'), ['int'])),
                                ('is_graceful_restart', (YLeaf(YType.boolean, 'is-graceful-restart'), ['bool'])),
                                ('distribute_list_in', (YLeaf(YType.str, 'distribute-list-in'), ['str'])),
                            ])
                            self.protocol_router_id = None
                            self.administrative_distance = None
                            self.administrative_distance_inter_area = None
                            self.administrative_distance_external = None
                            self.is_graceful_restart = None
                            self.distribute_list_in = None
                            self._segment_path = lambda: "protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Protocol, [u'protocol_router_id', u'administrative_distance', u'administrative_distance_inter_area', u'administrative_distance_external', u'is_graceful_restart', u'distribute_list_in'], name, value)


                    class Ospfv3_(Entity):
                        """
                        OSPFv3 summary
                        
                        .. attribute:: domain_id
                        
                        	Domain ID information
                        	**type**\:  :py:class:`DomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId>`
                        
                        .. attribute:: router_id
                        
                        	Router ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_role_standby
                        
                        	If true, the process is running as stanby role
                        	**type**\: bool
                        
                        .. attribute:: role
                        
                        	Role, V1/V2 Active/Standby
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_nsr_enabled
                        
                        	If true, NSR is enabled
                        	**type**\: bool
                        
                        .. attribute:: is_nsr_switchover_on_restart
                        
                        	Trigger RP Switchover on detectable process restart
                        	**type**\: bool
                        
                        .. attribute:: is_router_id_stalled
                        
                        	Stalled Router ID 
                        	**type**\: bool
                        
                        .. attribute:: is_opaque_capable
                        
                        	Opaque LSA capable 
                        	**type**\: bool
                        
                        .. attribute:: is_area_border_router
                        
                        	If true, is an area border router
                        	**type**\: bool
                        
                        .. attribute:: is_as_border_router
                        
                        	If true, is an AS border router
                        	**type**\: bool
                        
                        .. attribute:: capability_prefer_type7
                        
                        	If true, prefer type 7 LSAs over type 5
                        	**type**\: bool
                        
                        .. attribute:: metric
                        
                        	Redistribution metric 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_default_originated
                        
                        	If true, origin is by default 
                        	**type**\: bool
                        
                        .. attribute:: is_default_always
                        
                        	If true, default always 
                        	**type**\: bool
                        
                        .. attribute:: default_metric
                        
                        	Default metric 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: default_metric_type
                        
                        	Default metric type 
                        	**type**\:  :py:class:`Ospfv3DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3DefaultMetric>`
                        
                        .. attribute:: default_tag
                        
                        	Default tag 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_default_policy
                        
                        	If true, is a default policy 
                        	**type**\: bool
                        
                        .. attribute:: default_policy_name
                        
                        	Default policy name 
                        	**type**\: str
                        
                        .. attribute:: spf_start_time
                        
                        	Scheduling delay for SPF (ms)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: spf_hold_time
                        
                        	Minimum delay time between SPF runs (ms)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: spf_maximum_time
                        
                        	Maximum delay time between SPF runs (ms)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_start_time
                        
                        	Initial LSA throttle delay (ms)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_hold_time
                        
                        	Second delay before generating next LSA (ms)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_maximum_time
                        
                        	Maximum delay before generating an LSA (ms)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: minimum_lsa_interval
                        
                        	Minimum time between LSA regeneration (ms)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_group_interval
                        
                        	LSA refresh interval (sec)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_flood_pacing_interval
                        
                        	LSA flood pacing timer (ms)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsa_retransmission_pacing_interval
                        
                        	LSA retransmission pacing timer (ms)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_ls_as
                        
                        	Number of AS scope LSAs
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: opaque_lsas
                        
                        	Number of opaque LSAs
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: opaque_lsa_checksum
                        
                        	Sum of opaque LSA checksum
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_dc_bitless_ls_as
                        
                        	Number of external and AS opaque LSAs with demand circut bit not set
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_do_not_age_ls_as
                        
                        	Number of external and AS opaque LSAs with do not age set 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: areas
                        
                        	Number of areas
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: normal_areas
                        
                        	Number of normal areas
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: stub_areas
                        
                        	Number of stub and total stub areas
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: nssa_areas
                        
                        	Number of NSSA areas
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: as_lsa_flood_list_length
                        
                        	Length of AS LSAs flood list
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_grace_restart_enabled
                        
                        	If true, grace restart is enabled 
                        	**type**\: bool
                        
                        .. attribute:: last_nsf_time
                        
                        	 Length of time since the last NSF (s)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: grace_resync_time
                        
                        	Grace time to resync 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum_interfaces
                        
                        	Maximum number of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: maximum_paths
                        
                        	Maximum number of paths
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redistribution_limit
                        
                        	The number of redistributed prefixes allowed
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redistribution_threshold
                        
                        	When the number of redistributed prefixes reaches this threshold, a warning message is issued 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_auto_cost
                        
                        	If true, auto cost is enabled
                        	**type**\: bool
                        
                        .. attribute:: reference_bandwidth
                        
                        	Reference Bandwdith
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: context_name
                        
                        	Context name
                        	**type**\: str
                        
                        	**length:** 0..32
                        
                        .. attribute:: snmp_trap_enabled
                        
                        	If true, snmp trap is enabled
                        	**type**\: bool
                        
                        .. attribute:: graceful_shutdown_state
                        
                        	Graceful shutdown state
                        	**type**\:  :py:class:`Ospfv3GracefulShutdownState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3GracefulShutdownState>`
                        
                        .. attribute:: stub_router
                        
                        	Stub Router Information
                        	**type**\: list of  		 :py:class:`StubRouter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter>`
                        
                        .. attribute:: ipfrr_tiebreakers
                        
                        	IPFRR\-Tiebreakers list
                        	**type**\: list of  		 :py:class:`IpfrrTiebreakers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.IpfrrTiebreakers>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_, self).__init__()

                            self.yang_name = "ospfv3"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("domain-id", ("domain_id", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId)), ("stub-router", ("stub_router", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter)), ("ipfrr-tiebreakers", ("ipfrr_tiebreakers", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.IpfrrTiebreakers))])
                            self._leafs = OrderedDict([
                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                ('is_role_standby', (YLeaf(YType.boolean, 'is-role-standby'), ['bool'])),
                                ('role', (YLeaf(YType.uint32, 'role'), ['int'])),
                                ('is_nsr_enabled', (YLeaf(YType.boolean, 'is-nsr-enabled'), ['bool'])),
                                ('is_nsr_switchover_on_restart', (YLeaf(YType.boolean, 'is-nsr-switchover-on-restart'), ['bool'])),
                                ('is_router_id_stalled', (YLeaf(YType.boolean, 'is-router-id-stalled'), ['bool'])),
                                ('is_opaque_capable', (YLeaf(YType.boolean, 'is-opaque-capable'), ['bool'])),
                                ('is_area_border_router', (YLeaf(YType.boolean, 'is-area-border-router'), ['bool'])),
                                ('is_as_border_router', (YLeaf(YType.boolean, 'is-as-border-router'), ['bool'])),
                                ('capability_prefer_type7', (YLeaf(YType.boolean, 'capability-prefer-type7'), ['bool'])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('is_default_originated', (YLeaf(YType.boolean, 'is-default-originated'), ['bool'])),
                                ('is_default_always', (YLeaf(YType.boolean, 'is-default-always'), ['bool'])),
                                ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                                ('default_metric_type', (YLeaf(YType.enumeration, 'default-metric-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3DefaultMetric', '')])),
                                ('default_tag', (YLeaf(YType.uint32, 'default-tag'), ['int'])),
                                ('is_default_policy', (YLeaf(YType.boolean, 'is-default-policy'), ['bool'])),
                                ('default_policy_name', (YLeaf(YType.str, 'default-policy-name'), ['str'])),
                                ('spf_start_time', (YLeaf(YType.uint32, 'spf-start-time'), ['int'])),
                                ('spf_hold_time', (YLeaf(YType.uint32, 'spf-hold-time'), ['int'])),
                                ('spf_maximum_time', (YLeaf(YType.uint32, 'spf-maximum-time'), ['int'])),
                                ('lsa_start_time', (YLeaf(YType.uint32, 'lsa-start-time'), ['int'])),
                                ('lsa_hold_time', (YLeaf(YType.uint32, 'lsa-hold-time'), ['int'])),
                                ('lsa_maximum_time', (YLeaf(YType.uint32, 'lsa-maximum-time'), ['int'])),
                                ('minimum_lsa_interval', (YLeaf(YType.uint32, 'minimum-lsa-interval'), ['int'])),
                                ('lsa_group_interval', (YLeaf(YType.uint32, 'lsa-group-interval'), ['int'])),
                                ('lsa_flood_pacing_interval', (YLeaf(YType.uint32, 'lsa-flood-pacing-interval'), ['int'])),
                                ('lsa_retransmission_pacing_interval', (YLeaf(YType.uint32, 'lsa-retransmission-pacing-interval'), ['int'])),
                                ('as_ls_as', (YLeaf(YType.uint32, 'as-ls-as'), ['int'])),
                                ('opaque_lsas', (YLeaf(YType.uint32, 'opaque-lsas'), ['int'])),
                                ('opaque_lsa_checksum', (YLeaf(YType.uint32, 'opaque-lsa-checksum'), ['int'])),
                                ('as_dc_bitless_ls_as', (YLeaf(YType.uint32, 'as-dc-bitless-ls-as'), ['int'])),
                                ('as_do_not_age_ls_as', (YLeaf(YType.uint32, 'as-do-not-age-ls-as'), ['int'])),
                                ('areas', (YLeaf(YType.uint16, 'areas'), ['int'])),
                                ('normal_areas', (YLeaf(YType.uint16, 'normal-areas'), ['int'])),
                                ('stub_areas', (YLeaf(YType.uint16, 'stub-areas'), ['int'])),
                                ('nssa_areas', (YLeaf(YType.uint16, 'nssa-areas'), ['int'])),
                                ('as_lsa_flood_list_length', (YLeaf(YType.uint32, 'as-lsa-flood-list-length'), ['int'])),
                                ('is_grace_restart_enabled', (YLeaf(YType.boolean, 'is-grace-restart-enabled'), ['bool'])),
                                ('last_nsf_time', (YLeaf(YType.uint32, 'last-nsf-time'), ['int'])),
                                ('grace_resync_time', (YLeaf(YType.uint32, 'grace-resync-time'), ['int'])),
                                ('maximum_interfaces', (YLeaf(YType.uint32, 'maximum-interfaces'), ['int'])),
                                ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                ('redistribution_limit', (YLeaf(YType.uint32, 'redistribution-limit'), ['int'])),
                                ('redistribution_threshold', (YLeaf(YType.uint32, 'redistribution-threshold'), ['int'])),
                                ('is_auto_cost', (YLeaf(YType.boolean, 'is-auto-cost'), ['bool'])),
                                ('reference_bandwidth', (YLeaf(YType.uint32, 'reference-bandwidth'), ['int'])),
                                ('context_name', (YLeaf(YType.str, 'context-name'), ['str'])),
                                ('snmp_trap_enabled', (YLeaf(YType.boolean, 'snmp-trap-enabled'), ['bool'])),
                                ('graceful_shutdown_state', (YLeaf(YType.enumeration, 'graceful-shutdown-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3GracefulShutdownState', '')])),
                            ])
                            self.router_id = None
                            self.is_role_standby = None
                            self.role = None
                            self.is_nsr_enabled = None
                            self.is_nsr_switchover_on_restart = None
                            self.is_router_id_stalled = None
                            self.is_opaque_capable = None
                            self.is_area_border_router = None
                            self.is_as_border_router = None
                            self.capability_prefer_type7 = None
                            self.metric = None
                            self.is_default_originated = None
                            self.is_default_always = None
                            self.default_metric = None
                            self.default_metric_type = None
                            self.default_tag = None
                            self.is_default_policy = None
                            self.default_policy_name = None
                            self.spf_start_time = None
                            self.spf_hold_time = None
                            self.spf_maximum_time = None
                            self.lsa_start_time = None
                            self.lsa_hold_time = None
                            self.lsa_maximum_time = None
                            self.minimum_lsa_interval = None
                            self.lsa_group_interval = None
                            self.lsa_flood_pacing_interval = None
                            self.lsa_retransmission_pacing_interval = None
                            self.as_ls_as = None
                            self.opaque_lsas = None
                            self.opaque_lsa_checksum = None
                            self.as_dc_bitless_ls_as = None
                            self.as_do_not_age_ls_as = None
                            self.areas = None
                            self.normal_areas = None
                            self.stub_areas = None
                            self.nssa_areas = None
                            self.as_lsa_flood_list_length = None
                            self.is_grace_restart_enabled = None
                            self.last_nsf_time = None
                            self.grace_resync_time = None
                            self.maximum_interfaces = None
                            self.maximum_paths = None
                            self.redistribution_limit = None
                            self.redistribution_threshold = None
                            self.is_auto_cost = None
                            self.reference_bandwidth = None
                            self.context_name = None
                            self.snmp_trap_enabled = None
                            self.graceful_shutdown_state = None

                            self.domain_id = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId()
                            self.domain_id.parent = self
                            self._children_name_map["domain_id"] = "domain-id"

                            self.stub_router = YList(self)
                            self.ipfrr_tiebreakers = YList(self)
                            self._segment_path = lambda: "ospfv3"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_, [u'router_id', u'is_role_standby', u'role', u'is_nsr_enabled', u'is_nsr_switchover_on_restart', u'is_router_id_stalled', u'is_opaque_capable', u'is_area_border_router', u'is_as_border_router', u'capability_prefer_type7', u'metric', u'is_default_originated', u'is_default_always', u'default_metric', u'default_metric_type', u'default_tag', u'is_default_policy', u'default_policy_name', u'spf_start_time', u'spf_hold_time', u'spf_maximum_time', u'lsa_start_time', u'lsa_hold_time', u'lsa_maximum_time', u'minimum_lsa_interval', u'lsa_group_interval', u'lsa_flood_pacing_interval', u'lsa_retransmission_pacing_interval', u'as_ls_as', u'opaque_lsas', u'opaque_lsa_checksum', u'as_dc_bitless_ls_as', u'as_do_not_age_ls_as', u'areas', u'normal_areas', u'stub_areas', u'nssa_areas', u'as_lsa_flood_list_length', u'is_grace_restart_enabled', u'last_nsf_time', u'grace_resync_time', u'maximum_interfaces', u'maximum_paths', u'redistribution_limit', u'redistribution_threshold', u'is_auto_cost', u'reference_bandwidth', u'context_name', u'snmp_trap_enabled', u'graceful_shutdown_state'], name, value)


                        class DomainId(Entity):
                            """
                            Domain ID information
                            
                            .. attribute:: primary_domain_id
                            
                            	Primary Domain ID
                            	**type**\:  :py:class:`PrimaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId.PrimaryDomainId>`
                            
                            .. attribute:: secondary_domain_id
                            
                            	List of secondary domain IDs
                            	**type**\: list of  		 :py:class:`SecondaryDomainId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId.SecondaryDomainId>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId, self).__init__()

                                self.yang_name = "domain-id"
                                self.yang_parent_name = "ospfv3"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("primary-domain-id", ("primary_domain_id", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId.PrimaryDomainId)), ("secondary-domain-id", ("secondary_domain_id", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId.SecondaryDomainId))])
                                self._leafs = OrderedDict()

                                self.primary_domain_id = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId.PrimaryDomainId()
                                self.primary_domain_id.parent = self
                                self._children_name_map["primary_domain_id"] = "primary-domain-id"

                                self.secondary_domain_id = YList(self)
                                self._segment_path = lambda: "domain-id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId, [], name, value)


                            class PrimaryDomainId(Entity):
                                """
                                Primary Domain ID
                                
                                .. attribute:: domain_id_type
                                
                                	Domain ID Type
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: domain_id_value
                                
                                	Domain ID value
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId.PrimaryDomainId, self).__init__()

                                    self.yang_name = "primary-domain-id"
                                    self.yang_parent_name = "domain-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('domain_id_type', (YLeaf(YType.uint16, 'domain-id-type'), ['int'])),
                                        ('domain_id_value', (YLeaf(YType.str, 'domain-id-value'), ['str'])),
                                    ])
                                    self.domain_id_type = None
                                    self.domain_id_value = None
                                    self._segment_path = lambda: "primary-domain-id"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId.PrimaryDomainId, [u'domain_id_type', u'domain_id_value'], name, value)


                            class SecondaryDomainId(Entity):
                                """
                                List of secondary domain IDs
                                
                                .. attribute:: domain_id_type
                                
                                	Domain ID Type
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: domain_id_value
                                
                                	Domain ID value
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId.SecondaryDomainId, self).__init__()

                                    self.yang_name = "secondary-domain-id"
                                    self.yang_parent_name = "domain-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('domain_id_type', (YLeaf(YType.uint16, 'domain-id-type'), ['int'])),
                                        ('domain_id_value', (YLeaf(YType.str, 'domain-id-value'), ['str'])),
                                    ])
                                    self.domain_id_type = None
                                    self.domain_id_value = None
                                    self._segment_path = lambda: "secondary-domain-id"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.DomainId.SecondaryDomainId, [u'domain_id_type', u'domain_id_value'], name, value)


                        class StubRouter(Entity):
                            """
                            Stub Router Information
                            
                            .. attribute:: unset_time
                            
                            	Timestamp (relative to 1970/1/1 00\:00) when stub router condition was cleared
                            	**type**\:  :py:class:`UnsetTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.UnsetTime>`
                            
                            .. attribute:: start_time
                            
                            	Timestamp (relative to 1970/1/1 00\:00) when stub router mode was activated
                            	**type**\:  :py:class:`StartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.StartTime>`
                            
                            .. attribute:: abr_resume_time
                            
                            	Timestamp (relative to 1970/1/1 00\:00) when ABR duties were resumed
                            	**type**\:  :py:class:`AbrResumeTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.AbrResumeTime>`
                            
                            .. attribute:: mode
                            
                            	Stub router mode
                            	**type**\:  :py:class:`StubRouterMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterMode>`
                            
                            .. attribute:: active
                            
                            	If true, stub router mode is active
                            	**type**\: bool
                            
                            .. attribute:: remaining_time
                            
                            	Remaining time (in seconds) in stub router mode
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: set_reason
                            
                            	Reason for entering stub router mode
                            	**type**\:  :py:class:`StubRouterTrigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterTrigger>`
                            
                            .. attribute:: unset_reason
                            
                            	Reason for clearing stub router condition
                            	**type**\:  :py:class:`StubRouterExitReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterExitReason>`
                            
                            .. attribute:: include_stub_links
                            
                            	If true, advertise maximum metric for stub links
                            	**type**\: bool
                            
                            .. attribute:: summary_lsa_metric
                            
                            	Metric for summary LSAs in max\-metric mode
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: external_lsa_metric
                            
                            	Metric for external LSAs in max\-metric mode
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: abr_off_reason
                            
                            	Reason for being in ABR off mode
                            	**type**\:  :py:class:`StubRouterAbrOffReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterAbrOffReason>`
                            
                            .. attribute:: trigger
                            
                            	Triggers for entering stub router mode
                            	**type**\: list of  		 :py:class:`Trigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger>`
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter, self).__init__()

                                self.yang_name = "stub-router"
                                self.yang_parent_name = "ospfv3"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("unset-time", ("unset_time", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.UnsetTime)), ("start-time", ("start_time", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.StartTime)), ("abr-resume-time", ("abr_resume_time", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.AbrResumeTime)), ("trigger", ("trigger", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger))])
                                self._leafs = OrderedDict([
                                    ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'StubRouterMode', '')])),
                                    ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                    ('remaining_time', (YLeaf(YType.uint32, 'remaining-time'), ['int'])),
                                    ('set_reason', (YLeaf(YType.enumeration, 'set-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'StubRouterTrigger', '')])),
                                    ('unset_reason', (YLeaf(YType.enumeration, 'unset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'StubRouterExitReason', '')])),
                                    ('include_stub_links', (YLeaf(YType.boolean, 'include-stub-links'), ['bool'])),
                                    ('summary_lsa_metric', (YLeaf(YType.uint32, 'summary-lsa-metric'), ['int'])),
                                    ('external_lsa_metric', (YLeaf(YType.uint32, 'external-lsa-metric'), ['int'])),
                                    ('abr_off_reason', (YLeaf(YType.enumeration, 'abr-off-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'StubRouterAbrOffReason', '')])),
                                ])
                                self.mode = None
                                self.active = None
                                self.remaining_time = None
                                self.set_reason = None
                                self.unset_reason = None
                                self.include_stub_links = None
                                self.summary_lsa_metric = None
                                self.external_lsa_metric = None
                                self.abr_off_reason = None

                                self.unset_time = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.UnsetTime()
                                self.unset_time.parent = self
                                self._children_name_map["unset_time"] = "unset-time"

                                self.start_time = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.StartTime()
                                self.start_time.parent = self
                                self._children_name_map["start_time"] = "start-time"

                                self.abr_resume_time = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.AbrResumeTime()
                                self.abr_resume_time.parent = self
                                self._children_name_map["abr_resume_time"] = "abr-resume-time"

                                self.trigger = YList(self)
                                self._segment_path = lambda: "stub-router"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter, [u'mode', u'active', u'remaining_time', u'set_reason', u'unset_reason', u'include_stub_links', u'summary_lsa_metric', u'external_lsa_metric', u'abr_off_reason'], name, value)


                            class UnsetTime(Entity):
                                """
                                Timestamp (relative to 1970/1/1 00\:00) when stub
                                router condition was cleared
                                
                                .. attribute:: second
                                
                                	Seconds 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanosecond
                                
                                	Nano seconds 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.UnsetTime, self).__init__()

                                    self.yang_name = "unset-time"
                                    self.yang_parent_name = "stub-router"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('second', (YLeaf(YType.uint32, 'second'), ['int'])),
                                        ('nanosecond', (YLeaf(YType.uint32, 'nanosecond'), ['int'])),
                                    ])
                                    self.second = None
                                    self.nanosecond = None
                                    self._segment_path = lambda: "unset-time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.UnsetTime, [u'second', u'nanosecond'], name, value)


                            class StartTime(Entity):
                                """
                                Timestamp (relative to 1970/1/1 00\:00) when stub
                                router mode was activated
                                
                                .. attribute:: second
                                
                                	Seconds 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanosecond
                                
                                	Nano seconds 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.StartTime, self).__init__()

                                    self.yang_name = "start-time"
                                    self.yang_parent_name = "stub-router"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('second', (YLeaf(YType.uint32, 'second'), ['int'])),
                                        ('nanosecond', (YLeaf(YType.uint32, 'nanosecond'), ['int'])),
                                    ])
                                    self.second = None
                                    self.nanosecond = None
                                    self._segment_path = lambda: "start-time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.StartTime, [u'second', u'nanosecond'], name, value)


                            class AbrResumeTime(Entity):
                                """
                                Timestamp (relative to 1970/1/1 00\:00) when ABR
                                duties were resumed
                                
                                .. attribute:: second
                                
                                	Seconds 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: nanosecond
                                
                                	Nano seconds 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: nanosecond
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.AbrResumeTime, self).__init__()

                                    self.yang_name = "abr-resume-time"
                                    self.yang_parent_name = "stub-router"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('second', (YLeaf(YType.uint32, 'second'), ['int'])),
                                        ('nanosecond', (YLeaf(YType.uint32, 'nanosecond'), ['int'])),
                                    ])
                                    self.second = None
                                    self.nanosecond = None
                                    self._segment_path = lambda: "abr-resume-time"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.AbrResumeTime, [u'second', u'nanosecond'], name, value)


                            class Trigger(Entity):
                                """
                                Triggers for entering stub router mode
                                
                                .. attribute:: unset_time
                                
                                	Timestamp (relative to 1970/1/1 00\:00) when stub router condition was cleared
                                	**type**\:  :py:class:`UnsetTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger.UnsetTime>`
                                
                                .. attribute:: start_time
                                
                                	Timestamp (relative to 1970/1/1 00\:00) when stub router mode was activated
                                	**type**\:  :py:class:`StartTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger.StartTime>`
                                
                                .. attribute:: trigger
                                
                                	Stub Router Trigger type
                                	**type**\:  :py:class:`StubRouterTrigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterTrigger>`
                                
                                .. attribute:: wait_for_bgp
                                
                                	If true, stub router is terminated when BGP converges
                                	**type**\: bool
                                
                                .. attribute:: unset_reason
                                
                                	Reason for clearing stub router condition
                                	**type**\:  :py:class:`StubRouterExitReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.StubRouterExitReason>`
                                
                                .. attribute:: time
                                
                                	Time (in seconds) to stay in stub router mode
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger, self).__init__()

                                    self.yang_name = "trigger"
                                    self.yang_parent_name = "stub-router"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("unset-time", ("unset_time", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger.UnsetTime)), ("start-time", ("start_time", Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger.StartTime))])
                                    self._leafs = OrderedDict([
                                        ('trigger', (YLeaf(YType.enumeration, 'trigger'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'StubRouterTrigger', '')])),
                                        ('wait_for_bgp', (YLeaf(YType.boolean, 'wait-for-bgp'), ['bool'])),
                                        ('unset_reason', (YLeaf(YType.enumeration, 'unset-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'StubRouterExitReason', '')])),
                                        ('time', (YLeaf(YType.uint32, 'time'), ['int'])),
                                    ])
                                    self.trigger = None
                                    self.wait_for_bgp = None
                                    self.unset_reason = None
                                    self.time = None

                                    self.unset_time = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger.UnsetTime()
                                    self.unset_time.parent = self
                                    self._children_name_map["unset_time"] = "unset-time"

                                    self.start_time = Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger.StartTime()
                                    self.start_time.parent = self
                                    self._children_name_map["start_time"] = "start-time"
                                    self._segment_path = lambda: "trigger"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger, [u'trigger', u'wait_for_bgp', u'unset_reason', u'time'], name, value)


                                class UnsetTime(Entity):
                                    """
                                    Timestamp (relative to 1970/1/1 00\:00) when stub
                                    router condition was cleared
                                    
                                    .. attribute:: second
                                    
                                    	Seconds 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nano seconds 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger.UnsetTime, self).__init__()

                                        self.yang_name = "unset-time"
                                        self.yang_parent_name = "trigger"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('second', (YLeaf(YType.uint32, 'second'), ['int'])),
                                            ('nanosecond', (YLeaf(YType.uint32, 'nanosecond'), ['int'])),
                                        ])
                                        self.second = None
                                        self.nanosecond = None
                                        self._segment_path = lambda: "unset-time"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger.UnsetTime, [u'second', u'nanosecond'], name, value)


                                class StartTime(Entity):
                                    """
                                    Timestamp (relative to 1970/1/1 00\:00) when stub
                                    router mode was activated
                                    
                                    .. attribute:: second
                                    
                                    	Seconds 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nanosecond
                                    
                                    	Nano seconds 
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'ipv6-ospfv3-oper'
                                    _revision = '2017-10-30'

                                    def __init__(self):
                                        super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger.StartTime, self).__init__()

                                        self.yang_name = "start-time"
                                        self.yang_parent_name = "trigger"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('second', (YLeaf(YType.uint32, 'second'), ['int'])),
                                            ('nanosecond', (YLeaf(YType.uint32, 'nanosecond'), ['int'])),
                                        ])
                                        self.second = None
                                        self.nanosecond = None
                                        self._segment_path = lambda: "start-time"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.StubRouter.Trigger.StartTime, [u'second', u'nanosecond'], name, value)


                        class IpfrrTiebreakers(Entity):
                            """
                            IPFRR\-Tiebreakers list
                            
                            .. attribute:: tiebreaker_type
                            
                            	Tiebreaker Type
                            	**type**\:  :py:class:`IpfrrTbrkr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.IpfrrTbrkr>`
                            
                            .. attribute:: tiebreaker_index
                            
                            	Tiebreaker Index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.IpfrrTiebreakers, self).__init__()

                                self.yang_name = "ipfrr-tiebreakers"
                                self.yang_parent_name = "ospfv3"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('tiebreaker_type', (YLeaf(YType.enumeration, 'tiebreaker-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'IpfrrTbrkr', '')])),
                                    ('tiebreaker_index', (YLeaf(YType.uint32, 'tiebreaker-index'), ['int'])),
                                ])
                                self.tiebreaker_type = None
                                self.tiebreaker_index = None
                                self._segment_path = lambda: "ipfrr-tiebreakers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Ospfv3_.IpfrrTiebreakers, [u'tiebreaker_type', u'tiebreaker_index'], name, value)


                    class Route(Entity):
                        """
                        OSPFv3 route summary
                        
                        .. attribute:: route_id
                        
                        	Route summary of a route ID 
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: intra_area_route
                        
                        	Intra route summary 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: inter_area_route
                        
                        	Inter route summary 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: extern_one_route
                        
                        	Extern 1 route summary 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: extern_two_route
                        
                        	Extern 2 route summary 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nssa_one_route
                        
                        	NSSA 1 route summary 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nssa_two_route
                        
                        	NSSA 2 route summary 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_sent_route
                        
                        	Total route summary 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_connected
                        
                        	Route connected 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redistribution_route
                        
                        	Redistribution route summary 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_received_route
                        
                        	Total route received summary
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.Summary.Route, self).__init__()

                            self.yang_name = "route"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('route_id', (YLeaf(YType.str, 'route-id'), ['str'])),
                                ('intra_area_route', (YLeaf(YType.uint32, 'intra-area-route'), ['int'])),
                                ('inter_area_route', (YLeaf(YType.uint32, 'inter-area-route'), ['int'])),
                                ('extern_one_route', (YLeaf(YType.uint32, 'extern-one-route'), ['int'])),
                                ('extern_two_route', (YLeaf(YType.uint32, 'extern-two-route'), ['int'])),
                                ('nssa_one_route', (YLeaf(YType.uint32, 'nssa-one-route'), ['int'])),
                                ('nssa_two_route', (YLeaf(YType.uint32, 'nssa-two-route'), ['int'])),
                                ('total_sent_route', (YLeaf(YType.uint32, 'total-sent-route'), ['int'])),
                                ('route_connected', (YLeaf(YType.uint32, 'route-connected'), ['int'])),
                                ('redistribution_route', (YLeaf(YType.uint32, 'redistribution-route'), ['int'])),
                                ('total_received_route', (YLeaf(YType.uint32, 'total-received-route'), ['int'])),
                            ])
                            self.route_id = None
                            self.intra_area_route = None
                            self.inter_area_route = None
                            self.extern_one_route = None
                            self.extern_two_route = None
                            self.nssa_one_route = None
                            self.nssa_two_route = None
                            self.total_sent_route = None
                            self.route_connected = None
                            self.redistribution_route = None
                            self.total_received_route = None
                            self._segment_path = lambda: "route"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.Summary.Route, [u'route_id', u'intra_area_route', u'inter_area_route', u'extern_one_route', u'extern_two_route', u'nssa_one_route', u'nssa_two_route', u'total_sent_route', u'route_connected', u'redistribution_route', u'total_received_route'], name, value)


                class RetransmissionListProcessTable(Entity):
                    """
                    OSPFv3 retransmission list information table for
                    all areas
                    
                    .. attribute:: retransmission
                    
                    	OSPFv3 retransmission list information
                    	**type**\: list of  		 :py:class:`Retransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable, self).__init__()

                        self.yang_name = "retransmission-list-process-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("retransmission", ("retransmission", Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission))])
                        self._leafs = OrderedDict()

                        self.retransmission = YList(self)
                        self._segment_path = lambda: "retransmission-list-process-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable, [], name, value)


                    class Retransmission(Entity):
                        """
                        OSPFv3 retransmission list information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: retransmission_neighbor_address
                        
                        	Neighbor IP address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_retransmissionvirtual_link
                        
                        	If true, virtual link is retransmitted 
                        	**type**\: bool
                        
                        .. attribute:: retransmissionvirtual_link_id
                        
                        	Retransmission virtual link ID 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_retransmission_sham_link
                        
                        	If true, sham link is retransmitted 
                        	**type**\: bool
                        
                        .. attribute:: retransmission_sham_link_id
                        
                        	Retransmission sham link ID 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: retransmission_timer
                        
                        	Amount of time remaining on retransmission timer (ms)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: retransmission_length
                        
                        	Retransmission queue length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: retransmissionvirtual_link_db
                        
                        	List of virtual link scope entries 
                        	**type**\: list of  		 :py:class:`RetransmissionvirtualLinkDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb>`
                        
                        .. attribute:: retransmission_area_db
                        
                        	List of area scope entries
                        	**type**\: list of  		 :py:class:`RetransmissionAreaDb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb>`
                        
                        .. attribute:: retransmission_asdb
                        
                        	List of AS scope entries
                        	**type**\: list of  		 :py:class:`RetransmissionAsdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission, self).__init__()

                            self.yang_name = "retransmission"
                            self.yang_parent_name = "retransmission-list-process-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("retransmissionvirtual-link-db", ("retransmissionvirtual_link_db", Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb)), ("retransmission-area-db", ("retransmission_area_db", Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb)), ("retransmission-asdb", ("retransmission_asdb", Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                ('retransmission_neighbor_address', (YLeaf(YType.str, 'retransmission-neighbor-address'), ['str'])),
                                ('is_retransmissionvirtual_link', (YLeaf(YType.boolean, 'is-retransmissionvirtual-link'), ['bool'])),
                                ('retransmissionvirtual_link_id', (YLeaf(YType.uint32, 'retransmissionvirtual-link-id'), ['int'])),
                                ('is_retransmission_sham_link', (YLeaf(YType.boolean, 'is-retransmission-sham-link'), ['bool'])),
                                ('retransmission_sham_link_id', (YLeaf(YType.uint32, 'retransmission-sham-link-id'), ['int'])),
                                ('retransmission_timer', (YLeaf(YType.uint32, 'retransmission-timer'), ['int'])),
                                ('retransmission_length', (YLeaf(YType.uint32, 'retransmission-length'), ['int'])),
                            ])
                            self.interface_name = None
                            self.neighbor_address = None
                            self.retransmission_neighbor_address = None
                            self.is_retransmissionvirtual_link = None
                            self.retransmissionvirtual_link_id = None
                            self.is_retransmission_sham_link = None
                            self.retransmission_sham_link_id = None
                            self.retransmission_timer = None
                            self.retransmission_length = None

                            self.retransmissionvirtual_link_db = YList(self)
                            self.retransmission_area_db = YList(self)
                            self.retransmission_asdb = YList(self)
                            self._segment_path = lambda: "retransmission"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission, ['interface_name', 'neighbor_address', u'retransmission_neighbor_address', u'is_retransmissionvirtual_link', u'retransmissionvirtual_link_id', u'is_retransmission_sham_link', u'retransmission_sham_link_id', u'retransmission_timer', u'retransmission_length'], name, value)


                        class RetransmissionvirtualLinkDb(Entity):
                            """
                            List of virtual link scope entries 
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb, self).__init__()

                                self.yang_name = "retransmissionvirtual-link-db"
                                self.yang_parent_name = "retransmission"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                    ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                    ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                    ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                    ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                ])
                                self.header_lsa_type = None
                                self.header_lsa_age = None
                                self.header_lsa_id = None
                                self.header_advertising_router = None
                                self.header_sequence_number = None
                                self._segment_path = lambda: "retransmissionvirtual-link-db"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionvirtualLinkDb, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                        class RetransmissionAreaDb(Entity):
                            """
                            List of area scope entries
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb, self).__init__()

                                self.yang_name = "retransmission-area-db"
                                self.yang_parent_name = "retransmission"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                    ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                    ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                    ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                    ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                ])
                                self.header_lsa_type = None
                                self.header_lsa_age = None
                                self.header_lsa_id = None
                                self.header_advertising_router = None
                                self.header_sequence_number = None
                                self._segment_path = lambda: "retransmission-area-db"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAreaDb, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                        class RetransmissionAsdb(Entity):
                            """
                            List of AS scope entries
                            
                            .. attribute:: header_lsa_type
                            
                            	LSA type
                            	**type**\:  :py:class:`Ospfv3Lsa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Lsa1>`
                            
                            .. attribute:: header_lsa_age
                            
                            	Age of the LSA (seconds)
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: header_lsa_id
                            
                            	LSA ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_advertising_router
                            
                            	Router ID of the advertising router
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: header_sequence_number
                            
                            	Current LSA sequence number
                            	**type**\: int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb, self).__init__()

                                self.yang_name = "retransmission-asdb"
                                self.yang_parent_name = "retransmission"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('header_lsa_type', (YLeaf(YType.enumeration, 'header-lsa-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Lsa1', '')])),
                                    ('header_lsa_age', (YLeaf(YType.uint16, 'header-lsa-age'), ['int'])),
                                    ('header_lsa_id', (YLeaf(YType.str, 'header-lsa-id'), ['str'])),
                                    ('header_advertising_router', (YLeaf(YType.str, 'header-advertising-router'), ['str'])),
                                    ('header_sequence_number', (YLeaf(YType.int32, 'header-sequence-number'), ['int'])),
                                ])
                                self.header_lsa_type = None
                                self.header_lsa_age = None
                                self.header_lsa_id = None
                                self.header_advertising_router = None
                                self.header_sequence_number = None
                                self._segment_path = lambda: "retransmission-asdb"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.RetransmissionListProcessTable.Retransmission.RetransmissionAsdb, [u'header_lsa_type', u'header_lsa_age', u'header_lsa_id', u'header_advertising_router', u'header_sequence_number'], name, value)


                class BadChecksums(Entity):
                    """
                    Bad Checksum Packets information table
                    
                    .. attribute:: bad_checksum
                    
                    	Bad Checksum Packet information
                    	**type**\: list of  		 :py:class:`BadChecksum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.BadChecksums, self).__init__()

                        self.yang_name = "bad-checksums"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bad-checksum", ("bad_checksum", Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum))])
                        self._leafs = OrderedDict()

                        self.bad_checksum = YList(self)
                        self._segment_path = lambda: "bad-checksums"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.BadChecksums, [], name, value)


                    class BadChecksum(Entity):
                        """
                        Bad Checksum Packet information
                        
                        .. attribute:: packet_number  (key)
                        
                        	Bad Checksum Packets number
                        	**type**\: int
                        
                        	**range:** 0..9
                        
                        .. attribute:: timestamp
                        
                        	Packet Timestamp (relative to 1970/1/1 00\:00)
                        	**type**\:  :py:class:`Timestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum.Timestamp>`
                        
                        .. attribute:: received_checksum
                        
                        	Received Checksum
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: computed_checksum
                        
                        	Computed Checksum
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: received_data
                        
                        	Received Hexadecimal Data
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum, self).__init__()

                            self.yang_name = "bad-checksum"
                            self.yang_parent_name = "bad-checksums"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['packet_number']
                            self._child_classes = OrderedDict([("timestamp", ("timestamp", Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum.Timestamp))])
                            self._leafs = OrderedDict([
                                ('packet_number', (YLeaf(YType.uint32, 'packet-number'), ['int'])),
                                ('received_checksum', (YLeaf(YType.uint16, 'received-checksum'), ['int'])),
                                ('computed_checksum', (YLeaf(YType.uint16, 'computed-checksum'), ['int'])),
                                ('received_data', (YLeaf(YType.str, 'received-data'), ['str'])),
                            ])
                            self.packet_number = None
                            self.received_checksum = None
                            self.computed_checksum = None
                            self.received_data = None

                            self.timestamp = Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum.Timestamp()
                            self.timestamp.parent = self
                            self._children_name_map["timestamp"] = "timestamp"
                            self._segment_path = lambda: "bad-checksum" + "[packet-number='" + str(self.packet_number) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum, ['packet_number', u'received_checksum', u'computed_checksum', u'received_data'], name, value)


                        class Timestamp(Entity):
                            """
                            Packet Timestamp (relative to 1970/1/1 00\:00)
                            
                            .. attribute:: second
                            
                            	Seconds 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nanosecond
                            
                            	Nano seconds 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum.Timestamp, self).__init__()

                                self.yang_name = "timestamp"
                                self.yang_parent_name = "bad-checksum"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('second', (YLeaf(YType.uint32, 'second'), ['int'])),
                                    ('nanosecond', (YLeaf(YType.uint32, 'nanosecond'), ['int'])),
                                ])
                                self.second = None
                                self.nanosecond = None
                                self._segment_path = lambda: "timestamp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.BadChecksums.BadChecksum.Timestamp, [u'second', u'nanosecond'], name, value)


                class DatabaseSummaryTable(Entity):
                    """
                    Database summary table
                    
                    .. attribute:: database_summary
                    
                    	Database Summary information
                    	**type**\:  :py:class:`DatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable, self).__init__()

                        self.yang_name = "database-summary-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("database-summary", ("database_summary", Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary))])
                        self._leafs = OrderedDict()

                        self.database_summary = Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary()
                        self.database_summary.parent = self
                        self._children_name_map["database_summary"] = "database-summary"
                        self._segment_path = lambda: "database-summary-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable, [], name, value)


                    class DatabaseSummary(Entity):
                        """
                        Database Summary information
                        
                        .. attribute:: database_counters
                        
                        	OSPFv3 database counters 
                        	**type**\:  :py:class:`DatabaseCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters>`
                        
                        .. attribute:: database_router_id
                        
                        	Database router ID 
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_opaque_database_capable
                        
                        	If true, opaque database is capable 
                        	**type**\: bool
                        
                        .. attribute:: area_database
                        
                        	OSPFv3 Area Database list 
                        	**type**\: list of  		 :py:class:`AreaDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary, self).__init__()

                            self.yang_name = "database-summary"
                            self.yang_parent_name = "database-summary-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("database-counters", ("database_counters", Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters)), ("area-database", ("area_database", Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase))])
                            self._leafs = OrderedDict([
                                ('database_router_id', (YLeaf(YType.str, 'database-router-id'), ['str'])),
                                ('is_opaque_database_capable', (YLeaf(YType.boolean, 'is-opaque-database-capable'), ['bool'])),
                            ])
                            self.database_router_id = None
                            self.is_opaque_database_capable = None

                            self.database_counters = Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters()
                            self.database_counters.parent = self
                            self._children_name_map["database_counters"] = "database-counters"

                            self.area_database = YList(self)
                            self._segment_path = lambda: "database-summary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary, [u'database_router_id', u'is_opaque_database_capable'], name, value)


                        class DatabaseCounters(Entity):
                            """
                            OSPFv3 database counters 
                            
                            .. attribute:: lsa
                            
                            	lsa
                            	**type**\: list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: deleted_lsa
                            
                            	deleted lsa
                            	**type**\: list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: max_age_lsa
                            
                            	max age lsa
                            	**type**\: list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsa_checksum
                            
                            	lsa checksum
                            	**type**\: list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters, self).__init__()

                                self.yang_name = "database-counters"
                                self.yang_parent_name = "database-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('lsa', (YLeafList(YType.uint32, 'lsa'), ['int'])),
                                    ('deleted_lsa', (YLeafList(YType.uint32, 'deleted-lsa'), ['int'])),
                                    ('max_age_lsa', (YLeafList(YType.uint32, 'max-age-lsa'), ['int'])),
                                    ('lsa_checksum', (YLeafList(YType.uint32, 'lsa-checksum'), ['int'])),
                                ])
                                self.lsa = []
                                self.deleted_lsa = []
                                self.max_age_lsa = []
                                self.lsa_checksum = []
                                self._segment_path = lambda: "database-counters"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.DatabaseCounters, [u'lsa', u'deleted_lsa', u'max_age_lsa', u'lsa_checksum'], name, value)


                        class AreaDatabase(Entity):
                            """
                            OSPFv3 Area Database list 
                            
                            .. attribute:: area_database_summary
                            
                            	Area database summary 
                            	**type**\:  :py:class:`AreaDatabaseSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary>`
                            
                            .. attribute:: lsa_area_id
                            
                            	Area ID in decimal or dotted\-decimal format
                            	**type**\: str
                            
                            	**length:** 0..16
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase, self).__init__()

                                self.yang_name = "area-database"
                                self.yang_parent_name = "database-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("area-database-summary", ("area_database_summary", Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary))])
                                self._leafs = OrderedDict([
                                    ('lsa_area_id', (YLeaf(YType.str, 'lsa-area-id'), ['str'])),
                                ])
                                self.lsa_area_id = None

                                self.area_database_summary = Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary()
                                self.area_database_summary.parent = self
                                self._children_name_map["area_database_summary"] = "area-database-summary"
                                self._segment_path = lambda: "area-database"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase, [u'lsa_area_id'], name, value)


                            class AreaDatabaseSummary(Entity):
                                """
                                Area database summary 
                                
                                .. attribute:: lsa
                                
                                	lsa
                                	**type**\: list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: deleted_lsa
                                
                                	deleted lsa
                                	**type**\: list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: max_age_lsa
                                
                                	max age lsa
                                	**type**\: list of int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_checksum
                                
                                	lsa checksum
                                	**type**\: list of int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary, self).__init__()

                                    self.yang_name = "area-database-summary"
                                    self.yang_parent_name = "area-database"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lsa', (YLeafList(YType.uint32, 'lsa'), ['int'])),
                                        ('deleted_lsa', (YLeafList(YType.uint32, 'deleted-lsa'), ['int'])),
                                        ('max_age_lsa', (YLeafList(YType.uint32, 'max-age-lsa'), ['int'])),
                                        ('lsa_checksum', (YLeafList(YType.uint32, 'lsa-checksum'), ['int'])),
                                    ])
                                    self.lsa = []
                                    self.deleted_lsa = []
                                    self.max_age_lsa = []
                                    self.lsa_checksum = []
                                    self._segment_path = lambda: "area-database-summary"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.DatabaseSummaryTable.DatabaseSummary.AreaDatabase.AreaDatabaseSummary, [u'lsa', u'deleted_lsa', u'max_age_lsa', u'lsa_checksum'], name, value)


                class NeighborProcessTable(Entity):
                    """
                    OSPFv3 neighbor information table for all areas
                    
                    .. attribute:: neighbor
                    
                    	OSPFv3 neighbor detail information
                    	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable, self).__init__()

                        self.yang_name = "neighbor-process-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor", ("neighbor", Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor))])
                        self._leafs = OrderedDict()

                        self.neighbor = YList(self)
                        self._segment_path = lambda: "neighbor-process-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable, [], name, value)


                    class Neighbor(Entity):
                        """
                        OSPFv3 neighbor detail information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: neighbor_detail
                        
                        	Detailed OSPFv3 neighbor information 
                        	**type**\:  :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail>`
                        
                        .. attribute:: neighbor_bfd_info
                        
                        	Neighbor BFD information
                        	**type**\:  :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborBfdInfo>`
                        
                        .. attribute:: neighbor_address_xr
                        
                        	Neighbor IP Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: neighbor_interface_id
                        
                        	Neighbor interface ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_dr_priority
                        
                        	Neighbor's DR priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: neighbor_state
                        
                        	Neighbor's state
                        	**type**\:  :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                        
                        .. attribute:: neighbor_designated_router
                        
                        	Designated router 
                        	**type**\: str
                        
                        	**length:** 0..9
                        
                        .. attribute:: neighbor_dead_timer
                        
                        	Time until neighbor's dead timer expires (seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: neighbor_up_time
                        
                        	Amount of time since the adjacency is up (seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: neighbor_virtual_link_id
                        
                        	Neighbor virtual link id 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_neighbor_virtual_link
                        
                        	If true, neighbor is on a virtual link 
                        	**type**\: bool
                        
                        .. attribute:: neighbor_sham_link_id
                        
                        	Neighbor sham link id 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_neighbor_sham_link
                        
                        	If true, neighbor is on a sham link 
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor, self).__init__()

                            self.yang_name = "neighbor"
                            self.yang_parent_name = "neighbor-process-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-detail", ("neighbor_detail", Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail)), ("neighbor-bfd-info", ("neighbor_bfd_info", Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborBfdInfo))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                ('neighbor_address_xr', (YLeaf(YType.str, 'neighbor-address-xr'), ['str'])),
                                ('neighbor_interface_id', (YLeaf(YType.uint32, 'neighbor-interface-id'), ['int'])),
                                ('neighbor_dr_priority', (YLeaf(YType.uint8, 'neighbor-dr-priority'), ['int'])),
                                ('neighbor_state', (YLeaf(YType.enumeration, 'neighbor-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3NeighborState', '')])),
                                ('neighbor_designated_router', (YLeaf(YType.str, 'neighbor-designated-router'), ['str'])),
                                ('neighbor_dead_timer', (YLeaf(YType.uint32, 'neighbor-dead-timer'), ['int'])),
                                ('neighbor_up_time', (YLeaf(YType.uint32, 'neighbor-up-time'), ['int'])),
                                ('neighbor_virtual_link_id', (YLeaf(YType.uint32, 'neighbor-virtual-link-id'), ['int'])),
                                ('is_neighbor_virtual_link', (YLeaf(YType.boolean, 'is-neighbor-virtual-link'), ['bool'])),
                                ('neighbor_sham_link_id', (YLeaf(YType.uint32, 'neighbor-sham-link-id'), ['int'])),
                                ('is_neighbor_sham_link', (YLeaf(YType.boolean, 'is-neighbor-sham-link'), ['bool'])),
                            ])
                            self.interface_name = None
                            self.neighbor_address = None
                            self.neighbor_address_xr = None
                            self.neighbor_interface_id = None
                            self.neighbor_dr_priority = None
                            self.neighbor_state = None
                            self.neighbor_designated_router = None
                            self.neighbor_dead_timer = None
                            self.neighbor_up_time = None
                            self.neighbor_virtual_link_id = None
                            self.is_neighbor_virtual_link = None
                            self.neighbor_sham_link_id = None
                            self.is_neighbor_sham_link = None

                            self.neighbor_detail = Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail()
                            self.neighbor_detail.parent = self
                            self._children_name_map["neighbor_detail"] = "neighbor-detail"

                            self.neighbor_bfd_info = Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborBfdInfo()
                            self.neighbor_bfd_info.parent = self
                            self._children_name_map["neighbor_bfd_info"] = "neighbor-bfd-info"
                            self._segment_path = lambda: "neighbor"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor, ['interface_name', 'neighbor_address', u'neighbor_address_xr', u'neighbor_interface_id', u'neighbor_dr_priority', u'neighbor_state', u'neighbor_designated_router', u'neighbor_dead_timer', u'neighbor_up_time', u'neighbor_virtual_link_id', u'is_neighbor_virtual_link', u'neighbor_sham_link_id', u'is_neighbor_sham_link'], name, value)


                        class NeighborDetail(Entity):
                            """
                            Detailed OSPFv3 neighbor information 
                            
                            .. attribute:: neighbor_retransmission
                            
                            	Retransmission information with this neighbor
                            	**type**\:  :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission>`
                            
                            .. attribute:: state_changes
                            
                            	Number of state changes 
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: neighbor_cost
                            
                            	Cost of path to this neighbor 
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: is_neighbor_filtered
                            
                            	If true, filter outgoing LSAs 
                            	**type**\: bool
                            
                            .. attribute:: neighbor_designated_router_address
                            
                            	Address of designated router
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_backup_designated_router_address
                            
                            	Address of backup designated router
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_type
                            
                            	Interface type
                            	**type**\:  :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                            
                            .. attribute:: poll_interval
                            
                            	Poll interval (s)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_poll_interval
                            
                            	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: neighbor_ignore_timer
                            
                            	Remaining time when ignore timer is running 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_option
                            
                            	 This is bitmask of neighbor's option field received 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pending_events
                            
                            	Number of pending events 
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail, self).__init__()

                                self.yang_name = "neighbor-detail"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("neighbor-retransmission", ("neighbor_retransmission", Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission))])
                                self._leafs = OrderedDict([
                                    ('state_changes', (YLeaf(YType.uint16, 'state-changes'), ['int'])),
                                    ('neighbor_cost', (YLeaf(YType.uint16, 'neighbor-cost'), ['int'])),
                                    ('is_neighbor_filtered', (YLeaf(YType.boolean, 'is-neighbor-filtered'), ['bool'])),
                                    ('neighbor_designated_router_address', (YLeaf(YType.str, 'neighbor-designated-router-address'), ['str'])),
                                    ('neighbor_backup_designated_router_address', (YLeaf(YType.str, 'neighbor-backup-designated-router-address'), ['str'])),
                                    ('interface_type', (YLeaf(YType.enumeration, 'interface-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Interface', '')])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('next_poll_interval', (YLeaf(YType.uint32, 'next-poll-interval'), ['int'])),
                                    ('neighbor_ignore_timer', (YLeaf(YType.uint32, 'neighbor-ignore-timer'), ['int'])),
                                    ('neighbor_option', (YLeaf(YType.uint32, 'neighbor-option'), ['int'])),
                                    ('pending_events', (YLeaf(YType.uint16, 'pending-events'), ['int'])),
                                ])
                                self.state_changes = None
                                self.neighbor_cost = None
                                self.is_neighbor_filtered = None
                                self.neighbor_designated_router_address = None
                                self.neighbor_backup_designated_router_address = None
                                self.interface_type = None
                                self.poll_interval = None
                                self.next_poll_interval = None
                                self.neighbor_ignore_timer = None
                                self.neighbor_option = None
                                self.pending_events = None

                                self.neighbor_retransmission = Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission()
                                self.neighbor_retransmission.parent = self
                                self._children_name_map["neighbor_retransmission"] = "neighbor-retransmission"
                                self._segment_path = lambda: "neighbor-detail"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail, [u'state_changes', u'neighbor_cost', u'is_neighbor_filtered', u'neighbor_designated_router_address', u'neighbor_backup_designated_router_address', u'interface_type', u'poll_interval', u'next_poll_interval', u'neighbor_ignore_timer', u'neighbor_option', u'pending_events'], name, value)


                            class NeighborRetransmission(Entity):
                                """
                                Retransmission information with this neighbor
                                
                                .. attribute:: database_descriptor_retransmissions
                                
                                	Number of database descriptor retransmissions during last exchange
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_flood_index
                                
                                	Area scope LSA's flood index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_flood_index
                                
                                	AS scope LSA's flood index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_flood_index
                                
                                	Link flood index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_retransmissions
                                
                                	Number of neighbor retransmissions 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmissions
                                
                                	Number of retransmissions for this neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_first_flood
                                
                                	First flood item for area scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_first_flood_index
                                
                                	Index of the first flood item for area scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood
                                
                                	First flood item for AS scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood_index
                                
                                	Index for first flood item for AS scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood
                                
                                	Link first flood information 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood_index
                                
                                	Link first flood information index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood
                                
                                	Next flood item for area scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood_index
                                
                                	Index of next flood item for Area scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood
                                
                                	Next flood item for AS scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood_index
                                
                                	Index of next flood item for AS scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood
                                
                                	Link next flood information 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood_index
                                
                                	Link next flood information index 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_length
                                
                                	Number of LSAs sent in last retransmission
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_length
                                
                                	Maximum number of LSAs sent in a retransmission
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_time
                                
                                	Last retransmission scan time (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_time
                                
                                	Maximum retransmission scan time (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_retransmission_timer
                                
                                	Time until next LSA retransmission (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission, self).__init__()

                                    self.yang_name = "neighbor-retransmission"
                                    self.yang_parent_name = "neighbor-detail"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('database_descriptor_retransmissions', (YLeaf(YType.uint32, 'database-descriptor-retransmissions'), ['int'])),
                                        ('area_flood_index', (YLeaf(YType.uint32, 'area-flood-index'), ['int'])),
                                        ('as_flood_index', (YLeaf(YType.uint32, 'as-flood-index'), ['int'])),
                                        ('link_flood_index', (YLeaf(YType.uint32, 'link-flood-index'), ['int'])),
                                        ('neighbor_retransmissions', (YLeaf(YType.uint32, 'neighbor-retransmissions'), ['int'])),
                                        ('retransmissions', (YLeaf(YType.uint32, 'retransmissions'), ['int'])),
                                        ('area_first_flood', (YLeaf(YType.uint32, 'area-first-flood'), ['int'])),
                                        ('area_first_flood_index', (YLeaf(YType.uint32, 'area-first-flood-index'), ['int'])),
                                        ('as_first_flood', (YLeaf(YType.uint32, 'as-first-flood'), ['int'])),
                                        ('as_first_flood_index', (YLeaf(YType.uint32, 'as-first-flood-index'), ['int'])),
                                        ('link_first_flood', (YLeaf(YType.uint32, 'link-first-flood'), ['int'])),
                                        ('link_first_flood_index', (YLeaf(YType.uint32, 'link-first-flood-index'), ['int'])),
                                        ('area_next_flood', (YLeaf(YType.uint32, 'area-next-flood'), ['int'])),
                                        ('area_next_flood_index', (YLeaf(YType.uint32, 'area-next-flood-index'), ['int'])),
                                        ('as_next_flood', (YLeaf(YType.uint32, 'as-next-flood'), ['int'])),
                                        ('as_next_flood_index', (YLeaf(YType.uint32, 'as-next-flood-index'), ['int'])),
                                        ('link_next_flood', (YLeaf(YType.uint32, 'link-next-flood'), ['int'])),
                                        ('link_next_flood_index', (YLeaf(YType.uint32, 'link-next-flood-index'), ['int'])),
                                        ('last_retransmission_length', (YLeaf(YType.uint32, 'last-retransmission-length'), ['int'])),
                                        ('maximum_retransmission_length', (YLeaf(YType.uint32, 'maximum-retransmission-length'), ['int'])),
                                        ('last_retransmission_time', (YLeaf(YType.uint32, 'last-retransmission-time'), ['int'])),
                                        ('maximum_retransmission_time', (YLeaf(YType.uint32, 'maximum-retransmission-time'), ['int'])),
                                        ('lsa_retransmission_timer', (YLeaf(YType.uint32, 'lsa-retransmission-timer'), ['int'])),
                                    ])
                                    self.database_descriptor_retransmissions = None
                                    self.area_flood_index = None
                                    self.as_flood_index = None
                                    self.link_flood_index = None
                                    self.neighbor_retransmissions = None
                                    self.retransmissions = None
                                    self.area_first_flood = None
                                    self.area_first_flood_index = None
                                    self.as_first_flood = None
                                    self.as_first_flood_index = None
                                    self.link_first_flood = None
                                    self.link_first_flood_index = None
                                    self.area_next_flood = None
                                    self.area_next_flood_index = None
                                    self.as_next_flood = None
                                    self.as_next_flood_index = None
                                    self.link_next_flood = None
                                    self.link_next_flood_index = None
                                    self.last_retransmission_length = None
                                    self.maximum_retransmission_length = None
                                    self.last_retransmission_time = None
                                    self.maximum_retransmission_time = None
                                    self.lsa_retransmission_timer = None
                                    self._segment_path = lambda: "neighbor-retransmission"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborDetail.NeighborRetransmission, [u'database_descriptor_retransmissions', u'area_flood_index', u'as_flood_index', u'link_flood_index', u'neighbor_retransmissions', u'retransmissions', u'area_first_flood', u'area_first_flood_index', u'as_first_flood', u'as_first_flood_index', u'link_first_flood', u'link_first_flood_index', u'area_next_flood', u'area_next_flood_index', u'as_next_flood', u'as_next_flood_index', u'link_next_flood', u'link_next_flood_index', u'last_retransmission_length', u'maximum_retransmission_length', u'last_retransmission_time', u'maximum_retransmission_time', u'lsa_retransmission_timer'], name, value)


                        class NeighborBfdInfo(Entity):
                            """
                            Neighbor BFD information
                            
                            .. attribute:: bfd_intf_enable_mode
                            
                            	BFD enable mode \- Default/Strict
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_status_flag
                            
                            	Status of the BFD Session
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborBfdInfo, self).__init__()

                                self.yang_name = "neighbor-bfd-info"
                                self.yang_parent_name = "neighbor"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('bfd_intf_enable_mode', (YLeaf(YType.uint32, 'bfd-intf-enable-mode'), ['int'])),
                                    ('bfd_status_flag', (YLeaf(YType.uint8, 'bfd-status-flag'), ['int'])),
                                ])
                                self.bfd_intf_enable_mode = None
                                self.bfd_status_flag = None
                                self._segment_path = lambda: "neighbor-bfd-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborProcessTable.Neighbor.NeighborBfdInfo, [u'bfd_intf_enable_mode', u'bfd_status_flag'], name, value)


                class FastReroutes(Entity):
                    """
                    OSPFv3 fast reroute topology information table
                    
                    .. attribute:: fast_reroute
                    
                    	OSPFv3 fast reroute topology information
                    	**type**\: list of  		 :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.FastReroutes, self).__init__()

                        self.yang_name = "fast-reroutes"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("fast-reroute", ("fast_reroute", Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute))])
                        self._leafs = OrderedDict()

                        self.fast_reroute = YList(self)
                        self._segment_path = lambda: "fast-reroutes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.FastReroutes, [], name, value)


                    class FastReroute(Entity):
                        """
                        OSPFv3 fast reroute topology information
                        
                        .. attribute:: router_id
                        
                        	Router ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: area_id
                        
                        	AreaID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipfrr_topo_area_id
                        
                        	Area ID string in decimal or dotted decimal format
                        	**type**\: str
                        
                        	**length:** 0..16
                        
                        .. attribute:: ipfrr_router_id
                        
                        	OSPF Router ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipfrr_area_revision
                        
                        	IPFRR Topology Revision
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipfrr_topo
                        
                        	IPFRR Topology entries
                        	**type**\: list of  		 :py:class:`IpfrrTopo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute.IpfrrTopo>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute, self).__init__()

                            self.yang_name = "fast-reroute"
                            self.yang_parent_name = "fast-reroutes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipfrr-topo", ("ipfrr_topo", Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute.IpfrrTopo))])
                            self._leafs = OrderedDict([
                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                ('area_id', (YLeaf(YType.uint32, 'area-id'), ['int'])),
                                ('ipfrr_topo_area_id', (YLeaf(YType.str, 'ipfrr-topo-area-id'), ['str'])),
                                ('ipfrr_router_id', (YLeaf(YType.str, 'ipfrr-router-id'), ['str'])),
                                ('ipfrr_area_revision', (YLeaf(YType.uint32, 'ipfrr-area-revision'), ['int'])),
                            ])
                            self.router_id = None
                            self.area_id = None
                            self.ipfrr_topo_area_id = None
                            self.ipfrr_router_id = None
                            self.ipfrr_area_revision = None

                            self.ipfrr_topo = YList(self)
                            self._segment_path = lambda: "fast-reroute"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute, ['router_id', 'area_id', u'ipfrr_topo_area_id', u'ipfrr_router_id', u'ipfrr_area_revision'], name, value)


                        class IpfrrTopo(Entity):
                            """
                            IPFRR Topology entries
                            
                            .. attribute:: node_id
                            
                            	IPFRR Topology Node ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: lsaid
                            
                            	IPFRR Topology LSA ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: distance
                            
                            	IPFRR Topology Distance
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: type4
                            
                            	IPFRR Topoogy Type\-4 entry
                            	**type**\: bool
                            
                            .. attribute:: revision
                            
                            	IPFRR Topology Revision
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_sourced
                            
                            	IPFRR Topology Neighbor Sourced
                            	**type**\: bool
                            
                            .. attribute:: dr
                            
                            	IPFRR Topology DR entry
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute.IpfrrTopo, self).__init__()

                                self.yang_name = "ipfrr-topo"
                                self.yang_parent_name = "fast-reroute"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('node_id', (YLeaf(YType.str, 'node-id'), ['str'])),
                                    ('lsaid', (YLeaf(YType.uint32, 'lsaid'), ['int'])),
                                    ('distance', (YLeaf(YType.uint32, 'distance'), ['int'])),
                                    ('type4', (YLeaf(YType.boolean, 'type4'), ['bool'])),
                                    ('revision', (YLeaf(YType.uint32, 'revision'), ['int'])),
                                    ('neighbor_sourced', (YLeaf(YType.boolean, 'neighbor-sourced'), ['bool'])),
                                    ('dr', (YLeaf(YType.boolean, 'dr'), ['bool'])),
                                ])
                                self.node_id = None
                                self.lsaid = None
                                self.distance = None
                                self.type4 = None
                                self.revision = None
                                self.neighbor_sourced = None
                                self.dr = None
                                self._segment_path = lambda: "ipfrr-topo"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.FastReroutes.FastReroute.IpfrrTopo, [u'node_id', u'lsaid', u'distance', u'type4', u'revision', u'neighbor_sourced', u'dr'], name, value)


                class InterfaceBriefProcessTable(Entity):
                    """
                    OSPFv3 interface brief information table for all
                    areas
                    
                    .. attribute:: interface_brief
                    
                    	Interface brief information
                    	**type**\: list of  		 :py:class:`InterfaceBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable.InterfaceBrief>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable, self).__init__()

                        self.yang_name = "interface-brief-process-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface-brief", ("interface_brief", Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable.InterfaceBrief))])
                        self._leafs = OrderedDict()

                        self.interface_brief = YList(self)
                        self._segment_path = lambda: "interface-brief-process-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable, [], name, value)


                    class InterfaceBrief(Entity):
                        """
                        Interface brief information
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: interface_address
                        
                        	Interface IP address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: interface_link_cost
                        
                        	Interface link cost
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ospf_interface_state
                        
                        	Interface OSPF state
                        	**type**\:  :py:class:`Ospfv3InterfaceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3InterfaceState>`
                        
                        .. attribute:: interface_neighbors
                        
                        	Total number of neighbors 
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: interface_adjacent_neighbors
                        
                        	Total number of adjacent neighbors
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: network_type
                        
                        	Network type
                        	**type**\:  :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable.InterfaceBrief, self).__init__()

                            self.yang_name = "interface-brief"
                            self.yang_parent_name = "interface-brief-process-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('interface_address', (YLeaf(YType.str, 'interface-address'), ['str'])),
                                ('interface_link_cost', (YLeaf(YType.uint16, 'interface-link-cost'), ['int'])),
                                ('ospf_interface_state', (YLeaf(YType.enumeration, 'ospf-interface-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3InterfaceState', '')])),
                                ('interface_neighbors', (YLeaf(YType.uint16, 'interface-neighbors'), ['int'])),
                                ('interface_adjacent_neighbors', (YLeaf(YType.uint16, 'interface-adjacent-neighbors'), ['int'])),
                                ('network_type', (YLeaf(YType.enumeration, 'network-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Interface', '')])),
                            ])
                            self.interface_name = None
                            self.interface_address = None
                            self.interface_link_cost = None
                            self.ospf_interface_state = None
                            self.interface_neighbors = None
                            self.interface_adjacent_neighbors = None
                            self.network_type = None
                            self._segment_path = lambda: "interface-brief" + "[interface-name='" + str(self.interface_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.InterfaceBriefProcessTable.InterfaceBrief, ['interface_name', u'interface_address', u'interface_link_cost', u'ospf_interface_state', u'interface_neighbors', u'interface_adjacent_neighbors', u'network_type'], name, value)


                class NeighborDetailProcessTable(Entity):
                    """
                    OSPFv3 neighbor information table for all areas
                    
                    .. attribute:: neighbor_detail
                    
                    	OSPFv3 neighbor detail information
                    	**type**\: list of  		 :py:class:`NeighborDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail>`
                    
                    

                    """

                    _prefix = 'ipv6-ospfv3-oper'
                    _revision = '2017-10-30'

                    def __init__(self):
                        super(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable, self).__init__()

                        self.yang_name = "neighbor-detail-process-table"
                        self.yang_parent_name = "default-vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-detail", ("neighbor_detail", Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail))])
                        self._leafs = OrderedDict()

                        self.neighbor_detail = YList(self)
                        self._segment_path = lambda: "neighbor-detail-process-table"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable, [], name, value)


                    class NeighborDetail(Entity):
                        """
                        OSPFv3 neighbor detail information
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: neighbor_address
                        
                        	Neighbor ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: neighbor_detail
                        
                        	Detailed OSPFv3 neighbor information 
                        	**type**\:  :py:class:`NeighborDetail_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_>`
                        
                        .. attribute:: neighbor_bfd_info
                        
                        	Neighbor BFD information
                        	**type**\:  :py:class:`NeighborBfdInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo>`
                        
                        .. attribute:: neighbor_address_xr
                        
                        	Neighbor IP Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: neighbor_interface_id
                        
                        	Neighbor interface ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_dr_priority
                        
                        	Neighbor's DR priority
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: neighbor_state
                        
                        	Neighbor's state
                        	**type**\:  :py:class:`Ospfv3NeighborState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3NeighborState>`
                        
                        .. attribute:: neighbor_designated_router
                        
                        	Designated router 
                        	**type**\: str
                        
                        	**length:** 0..9
                        
                        .. attribute:: neighbor_dead_timer
                        
                        	Time until neighbor's dead timer expires (seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: neighbor_up_time
                        
                        	Amount of time since the adjacency is up (seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: neighbor_virtual_link_id
                        
                        	Neighbor virtual link id 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_neighbor_virtual_link
                        
                        	If true, neighbor is on a virtual link 
                        	**type**\: bool
                        
                        .. attribute:: neighbor_sham_link_id
                        
                        	Neighbor sham link id 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_neighbor_sham_link
                        
                        	If true, neighbor is on a sham link 
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'ipv6-ospfv3-oper'
                        _revision = '2017-10-30'

                        def __init__(self):
                            super(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail, self).__init__()

                            self.yang_name = "neighbor-detail"
                            self.yang_parent_name = "neighbor-detail-process-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor-detail", ("neighbor_detail", Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_)), ("neighbor-bfd-info", ("neighbor_bfd_info", Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo))])
                            self._leafs = OrderedDict([
                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                ('neighbor_address_xr', (YLeaf(YType.str, 'neighbor-address-xr'), ['str'])),
                                ('neighbor_interface_id', (YLeaf(YType.uint32, 'neighbor-interface-id'), ['int'])),
                                ('neighbor_dr_priority', (YLeaf(YType.uint8, 'neighbor-dr-priority'), ['int'])),
                                ('neighbor_state', (YLeaf(YType.enumeration, 'neighbor-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3NeighborState', '')])),
                                ('neighbor_designated_router', (YLeaf(YType.str, 'neighbor-designated-router'), ['str'])),
                                ('neighbor_dead_timer', (YLeaf(YType.uint32, 'neighbor-dead-timer'), ['int'])),
                                ('neighbor_up_time', (YLeaf(YType.uint32, 'neighbor-up-time'), ['int'])),
                                ('neighbor_virtual_link_id', (YLeaf(YType.uint32, 'neighbor-virtual-link-id'), ['int'])),
                                ('is_neighbor_virtual_link', (YLeaf(YType.boolean, 'is-neighbor-virtual-link'), ['bool'])),
                                ('neighbor_sham_link_id', (YLeaf(YType.uint32, 'neighbor-sham-link-id'), ['int'])),
                                ('is_neighbor_sham_link', (YLeaf(YType.boolean, 'is-neighbor-sham-link'), ['bool'])),
                            ])
                            self.interface_name = None
                            self.neighbor_address = None
                            self.neighbor_address_xr = None
                            self.neighbor_interface_id = None
                            self.neighbor_dr_priority = None
                            self.neighbor_state = None
                            self.neighbor_designated_router = None
                            self.neighbor_dead_timer = None
                            self.neighbor_up_time = None
                            self.neighbor_virtual_link_id = None
                            self.is_neighbor_virtual_link = None
                            self.neighbor_sham_link_id = None
                            self.is_neighbor_sham_link = None

                            self.neighbor_detail = Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_()
                            self.neighbor_detail.parent = self
                            self._children_name_map["neighbor_detail"] = "neighbor-detail"

                            self.neighbor_bfd_info = Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo()
                            self.neighbor_bfd_info.parent = self
                            self._children_name_map["neighbor_bfd_info"] = "neighbor-bfd-info"
                            self._segment_path = lambda: "neighbor-detail"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail, ['interface_name', 'neighbor_address', u'neighbor_address_xr', u'neighbor_interface_id', u'neighbor_dr_priority', u'neighbor_state', u'neighbor_designated_router', u'neighbor_dead_timer', u'neighbor_up_time', u'neighbor_virtual_link_id', u'is_neighbor_virtual_link', u'neighbor_sham_link_id', u'is_neighbor_sham_link'], name, value)


                        class NeighborDetail_(Entity):
                            """
                            Detailed OSPFv3 neighbor information 
                            
                            .. attribute:: neighbor_retransmission
                            
                            	Retransmission information with this neighbor
                            	**type**\:  :py:class:`NeighborRetransmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_.NeighborRetransmission>`
                            
                            .. attribute:: state_changes
                            
                            	Number of state changes 
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: neighbor_cost
                            
                            	Cost of path to this neighbor 
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: is_neighbor_filtered
                            
                            	If true, filter outgoing LSAs 
                            	**type**\: bool
                            
                            .. attribute:: neighbor_designated_router_address
                            
                            	Address of designated router
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: neighbor_backup_designated_router_address
                            
                            	Address of backup designated router
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_type
                            
                            	Interface type
                            	**type**\:  :py:class:`Ospfv3Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper.Ospfv3Interface>`
                            
                            .. attribute:: poll_interval
                            
                            	Poll interval (s)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_poll_interval
                            
                            	For NBMA networks, amount of time remaining in seconds before the next poll interval expires and Hello is sent (s)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: neighbor_ignore_timer
                            
                            	Remaining time when ignore timer is running 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: neighbor_option
                            
                            	 This is bitmask of neighbor's option field received 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pending_events
                            
                            	Number of pending events 
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_, self).__init__()

                                self.yang_name = "neighbor-detail"
                                self.yang_parent_name = "neighbor-detail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("neighbor-retransmission", ("neighbor_retransmission", Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_.NeighborRetransmission))])
                                self._leafs = OrderedDict([
                                    ('state_changes', (YLeaf(YType.uint16, 'state-changes'), ['int'])),
                                    ('neighbor_cost', (YLeaf(YType.uint16, 'neighbor-cost'), ['int'])),
                                    ('is_neighbor_filtered', (YLeaf(YType.boolean, 'is-neighbor-filtered'), ['bool'])),
                                    ('neighbor_designated_router_address', (YLeaf(YType.str, 'neighbor-designated-router-address'), ['str'])),
                                    ('neighbor_backup_designated_router_address', (YLeaf(YType.str, 'neighbor-backup-designated-router-address'), ['str'])),
                                    ('interface_type', (YLeaf(YType.enumeration, 'interface-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ospfv3_oper', 'Ospfv3Interface', '')])),
                                    ('poll_interval', (YLeaf(YType.uint32, 'poll-interval'), ['int'])),
                                    ('next_poll_interval', (YLeaf(YType.uint32, 'next-poll-interval'), ['int'])),
                                    ('neighbor_ignore_timer', (YLeaf(YType.uint32, 'neighbor-ignore-timer'), ['int'])),
                                    ('neighbor_option', (YLeaf(YType.uint32, 'neighbor-option'), ['int'])),
                                    ('pending_events', (YLeaf(YType.uint16, 'pending-events'), ['int'])),
                                ])
                                self.state_changes = None
                                self.neighbor_cost = None
                                self.is_neighbor_filtered = None
                                self.neighbor_designated_router_address = None
                                self.neighbor_backup_designated_router_address = None
                                self.interface_type = None
                                self.poll_interval = None
                                self.next_poll_interval = None
                                self.neighbor_ignore_timer = None
                                self.neighbor_option = None
                                self.pending_events = None

                                self.neighbor_retransmission = Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_.NeighborRetransmission()
                                self.neighbor_retransmission.parent = self
                                self._children_name_map["neighbor_retransmission"] = "neighbor-retransmission"
                                self._segment_path = lambda: "neighbor-detail"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_, [u'state_changes', u'neighbor_cost', u'is_neighbor_filtered', u'neighbor_designated_router_address', u'neighbor_backup_designated_router_address', u'interface_type', u'poll_interval', u'next_poll_interval', u'neighbor_ignore_timer', u'neighbor_option', u'pending_events'], name, value)


                            class NeighborRetransmission(Entity):
                                """
                                Retransmission information with this neighbor
                                
                                .. attribute:: database_descriptor_retransmissions
                                
                                	Number of database descriptor retransmissions during last exchange
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_flood_index
                                
                                	Area scope LSA's flood index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_flood_index
                                
                                	AS scope LSA's flood index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_flood_index
                                
                                	Link flood index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: neighbor_retransmissions
                                
                                	Number of neighbor retransmissions 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmissions
                                
                                	Number of retransmissions for this neighbor
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_first_flood
                                
                                	First flood item for area scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_first_flood_index
                                
                                	Index of the first flood item for area scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood
                                
                                	First flood item for AS scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_first_flood_index
                                
                                	Index for first flood item for AS scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood
                                
                                	Link first flood information 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_first_flood_index
                                
                                	Link first flood information index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood
                                
                                	Next flood item for area scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: area_next_flood_index
                                
                                	Index of next flood item for Area scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood
                                
                                	Next flood item for AS scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_next_flood_index
                                
                                	Index of next flood item for AS scope LSAs
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood
                                
                                	Link next flood information 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: link_next_flood_index
                                
                                	Link next flood information index 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_length
                                
                                	Number of LSAs sent in last retransmission
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_length
                                
                                	Maximum number of LSAs sent in a retransmission
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_retransmission_time
                                
                                	Last retransmission scan time (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: maximum_retransmission_time
                                
                                	Maximum retransmission scan time (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsa_retransmission_timer
                                
                                	Time until next LSA retransmission (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv6-ospfv3-oper'
                                _revision = '2017-10-30'

                                def __init__(self):
                                    super(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_.NeighborRetransmission, self).__init__()

                                    self.yang_name = "neighbor-retransmission"
                                    self.yang_parent_name = "neighbor-detail"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('database_descriptor_retransmissions', (YLeaf(YType.uint32, 'database-descriptor-retransmissions'), ['int'])),
                                        ('area_flood_index', (YLeaf(YType.uint32, 'area-flood-index'), ['int'])),
                                        ('as_flood_index', (YLeaf(YType.uint32, 'as-flood-index'), ['int'])),
                                        ('link_flood_index', (YLeaf(YType.uint32, 'link-flood-index'), ['int'])),
                                        ('neighbor_retransmissions', (YLeaf(YType.uint32, 'neighbor-retransmissions'), ['int'])),
                                        ('retransmissions', (YLeaf(YType.uint32, 'retransmissions'), ['int'])),
                                        ('area_first_flood', (YLeaf(YType.uint32, 'area-first-flood'), ['int'])),
                                        ('area_first_flood_index', (YLeaf(YType.uint32, 'area-first-flood-index'), ['int'])),
                                        ('as_first_flood', (YLeaf(YType.uint32, 'as-first-flood'), ['int'])),
                                        ('as_first_flood_index', (YLeaf(YType.uint32, 'as-first-flood-index'), ['int'])),
                                        ('link_first_flood', (YLeaf(YType.uint32, 'link-first-flood'), ['int'])),
                                        ('link_first_flood_index', (YLeaf(YType.uint32, 'link-first-flood-index'), ['int'])),
                                        ('area_next_flood', (YLeaf(YType.uint32, 'area-next-flood'), ['int'])),
                                        ('area_next_flood_index', (YLeaf(YType.uint32, 'area-next-flood-index'), ['int'])),
                                        ('as_next_flood', (YLeaf(YType.uint32, 'as-next-flood'), ['int'])),
                                        ('as_next_flood_index', (YLeaf(YType.uint32, 'as-next-flood-index'), ['int'])),
                                        ('link_next_flood', (YLeaf(YType.uint32, 'link-next-flood'), ['int'])),
                                        ('link_next_flood_index', (YLeaf(YType.uint32, 'link-next-flood-index'), ['int'])),
                                        ('last_retransmission_length', (YLeaf(YType.uint32, 'last-retransmission-length'), ['int'])),
                                        ('maximum_retransmission_length', (YLeaf(YType.uint32, 'maximum-retransmission-length'), ['int'])),
                                        ('last_retransmission_time', (YLeaf(YType.uint32, 'last-retransmission-time'), ['int'])),
                                        ('maximum_retransmission_time', (YLeaf(YType.uint32, 'maximum-retransmission-time'), ['int'])),
                                        ('lsa_retransmission_timer', (YLeaf(YType.uint32, 'lsa-retransmission-timer'), ['int'])),
                                    ])
                                    self.database_descriptor_retransmissions = None
                                    self.area_flood_index = None
                                    self.as_flood_index = None
                                    self.link_flood_index = None
                                    self.neighbor_retransmissions = None
                                    self.retransmissions = None
                                    self.area_first_flood = None
                                    self.area_first_flood_index = None
                                    self.as_first_flood = None
                                    self.as_first_flood_index = None
                                    self.link_first_flood = None
                                    self.link_first_flood_index = None
                                    self.area_next_flood = None
                                    self.area_next_flood_index = None
                                    self.as_next_flood = None
                                    self.as_next_flood_index = None
                                    self.link_next_flood = None
                                    self.link_next_flood_index = None
                                    self.last_retransmission_length = None
                                    self.maximum_retransmission_length = None
                                    self.last_retransmission_time = None
                                    self.maximum_retransmission_time = None
                                    self.lsa_retransmission_timer = None
                                    self._segment_path = lambda: "neighbor-retransmission"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborDetail_.NeighborRetransmission, [u'database_descriptor_retransmissions', u'area_flood_index', u'as_flood_index', u'link_flood_index', u'neighbor_retransmissions', u'retransmissions', u'area_first_flood', u'area_first_flood_index', u'as_first_flood', u'as_first_flood_index', u'link_first_flood', u'link_first_flood_index', u'area_next_flood', u'area_next_flood_index', u'as_next_flood', u'as_next_flood_index', u'link_next_flood', u'link_next_flood_index', u'last_retransmission_length', u'maximum_retransmission_length', u'last_retransmission_time', u'maximum_retransmission_time', u'lsa_retransmission_timer'], name, value)


                        class NeighborBfdInfo(Entity):
                            """
                            Neighbor BFD information
                            
                            .. attribute:: bfd_intf_enable_mode
                            
                            	BFD enable mode \- Default/Strict
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bfd_status_flag
                            
                            	Status of the BFD Session
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'ipv6-ospfv3-oper'
                            _revision = '2017-10-30'

                            def __init__(self):
                                super(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo, self).__init__()

                                self.yang_name = "neighbor-bfd-info"
                                self.yang_parent_name = "neighbor-detail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('bfd_intf_enable_mode', (YLeaf(YType.uint32, 'bfd-intf-enable-mode'), ['int'])),
                                    ('bfd_status_flag', (YLeaf(YType.uint8, 'bfd-status-flag'), ['int'])),
                                ])
                                self.bfd_intf_enable_mode = None
                                self.bfd_status_flag = None
                                self._segment_path = lambda: "neighbor-bfd-info"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Ospfv3.Processes.Process.DefaultVrf.NeighborDetailProcessTable.NeighborDetail.NeighborBfdInfo, [u'bfd_intf_enable_mode', u'bfd_status_flag'], name, value)

    def clone_ptr(self):
        self._top_entity = Ospfv3()
        return self._top_entity

